[![logo](http://shevegen.square7.ch/COOKBOOKS_LOGO.png)](https://rubygems.org/gems/cookbooks)

[![forthebadge](http://forthebadge.com/images/badges/built-with-love.svg)](https://www.gobolinux.org/)[![forthebadge](http://forthebadge.com/images/badges/made-with-ruby.svg)](http://forthebadge.com)

## Cookbooks - Recipes to install programs from source

The Cookbooks project attempts to collect recipes and instructions that allow
you to **install programs** from source (primarily).

If you want to see the available program versions, have a look at the side
pane, at **Program versions available**.

It is recommended to use the Cookbooks project together with the RBT (Ruby Build
Tools) project, as the latter is the one that formally integrates the dataset
provided by the Cookbooks project into general compile/install related activities.
If the cookbooks project and the RBT project are used in combination, then they
are in some ways similar to the **MacOSX homebrew project** or the
**fpm project**.

There may be some philosophical differences between these projects, but the
cookbooks project and the RBT project will attempt very hard to provide
similar functionality as fpm and mac homebrew do, too, in the long run.

The similarity towards **fpm** is that the cookbooks project will also attempt
to allow you to interconvert the registered dataset into .deb or .rpm files or
even homebrew formulas - but this functionality is very limited (as of in
2017). It will definitely become better over time. The slackware support is
a bit better, but requires some more polish and clean-up before it can be
easily used.

The **Cookbooks project** is in some ways similar to the LFS/BLFS project
in that it attempts to put together information that would be useful for
when a user wishes to compile some program from source, in particular
when these programs are requiring modifications to their build system,
such as when "sed" is used - but the Cookbooks project could also be used
when installing a binary program. In doing so, the Cookbooks project can
also be used as a basic **building block** for creating package managers
or other compile-tools in Ruby. If you have a project like this and may
want to make use of Cookbooks and/or RBT, and require some modification,
let me know - I'll try to adapt the two projects to make them useful
for these cases as well.

Now, let's have a look as to **how information is stored** in the Cookbooks
project.

The information for the respective programs is stored in yaml files by
default, largely due to convenience and "historic reasons". Taken together,
we could call the collection of yaml files a "yaml database" - even though
it is not a real database, per se.

These individual .yml files, by default, reside in the subdirectory called
**yaml/individual_cookbooks/** of this gem. The .yml files usually also
make use of shortcuts and abbreviations, which will be sanitized when
the specific yaml file is loaded by the Cookbooks project.

For example, a common entry point may be like so:

    "keep_extracted: t"

The "t" at the end is a shortcut for "true". The entry **keep_extracted** 
means that, after an archive is extracted, it will be kept rather than
removed, after compilation has finished.

The Cookbooks project operates under the assumption that all archives that
the user will use, are put into a certain base directory, which, for the
purpose of this file here, will be called the **archive directory**.

This is the directory where your archives should reside. You can ultimately
decide which directory that shall be.

On my home system, this archive directory is at **/Users/x/SRC/**, mostly
due to historic reasons how I kept making backups. On GoboLinux, you may
want to use perhaps /Files/Archives/ or /Depot/Backup/ or something 
similar. You can query the current archive directory in use by issuing
this command:

    cookbooks --archive-directory?

There, source files can be stored, such as **htop-2.0.2.tar.xz**
or **ruby-2.4.1.tar.gz** and so forth.

Since many other users may wish to use another base directory for
their archives, you can define another archive directory on the
commandline like so:

    cookbooks --permanently-set-base-directory-to=/opt

The above would assume that all source archives will be stored
within the /opt/ hierarchy.

Within that archive directory, subdirectories have to be created.

Actually, ruby may already do this for you, via the cookbooks +
rbt projects; but I recommend that you first start slowly and 
manually create directories for now. So, pick just some program,
anyone will do fine as long as it is registered in the Cookbooks
project. Create that archive directory if it does not yet exist,
cd into it, create the directory of the program which is the
program name (downcased, and without any '-' or '_' tokens).

Let's break this down and use specific examples, to illustrate
what is meant - we wil pick the program "htop" as example.

First, create a subdirectory called "htop/", within the source archive
directory.

On any linux/unix system, "mkdir" should be able to allow you to do that -
but you could also use Ruby's fileutils class to do so, via
**FileUtils.mkdir_p**. :)

Next, download the remote source for this program locally (you can
also use the rbt project to do so for you: **"rbt htop --download-source"**
but for the first steps, again, I recommend to do these steps manually
instead).

    wget http://hisham.hm/htop/releases/2.0.2/htop-2.0.2.tar.gz

More specifically, on my home system, I'd do the following things manually
(but keep in mind that ruby does this for me automatically):

    mkdir /Users/x/SRC/htop
    cd /Users/x/SRC/htop
    wget http://hisham.hm/htop/releases/2.0.2/htop-2.0.2.tar.gz

If you, for instance, want to store multiple versions of GLib, then a 
downcased directory called glib/ has to exist within that 
source archive directory - just as the example above shows.

Different versions of **GLib** can then be stored in that directory.

The path would, in my case, be:

    /Users/x/SRC/glib/

That's it, essentially!

Past this point, the cookbooks project can feedback some information
about htop via "scookie".

For example, to use scookie (<b>bin/scookie</b>) and thus display information
about a program in a colourized manner, on the commandline, do:

    scookie glib
    scookie htop

The associated .yml file is always available anyway, with or without the
archive being available locally as well. So you can always query the
information stored in these .yml files the moment you install the
Cookbooks project; it can thus function as a weak "database". (I will
at a later time add SQL instructions in how to create a SQL database
and use it with the Cookbooks project. But note that the .yml way will
most likely remain the default way; primary reason being out of
convenience, since it is so trivial to edit a single text file such
as .yml files.)

If you are wondering why the name "scookie" was picked - it originated
from the **sanitize_cookbook_dataset** functionality, which ensures
that the dataset is correct. I was using the abbreviation "scook" to
refer to sanitize_cookbook_dataset, but I found that "scookie" is
easier to remember. Everyone likes cookies, right?

The **cookbooks project** should now be usable to display information
about this project - provided that it has been registered of
course. If it is not yet registered, then someone has to register
it; there are some helper scripts that can aid you there, but as
a rule of thumb, I'll add new program entries when needed. They
are essentially just a single .yml file.

Currently, there are more than 3000 programs that are registered
in the Cookbooks project; almost 3200 already and this number is
very slowly continuing to grow.

Cookbooks may also keep track of information such as whether
a given progam at hand will install a .pc file (pkgconfig file).
This may help if you are on a non-GoboLinux system and wish to
find out which particular program installed which specific
.pc file, too. (On GoboLinux this is trivial to find out since
it keeps AppDir-related and versioned programs, whereas on
the traditional FHS preferring /usr prefix, the individual 
.pc files would usually reside under /usr/lib/pkgconfig/, 
without always giving you a simple way to ind out as to where
they came from.)

You can query this by using "scookie", which will show this, and
more, in a colourized manner.

An example follows:

    scookie libvorbis

If you wish to support this project, for now please just test it and
report any bugs or report inadequate or confusing documentation.

The project is still in a beta stage and it will take quite a long
while before it can leave that beta stage.

## Colours used by the Cookbooks project

By default, the cookbooks project will use lots of different colours.
These colours are used on a KDE Konsole on my home system - and they
work best with a black background in the terminal.

If the colours are to your dislike or do not work on your setup,
you can always disable them via an option such as "--disable-colours"
or "--disable-colors", if you prefer the US spelling. Shortcuts
exist too such as "nocolours" and so forth.

If you want to **permanently disable the colours***, use this:

    cobooks  --permanently-disable-colours

This will modify the file '<b>use_colours.yml</b>' in the 
**yaml/** subdirectory, which is the file that handles whether
we will use any colours for the whole Cookbooks namespace.

## Available programs and the corresponding program version

Every time the cookbooks gem is updated, a .html file is created
and uploaded at this location:

  http://shevegen.square7.ch/programs_version.html

This remote .html file will show which programs are registered, part of
the Cookbooks project, and what the corresponding program versions are.

Note that you can also generate a .html page for some select programs,
via the commandline. For instance, if you wish to show ruby, python
and php, then you can use this commandline invocation:

    cookbook --create-html-page-for-these-programs=ruby,python,php

The input program names should be separated via **,** and not 
include any '-' or '_' character. There are also some ways to
display the full, e. g. KDE stack. More on this at a later
time though.

## Obtaining the number of registered programs

You can obtain the **number of registered programs** from the
commandline by issuing any of the following:

    cookbooks --registered_programs?
    cookbooks --n_programs?
    cookbooks registered_programs?

This would then output something such as:

    -> 3330 programs registered as of 30 January 2018.

## How do I use the Cookbooks project personally

How do I use the cookbooks project primarily, on my Linux systems?

Note that I use the Cookbooks project in combination with the RBT
gem predominantly.

When I compile a program via RBT, such as by doing "compile htop"
or "rbt htop" or "ry htop" (I make use of aliases a lot), then ruby
will compile the program **htop** for me, as specified in the
corresponding "htop.yml" file, which is part of the Cookbooks project.

If I need a change to the compilation process, such as a different 
default **prefix**, then I simply edit the **htop.yml** file and things
will (should) work past this point - but I can also override settings
from the commandline, so I have all the flexibility required available.

The "default settings" thus go into specific .yml file, whereas the
commandline switches allow me to specifically override or cherry-pick
other settings, based on the machine that I am working with. For
example, on GoboLinux the AppDir prefix makes sense. On traditional
linux distributions, I either use /usr as prefix or compile into
the user's home directory. (A commandline switch exists for the
latter, called --home-directory, but this is part of the rbt gem,
not the cookbooks gem.)

This is useful in the sense that, ideally, I can get away with only
passing the name of the program that is to be compiled, without
needing to change anything. This should allow me to be lazy - and
just get things to "work", when they are compiled.

## Usefulness of this project

If you may wonder how this project may be useful to you, well -
I think the **main target audience** will be fairly small, mostly
only more experienced users, in particular linux users. These
people often already know a lot about, not only linux, but also
programming.

While I will try to **improve the documentation** so that novice
users can understand what the Cookbooks project is doing as well,
to the point of being easily able to use the project, I think that
there will not be many novice users who are even interested in
such a project in the first place.

So the project should perhaps be seen as a "complementary" project
to the LFS/BLFS project (Linux from Scratch etc..) - or for smaller
linux distributions as an additional set of scripts that aid in
managing a distribution.

At the very least, the programs found in this project have a
description, so this alone can be of help to
**distribution-creators**. And there are some classes that 
focus on validation the dataset, so that people who use the
project can be reasonable sure that everything is in proper
order.

## Brief commandline introduction

If you wish to see a **brief introduction on the commandline**,
issue the following command:

    cookbooks --tutorial

This tutorial is really just very short - the more verbose,
long documentation here may be sufficiently more useful. :)

## Future Goals

Note that the Cookbooks project will never have truly grand goals -
the scope is too narrow. The Cookbooks project's primary goal is
to gather information about source code packages, and to present
that data to other programs or suites (such as rbt), or on the
commandline or via a GUI or via the WWW - to the user. So it has
to be a practical project rather than a visionnaire one.

But there are some **future goals** nonetheless.

- One goal is to translate the instructions stored in the various
yaml files, into **specific SQL instructions** which can be used to
populate a SQL table - this is currently (October 2017) not working,
but stay tuned; it will eventually work and be properly detailed
and documented. The idea behind this is to be able to store all
the data stored in the various .yml files, into a single database
instead.

- Another goal is to use the project in order to create a full
LFS/BLFS build, in combination with the RBT project.

- And yet another goal is, similar to the point above, to turn
an existing Linux-system into a Linux-system based on an **AppDir
approach**. Note that this is also covered by the RBT project
primarily, and it does not work yet (Jan 2018). That means that
rather than having files spread all over the place on a system,
they will be contained in the respective directory of the given
program at hand.

Stay tuned until these goals have been reached.

## How does the format of a cookbook recipe look like?

Each cookbook entry is just an **individual yaml file**, with the
extension name being **.yml**. This file should contain all the
required information to get that particular program to install.

Additional information can be added as well, such as **maintainer**(s),
**extra information** of the program at hand, tips and hints in how
to install or use the program, sed-modifications, pkgconfig files
(aka .pc files) that are installed, patchsets that are to be
applied, binaries, headers and libraries and so on and so forth.

It is quite detailed, mostly due to being able to allow some flexibility
during installation. 

Many programs "out in the wild" are **well-behaving** and will honour a 
**--prefix** variable given (or **-DCMAKE_INSTALL_PREFIX=** such as in
use by **cmake**). Such programs usually require little to no modification.

Unfortunately, some other programs come with buggy installation scripts,
and workarounds have to be employed to get these to work. Or they may
become obsolete at a later time, due to changes e. g. in glibc/gcc and
other programs.

As a reference project, the **LFS project** provides a **lot** of useful
information in how to get many programs to work.

At any rate, let's now have a look at the **fish.yml** recipe, to give
a specific example.

This file will look like this as of January 2018:

    fish:
     binaries: "fish,fish_indent,fish_key_reader"
     short_description: |
      FISH is an interactive (commandline) shell.
     description: |
      FISH is the Friendly Interactive Shell, a smart and user-friendly
      command line shell for macOS, Linux, and the rest of the family.
     url1: https://github.com/fish-shell/fish-shell/releases/download/2.7.1/fish-2.7.1.tar.gz
     url2: http://fishshell.com/files/2.1.0
     url3: http://sourceforge.net/projects/fish/
     homepage: http://fishshell.com/
     tags: shell
     prefix: f
     keep_extracted: t
     last_update: 08 Jan 2018

The very first entry, on top, is the name of the program itself, in this
case, **fish**.

While this could in theory be omitted, I found that it is useful to have
this entry, primarily as a visual identifier if you work with it in an
editor.

Note that no '-' or '_' characters are allowed there in this entry - it is
really a stripped down name of the program at hand only. If the name would
be e. g. "gtk-doc", with an URL such as
**http://ftp.gnome.org/pub/gnome/sources/gtk-doc/1.26/gtk-doc-1.26.tar.xz**,
then the name there for the gtkdoc.yml file would have
to be **gtkdoc:** - thus, all '-' were removed. The name that appears there
is also the name of the .yml file at hand. The .yml files may also not 
include any '-' or '_' characters. Do also note that while I am following
this convention since many years, it may one day be changed to allow for
'-' and '_'. But for the time being, the strict requirement is that we may
not have '-' or '_' characters there.

Next, let's look at the entry **binaries:**. This entry tells us which
binaries/executables this particular program will install. This also
allows us to remove binaries in the /usr/bin/ hierarchy, if you compiled
into an AppDir prefix - for more information here, see class
**RBT::PurgeBinariesOfThisProgram**.

The next entry is **short_description**, which is e. g. equivalent
to slackware's pkg-format, as introduction to the specific program
at hand, in a short notation.

Then we have the entry **main description**, followed by several **url**
entries. The first url entry, aptly named **url1**, is the most important
entry. It tells us where to find the archive to the program at hand.
This is ideal the URL to an existing archive, but it could also be
a github repository, in principle.

Then we also have the **homepage** entry, which denotes the homepage of
the program (or any other webpage that has relevant information, in the
event that there no homepage entry exists for that particular program).

Then we have **tags**: which just groups the program into popular
**tag-classifiers**, such as "shell" in this case. Then the prefix in
use, which is f for false, meaning "non-traditional" aka "appdir" prefix
such as GoboLinux makes use of. Then there is the keep_extracted 
setting, which tells us whether to keep the archive extracted or not
after extracting/compiling it. Last but not least, the last_update
tag tells us when this program was last updated. The default format
here is dd.mm.yyy, but shortcuts are allowed. For example, Oct, for
October, can be used rather than 10, and so on. 

The next entry is <b>prefix</b>. This one is mostly synonymous for
the --prefix= option given to GNU autoconfigure based projects.
A prefix value of t means true, which stands for /usr/. A prefix
value of f means false, which stands for the particular AppDir-like
prefix. In the case here, for fish, this would expand to
<b>/Programs/Fish/2.7.1</b>. GoboLinux uses a very similar AppDir
layout by default, although with slightly different program names
that can also be upcased, e. g. "KDE-Libs" and so forth. (RBT will
offer both variants here; the GoboLinux naming scheme, and the
simpler scheme where only the first character is upcased, and
the other characters are all downcased.)

## Checking the validity of the yaml files

Some code exists to ensure that the yaml files are (mostly) valid
and correct.

The code can be found under the validation/ subdirectory. Most users
will not need it, though, since I will run these scripts when needed.
They are a bit like test-code, but more code that ensures that the
files conform to the given specification at hand.

If you really want to check the validity of the cookbook files,
then run this command:

    cookbooks --validate

But note that I will try to ensure that the cookbooks .yml files
are valid; sometimes not all of them are valid, in which case
they will be fixed eventually.

## Batch-downloading all source archives

You can download all source archives by calling
**class Cookbooks::DownloadAllSourceArchives**.

I use an alias to call that **.rb** file. Then I can do, for example:

    download_all_source_archives

Alternatively, you can also **invoke the file from the commandline 
directly, by issuing either one of the following**:

    cookbooks --download-all-source-archives
    cookbooks --downloadallsourcearchives
    cookbooks --grab-source-archives
    cookbooks --grabsourcearchives

You can also download only those files that have a certain **tag**
registered. For example, if you want to download all programs that
have the tag "plasma" attached, you can issue the following 
command (and argument) this:

    download_all_source_archives --tags=plasma

In order for this to work, the tag has had to be **registered**
(and thus, logically, exist).

If you need an overview over the existing tags, issue this command:

    cookbooks --available-tags

## Validate the cookbook recipes

You can invoke, from the commandline, the following:

    cookbook --validate-entries

This will validate the dataset stored in the various .yml files.

It will run the test-code in the validation/ subdirectory.

This is not so useful for casual users though, more interesting
for people who may want to contribute recipes and such.

## Extended cookbook dataset

You can "copy" the program names onto the Cookbooks module namespace.

First, let's demonstrate how this is done:

    require 'cookbooks/extended'

Past this point, these method-calls will work:

    Cookbooks.htop
    Cookbooks.ruby
    Cookbooks.php
    Cookbooks.gnomemimedata
    Cookbooks.evince

This will return a sanitized Hash that holds all the information
required to compile a program from source. That information may
still have to be interpreted by a program, of course.

This functionality exists primarily because it may be easier for you
to use the above API calls. Internally though, the Cookbooks project
will prefer API calls such as **Cookbooks::Cookbook.new :htop**
instead.

Note that the above works without any '-' as part of the name, so
there will not be **Cookbooks.gnome-mime-data()** - it would be
**Cookbooks.gnomemimedata()**.

## Generate a .html file for several programs

You can generate a .html file for several programs, by making use
of **Cookbooks.create_html_page_for_these_programs()**.

The input to this method should be an Array of programs, but you
can also input a String such as "php,ruby,elixir,enchant".

The code there will then generate a .html file that shows some
information about these programs, in the given input-output
order.

Commandline invocation example:

    cookbooks --create_html_page_for_these_programs="php,ruby,elixir,enchant"

Why was this functionality added?

Mostly because I needed a way to autogenerate a .html file that
contains information about several programs, such as the whole
kde5-set of archives. This then generates a .html file with
about ~170 kde5-related programs, and can then be uploaded 
somewhere for other people to have a look at, not unlike the
LFS/BLFS project is doing already so.

In fact, if you also want to generate a .html file for the **whole
KDE toolchain**, try this:

    cookbooks --create_html_page_for_these_programs=:kde5_toolchain

You can also autogenerate a set of "homepages" for all programs,
via class <b>Cookbooks::GenerateHomepage</b>.

Either invoke the file directly (cookbooks/utility_scripts/generate_homepage/generate_homepage.rb)
or simply use this commandline instruction:

    cookbooks --generate-homepage

This will generate .html files that are somewhat similar to the LFS/BLFS
files.

## Optional dependencies for the Cookbooks gem

The **wget gem** is recommended, but you can also use the Cookbooks
project without the wget gem. In that case, if the wget gem is not 
available, the Cookbooks project will attempt to use the wget 
binary via a system()-call, hence an "external" program, to ruby.

This requires the installation of wget e. g. from this URL:

    http://ftp.gnu.org/pub/gnu/wget/?C=M;O=D

Or any other way that your operating system supports.

Of course, most Linux systems will have "wget" available by
default, so the above more applies towards operating systems
such as windows (although more recent windows versions
also include a linux-subsystem including bash, the WSL).

## Expanding the cookbook dataset

By default, the individual yaml files are kept in a **minimal state**.

This also means that the format is not terribly useful by default.

For example, **keep_extracted: t** actually is short for
**keep_extracted: true**. (Note that this entry means that the
archive will remain extracted after compilation has finished.)

When a yaml file is loaded up, the cookbooks project normally has
to sanitize that yaml file, which takes a little time. If you do
not want to wait, you can speed up this process by running the
**expand** functionality, which will expand all yaml files and
store them in the expanded (correct) format. Then, when such a
yaml file is loaded up lateron, no change has to be made at 
all, thus no time has to be spent sanitizing the information.

In order to do so, you can invoke the cookbooks project like so:

    cookbooks --expand
    cookbooks --expand-dataset 

You normally only have to do this once, but it is purely optional.

If the expanded dataset is not available then the cookbooks 
project will do the sanitize-way.

(Also note that the expanded dataset could be converted into
SQL instructions. I'll still have to add that step though.)

## YAML Engine

Ruby itself defaults to **psych** as its **main yaml engine**.

When the cookbooks project was started, syck was the main yaml
engine.

Since as of **January 2018**, the Cookbooks project will default
to **psych**. If for some reason you prefer syck, then you
can use a commandline switch to denote which yaml engine is
to be used.

To **enable syck**, do:

    cookbooks --use-syck

To **enable psych**, do:

    cookbooks --use-psych

This will modify the yaml file called **use_psych_or_syck.yml**.

Note that in order to use **syck**, you may have to install
the **syck gem** first, via:

    gem install syck

If you want to find out which yaml engine is in use, you can do:

    Cookbooks.yaml_engine?

Both engines should work fine. The reason why I kept on using
syck for such a long time was mostly because I used to have
some german comments in the various yaml files, which had
umlauts in non-UTF encoding. I lateron switched to pure 
english instead, since it is easier for other people, and
since that time, psych works just fine for the **Cookbooks
project**.

## Mate-desktop

You can try to update some of the **mate-desktop components**.

In order to do this, call either of the following variants.

    cookbooks --update-mate
    cookbooks --update-mate-desktop
    cookbooks --check-for-mate-updates
    cookbooks --check-for-mate-desktop-updates
    cookbooks --check-for-mate-desktop
    cookbooks --check-for-matedesktop

The first variant is the **shortest**, whereas the second one is
the main entry point in the **case/when** setup.

This instruction will check for new updates to the mate-desktop
releases and download them when found. Note that presently, any
more recent version is preferred, so unstable versions will often
be downloaded (since e. g. 1.19.1 is a higher version than e. g.
1.18.0).

## GNOME

The gnome-project tarball archives can be found here:

    http://ftp.gnome.org/pub/gnome/sources/?C=M;O=D

The releases usually have even numbers for stable releases; and
odd numbers for unstable releases.

I myself usually stayed on the bleeding edge, but after some 
time I think the stable releases are better, since you will have
less problems or errors in the long run. That has been my own
personal experience, so I added some code to the class that 
automatically downloads gnome-packages, to only considered
even numbers. But this can be toggled via a commandline switch
on the commandline, anyway - so the subsection here just 
explains as to why I favour stable releases.

## KDE

Many KDE components (== <b>programs</b>) are registered in the
cookbooks project.

These programs usually have the registered tag **kde** or **kde5**, in the
respective .yml file. You can also search for these via
**class Cookbooks::SearchForTags**; just pass in kde or kde5 as
argument to that file/class. (I have the file aliased to "stag",
so I can just do "stag kde5".) 

You can also **batch-download** KDE components - that is, to download
them all to the local filesystem.

There are several ways how to do this. Either call the respective
class directly. These .rb files will reside in the subdirectory
**check_for_updates/**.

Alternatively, you can invoke them directly from the commandline
like so:

    cookbooks --update-kde-plasma

This will download all of the KDE5 plasma components (unless they
are already available locally).

If you wish to download the **KDE5 applications**, then you can
try this command:

    cookbooks --update-kde-applications

An **alias** exists to the above:

    cookbooks --kde-apps

In general, the cookbooks project attempts to allow aliases, for
sake of convenience. The "official" entry points are usually the
longer ones though, as they are less likely to conflict with
other instructions given on the commandline. ("update kde 
applications" is more explicit than "kde apps", but the latter
is shorter, and thus may be more convenient when used on the
commandline).

To update the **KDE5 Frameworks**, do:

    cookbooks --update-kde-framework

To update the **KDE5 porting aids**, do:

    cookbooks --update-kde-porting-aids

Note that you could also use '_' tokens in the above invocation examples,
or omit these, so the following would work just as well:

    cookbooks --update_kde_porting_aids
    cookbooks --updatekdeportingaids

You can also query the KDE "status", that is, which variant is
currently the most recent one. Use something like this:

    cookbooks --kde-status

This can be useful if you go to the official KDE homepage and want
to find out whether there have been any updates recently.

## Increment Program Version

class **Cookbooks::IncrementProgramVersion**, in the file
**increment_program_version.rb**, can be used to automatically
update a local program version, provided that the new version
can be "guessed".

Let's use a specific example, because it wil be easier to explain
this when we can be specific.

Take the program called **wget**.

An **older version** may be at:

    ftp://ftp.gnu.org/gnu/wget/wget-1.19.1.tar.gz

The (more recent) version in use may be for version <b>1.19.2</b>.

**class IncrementProgramVersion** will then test whether a
remote URL such as:

    ftp://ftp.gnu.org/gnu/wget/wget-1.19.2.tar.gz

exists. If it does, it will be downloaded and the new 
program version will be for wget 1.19.2.

This can be done for all programs, and it allows a 
simple update-mechanism for individual programs.

If you have to or want to batch-update several programs,
this is possible for some of the *nix stack. For example,
there are some classes that can download the KDE5 stack;
have a look at the KDE entry or the mate-desktop entry,
in this (autogenerated) README.md file here.

## Available program versions 

The following list, as html-pre tag, shows which versions are currently
tracked, including the URL to these programs.

The four entries are:

    (1) <b>program name</b>
    (2) <b>program version</b>
    (3) <b>last update of this program</b> (in regards to the cookbooks project)
    (4) <b>remote URL</b>

The most useful part for people is probably the **remote URL** entry
there - the most right entry.

Note that some old programs are no longer available, which explains
why they have not been updated in many years. Can't update what is
no longer there now, can you. :)


<pre>
0install                    2.12.1                19 Jun 2017   https://sourceforge.net/projects/zero-install/files/0install/2.12.1/0install-2.12.1.tar.bz2
3ddesktop                   0.2.9                 01 Jun 2014   https://sourceforge.net/projects/desk3d/files/3ddesktop/0.2.9/3ddesktop-0.2.9.tar.gz
3dpong                      0.5                   01 May 2014   ftp://ftp.billsgames.com/unix/x/3dpong/src/3dpong-0.5.tar.gz
BuildStream                                                     
LibRaw                                                          
ParseTree                                                       
RedCloth                                                        
RubyInline                                                      
a2png                       0.1.5                 01 Jun 2014   http://sourceforge.net/projects/a2png/files/a2png/0.1.5/a2png-0.1.5.tar.gz
a2ps                        4.14                  01 Jun 2014   http://ftp.gnu.org/gnu/a2ps/a2ps-4.14.tar.gz
a52dec                      0.7.4                 01 Oct 2013   http://liba52.sourceforge.net/files/a52dec-0.7.4.tar.gz
aalib                       1.4rc5                01 Jan 2013   http://sourceforge.net/projects/aa-project/files/aa-lib/1.4rc5/aalib-1.4rc5.tar.gz
aamath                      0.3                   01 May 2014   http://fuse.superglue.se/aamath/aamath-0.3.tar.gz
abcde                       2.8.1                 23 Oct 2017   https://abcde.einval.com/download/abcde-2.8.1.tar.gz
abe                         1.1                   01 May 2014   http://kent.dl.sourceforge.net/sourceforge/abe/abe-1.1.tar.gz
abiword                     3.0.2                 21 Oct 2016   http://www.abisource.com/downloads/abiword/3.0.2/source/abiword-3.0.2.tar.gz
abnfgen                     0.17                  16 Sep 2016   http://www.quut.com/abnfgen/abnfgen-0.17.tar.gz
abstk                       0.1                   07 Feb 2016   http://www.gobolinux.org/abstk/AbsTK-0.1.tar.gz
abuse                       0.8                   01 Dec 2012   http://abuse.zoy.org/raw-attachment/wiki/download/abuse-0.8.tar.gz
accerciser                  3.14.0                24 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/accerciser/3.14/accerciser-3.14.0.tar.xz
accountsservice             0.6.46                08 Apr 2018   https://www.freedesktop.org/software/accountsservice/accountsservice-0.6.46.tar.xz
acl                         2.2.52                10 Oct 2015   http://download.savannah.gnu.org/releases/acl/acl-2.2.52.src.tar.gz
acoc                        0.7.1                 01 May 2014   http://www.caliban.org/files/ruby/acoc-0.7.1.tar.gz
acpi                        0.09                  01 May 2014   http://grahame.angrygoats.net/source/acpi/acpi-0.09.tar.gz
acpica                      11.10.2017            11 Oct 2017   http://www.acpica.org/download/acpica-unix-20080701.tar.gz
acpid                       2.0.29                18 Apr 2018   http://downloads.sourceforge.net/acpid2/acpid-2.0.29.tar.xz
acpitool                    0.5.1                 12 Oct 2017   https://sourceforge.net/projects/acpitool/files/acpitool/0.5.1/acpitool-0.5.1.tar.gz
actionmailer                5.2.0                 01 May 2018   https://rubygems.org/downloads/actionmailer-5.2.0.gem
actionpack                  5.2.0                 01 May 2018   https://rubygems.org/downloads/actionpack-5.2.0.gem
actionwebservice            1.2.6                 21 Sep 2017   https://rubygems.org/downloads/actionwebservice-1.2.6.gem
activemodel                 5.2.0                 01 May 2018   https://rubygems.org/downloads/activemodel-5.2.0.gem
activerecord                5.2.0                 01 May 2018   https://rubygems.org/downloads/activerecord-5.2.0.gem
activeresource              5.0.0                 22 Dec 2017   https://rubygems.org/downloads/activeresource-5.0.0.gem
activesupport               5.2.0                 01 May 2018   https://rubygems.org/downloads/activesupport-5.2.0.gem
addressable                 2.5.2                 09 Dec 2017   https://rubygems.org/downloads/addressable-2.5.2.gem
adwaitaicontheme            3.27.90               08 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/adwaita-icon-theme/3.27/adwaita-icon-theme-3.27.90.tar.xz
aegisub                     3.2.2                 24 Jan 2018   http://ftp.aegisub.org/pub/archives/releases/source/aegisub-3.2.2.tar.xz
aeolus                      0.9.0                 15 Mar 2016   http://kokkinizita.linuxaudio.org/linuxaudio/downloads/aeolus-0.9.0.tar.bz2
afterstep                   2.2.9                 01 May 2014   ftp://ftp.afterstep.org/stable/AfterStep-2.2.9.tar.bz2
aircrackng                  1.1                   01 Feb 2013   http://download.aircrack-ng.org/aircrack-ng-1.1.tar.gz
airsnort                    0.2.7e                01 Oct 2013   http://sourceforge.net/projects/airsnort/files/airsnort/airsnort-0.2.7e/airsnort-0.2.7e.tar.gz
airstrike                   6a                    01 Dec 2012   http://icculus.org/airstrike/airstrike-pre6a-src.tar.gz
aisleriot                   3.22.3                12 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/aisleriot/3.22/aisleriot-3.22.3.tar.xz
akode                       2.0.1                 01 Nov 2012   http://carewolf.com/akode/
akonadi                     18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akonadi-18.04.0.tar.xz
akonadicalendar             18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akonadi-calendar-18.04.0.tar.xz
akonadicalendartools        18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akonadi-calendar-tools-18.04.0.tar.xz
akonadiconsole              18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akonadiconsole-18.04.0.tar.xz
akonadicontacts             18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akonadi-contacts-18.04.0.tar.xz
akonadiimportwizard         18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akonadi-import-wizard-18.04.0.tar.xz
akonadimime                 18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akonadi-mime-18.04.0.tar.xz
akonadinotes                18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akonadi-notes-18.04.0.tar.xz
akonadisearch               18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akonadi-search-18.04.0.tar.xz
akregator                   18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/akregator-18.04.0.tar.xz
alacarte                    3.11.91               01 Mar 2014   http://ftp.gnome.org/pub/GNOME/sources/alacarte/3.11/alacarte-3.11.91.tar.xz
alien                       8.95                  06 Oct 2015   http://http.debian.net/debian/pool/main/a/alien/alien_8.95.tar.xz
allegro                     5.2.3.0               25 Nov 2017   https://github.com/liballeg/allegro5/releases/download/5.2.3.0/allegro-5.2.3.0.tar.gz
alltray                     0.70                  12 Nov 2017   https://launchpad.net/alltray/historic-releases/0.70/+download/alltray-0.70.tar.gz
almanah                     0.11.1                25 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/almanah/0.11/almanah-0.11.1.tar.xz
alock                       94                    01 Jul 2011   http://alock.googlecode.com/files/alock-94.tar.bz2
alsadriver                  1.0.25                20 Jun 2015   ftp://ftp.alsa-project.org/pub/driver/alsa-driver-1.0.25.tar.bz2
alsafirmware                1.0.27                01 Jun 2013   ftp://ftp.alsa-project.org/pub/firmware/alsa-firmware-1.0.27.tar.bz2
alsalib                     1.1.6                 04 Apr 2018   ftp://ftp.alsa-project.org/pub/lib/alsa-lib-1.1.6.tar.bz2
alsaoss                     1.0.25                01 Jun 2013   ftp://ftp.alsa-project.org/pub/oss-lib/alsa-oss-1.0.25.tar.bz2
alsaplayer                  0.99.81               01 Jun 2013   http://www.alsaplayer.org/alsaplayer-0.99.81.tar.bz2
alsaplugins                 1.0.29                02 Oct 2017   ftp://ftp.alsa-project.org/pub/plugins/alsa-plugins-1.0.29.tar.bz2
alsatools                   1.0.29                20 Nov 2017   ftp://ftp.alsa-project.org/pub/tools/alsa-tools-1.0.29.tar.bz2
alsautils                   1.1.6                 10 Apr 2018   ftp://ftp.alsa-project.org/pub/utils/alsa-utils-1.1.6.tar.bz2
amarok                      2.9.0                 07 Mar 2018   https://download.kde.org/stable/amarok/2.9.0/src/amarok-2.9.0.tar.xz
amidiplug                   0.7                   01 Nov 2012   http://www.develia.org/files/amidi-plug-0.7.tar.bz2
amigadepacker               0.04                  01 Jun 2014   http://zakalwe.fi/~shd/foss/amigadepacker/amigadepacker-0.04.tar.bz2
amoebax                     0.2.1                 01 Jan 2013   http://www.emma-soft.com/games/amoebax/download/amoebax-0.2.1.tar.bz2
amphetamine                 0.8.10                01 Jun 2014   http://n.ethz.ch/student/loehrerl/amph/files/amphetamine-0.8.10.tar.bz2
amule                       2.3.1                 01 Jun 2014   http://sourceforge.net/projects/amule/files/aMule/2.3.1/aMule-2.3.1.tar.xz
analitza                    18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/analitza-18.04.0.tar.xz
analogger                   0.9.3                 01 May 2018   https://rubygems.org/downloads/analogger-0.9.3.gem
anjuta                      3.26.0                11 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/anjuta/3.26/anjuta-3.26.0.tar.xz
anjutaextras                3.26.0                11 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/anjuta-extras/3.26/anjuta-extras-3.26.0.tar.xz
ansi                        1.5.0                 09 Jan 2018   https://rubygems.org/downloads/ansi-1.5.0.gem
antiword                    0.37                  01 May 2014   http://www.winfield.demon.nl/linux/antiword-0.37.tar.gz
anyremote                   1.1                   01 Jun 2014   http://anyremote.sourceforge.net/dload.html
aoetools                    36                    22 Feb 2017   https://downloads.sourceforge.net/project/aoetools/aoetools/aoetools-36.tar.gz
apacheant                   1.10.2                19 Feb 2018   https://archive.apache.org/dist/ant/source/apache-ant-1.10.2-src.tar.xz
apachemaven                 3.5.0                 03 Oct 2017   http://www-us.apache.org/dist/maven/maven-3/3.5.0/source/apache-maven-3.5.0-src.tar.gz
apl                         1.0                   01 Sep 2013   http://ftp.gnu.org/gnu/apl/apl-1.0.tar.gz
apophenia                   0.99                  01 Jun 2014   http://osdn.dl.sourceforge.net/sourceforge/apophenia/apophenia-0.16-23april06.tgz
aporia                      27.12.2011            01 Jun 2014   aporia-27.12.2011
appdatatools                0.1.8                 01 Sep 2014   http://people.freedesktop.org/~hughsient/releases/appdata-tools-0.1.8.tar.xz
appfs                       1.8                   29 May 2015   http://www.rkeene.org/devel/appfs/appfs-1.8.tar.gz
applewmproto                1.4.2                 01 May 2014   http://xorg.freedesktop.org/releases/individual/proto/applewmproto-1.4.2.tar.bz2
appres                      1.0.4                 Feb 2013      http://xorg.freedesktop.org/releases/individual/app/appres-1.0.4.tar.bz2
appstream                   0.11.5                02 Oct 2017   https://www.freedesktop.org/software/appstream/releases/AppStream-0.11.5.tar.xz
appstreamglib               0.7.1                 21 Aug 2017   https://people.freedesktop.org/~hughsient/appstream-glib/releases/appstream-glib-0.7.1.tar.xz
apr                         1.6.3                 26 Oct 2017   http://mirror2.klaus-uwe.me/apache/apr/apr-1.6.3.tar.gz
apricots                    0.2.6                 May 2014      http://www.fishies.org.uk/apricots-0.2.6.tar.gz
aproc                       0.1                   22 Mar 2016   http://stinfwww.informatik.uni-leipzig.de/~mai00bgn/aproc/tb/aproc-0.1.tar.bz2
aprutil                     1.6.1                 26 Oct 2017   http://archive.apache.org/dist/apr/apr-util-1.6.1.tar.bz2
apt                         1.2.1                 26 Jan 2016   http://ftp.debian.org/debian/pool/main/a/apt/apt_1.2.1.tar.xz
apulse                      02.10.2017            02 Oct 2017   http://freedesktop.org/software/pulseaudio/releases/apulse-02.10.2017
aravis                      0.5.11                29 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/aravis/0.5/aravis-0.5.11.tar.xz
archivezip                  1.60                  23 Dec 2017   http://search.cpan.org/CPAN/authors/id/P/PH/PHRED/Archive-Zip-1.60.tar.gz
ardour                      2.8.16                01 Jan 2014   http://releases.ardour.org/ardour-2.8.16.tar.bz2
aria2                       1.16.0                01 Dec 2012   http://downloads.sourceforge.net/project/aria2/stable/aria2-1.16.0/aria2-1.16.0.tar.bz2
aris                        2.2                   11 Dec 2017   http://ftp.gnu.org/gnu/aris/aris-2.2.tar.gz
ark                         18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ark-18.04.0.tar.xz
armagetronad                0.2.8.3.4             12 Nov 2017   https://launchpad.net/armagetronad/0.2.8/0.2.8.3.4/+download/armagetronad-0.2.8.3.4.src.tar.gz
artemis                     v16.0.11              14 Feb 2016   ftp://ftp.sanger.ac.uk/pub4/resources/software/artemis/v16/v16.0.11/artemis_v16.0.11.jar
artikulate                  18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/artikulate-18.04.0.tar.xz
asc                         2.6.1.0               14 Feb 2016   https://sourceforge.net/projects/asc-hq/files/ASC%20Source/2.6.1/asc-2.6.1.0.tar.bz2
ascal                       0.1.1                 01 May 2014   http://sourceforge.net/projects/ascal/files/ascal/the%20last%20one%20this%20year/ascal-0.1.1.tar.bz2
asciidoc                    8.6.9                 25 Jul 2017   https://sourceforge.net/projects/asciidoc/files/asciidoc/8.6.9/asciidoc-8.6.9.tar.gz
aspell                      0.60.6.1              01 May 2012   ftp://ftp.gnu.org/gnu/aspell/aspell-0.60.6.1.tar.gz
asunder                     2.1                   May 2014      http://littlesvr.ca/asunder/releases/asunder-2.1.tar.bz2
asymptote                   2.44                  10 Apr 2018   https://downloads.sourceforge.net/asymptote/asymptote-2.44.src.tgz
aterm                       1.0.1                 May 2014      ftp://ftp.afterstep.org/apps/aterm/aterm-1.0.1.tar.bz2
atk                         2.28.1                18 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/atk/2.28/atk-2.28.1.tar.xz
atkmm                       2.24.2                25 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/atkmm/2.24/atkmm-2.24.2.tar.xz
atomix                      3.20.0                22 Mar 2016   http://ftp.gnome.org/pub/GNOME/sources/atomix/3.20/atomix-3.20.0.tar.xz
atool                       0.39.0                May 2014      http://savannah.nongnu.org/download/atool/atool-0.39.0.tar.gz
atril                       1.21.0                30 Apr 2018   http://pub.mate-desktop.org/releases/1.21/atril-1.21.0.tar.xz
atspi                       1.32.0                Dec 2012      http://ftp.gnome.org/pub/gnome/sources/at-spi/1.32/at-spi-1.32.0.tar.bz2
atspi2atk                   2.26.1                11 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/at-spi2-atk/2.26/at-spi2-atk-2.26.1.tar.xz
atspi2core                  2.26.2                11 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/at-spi2-core/2.26/at-spi2-core-2.26.2.tar.xz
attal                       1.0rc1                01 May 2014   http://www.attal-thegame.org/base.php?langue=en&page=accueil
attica                      5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/attica-5.45.0.tar.xz
attr                        2.4.47                10 Apr 2015   http://download.savannah.gnu.org/releases/attr/attr-2.4.47.src.tar.gz
aubio                       0.4.5                 01 Aug 2017   https://aubio.org/pub/aubio-0.4.5.tar.bz2
audacious                   3.9                   25 Sep 2017   http://distfiles.audacious-media-player.org/audacious-3.9.tar.bz2
audaciousplugins            3.9                   25 Sep 2017   http://distfiles.audacious-media-player.org/audacious-plugins-3.9.tar.bz2
audacityminsrc              2.2.1                 08 Dec 2017   https://www.fosshub.com/Audacity.html/audacity-minsrc-2.2.1.tar.xz
audiere                     1.9.4                 May 2014      http://prdownloads.sourceforge.net/audiere/audiere-1.9.4.tar.gz
audiocdkio                  18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/audiocd-kio-18.04.0.tar.xz
audiofile                   0.3.6                 01 May 2014   https://github.com/downloads/mpruett/audiofile/audiofile-0.3.6.tar.gz
aufs                        09.01.2009            01 May 2014   http://aufs.sourceforge.net/
augeas                      1.8.1                 02 Sep 2017   http://download.augeas.net/augeas-1.8.1.tar.gz
aumix                       2.9.1                 17 Nov 2015   http://sourceforge.net/projects/aumix/files/aumix/2.9.1/aumix-2.9.1.tar.bz2
autoconf                    2.69                  01 Jul 2013   ftp://ftp.gnu.org/gnu/autoconf/autoconf-2.69.tar.xz
autofs                      5.1.4                 25 Dec 2017   http://www.kernel.org/pub/linux/daemons/autofs/v5/autofs-5.1.4.tar.xz
autogen                     5.18.10               20 Sep 2016   https://ftp.gnu.org/gnu/autogen/rel5.18.10/autogen-5.18.10.tar.xz
automake                    1.16.1                12 Mar 2018   ftp://ftp.gnu.org/gnu/automake/automake-1.16.1.tar.xz
automoc                     27.03.2011            01 Nov 2012   http://techbase.kde.org/Getting_Started/Build/KDE4/Gentoo
automoc4                    0.9.88                01 Jan 2014   http://download.kde.org/stable/automoc4/0.9.88/automoc4-0.9.88.tar.bz2
autotoolset                 0.11.4                May 2014      autotoolset-0.11.4
autovivification            0.17                  05 Aug 2017   http://search.cpan.org/CPAN/authors/id/V/VP/VPIT/autovivification-0.17.tar.gz
avahi                       0.6.32                28 Aug 2016   https://github.com/lathiat/avahi/releases/download/v0.6.32/avahi-0.6.32.tar.gz
avantwindownavigator        0.4.2                 Sep 2014      https://launchpad.net/awn/0.4/0.4.2/+download/avant-window-navigator-0.4.2.tar.gz
avc                         0.8.2                 May 2014      http://avc.inrim.it/dist/avc-0.8.2.tar.gz
avidemux                    2.7.0                 14 Aug 2017   http://downloads.sourceforge.net/avidemux/avidemux_2.7.0.tar.gz
avifile                     0.7.45                01 May 2014   http://avifile.sourceforge.net/
avinfo                      1.0a12                01 May 2014   http://shounen.ru/soft/avinfo/avinfo-1.0a16.zip
awesome                     4.2                   15 Jul 2017   https://github.com/awesomeWM/awesome/releases/download/v4.2/awesome-4.2.tar.xz
axtls                       2.1.3                 02 Aug 2017   https://sourceforge.net/projects/axtls/files/2.1.3/axTLS-2.1.3.tar.gz
axv                         0.1                   01 May 2014   http://axv.sourceforge.net/
b43fwcutter                 015                   01 May 2014   http://bues.ch/b43/fwcutter/b43-fwcutter-015.tar.bz2
babl                        0.1.46                13 Apr 2018   https://download.gimp.org/pub/babl/0.1/babl-0.1.46.tar.bz2
bacula                      5.2.9                 01 May 2014   http://sourceforge.net/projects/bacula/files/bacula/5.2.9/bacula-5.2.9.tar.gz
bakery                      2.5.1                 01 May 2014   http://ftp.gnome.org/pub/GNOME/sources/bakery/2.5/bakery-2.5.1.tar.bz2
ballbuster                  1.1                   01 Jan 2013   http://www.patrickavella.com/ballbuster-1.1.tar.bz2
baloo                       5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/baloo-5.45.0.tar.xz
baloowidgets                18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/baloo-widgets-18.04.0.tar.xz
balsa                       2.5.5                 16 Mar 2018   http://pawsa.fedorapeople.org/balsa/balsa-2.5.5.tar.bz2
banshee                     2.9.1                 10 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/banshee/2.9/banshee-2.9.1.tar.xz
baobab                      3.27.90               14 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/baobab/3.27/baobab-3.27.90.tar.xz
barcode                     0.98                  01 May 2014   ftp://mirrors.usc.edu/pub/gnu/barcode/barcode-0.98.tar.gz
barrage                     1.0.4                 01 May 2014   http://prdownloads.sourceforge.net/lgames/barrage-1.0.4.tar.gz
bash                        4.4.18                31 Jan 2018   https://ftp.gnu.org/pub/gnu/bash/bash-4.4.18.tar.gz
bazar                       1.1                   01 May 2014   http://cvlab.epfl.ch/software/bazar/bazar-1.1.tar.gz
bc                          1.07.1                22 Jul 2017   http://ftp.gnu.org/gnu/bc/bc-1.07.1.tar.gz
bchunk                      1.2.0                 01 May 2014   http://he.fi/bchunk/
bdftopcf                    1.1                   09 Nov 2017   https://www.x.org/releases/individual/app/bdftopcf-1.1.tar.gz
beagle                      0.3.6                 01 May 2014   ftp://ftp.gnome.org/pub/GNOME/sources/beagle/0.3/beagle-0.3.6.tar.bz2
bedtools2                   24.11.2017            29 Jun 2017   https://github.com/arq5x/bedtools2/archive/master.zip
beecrypt                    4.2.1                 01 May 2014   http://sourceforge.net/projects/beecrypt/files/beecrypt/4.2.1/beecrypt-4.2.1.tar.gz
beforelight                 1.0.5                 01 Jan 2013   http://xorg.freedesktop.org/releases/individual/app/beforelight-1.0.5.tar.bz2
benchmarkips                2.7.2                 12 Oct 2017   https://rubygems.org/downloads/benchmark-ips-2.7.2.gem
bftpd                       4.6                   31 Oct 2017   https://sourceforge.net/projects/bftpd/files/bftpd/bftpd-4.6/bftpd-4.6.tar.gz
bigreqsproto                1.1.2                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/proto/bigreqsproto-1.1.2.tar.bz2
bijiben                     3.28.1                29 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/bijiben/3.28/bijiben-3.28.1.tar.xz
biloba                      0.4                   01 Jun 2014   http://surfnet.dl.sourceforge.net/sourceforge/biloba/biloba-0.4.tar.gz
bind                        9.12.1                14 Mar 2018   ftp://ftp.isc.org/isc/bind9/9.12.1/bind-9.12.1.tar.gz
biniax                      1.2                   01 Jan 2013   http://mordred.dir.bg/biniax/download.htm
binutils                    2.30                  28 Jan 2018   ftp://ftp.gnu.org/gnu/binutils/binutils-2.30.tar.gz
bio                         1.5.1                 09 Jan 2018   https://rubygems.org/downloads/bio-1.5.1.gem
bioperl                     1.007002              02 Jan 2018   https://cpan.metacpan.org/authors/id/C/CJ/CJFIELDS/BioPerl-1.007002.tar.gz
biopython                   1.71                  04 Apr 2018   http://biopython.org/DIST/biopython-1.71.tar.gz
bioruby                     1.5.0                 30 Jan 2016   http://bioruby.open-bio.org/archive/bioruby-1.5.0.tar.gz
biosdevname                 0.7.1                 25 Dec 2015   http://linux.dell.com/files/biosdevname/biosdevname-0.7.1/biosdevname-0.7.1.tar.gz
bison                       3.0.4                 26 Feb 2017   ftp://ftp.gnu.org/gnu/bison/bison-3.0.4.tar.xz
bitlbee                     1.2.1                 01 Jun 2014   http://get.bitlbee.org/src/bitlbee-1.2.1.tar.gz
bitmap                      1.0.7                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/app/bitmap-1.0.7.tar.bz2
bittorrent                  4.4.0                 01 Jun 2014   http://www.bittorrent.com/dl/BitTorrent-4.4.0.tar.gz
bkchem                      0.13.0                01 Feb 2014   http://bkchem.zirael.org/download/bkchem-0.13.0.tar.gz
blackbox                    0.70.1                01 Jun 2014   http://kent.dl.sourceforge.net/sourceforge/blackboxwm/blackbox-0.70.1.tar.bz2
blam                        1.8.12                24 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/blam/1.8/blam-1.8.12.tar.xz
blender                     2.79                  12 Sep 2017   http://download.blender.org/source/blender-2.79.tar.gz
bless                       0.5.2                 01 Nov 2012   http://download.gna.org/bless/bless-0.5.2.tar.gz
blessings                   1.5                   01 May 2014   http://pypi.python.org/packages/source/b/blessings/blessings-1.5.tar.gz
blinken                     18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/blinken-18.04.0.tar.xz
blobwars                    1.04                  01 Jan 2013   http://www.parallelrealities.co.uk/download.php?file=blobwars-1.04-1.tar.gz&type=zip
blockattack                 1.3.0                 Jan 2013      http://belnet.dl.sourceforge.net/sourceforge/blockattack/BlockAttackLinux112.tar.gz
blogilo                     17.08.3               09 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/blogilo-17.08.3.tar.xz
bluedevil                   5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/bluedevil-5.12.4.tar.xz
bluefish                    2.2.10                26 Jul 2017   http://www.bennewitz.com/bluefish/stable/source/bluefish-2.2.10.tar.bz2
blueman                     23.09.2017            23 Sep 2017   https://github.com/blueman-project/blueman-23.09.2017
bluez                       5.49                  18 Mar 2018   http://www.kernel.org/pub/linux/bluetooth/bluez-5.49.tar.xz
bluezgnome                  0.14                  Jun 2014      http://www.kernel.org/pub/linux/bluetooth/bluez-gnome-0.14.tar.gz
bluezqt                     5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/bluez-qt-5.45.0.tar.xz
bluezutils                  2.25                  28 Jul 2016   http://bluez.sf.net/download/bluez-utils-2.25.tar.gz
bodr                        6                     01 May 2014   http://www.blueobelisk.org/
bol                         0.8                   May 2014      http://surfnet.dl.sourceforge.net/sourceforge/fpcbol/bol.tar.bz
bomber                      18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/bomber-18.04.0.tar.xz
bomberclone                 0.11.9                10 Oct 2017   https://sourceforge.net/projects/bomberclone/files/bomberclone/bomberclone-0.11.9.tar.gz
bombic                      0.0.1                 01 Jan 2013   https://sourceforge.net/projects/bombic/files/bombic/Bombic%200.0.1/bombic-0.0.1-src.tar.gz
bomns                       0.99.1                Jun 2014      http://ovh.dl.sourceforge.net/sourceforge/greenridge/bomns-0.99.1.tar.bz2
bookify                     1.4.3                 13 Feb 2018   https://rubygems.org/downloads/bookify-1.4.3.gem
boost                       1.65.1                19 Sep 2017   https://dl.bintray.com/boostorg/release/1.65.1/source/boost_1_65_1.tar.bz2
boostbuild                  2014-10               11 Sep 2017   https://github.com/boostorg/build/releases/download/2014.10/boost-build-2014-10.tar.bz2
boswars                     2.7                   01 Aug 2013   https://www.boswars.org/dist/releases/boswars-2.7-src.tar.gz
bovo                        4.14.3                14 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/bovo-4.14.3.tar.xz
brasero                     3.12.2                01 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/brasero/3.12/brasero-3.12.2.tar.xz
breeze                      5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/breeze-5.12.4.tar.xz
breezegrub                  5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/breeze-grub-5.12.4.tar.xz
breezegtk                   5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/breeze-gtk-5.12.4.tar.xz
breezeicons                 5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/breeze-icons-5.45.0.tar.xz
breezeplymouth              5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/breeze-plymouth-5.12.4.tar.xz
bridgeutils                 1.6                   26 Jul 2017   https://www.kernel.org/pub/linux/utils/net/bridge-utils/bridge-utils-1.6.tar.xz
briquolo                    0.5.7                 01 Jun 2014   http://briquolo.free.fr/download/briquolo-0.5.7.tar.bz2
brlcad                      7.26.0                22 Feb 2017   https://sourceforge.net/projects/brlcad/files/BRL-CAD%20Source/7.26.0/brlcad-7.26.0.tar.bz2
brotli                      1.0.2                 01 Dec 2017   https://github.com/google/brotli/archive/v1.0.2.tar.gz
bsc                         2.27                  01 Jun 2014   http://www.beesoft.org/download/bsc_2.20_src.tar.gz
btrfsprogs                  v4.15                 05 Feb 2018   https://www.kernel.org/pub/linux/kernel/people/kdave/btrfs-progs/btrfs-progs-v4.15.tar.xz
bubbros                     1.6                   01 Jun 2014   http://briquolo.free.fr/en/download.html
budgiedesktop               10.4                  15 Aug 2017   https://github.com/solus-project/budgie-desktop/releases/download/v10.4/budgie-desktop-10.4.tar.xz
bugbuddy                    2.32.0                Jun 2014      http://ftp.acc.umu.se/pub/GNOME/sources/bug-buddy/2.32/bug-buddy-2.32.0.tar.bz2
builder                     3.2.3                 03 Dec 2017   https://rubygems.org/downloads/builder-3.2.3.gem
buildroot                   20171011              11 Oct 2017   http://buildroot.uclibc.org/downloads/snapshots/buildroot-20171011.tar.bz2
buildstream                 1.1.3                 29 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/BuildStream/1.1/BuildStream-1.1.3.tar.xz
bullet                      2.83.6                22 Sep 2015   https://github.com/bulletphysics/bullet3/archive/bullet-2.83.6.tar.gz
bumprace                    1.5.3                 Jun 2014      http://www.linux-games.com/bumprace/index.html
bundler                     1.16.1                22 Dec 2017   https://rubygems.org/downloads/bundler-1.16.1.gem
burgerspace                 1.9.2                 02 Nov 2015   http://perso.b2b2c.ca/sarrazip/dev/burgerspace-1.9.2.tar.gz
busybox                     1.28.3                04 Apr 2018   http://www.busybox.net/downloads/busybox-1.28.3.tar.bz2
bytename                    1.9                   Jun 2014      http://billposer.org/Software/Downloads/bytename-1.9.tar.bz2
bzip2                       1.0.6                 01 Nov 2012   http://www.bzip.org/1.0.6/bzip2-1.0.6.tar.gz
bzr                         2.7.0                 14 Mar 2017   http://launchpad.net/bzr/2.7/2.7.0/+download/bzr-2.7.0.tar.gz
cabextract                  1.6                   31 Aug 2017   https://www.cabextract.org.uk/cabextract-1.6.tar.gz
cacti                       1.1.17                14 Aug 2017   http://www.cacti.net/downloads/cacti-1.1.17.tar.gz
cairo                       1.14.12               09 Dec 2017   https://www.cairographics.org/releases/cairo-1.14.12.tar.xz
cairodock                   3.4.1                 04 Mar 2017   https://github.com/Cairo-Dock/cairo-dock-core/releases/download/3.4.1/cairo-dock-3.4.1.tar.gz
cairomm                     1.15.5                11 Oct 2017   https://www.cairographics.org/releases/cairomm-1.15.5.tar.gz
caja                        1.20.2                07 Apr 2018   http://pub.mate-desktop.org/releases/1.20/caja-1.20.2.tar.xz
cajadropbox                 1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/caja-dropbox-1.20.0.tar.xz
cajaextensions              1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/caja-extensions-1.20.0.tar.xz
cajun                       4.2                   Jun 2014      http://cajun.sourceforge.net/
cal3d                       0.11.0                28 Jul 2016   http://download.gna.org/cal3d/sources/cal3d-0.11.0.tar.gz
calendarsupport             18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/calendarsupport-18.04.0.tar.xz
calf                        0.90.0                28 Nov 2017   https://github.com/calf-studio-gear/calf/archive/0.90.0.tar.gz
calibre                     3.22.0                20 Apr 2018   https://download.calibre-ebook.com/3.22.0/calibre-3.22.0.tar.xz
california                  0.4.0                 24 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/california/0.4/california-0.4.0.tar.xz
callgrind                   0.9.12                Jun 2014      http://kcachegrind.sourceforge.net/callgrind-0.9.12.tar.gz
calligra                    3.1.0                 01 Feb 2018   http://download.kde.org/stable/calligra/3.1.0/calligra-3.1.0.tar.xz
camping                     2.1.532               30 Nov 2017   https://rubygems.org/downloads/camping-2.1.532.gem
cantarellfonts              0.101                 18 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/cantarell-fonts/0.101/cantarell-fonts-0.101.tar.xz
cantor                      18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/cantor-18.04.0.tar.xz
captive                     1.1.7                 Jun 2014      http://www.jankratochvil.net/project/captive/dist/captive-1.1.7.tar.gz
cares                       1.13.0                15 Sep 2017   https://c-ares.haxx.se/download/c-ares-1.13.0.tar.gz
caribou                     0.4.20                16 Feb 2016   http://ftp.gnome.org/pub/GNOME/sources/caribou/0.4/caribou-0.4.20.tar.xz
castlecombat                0.8.1                 28 Jul 2016   http://prdownloads.sourceforge.net/castle-combat/castle-combat-0.8.1.tar.gz
cbase                       1.3.5                 Jun 2014      http://www.hyperrealm.com/cbase/cbase-1.3.5.tar.gz
ccache                      3.3.4                 12 Mar 2017   https://www.samba.org/ftp/ccache/ccache-3.3.4.tar.xz
ccaudio2                    2.1.5                 May 2014      http://ftp.gnu.org/pub/gnu/ccaudio/ccaudio2-2.1.5.tar.gz
ccmath                      2.2.1                 Jun 2014      http://www.ibiblio.org/pub/Linux/libs/ccmath-2.2.1.tar.gz
cdemuclient                 3.0.1                 28 Jul 2016   http://downloads.sourceforge.net/cdemu/cdemu-client-3.0.1.tar.bz2
cdemudaemon                 3.0.4                 28 Jul 2016   http://downloads.sourceforge.net/cdemu/cdemu-daemon-3.0.4.tar.bz2
cdogs                       13.03.2007            Jun 2014      http://lumaki.com/code/cdogs
cdparanoia                  3.10.0                Jun 2014      http://xiph.org/paranoia/down.html
cdrdao                      1.2.3                 Jun 2014      http://sourceforge.net/projects/cdrdao/files/cdrdao/1.2.3/cdrdao-1.2.3.tar.bz2
cdrkit                      1.1.11                Jun 2014      http://cdrkit.org/releases/cdrkit-1.1.11.tar.gz
cdrtools                    3.01a24               16 Aug 2015   http://downloads.sourceforge.net/project/cdrtools/alpha/cdrtools-3.01a24.tar.gz
ceferino                    0.97.8                Jun 2014      http://www.loosersjuegos.com.ar/_media/juegos/ceferino/descargas/ceferino-0.97.8.tar.gz
cegui                       0.7.7                 Jun 2014      http://prdownloads.sourceforge.net/crayzedsgui/CEGUI-0.7.7.tar.gz
celt                        0.11.3                08 Aug 2016   http://downloads.xiph.org/releases/celt/celt-0.11.3.tar.gz
centericq                   4.21.0                31 Oct 2017   http://thekonst.net/download/centericq-4.21.0.tar.bz2
ceph                        0.47.2                Jun 2014      http://ceph.com/download/ceph-0.47.2.tar.bz2
certifi                     2017.7.27.1           23 Sep 2017   https://pypi.python.org/packages/20/d0/3f7a84b0c5b89e94abbd073a5f00c7176089f526edb056686751d5064cbd/certifi-2017.7.27.1.tar.gz
cervisia                    18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/cervisia-18.04.0.tar.xz
cfengine                    3.8.0                 12 Dec 2015   https://cfengine-package-repos.s3.amazonaws.com/tarballs/cfengine-3.8.0.tar.gz
cflow                       1.4                   01 Jun 2014   http://gd.tuwien.ac.at/gnu/gnusrc/cflow/cflow-1.4.tar.bz2
cgiirc                      0.5.8                 Jun 2014      http://kent.dl.sourceforge.net/sourceforge/cgiirc/cgiirc-0.5.8.tar.gz
cgilib                      0.6                   Jun 2014      http://www.infodrom.org/projects/cgilib/download/cgilib-0.6.tar.gz
changepassword              0.9                   Jun 2014      http://prdownloads.sourceforge.net/changepassword/changepassword-0.9.tar.gz
char                        1.0                   Jun 2014      http://ltsword.allegronetwork.com/char-linux.tar.gz
charlix                     0.4                   Jun 2014      http://charlix.sourceforge.net/
check                       0.12.0                01 Jan 2018   https://github.com/libcheck/check/releases/download/0.12.0/check-0.12.0.tar.gz
checkinstall                1.6.2                 01 Jun 2014   http://asic-linux.com.mx/~izto/checkinstall/files/source/checkinstall-1.6.2.tar.gz
cheese                      3.26.0                12 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/cheese/3.26/cheese-3.26.0.tar.xz
chemtool                    1.6.14                01 Mar 2014   http://ruby.chemie.uni-freiburg.de/~martin/chemtool/chemtool-1.6.14.tar.gz
cherokee                    1.2.99                Apr 2014      http://www.cherokee-project.com/download/1.2/1.2.99/cherokee-1.2.99.tar.gz
chkrootkit                  0.49                  Jun 2014      ftp://ftp.pangeia.com.br/pub/seg/pac/chkrootkit-0.49.tar.gz
chmlib                      0.40                  17 Mar 2017   http://www.jedrea.com/chmlib/chmlib-0.40.tar.gz
chromaprint                 1.1                   10 Mar 2015   https://bitbucket.org/acoustid/chromaprint/downloads/chromaprint-1.1.tar.gz
chromegnomeshell            10                    05 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/chrome-gnome-shell/10/chrome-gnome-shell-10.tar.xz
chromium                    61.0.3163.100         13 Oct 2017   https://commondatastorage.googleapis.com/chromium-browser-official/chromium-61.0.3163.100.tar.xz
chromiumbsu                 0.9.16.1              01 Jan 2017   https://sourceforge.net/projects/chromium-bsu/files/Chromium%20B.S.U.%20source%20code/chromium-bsu-0.9.16.1.tar.gz
chronojump                  1.8.1                 29 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/chronojump/1.8/chronojump-1.8.1.tar.xz
chrpath                     0.16                  31 Oct 2015   https://alioth.debian.org/frs/download.php/latestfile/813/chrpath-0.16.tar.gz
chunkypng                   1.3.10                27 Jan 2018   https://rubygems.org/downloads/chunky_png-1.3.10.gem
cifsutils                   6.8                   22 Mar 2018   https://www.samba.org/ftp/linux-cifs/cifs-utils/cifs-utils-6.8.tar.bz2
cinelerra                   4.6.1                 10 Nov 2015   http://sourceforge.net/projects/heroines/files/cinelerra-4.6.1-src.tar.xz
cinepaint                   0.22.1                Jun 2014      http://sourceforge.net/projects/cinepaint/files/CinePaint/CinePaint-0.22-1/cinepaint-0.22.1.tar.gz
circuslinux                 1.0.3                 Jun 2014      ftp://ftp.tuxpaint.org/unix/x/circus-linux/src/circuslinux-1.0.3.tar.gz
clamav                      0.99.1                29 Jun 2017   https://sourceforge.net/projects/clamav/files/clamav/0.99.1/clamav-0.99.1.tar.gz
clang                       3.4                   Apr 2014      http://llvm.org/releases/3.4/clang-3.4.src.tar.gz
clanlib                     24.10.2015            24 Oct 2015   http://www.clanlib.org/download/releases-3.0/ClanLib-24.10.2015
classaccessor               0.51                  28 Oct 2017   http://search.cpan.org/CPAN/authors/id/K/KA/KASEI/Class-Accessor-0.51.tar.gz
classlib                    0.1                   01 Jun 2014   http://students.washington.edu/aemk/cm/releases/classlib-0.1.tar.gz
classtiny                   1.004                 01 Apr 2016   http://search.cpan.org/CPAN/authors/id/D/DA/DAGOLDEN/Class-Tiny-1.004.tar.gz
clawsmail                   2.8.1                 Jun 2014      http://www.claws-mail.org/
clearsilver                 0.10.5                Jun 2014      http://www.clearsilver.net/downloads/clearsilver-0.10.5.tar.gz
clementine                  1.2.3                 Apr 2014      http://clementine-player.googlecode.com/files/clementine-1.2.3.tar.gz
click                       5.1                   09 Sep 2015   https://pypi.python.org/packages/source/c/click/click-5.1.tar.gz#md5=9c5323008cccfe232a8b161fc8196d41
clisp                       2.49                  May 2014      https://sourceforge.net/projects/clisp/files/clisp/2.49/clisp-2.49.tar.gz
clive                       1.0.2                 Jun 2014      http://download.gna.org/clive/1.0.x/clive-1.0.2.tar.bz2
cloog                       0.18.4                11 Feb 2017   http://www.bastoul.net/cloog/pages/download/cloog-0.18.4.tar.gz
cloogparma                  0.16.1                01 Nov 2012   http://www.bastoul.net/cloog/pages/download/cloog-parma-0.16.1.tar.gz
cloogppl                    0.15.11               01 Nov 2012   ftp://gcc.gnu.org/pub/gcc/infrastructure/cloog-ppl-0.15.11.tar.gz
clucenecore                 2.3.3.4               28 Jul 2016   https://sourceforge.net/projects/clucene/files/clucene-core-unstable/2.3/clucene-core-2.3.3.4.tar.gz
clustalw                    2.1                   11 Apr 2016   http://www.clustal.org/download/current/clustalw-2.1.tar.gz
clutter                     1.26.2                13 May 2017   http://ftp.gnome.org/pub/gnome/sources/clutter/1.26/clutter-1.26.2.tar.xz
cluttergst                  3.0.26                20 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/clutter-gst/3.0/clutter-gst-3.0.26.tar.xz
cluttergtk                  1.8.4                 09 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/clutter-gtk/1.8/clutter-gtk-1.8.4.tar.xz
cluttergtkmm                1.6.0                 18 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/clutter-gtkmm/1.6/clutter-gtkmm-1.6.0.tar.xz
cluttermm                   1.17.3                May 2014      http://ftp.gnome.org/pub/GNOME/sources/cluttermm/1.17/cluttermm-1.17.3.tar.xz
cmake                       3.11.1                17 Apr 2018   http://www.cmake.org/files/v3.11/cmake-3.11.1.tar.gz
cmdftp                      0.9.7                 Jun 2014      http://download.savannah.nongnu.org/releases/cmdftp/cmdftp-0.9.7.tar.gz
codebrowser                 4.9                   Dec 2012      http://tibleiz.net/download/code-browser-4.9-src.tar.gz
coderay                     1.1.2                 11 Sep 2017   https://rubygems.org/downloads/coderay-1.1.2.gem
codestriker                 1.9.10                Jun 2014      http://sourceforge.net/projects/codestriker/files/codestriker/1.9.10/codestriker-1.9.10.tar.gz
coffeescript                2.4.1                 10 Dec 2017   https://rubygems.org/downloads/coffee-script-2.4.1.gem
cogito                      0.17.2                Jun 2014      http://www.kernel.org/pub/software/scm/cogito/cogito-0.17.2.tar.bz2
cogl                        1.22.2                11 Jul 2017   http://ftp.gnome.org/pub/gnome/sources/cogl/1.22/cogl-1.22.2.tar.xz
coin                        2.5.0                 Jun 2014      http://www.coin3d.org/lib/coin/releases/2.5.0
collectd                    3.8.4                 Jun 2014      http://collectd.org/files/collectd-3.8.4.tar.bz2
collectl                    4.2.0                 14 Jul 2017   https://sourceforge.net/projects/collectl/files/collectl/collectl-4.2.0/collectl-4.2.0.src.tar.gz
colorama                    0.3.9                 04 Oct 2017   https://pypi.python.org/packages/e6/76/257b53926889e2835355d74fec73d82662100135293e17d382e2b74d1669/colorama-0.3.9.tar.gz
colord                      1.4.3                 21 Apr 2018   https://www.freedesktop.org/software/colord/releases/colord-1.4.3.tar.xz
colordgtk                   0.1.26                01 Nov 2017   https://www.freedesktop.org/software/colord/releases/colord-gtk-0.1.26.tar.xz
colortools                  1.3.0                 22 Jul 2017   https://rubygems.org/downloads/color-tools-1.3.0.gem
comix                       4.0.4                 11 Oct 2017   https://sourceforge.net/projects/comix/files/comix/comix-4.0.4/comix-4.0.4.tar.gz
compface                    1.5.2                 Jan 2013      http://ftp.xemacs.org/pub/xemacs/aux/compface-1.5.2.tar.gz
compiz                      0.9.13.1              07 Oct 2017   https://launchpad.net/compiz/0.9.13/0.9.13.1/+download/compiz-0.9.13.1.tar.bz2
compositeproto              0.4.2                 08 Aug 2016   https://www.x.org/releases/individual/proto/compositeproto-0.4.2.tar.gz
conary                      1.1.18                Dec 2012      ftp://download.rpath.com/conary/
concurrentruby              1.0.5                 18 Dec 2017   https://rubygems.org/downloads/concurrent-ruby-1.0.5.gem
confuse                     2.7                   01 Dec 2013   http://download.savannah.gnu.org/releases/confuse/confuse-2.7.tar.gz
conky                       1.9.0                 Mar 2014      https://sourceforge.net/projects/conky/files/conky/1.9.0/conky-1.9.0.tar.bz2
connman                     1.33                  22 Feb 2017   https://www.kernel.org/pub/linux/network/connman/connman-1.33.tar.xz
consolekit                  0.4.6                 Jun 2014      http://anduin.linuxfromscratch.org/sources/BLFS/svn/c/ConsoleKit-0.4.6.tar.xz
constype                    1.0.4                 May 2014      http://xorg.freedesktop.org/releases/individual/app/constype-1.0.4.tar.bz2
contextfree                 3.0.11.4              18 Jan 2018   https://www.contextfreeart.org/download/ContextFreeSource3.0.11.4.tar.xz
controlcenter               2.18.1                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/control-center/2.18/control-center-2.18.1.tar.bz2
convmv                      1.10                  Jun 2014      http://www.j3e.de/linux/convmv/
cook                        2.28                  Jun 2014      cook-2.28
coreutils                   8.29                  28 Dec 2017   ftp://ftp.gnu.org/gnu/coreutils/coreutils-8.29.tar.xz
cparser                     1.22.0                04 Jan 2016   https://github.com/MatzeB/cparser/archive/cparser-1.22.0.tar.gz
cpio                        2.12                  03 Feb 2016   http://ftp.gnu.org/pub/gnu/cpio/cpio-2.12.tar.bz2
cppunit                     1.12.1                Nov 2012      https://sourceforge.net/projects/cppunit/files/cppunit/1.12.1/cppunit-1.12.1.tar.gz
cpufreqd                    2.4.2                 24 Dec 2015   http://sourceforge.net/projects/cpufreqd/files/Source%20packages/2.4.2/cpufreqd-2.4.2.tar.bz2
cracklib                    2.9.6                 18 Jul 2017   https://github.com/cracklib/cracklib/releases/download/cracklib-2.9.6/cracklib-2.9.6.tar.gz
cream                       0.43                  01 Jun 2014   http://prdownloads.sourceforge.net/cream/cream-0.43.tar.gz
createtorrent               1.1.4                 01 Jan 2013   http://www.createtorrent.com/createtorrent-1.1.4.tar.gz
crimson                     0.5.3                 Jan 2013      http://crimson.seul.org/files/crimson-0.5.3.tar.bz2
crunchyfrog                 0.2.0                 Jun 2014      http://crunchyfrog.googlecode.com/files/crunchyfrog-0.2.0.tar.gz
cryopid                     0.5.9.1               Jun 2014      http://dagobah.ucc.asn.au/wacky/cryopid-0.5.9.1-i386.tar.gz
cryptkeeper                 0.9.5                 Jun 2014      http://tom.noflag.org.uk/cryptkeeper/cryptkeeper-0.9.5.tar.gz
cryptopp                    5.5.2                 Jun 2014      http://www.cryptopp.com/cryptopp561.zip
cryptsetup                  1.7.5                 18 Mar 2018   https://www.kernel.org/pub/linux/utils/cryptsetup/v1.7/cryptsetup-1.7.5.tar.xz
crystal                     0.15.0                05 Apr 2016   https://github.com/crystal-lang/crystal/archive/0.15.0.tar.gz
crystalspace                1.2                   Jun 2014      http://www.crystalspace3d.org/downloads/release/crystalspace-src-2.0.tar.bz2
csmash                      0.6.6                 Jun 2014      http://cannonsmash.sourceforge.net/
ctags                       5.8                   01 Jun 2014   http://prdownloads.sourceforge.net/ctags/ctags-5.8.tar.gz
ctalk                       0.0.77a               Jun 2014      http://ctalk-lang.sourceforge.net/
ctioga                      1.11.1                01 Dec 2017   https://rubygems.org/downloads/ctioga-1.11.1.gem
ctorrent                    1.3.4                 01 Jun 2014   https://sourceforge.net/projects/ctorrent/files/CTorrent-1.3.4/CTorrent-1.3.4/ctorrent-1.3.4.tar.bz2
ctris                       0.42                  Jun 2014      http://www.hackl.dhs.org/ctris/
ctypes                      1.0.2                 01 Jan 2013   http://downloads.sourceforge.net/project/ctypes/ctypes/1.0.2/ctypes-1.0.2.tar.gz
cuiterm                     0.9.9                 01 Jun 2014   ftp://linux.pte.hu/pub/CUI/cuiterm-0.9.9.tar.gz
cunit                       2.1-3                 20 Feb 2017   https://downloads.sourceforge.net/project/cunit/CUnit/2.1-3/CUnit-2.1-3.tar.bz2
cups                        2.2.7                 27 Mar 2018   https://github.com/apple/cups/releases/download/v2.2.7/cups-2.2.7-source.tar.gz
cupsfilters                 1.20.3                15 Apr 2018   https://www.openprinting.org/download/cups-filters/cups-filters-1.20.3.tar.xz
cupspdf                     2.6.1                 Jul 2013      http://www.physik.uni-wuerzburg.de/~vrbehr/cups-pdf/src/cups-pdf_2.6.1.tar.gz
curl                        7.59.0                14 Mar 2018   http://curl.haxx.se/download/curl-7.59.0.tar.bz2
cutmp3                      3.0.1                 12 Dec 2015   http://www.puchalla-online.de/cutmp3-3.0.1.tar.bz2
cvs                         1.11.23               Mar 2013      http://ftp.gnu.org/non-gnu/cvs/source/stable/1.11.23/cvs-1.11.23.tar.bz2
cvtool                      0.1.0                 Jun 2014      http://sourceforge.net/projects/cvtool/
cxxtools                    2.2.1                 02 Aug 2017   http://www.tntnet.org/download/cxxtools-2.2.1.tar.gz
cyrussasl                   2.1.26                09 Jul 2015   ftp://ftp.cyrusimap.org/cyrus-sasl/cyrus-sasl-2.1.26.tar.gz
cython                      0.28.1                01 Apr 2018   https://pypi.python.org/packages/be/08/bb5ffd1c32a951cbc26011ecb8557e59dc7a0a4975f0ad98b2cd7446f7dd/Cython-0.28.1.tar.gz
daemons                     1.2.6                 09 Jan 2018   https://rubygems.org/downloads/daemons-1.2.6.gem
damageproto                 1.2.1                 08 Aug 2016   http://xorg.freedesktop.org/releases/individual/proto/damageproto-1.2.1.tar.bz2
daq                         2.0.5                 20 May 2015   https://www.snort.org/downloads/snort/daq-2.0.5.tar.gz
darcs                       2.12.5                21 Feb 2017   http://darcs.net/releases/darcs-2.12.5.tar.gz
dash                        0.5.9.1               12 Sep 2017   http://gondor.apana.org.au/~herbert/dash/files/dash-0.5.9.1.tar.gz
dasher                      4.11                  01 Jun 2014   http://ftp.acc.umu.se/pub/GNOME/sources/dasher/4.11/dasher-4.11.tar.bz2
datamash                    1.2                   26 Aug 2017   http://ftp.gnu.org/pub/gnu/datamash/datamash-1.2.tar.gz
db                          6.1.26                24 Jan 2016   http://download.oracle.com/berkeley-db/db-6.1.26.tar.gz
dbh                         1.0.24                Jun 2014      http://heanet.dl.sourceforge.net/sourceforge/xfce/xfce-4.2.3.2-src.tar.bz2
dblatex                     0.3                   Jun 2014      http://prdownloads.sourceforge.net/dblatex/dblatex-0.3.tar.bz2
dbus                        1.12.6                08 Mar 2018   https://dbus.freedesktop.org/releases/dbus/dbus-1.12.6.tar.gz
dbusglib                    0.110                 03 Feb 2018   https://dbus.freedesktop.org/releases/dbus-glib/dbus-glib-0.110.tar.gz
dbuspython                  1.2.6                 04 Feb 2018   http://dbus.freedesktop.org/releases/dbus-python/dbus-python-1.2.6.tar.gz
dconf                       0.28.0                19 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/dconf/0.28/dconf-0.28.0.tar.xz
dconfeditor                 3.26.2                19 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/dconf-editor/3.26/dconf-editor-3.26.2.tar.xz
dcraw                       9.15                  Jun 2014      http://www.cybercom.net/~dcoffin/dcraw/archive/dcraw-9.15.tar.gz
ddclient                    3.8.3                 07 Feb 2016   https://sourceforge.net/projects/ddclient/files/ddclient/ddclient-3.8.3/ddclient-3.8.3.tar.bz2
ddd                         3.3.12                Jun 2014      http://ftp.gnu.org/gnu/ddd/ddd-3.3.12.tar.gz
ddrescue                    1.20                  29 Dec 2015   http://ftp.gnu.org/gnu/ddrescue/ddrescue-1.20.tar.lz
defendguin                  0.0.11                Jun 2014      http://www.newbreedsoftware.com/defendguin/download/
dejagnu                     1.6.1                 19 Nov 2017   https://ftp.gnu.org/pub/gnu/dejagnu/dejagnu-1.6.1.tar.gz
deluge                      1.3.15                30 Jul 2017   http://download.deluge-torrent.org/source/deluge-1.3.15.tar.xz
denemo                      2.2.0                 01 Aug 2017   http://ftp.gnu.org/pub/gnu/denemo/denemo-2.2.0.tar.gz
deplate                     0.8.5                 13 Feb 2016   https://sourceforge.net/projects/deplate/files/deplate/0.8.5/deplate-0.8.5.gem
dermixd                     2.0.1                 16 Apr 2016   http://thomas.orgis.org/dermixd/dermixd-2.0.1.tar.bz2
deskbarapplet               2.20.0                Jun 2014      http://ftp.acc.umu.se/pub/GNOME/sources/deskbar-applet/2.20/deskbar-applet-2.20.0.tar.bz2
desksanity                  1.1.0                 05 Feb 2016   https://download.enlightenment.org/rel/apps/enlightenment/desksanity-1.1.0.tar.xz
desktopfileutils            0.23                  22 Oct 2016   http://freedesktop.org/software/desktop-file-utils/releases/desktop-file-utils-0.23.tar.xz
detect                      0.9.83                Jun 2014      http://www.hylius.fr/
devede                      4.5.0                 02 Feb 2016   https://github.com/rastersoft/devedeng/archive/4.5.0.tar.gz
devhelp                     3.28.1                08 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/devhelp/3.28/devhelp-3.28.1.tar.xz
devil                       1.7.8                 19 Jun 2015   http://downloads.sourceforge.net/openil/DevIL-1.7.8.tar.gz
dfeet                       0.3.13                25 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/d-feet/0.3/d-feet-0.3.13.tar.xz
dhcp                        4.4.1                 28 Feb 2018   ftp://ftp.isc.org/isc/dhcp/4.4.1/dhcp-4.4.1.tar.gz
dhcpcd                      7.0.3                 10 Apr 2018   http://roy.marples.name/downloads/dhcpcd/dhcpcd-7.0.3.tar.xz
dia                         0.97.3                05 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/dia/0.97/dia-0.97.3.tar.xz
diakonos                    0.9.4                 15 Nov 2015   http://diakonos.pist0s.ca/archives/diakonos-0.9.4.tar.gz
dictd                       1.12.1                Jun 2014      https://sourceforge.net/projects/dict/files/dictd/dictd-1.12.1/dictd-1.12.1.tar.gz
didyoumean                  1.2.1                 01 May 2018   https://rubygems.org/downloads/did_you_mean-1.2.1.gem
dietlibc                    0.33                  11 Oct 2017   https://www.fefe.de/dietlibc/dietlibc-0.33.tar.bz2
difflcs                     1.3                   03 Dec 2017   https://rubygems.org/downloads/diff-lcs-1.3.gem
diffutils                   3.6                   22 May 2017   ftp://ftp.gnu.org/gnu/diffutils/diffutils-3.6.tar.xz
digger                      14.03.2002            Jun 2014      http://www.digger.org/unix.html
digikam                     5.9.0                 24 Mar 2018   http://download.kde.org/stable/digikam/digikam-5.9.0.tar.xz
dillo                       3.0.5                 03 Jul 2015   http://www.dillo.org/download/dillo-3.0.5.tar.bz2
ding                        1.7                   May 2014      ftp://ftp.tu-chemnitz.de/pub/Local/urz/ding/ding-1.7.tar.gz
dirac                       1.0.0                 Jun 2014      https://sourceforge.net/projects/dirac/files/dirac-codec/Dirac-1.0.0/dirac-1.0.0.tar.gz
directfb                    1.7.7                 18 Apr 2015   http://directfb.org/downloads/Core/DirectFB-1.7/DirectFB-1.7.7.tar.gz
direvent                    5.1                   24 Jul 2016   http://ftp.gnu.org/gnu/direvent/direvent-5.1.tar.gz
discover                    5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/discover-5.12.4.tar.xz
disko                       1.8.0                 May 2014      http://www.diskohq.com/repository/sources/disko_1.8.0.tar.gz
distcc                      3.1                   01 Jun 2014   http://distcc.googlecode.com/files/distcc-3.1.tar.bz2
dit                         0.4                   24 Nov 2016   https://hisham.hm/dit/releases/0.4/dit-0.4.tar.gz
diva                        0.0.2                 May 2014      http://files.diva-project.org/releases/diva-0.0.2.tar.gz
django                      1.10.5                22 Feb 2017   https://www.djangoproject.com/download/1.10.5/tarball/
djview                      4.10.6                25 Dec 2017   http://downloads.sourceforge.net/djvu/djview-4.10.6.tar.gz
djvulibre                   3.5.27                19 Jan 2016   http://sourceforge.net/projects/djvu/files/DjVuLibre/3.5.27/djvulibre-3.5.27.tar.gz
dkms                        2.2.0.3               May 2014      http://linux.dell.com/dkms/permalink/dkms-2.2.0.3.tar.gz
dmidecode                   3.0                   25 Oct 2016   http://download.savannah.gnu.org/releases/dmidecode/dmidecode-3.0.tar.xz
dmxproto                    2.3.1                 May 2014      https://xorg.freedesktop.org/releases/individual/proto/dmxproto-2.3.1.tar.bz2
dnsmasq                     2.78                  03 Oct 2017   http://www.thekelleys.org.uk/dnsmasq/dnsmasq-2.78.tar.xz
dnspython                   1.15.0                04 Nov 2017   http://www.dnspython.org/kits/1.15.0/dnspython-1.15.0.tar.gz
docbook                     4.5                   01 Oct 2013   http://www.docbook.org/sgml/4.5/docbook-4.5.zip
docbook2x                   0.8.8                 01 May 2014   http://downloads.sourceforge.net/docbook2x/docbook2X-0.8.8.tar.gz
docbookutils                0.6.14                27 Oct 2015   http://sources-redhat.mirrors.redwire.net/docbook-tools/new-trials/SOURCES/docbook-utils-0.6.14.tar.gz
docbookxsl                  1.79.2                30 Dec 2017   https://github.com/docbook/xslt10-stylesheets/releases/download/release/1.79.2/docbook-xsl-1.79.2.tar.bz2
docutils                    0.14                  21 Nov 2017   https://pypi.python.org/packages/84/f4/5771e41fdf52aabebbadecc9381d11dea0fa34e4759b4071244fa094804c/docutils-0.14.tar.gz
docx2txt                    1.4                   24 Oct 2016   http://downloads.sourceforge.net/docx2txt/docx2txt-1.4.tgz
dolphin                     18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/dolphin-18.04.0.tar.xz
dolphinplugins              4.14.3                29 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/dolphin-plugins-4.14.3.tar.xz
domainname                  0.5.20180417          01 May 2018   https://rubygems.org/downloads/domain_name-0.5.20180417.gem
dosbox                      14.09.2017            12 Sep 2017   http://downloads.sourceforge.net/dosbox/dosbox-0.74.tar.gz
dosfstools                  3.0.12                Jan 2013      http://fossies.org/linux/misc/dosfstools-3.0.12.tar.gz
dotconf                     1.0.13                Nov 2013      http://www.azzit.de/dotconf/download/v1.0/dotconf-1.0.13.tar.gz
dovecot                     2.3.1                 28 Mar 2018   http://www.dovecot.org/releases/2.3/dovecot-2.3.1.tar.gz
doxygen                     1.8.14                25 Dec 2017   ftp://ftp.stack.nl/pub/users/dimitri/doxygen-1.8.14.src.tar.gz
dpkg                        1.18.22               25 Feb 2017   http://ftp.debian.org/debian/pool/main/d/dpkg/dpkg_1.18.22.tar.xz
dragon                      4.14.3                03 Apr 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/dragon-4.14.3.tar.xz
dragonhunt                  3.56                  01 Jun 2014   http://emhsoft.com/dh/Dragon_Hunt-3.56.tar.gz
dri2proto                   2.8                   01 Jan 2014   http://xorg.freedesktop.org/releases/individual/proto/dri2proto-2.8.tar.bz2
dri3proto                   1.0                   01 Nov 2013   http://xorg.freedesktop.org/releases/individual/proto/dri3proto-1.0.tar.bz2
drkonqi                     5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/drkonqi-5.12.4.tar.xz
drupal                      7.38                  06 Aug 2015   http://ftp.drupal.org/files/projects/drupal-7.38.tar.gz
dssi                        1.1.1                 Jun 2014      https://sourceforge.net/projects/dssi/files/dssi/1.1.1/dssi-1.1.1.tar.gz
duma                        2.4.27                Jun 2014      http://duma.sourceforge.net/
dumb                        0.9.3                 May 2014      http://switch.dl.sourceforge.net/sourceforge/dumb/dumb-0.9.3.tar.gz
dunelegacy                  0.96.4                21 Aug 2017   https://sourceforge.net/projects/dunelegacy/files/dunelegacy/0.96.4/dunelegacy-0.96.4-src.tar.bz2
dvd+rwtools                 7.1                   May 2014      http://fy.chalmers.se/~appro/linux/DVD+RW/tools/dvd+rw-tools-7.1.tar.gz
dvdauthor                   0.7.1                 Sep 2014      https://sourceforge.net/projects/dvdauthor/files/dvdauthor/0.7.1/dvdauthor-0.7.1.tar.gz
dvdrip                      0.98.11               01 May 2014   http://www.exit1.org/dvdrip/dist/dvdrip-0.98.11.tar.gz
dvdripomatic                0.94                  May 2014      http://surfnet.dl.sourceforge.net/sourceforge/dvdripomatic/DVDRipOMatic-0.94.tar.bz2
dvdrtools                   0.3.1                 May 2014      http://www.arklinux.org/download/dvdrtools-0.3.1.tar.bz2
dvdslideshow                0.7.5                 May 2014      http://dvd-slideshow.sourceforge.net/
dvgrab                      1.7                   01 May 2014   https://github.com/ddennedy/dvgrab
dwm                         6.1                   25 Dec 2015   http://dl.suckless.org/dwm/dwm-6.1.tar.gz
dxpy                        0.172.0               06 Dec 2015   https://pypi.python.org/packages/source/d/dxpy/dxpy-0.172.0.tar.gz
dzen2                       0.4.5                 28 Jul 2016   https://github.com/robm/dzen2-0.4.5.tar.xz
e16                         1.0.17                16 Aug 2015   http://sourceforge.net/projects/enlightenment/files/e16/1.0.17/e16-1.0.17.tar.gz
e2fsprogs                   1.44.1                25 Mar 2018   http://downloads.sourceforge.net/e2fsprogs/e2fsprogs-1.44.1.tar.gz
easytag                     2.4.2                 22 Feb 2016   http://ftp.gnome.org/pub/GNOME/sources/easytag/2.4/easytag-2.4.2.tar.xz
ecasound                    2.9.0                 Jun 2014      http://ecasound.seul.org/download/ecasound-2.9.0.tar.gz
ecawave                     0.6.1                 Jun 2014      http://ecasound.seul.org/download/ecawave-0.6.1.tar.gz
ecell                       3.2.2                 Nov 2012      http://sourceforge.net/projects/ecell/files/E-Cell%203.2/3.2.2/ecell-3.2.2.tar.bz2
echievements                2                     Dec 2012      http://download.enlightenment.fr/releases/echievements-2.tar.bz2
ecore                       1.7.10                Jan 2014      http://download.enlightenment.org/releases/ecore-1.7.10.tar.gz
ed                          1.14.2                26 Jul 2017   http://ftp.gnu.org/pub/gnu/ed/ed-1.14.2.tar.lz
edb                         1.0.5.042             Jun 2014      http://download.enlightenment.org/snapshots/2008-01-25/edb-1.0.5.042.tar.bz2
edbus                       1.7.10                Jan 2014      http://download.enlightenment.org/releases/e_dbus-1.7.10.tar.gz
ede                         2.1                   17 Sep 2014   https://sourceforge.net/projects/ede/files/ede/2.1/ede-2.1.tar.gz
edelib                      2.1                   24 Feb 2017   http://sourceforge.net/projects/ede/files/edelib/2.1/edelib-2.1.tar.gz
editres                     1.0.4                 Jun 2014      http://xorg.freedesktop.org/releases/individual/app/editres-1.0.4.tar.bz2
edje                        1.7.10                Jan 2014      http://download.enlightenment.org/releases/edje-1.7.10.tar.gz
eel                         2.26.0                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/eel/2.26/eel-2.26.0.tar.bz2
eet                         1.7.10                Jan 2014      http://download.enlightenment.org/releases/eet-1.7.10.tar.gz
eeze                        1.7.10                Jan 2014      http://download.enlightenment.org/releases/eeze-1.7.10.tar.gz
efl                         1.20.5                02 Nov 2017   https://download.enlightenment.org/rel/libs/efl/efl-1.20.5.tar.xz
efltk                       2.0.7                 Jun 2014      http://ovh.dl.sourceforge.net/sourceforge/ede/efltk-2.0.7.tar.bz2
efreet                      1.7.10                Jan 2014      http://download.enlightenment.org/releases/efreet-1.7.10.tar.bz2
eggdbus                     0.6                   Nov 2012      http://cgit.freedesktop.org/~david/eggdbus/snapshot/eggdbus-0.6.tar.bz2
eigen                       3.2.10                06 Dec 2017   http://bitbucket.org/eigen/eigen/get/3.2.10.tar.bz2
eina                        1.7.10                Jan 2014      https://download.enlightenment.org/releases/eina-1.7.10.tar.gz
eio                         1.7.10                Jan 2014      http://download.enlightenment.org/releases/eio-1.7.10.tar.gz
eject                       2.1.5                 Nov 2012      http://ca.geocities.com/jefftranter@rogers.com/eject-2.1.5.tar.gz
ekiga                       4.0.1                 Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/ekiga/4.0/ekiga-4.0.1.tar.xz
eldbus                      1.7.9                 01 Dec 2013   http://download.enlightenment.org/releases/eldbus-1.7.9.tar.bz2
elementary                  1.7.10                28 Jan 2016   https://download.enlightenment.org/releases/elementary-1.7.10.tar.gz
elfrc                       0.7                   Jun 2014      http://ktown.kde.org/~frerich/elfrc.html
elfutils                    0.170                 05 Aug 2017   https://sourceware.org/elfutils/ftp/0.170/elfutils-0.170.tar.bz2
elinks                      0.11.7                28 Aug 2016   http://elinks.or.cz/download/elinks-0.11.7.tar.bz2
elixir                      25.09.2017            25 Sep 2017   https://github.com/elixir-lang/elixir/archive/v1.5.1.tar.gz
elph                        1.0.1                 29 Jun 2017   ftp://ftp.cbcb.umd.edu/pub/software/elph/ELPH-1.0.1.tar.gz
emacs                       25.3                  12 Sep 2017   ftp://ftp.gnu.org/gnu/emacs/emacs-25.3.tar.xz
embryo                      1.7.10                Jan 2014      http://download.enlightenment.org/releases/embryo-1.7.10.tar.gz
emech                       3.0.99p3              Jun 2014      http://www.energymech.net/files/emech-3.0.99p3.tar.gz
emelfm                      0.9.2                 Jun 2014      http://emelfm.sourceforge.net/emelfm-0.9.2.tar.gz
emotion                     1.7.10                Jan 2014      http://download.enlightenment.org/releases/emotion-1.7.10.tar.gz
emotiongenericplayers       1.15.0                04 Aug 2015   http://download.enlightenment.org/rel/libs/emotion_generic_players/emotion_generic_players-1.15.0.tar.gz
empathy                     3.25.90               17 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/empathy/3.25/empathy-3.25.90.tar.xz
enca                        1.9                   Jun 2014      http://trific.ath.cx/Ftp//enca/enca-1.9.tar.bz2
enchant                     2.2.1                 05 Jan 2018   https://github.com/AbiWord/enchant/releases/download/v2.2.1/enchant-2.2.1.tar.gz
encodings                   1.0.4                 16 Jan 2016   http://xorg.freedesktop.org/releases/individual/font/encodings-1.0.4.tar.bz2
engrampa                    1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/engrampa-1.20.0.tar.xz
enigma                      1.01                  Jun 2014      http://www.nongnu.org/enigma/
enlightenment               0.22.3                23 Mar 2018   http://download.enlightenment.org/rel/apps/enlightenment/enlightenment-0.22.3.tar.xz
enscript                    1.6.6                 01 Sep 2012   http://ftp.gnu.org/gnu/enscript/enscript-1.6.6.tar.gz
enter                       0.0.9                 13 Feb 2016   https://sourceforge.net/projects/enter/files/enter/0.0.9/enter-0.0.9.tar.gz
entrance                    0.9.0.013             01 Jun 2014   http://download.enlightenment.org/snapshots/2007-08-26/entrance-0.9.0.013.tar.gz
enventor                    0.3.2                 01 Sep 2014   http://download.enlightenment.org/rel/apps/enventor/enventor-0.3.2.tar.gz
eog                         3.27.3                09 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/eog/3.27/eog-3.27.3.tar.xz
eogplugins                  3.26.2                19 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/eog-plugins/3.26/eog-plugins-3.26.2.tar.xz
eom                         1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/eom-1.20.0.tar.xz
epdfview                    0.1.8                 01 Jun 2014   http://trac.emma-soft.com/epdfview/chrome/site/releases/epdfview-0.1.8.tar.bz2
epeg                        0.9.1.042             Nov 2012      http://download.enlightenment.org/snapshots/2008-01-25/epeg-0.9.1.042.tar.bz2
epiphany                    3.28.1                13 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/epiphany/3.28/epiphany-3.28.1.tar.xz
epkg                        2.3.9                 Jun 2014      ftp://ftp.encap.org/pub/encap/epkg/epkg-2.3.9.tar.gz
epm                         4.1                   Jun 2014      http://www.nu6.org/_/mirror/ftp.easysw.com/pub/epm/4.1/epm-4.1-source.tar.bz2
eps                         1.5                   Jun 2014      http://www.inter7.com/eps/eps-1.5.tar.gz
epsilon                     0.3.0.012             Nov 2012      http://download.enlightenment.org/snapshots/2008-01-25/epsilon-0.3.0.012.tar.bz2
erlang                      20.1                  29 Sep 2017   http://erlang.org/download/otp_src_20.1.tar.gz
error                       0.17025               11 Aug 2017   http://www.cpan.org/authors/id/S/SH/SHLOMIF/Error-0.17025.tar.gz
erubis                      2.7.0                 03 Dec 2017   https://rubygems.org/downloads/erubis-2.7.0.gem
esdl                        1.3.1                 02 Aug 2017   https://sourceforge.net/projects/esdl/files/esdl/esdl-1.3.1/esdl-1.3.1.src.tgz
eselect                     1.4.9                 18 Jul 2017   https://gitweb.gentoo.org/proj/eselect.git/snapshot/eselect-1.4.9.tar.bz2
esmtp                       1.2                   Jun 2014      http://sourceforge.net/projects/esmtp/files/esmtp/1.2/esmtp-1.2.tar.bz2
esound                      0.2.38                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/esound/0.2/esound-0.2.38.tar.bz2
espeak                      1.46.02               Jun 2014      http://sourceforge.net/projects/espeak/files/espeak/espeak-1.46/espeak-1.46.02-source.zip
eterm                       0.9.6                 Jul 2013      http://www.eterm.org/download/Eterm-0.9.6.tar.gz
ethtool                     2.6.36                01 Jun 2014   https://sourceforge.net/projects/gkernel/files/ethtool/2.6.36/ethtool-2.6.36.tar.gz
ethumb                      1.7.10                Jan 2014      http://download.enlightenment.org/releases/ethumb-1.7.10.tar.gz
etk                         0.1.0.042             01 Nov 2012   http://download.enlightenment.org/snapshots/2008-01-25/etk-0.1.0.042.tar.bz2
eudev                       3.2.5                 28 Nov 2017   http://dev.gentoo.org/~blueness/eudev/eudev-3.2.5.tar.gz
evas                        1.7.10                Jan 2014      http://download.enlightenment.org/releases/evas-1.7.10.tar.gz
evasgenericloaders          1.13.2                16 Apr 2015   https://download.enlightenment.org/rel/libs/evas_generic_loaders/evas_generic_loaders-1.13.2.tar.xz
eve                         0.3.0                 Dec 2012      http://download.enlightenment.org/snapshots/2010-12-03/eve-0.3.0.tar.bz2
event                       1.03                  01 Jan 2013   Event-1.03.tar.xz
eventviews                  18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/eventviews-18.04.0.tar.xz
evieext                     1.1.1                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/proto/evieext-1.1.1.tar.bz2
evil                        1.7.10                01 Jan 2014   http://download.enlightenment.org/releases/evil-1.7.10.tar.gz
evilvte                     0.5.2~pre1            01 Jun 2013   http://www.calno.com/evilvte/evilvte-0.5.2~pre1.tar.xz
evilwm                      1.1.1                 24 Feb 2017   http://www.6809.org.uk/evilwm/evilwm-1.1.1.tar.gz
evince                      3.28.2                13 Apr 2018   http://ftp.gnome.org/pub/GNOME/sources/evince/3.28/evince-3.28.2.tar.xz
evolution                   3.26.6                05 Mar 2018   ftp://ftp.gnome.org/pub/gnome/sources/evolution/3.26/evolution-3.26.6.tar.xz
evolutiondataserver         3.26.3                11 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/evolution-data-server/3.26/evolution-data-server-3.26.3.tar.xz
evolutionews                3.26.3                11 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/evolution-ews/3.26/evolution-ews-3.26.3.tar.xz
evolutionmapi               3.26.3                11 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/evolution-mapi/3.26/evolution-mapi-3.26.3.tar.xz
ewl                         0.5.2.042             01 Dec 2012   http://download.enlightenment.org/snapshots/2008-01-25/ewl-0.5.2.042.tar.bz2
exactimage                  1.0.1                 04 Jan 2018   http://dl.exactcode.de/oss/exact-image/exact-image-1.0.1.tar.bz2
exempi                      2.4.3                 07 Aug 2017   https://libopenraw.freedesktop.org/download/exempi-2.4.3.tar.gz
exim                        4.91                  16 Apr 2018   ftp://ftp.exim.org/pub/exim/exim4/exim-4.91.tar.bz2
exiv2                       0.26                  01 Aug 2017   http://www.exiv2.org/exiv2-0.26.tar.gz
exo                         0.12.0                16 Feb 2018   http://archive.xfce.org/src/xfce/exo/0.12/exo-0.12.0.tar.bz2
expat                       2.2.5                 01 Nov 2017   https://sourceforge.net/projects/expat/files/expat/2.2.5/expat-2.2.5.tar.bz2
expect                      5.45.4                18 Feb 2018   https://sourceforge.net/projects/expect/files/Expect/5.45.4/expect5.45.4.tar.gz
expedite                    1.7.10                22 Dec 2015   http://download.enlightenment.org/releases/expedite-1.7.10.tar.bz2
explore                     11                    01 Jun 2014   http://mesh.dl.sourceforge.net/sourceforge/openexplore/explore_v11_src.zip
extracmakemodules           5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/extra-cmake-modules-5.45.0.tar.xz
extutilsdepends             0.405                 22 Feb 2016   http://search.cpan.org/CPAN/authors/id/X/XA/XAOC/ExtUtils-Depends-0.405.tar.gz
extutilshelpers             0.026                 15 Sep 2016   http://search.cpan.org/CPAN/authors/id/L/LE/LEONT/ExtUtils-Helpers-0.026.tar.gz
extutilspkgconfig           1.16                  30 Aug 2017   http://search.cpan.org/CPAN/authors/id/X/XA/XAOC/ExtUtils-PkgConfig-1.16.tar.gz
exult                       1.2                   Jun 2014      http://exult.sourceforge.net/
faac                        1.29.9                11 Nov 2017   https://downloads.sourceforge.net/faac/faac-1.29.9.tar.gz
faad2                       2.8.8                 22 Dec 2017   https://sourceforge.net/projects/faac/files/faad2-src/faad2-2.8.0/faad2-2.8.8.tar.gz
facter                      1.5.4rc1              May 2013      http://reductivelabs.com/downloads/facter/facter-1.5.4rc1.tgz
factorygirl                 4.9.0                 06 Jan 2018   https://rubygems.org/downloads/factory_girl-4.9.0.gem
fam                         2.7.0                 01 Jun 2014   http://gd.tuwien.ac.at/opsys/linux/gentoo/distfiles/fam-2.7.0.tar.gz
faraday                     0.15.0                01 May 2018   https://rubygems.org/downloads/faraday-0.15.0.gem
farstream                   0.2.7                 16 Sep 2015   http://freedesktop.org/software/farstream/releases/farstream/farstream-0.2.7.tar.gz
fasta                       36.3.8e               10 Jul 2017   http://faculty.virginia.edu/wrpearson/fasta/fasta36/fasta-36.3.8e.tar.gz
fbdesk                      1.4.1                 01 Jun 2014   http://fluxbox.sourceforge.net/download/fbdesk-1.4.1.tar.gz
fbida                       2.09                  Jun 2014      http://www.kraxel.org/releases/fbida/fbida-2.09.tar.gz
fcgi                        2.4.0                 Jan 2014      http://www.fastcgi.com/dist/fcgi-2.4.0.tar.gz
fdkaac                      0.1.6                 16 Mar 2018   http://downloads.sourceforge.net/opencore-amr/fdk-aac-0.1.6.tar.gz
feh                         2.26                  21 Apr 2018   http://feh.finalrewind.org/feh-2.26.tar.bz2
ferret                      0.11.8.7              09 Jan 2018   https://rubygems.org/downloads/ferret-0.11.8.7.gem
fetchmail                   6.3.26                Mar 2013      http://download.berlios.de/fetchmail/fetchmail-6.3.26.tar.xz
ffe                         0.3.7                 21 Aug 2017   https://sourceforge.net/projects/ff-extractor/files/ff-extractor/0.3.7/ffe-0.3.7.tar.gz
ffmpeg                      4.0                   20 Apr 2018   http://ffmpeg.org/releases/ffmpeg-4.0.tar.xz
ffmpeg2theora               0.30                  30 Sep 2017   http://v2v.cc/~j/ffmpeg2theora/downloads/ffmpeg2theora-0.30.tar.bz2
ffmpegphp                   0.5.0                 01 Jun 2014   http://ffmpeg-php.sourceforge.net/
ffmpegthumbs                18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ffmpegthumbs-18.04.0.tar.xz
ffpocket                    0.6.5                 Jun 2014      http://members.hellug.gr/djart/ffpocket/ffpocket-0.6.5.tar.bz2
fftw                        3.3.7                 03 Dec 2017   http://www.fftw.org/fftw-3.3.7.tar.gz
fiddle                      1.0.0                 05 Dec 2017   https://rubygems.org/downloads/fiddle-1.0.0.gem
fife                        0.3.4                 Mar 2013      http://sourceforge.net/projects/fife/files/active/src/fife_0.3.4.tar.gz
fifoembed                   2.1.1                 01 Jun 2014   https://sourceforge.net/projects/fifoembed/files/fifoembed/2.1.1/fifoembed-2.1.1.tar.bz2
figlet                      2.2.4                 01 Jun 2014   ftp://ftp.figlet.org/pub/figlet/program/unix/figlet-2.2.4.tar.gz
file                        5.33                  16 Apr 2018   ftp://ftp.astron.com/pub/file/file-5.33.tar.gz
filelight                   18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/filelight-18.04.0.tar.xz
fileroller                  3.26.2                01 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/file-roller/3.26/file-roller-3.26.2.tar.xz
fileslurper                 0.010                 26 Dec 2017   http://search.cpan.org/CPAN/authors/id/L/LE/LEONT/File-Slurper-0.010.tar.gz
filewhich                   1.22                  11 Sep 2017   http://search.cpan.org/CPAN/authors/id/P/PL/PLICEASE/File-Which-1.22.tar.gz
filezilla                   3.5.2                 Jun 2014      http://filezilla-project.org/download.php?type=client
findlib                     1.7.1                 11 Mar 2017   http://download.camlcity.org/download/findlib-1.7.1.tar.gz
findutils                   4.6.0                 29 Dec 2015   ftp://ftp.gnu.org/gnu/findutils/findutils-4.6.0.tar.gz
firebird                    3.0.1                 Oct 2016      https://sourceforge.net/projects/firebird/files/firebird/3.0.1-Release/Firebird-3.0.1.32609-0.tar.bz2
firefox                     55.0                  12 Aug 2017   https://ftp.mozilla.org/pub/mozilla.org/firefox/releases/55.0/source/firefox-55.0.source.tar.xz
firejail                    0.9.42                09 Sep 2016   https://sourceforge.net/projects/firejail/files/firejail/firejail-0.9.42.tar.xz
fische                      3.2.2                 Nov 2012      http://26elf.at/files/fische-3.2.2.tar.gz
fish                        2.7.1                 08 Jan 2018   https://github.com/fish-shell/fish-shell/releases/download/2.7.1/fish-2.7.1.tar.gz
fitd                        0.1                   Jun 2014      http://sourceforge.net/project/showfiles.php?group_id=104884
fiveormore                  3.26.0                12 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/five-or-more/3.26/five-or-more-3.26.0.tar.xz
fixesproto                  5.0                   Jun 2014      http://xorg.freedesktop.org/releases/individual/proto/fixesproto-5.0.tar.bz2
flac                        1.3.2                 02 Jan 2017   http://sourceforge.net/projects/flac/files/flac-src/flac-1.3.2.tar.xz
flagpoll                    0.3.0                 01 Jun 2014   https://crate.io/packages/flagpoll/0.3.0/
flam3                       3.0.1                 Aug 2014      http://flam3.googlecode.com/files/flam3-3.0.1.zip
flask                       0.9                   Jan 2013      http://pypi.python.org/packages/source/F/Flask/Flask-0.9.tar.gz
flatzebra                   0.1.1                 02 Nov 2015   http://perso.b2b2c.ca/sarrazip/dev/flatzebra-0.1.6.tar.gz
fldigi                      3.23.12               20 Jul 2016   https://sourceforge.net/projects/fldigi/files/fldigi/fldigi-3.23.12.tar.gz
flex                        2.6.4                 07 May 2017   https://github.com/westes/flex/releases/download/v2.6.4/flex-2.6.4.tar.gz
flimp                       0.0.3                 25 Apr 2015   http://www.ecademix.com/JohannesHofmann/flimp-0.0.11.tar.gz
florence                    0.6.3                 25 Apr 2015   http://sourceforge.net/projects/florence/files/florence/0.6.3/florence-0.6.3.tar.bz2
fltk                        1.3.4-1               18 Mar 2017   http://www.fltk.org/software.php?VERSION=1.3.4&FILE=fltk/1.3.4/fltk-1.3.4-1-source.tar.gz
fluidsynth                  1.1.6                 24 Oct 2015   http://sourceforge.net/projects/fluidsynth/files/fluidsynth-1.1.6/fluidsynth-1.1.6.tar.bz2
fluxbox                     1.3.7                 17 May 2015   http://sourceforge.net/projects/fluxbox/files/fluxbox/1.3.7/fluxbox-1.3.7.tar.xz
folks                       0.11.4                03 Jul 2017   http://ftp.gnome.org/pub/gnome/sources/folks/0.11/folks-0.11.4.tar.xz
fontadobe100dpi             1.0.0                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/font/font-adobe-100dpi-1.0.0.tar.bz2
fontadobe75dpi              1.0.0                 Jun 2014      http://xorg.freedesktop.org/releases/individual/font/font-adobe-75dpi-1.0.0.tar.bz2
fontadobeutopia100dpi       100                   Jun 2014      http://xorg.freedesktop.org/releases/individual/font/font-adobe-utopia-100dpi-1.0.1.tar.bz2
fontadobeutopia75dpi        1.0.1                 Jun 2014      http://xorg.freedesktop.org/releases/individual/font/font-adobe-utopia-75dpi-1.0.1.tar.bz2
fontadobeutopiatype1        1.0.4                 May 2014      http://xorg.freedesktop.org/releases/individual/font/font-adobe-utopia-type1-1.0.4.tar.gz
fontalias                   1.0.1                 Jun 2014      http://xorg.freedesktop.org/releases/individual/font/font-alias-1.0.1.tar.bz2
fontbh75dpi                 1.0.0                 Jan 2013      http://xorg.freedesktop.org/releases/individual/font/font-bh-75dpi-1.0.0.tar.bz2
fontbitstream100dpi         1.0.0                 Jun 2014      http://xorg.freedesktop.org/releases/individual/font/font-bitstream-100dpi-1.0.0.tar.bz2
fontbitstream75dpi          1.0.3                 Jun 2014      http://xorg.freedesktop.org/releases/individual/font/font-bitstream-75dpi-1.0.3.tar.bz2
fontcacheproto              0.1.2                 01 May 2014   http://xorg.freedesktop.org/releases/individual/proto/fontcacheproto-0.1.2.tar.bz2
fontconfig                  2.13.0                08 Mar 2018   https://www.freedesktop.org/software/fontconfig/release/fontconfig-2.13.0.tar.bz2
fontforge                   29.05.2011            May 2014      https://sourceforge.net/projects/fontforge/files/fontforge-source/fontforge_full-20110222.tar.bz2
fontopia                    1.7                   21 Aug 2016   http://ftp.gnu.org/pub/gnu/fontopia/fontopia-1.7.tar.gz
fontsonymisc                1.0.3                 Aug 2013      http://xorg.freedesktop.org/releases/individual/font/font-sony-misc-1.0.3.tar.bz2
fontsproto                  2.1.3                 Apr 2014      http://xorg.freedesktop.org/releases/individual/proto/fontsproto-2.1.3.tar.bz2
fonttosfnt                  1.0.4                 Aug 2013      http://xorg.freedesktop.org/releases/individual/app/fonttosfnt-1.0.4.tar.bz2
fontutil                    1.3.1                 26 Jul 2015   http://xorg.freedesktop.org/releases/individual/font/font-util-1.3.1.tar.gz
fontxfree86type1            1.0.4                 May 2014      http://xorg.freedesktop.org/releases/individual/font/font-xfree86-type1-1.0.4.tar.bz2
formatador                  0.2.5                 25 Dec 2017   https://rubygems.org/downloads/formatador-0.2.5.gem
fosfat                      0.2.3                 May 2014      http://download.gna.org/fosfat/fosfat_0.2.3.orig.tar.gz
fourinarow                  3.22.2                09 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/four-in-a-row/3.22/four-in-a-row-3.22.2.tar.xz
fox                         1.7.50                03 Mar 2015   ftp://ftp.fox-toolkit.org/pub/fox-1.7.50.tar.gz
fpdf                        1.53                  01 Jun 2014   http://www.fpdf.de/downloads/fpdf17.tgz
fpm                         1.9.3                 09 Jan 2018   https://rubygems.org/downloads/fpm-1.9.3.gem
fprintd                     0.6.0                 01 Mar 2015   http://people.freedesktop.org/~hadess/fprintd-0.6.0.tar.xz
frameworkintegration        5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/frameworkintegration-5.45.0.tar.xz
freealut                    1.1.0                 01 Jun 2014   http://www.openal.org/openal_webstf/downloads/freealut-1.1.0.tar.gz
freebasic                   0.23.0                Jun 2014      http://sourceforge.net/projects/fbc/files/Source%20Code/FreeBASIC-0.23.0-source.tar.gz
freeciv                     2.5.4                 21 Jul 2016   http://prdownloads.sourceforge.net/freeciv/freeciv-2.5.4.tar.bz2
freecol                     0.7.1                 Dec 2012      http://www.freecol.org/news/freecol-0.10.5-released.html
freecycle                   0.6.1.1alpha          25 Dec 2015   http://download.savannah.gnu.org/releases/freecycle/freecycle-0.6.1.1alpha.tar.bz2
freeglut                    2.8.0                 Nov 2012      http://sourceforge.net/projects/freeglut/files/freeglut/2.8.0/freeglut-2.8.0.tar.gz
freeimage                   3.15.4                Nov 2013      http://sourceforge.net/projects/freeimage/files/Source%20Distribution/3.15.4/FreeImage3154.zip
freeipmi                    1.6.1                 06 Feb 2018   https://ftp.gnu.org/pub/gnu/freeipmi/freeipmi-1.6.1.tar.gz
freepop                     0.6.0                 Dec 2012      http://sourceforge.net/project/showfiles.php?group_id=43507&package_id=35844&release_id=306784
freesci                     0.3.5                 01 Jun 2014   http://freesci.linuxgames.com/
freesteam                   2.0                   01 Jun 2014   http://sourceforge.net/projects/freesteam/files/freesteam/2.0/freesteam-2.0.tar.bz2
freesynd                    0.7.5                 14 Apr 2017   https://sourceforge.net/projects/freesynd/files/freesynd/freesynd-0.7.5/freesynd-0.7.5.tar.gz
freetype                    2.9                   08 Jan 2018   https://downloads.sourceforge.net/freetype/freetype-2.9.tar.bz2
freevo                      1.9.2b2               11 Dec 2017   https://sourceforge.net/projects/freevo/files/Freevo%20releases/1.9.2b2/freevo-1.9.2b2.tar.bz2
freewrl                     1.18.4                01 Jun 2014   http://ovh.dl.sourceforge.net/sourceforge/freewrl/freewrl-1.18.4.tar.gz
fribidi                     1.0.2                 27 Mar 2018   https://github.com/fribidi/fribidi/releases/download/v1.0.2/fribidi-1.0.2.tar.bz2
friction                    0.1                   Jun 2014      http://remar.se/games/files/
frogr                       1.4                   28 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/frogr/1.4/frogr-1.4.tar.xz
frozenbubble                2.2.0                 01 Jan 2013   http://www.frozen-bubble.org/data/frozen-bubble-2.2.0.tar.bz2
fslsfonts                   1.0.4                 Jun 2014      http://xorg.freedesktop.org/releases/individual/app/fslsfonts-1.0.4.tar.bz2
fspot                       0.6.2                 01 Jun 2014   http://ftp.gnome.org/Public/GNOME/sources/f-spot/0.6/f-spot-0.6.2.tar.bz2
fstobdf                     1.0.5                 Jun 2014      http://xorg.freedesktop.org/releases/individual/app/fstobdf-1.0.5.tar.bz2
ftwin                       0.4.0                 Jun 2014      http://jok.is-a-geek.net/ftwin.php
fuse                        3.2.2                 08 Apr 2018   https://github.com/libfuse/libfuse/releases/download/fuse-3.2.2/fuse-3.2.2.tar.xz
fuseiso                     20070708              29 Oct 2014   http://sourceforge.net/projects/fuseiso/files/fuseiso/20070708/fuseiso-20070708.tar.bz2
fvwm                        2.7.0                 Jun 2014      ftp://ftp.fvwm.org/pub/fvwm/version-2/fvwm-2.7.0.tar.gz
fxruby                      1.6.39                09 Jan 2018   https://rubygems.org/downloads/fxruby-1.6.39.gem
g3d                         10.00                 01 May 2014   https://sourceforge.net/projects/g3d/files/g3d-cpp/10.00/G3D-10.00-source.zip
gaa                         1.6.6                 May 2014      http://sourceforge.net/projects/gaa/files/gaa/gaa-1.6.6/gaa-1.6.6.tar.gz
gabedit                     2.1.8                 Jun 2014      http://dfn.dl.sourceforge.net/sourceforge/gabedit/Gabedit218Src.tar.gz
gail                        1.22.3                01 May 2014   http://ftp.gnome.org/pub/GNOME/sources/gail/1.22/gail-1.22.3.tar.bz2
gal                         2.5.3                 01 May 2014   http://ftp.acc.umu.se/pub/GNOME/sources/gal/2.5/gal-2.5.3.tar.bz2
galculator                  2.1.4                 02 Aug 2017   http://galculator.mnim.org/downloads/galculator-2.1.4.tar.bz2
gallipoli                   0.7.0                 01 Dec 2012   http://www.um.com.au/gallipoli/
gama                        1.20                  16 Nov 2017   http://ftp.gnu.org/pub/gnu/gama/gama-1.20.tar.gz
gambas3                     3.10.0                15 Jan 2018   https://sourceforge.net/projects/gambas/files/gambas3/gambas3-3.10.0.tar.bz2
gamgi                       0.13.4                Jun 2014      http://www.gamgi.org/changelogs/changelogs13.html
gamin                       0.1.10                Jan 2013      http://www.gnome.org/~veillard/gamin/sources/gamin-0.1.10.tar.gz
garcon                      0.6.1                 30 Aug 2017   http://archive.xfce.org/src/xfce/garcon/0.6/garcon-0.6.1.tar.bz2
garnome                     2.19.3                Jun 2014      http://ftp.acc.umu.se/pub/GNOME/sources/garnome
gaupol                      0.28.2                29 Aug 2015   http://download.gna.org/gaupol/0.28/gaupol-0.28.2.tar.xz
gav                         0.9.0                 01 Dec 2012   https://sourceforge.net/projects/gav/files/gav/0.9.0/gav-0.9.0.tar.gz
gavl                        1.2.0                 01 Jun 2014   http://sourceforge.net/projects/gmerlin/files/gavl/1.2.0/gavl-1.2.0.tar.gz
gawk                        4.2.1                 26 Feb 2018   ftp://ftp.gnu.org/gnu/gawk/gawk-4.2.1.tar.xz
gbench                      2.6.0                 01 Oct 2012   ftp://ftp.ncbi.nlm.nih.gov/toolbox/gbench/ver-2.6.0/gbench-src-2.6.0.tgz
gc                          7.6.2                 03 Jan 2018   http://www.hboehm.info/gc/gc_source/gc-7.6.2.tar.gz
gcab                        1.1                   10 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gcab/1.1/gcab-1.1.tar.xz
gcal                        3.6.2                 Jun 2014      http://ftpmirror.gnu.org/gcal/gcal-3.6.2.tar.xz
gcalctool                   6.6.2                 24 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/gcalctool/6.6/gcalctool-6.6.2.tar.xz
gcc                         7.3.0                 25 Jan 2018   http://ftp.gnu.org/gnu/gcc/gcc-7.3.0/gcc-7.3.0.tar.xz
gccmakedep                  1.0.3                 01 May 2014   http://xorg.freedesktop.org/releases/individual/util/gccmakedep-1.0.3.tar.bz2
gcdemu                      1.2.0                 01 Jun 2014   http://sourceforge.net/projects/cdemu/files/CDemu%20clients/gcdemu-1.2.0/gcdemu-1.2.0.tar.bz2
gchart                      1.0.0                 01 Dec 2017   https://rubygems.org/downloads/gchart-1.0.0.gem
gcide                       0.52                  31 Jan 2018   https://ftp.gnu.org/pub/gnu/gcide/gcide-0.52.tar.xz
gconf                       3.2.6                 16 Sep 2017   http://ftp.acc.umu.se/pub/GNOME/sources/GConf/3.2/GConf-3.2.6.tar.xz
gconfcleaner                0.0.3                 01 Jun 2014   http://code.google.com/p/gconf-cleaner/downloads/list
gconfeditor                 3.0.1                 20 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/gconf-editor/3.0/gconf-editor-3.0.1.tar.xz
gconfmm                     2.28.3                20 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/gconfmm/2.28/gconfmm-2.28.3.tar.xz
gcr                         3.27.4                08 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gcr/3.27/gcr-3.27.4.tar.xz
gdado                       2.2                   01 Jun 2014   http://sourceforge.net/projects/gdado/files/souce%20code/gdado-2.2/gdado-2.2.tar.gz
gdal                        2.1.4                 20 Sep 2017   http://download.osgeo.org/gdal/2.1.4/gdal-2.1.4.tar.xz
gdb                         8.1                   10 Feb 2018   https://ftp.gnu.org/pub/gnu/gdb/gdb-8.1.tar.xz
gdbm                        1.13                  15 Sep 2017   ftp://ftp.gnu.org/gnu/gdbm/gdbm-1.13.tar.gz
gdesklets                   0.35.4                01 Jun 2014   http://www.gdesklets.de/files/gDesklets-0.35.4.tar.bz2
gdkpixbuf                   2.36.12               08 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gdk-pixbuf/2.36/gdk-pixbuf-2.36.12.tar.xz
gdl                         3.26.0                11 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gdl/3.26/gdl-3.26.0.tar.xz
gdm                         3.27.4                09 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gdm/3.27/gdm-3.27.4.tar.xz
gdsl                        1.8                   25 Apr 2015   http://download.gna.org/gdsl/gdsl-1.8.tar.gz
geany                       1.32                  08 Dec 2017   http://download.geany.org/geany-1.32.tar.gz
geanyplugins                1.31                  21 Aug 2017   http://plugins.geany.org/geany-plugins/geany-plugins-1.31.tar.gz
geary                       0.12.2                29 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/geary/0.12/geary-0.12.2.tar.xz
gedit                       3.27.90               08 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gedit/3.27/gedit-3.27.90.tar.xz
geditcodeassistance         3.16.0                30 Apr 2015   http://ftp.gnome.org/pub/GNOME/sources/gedit-code-assistance/3.16/gedit-code-assistance-3.16.0.tar.xz
geditplugins                3.22.0                03 Sep 2017   http://ftp.gnome.org/pub/GNOME/sources/gedit-plugins/3.22/gedit-plugins-3.22.0.tar.xz
gegl                        0.4.0                 27 Apr 2018   https://download.gimp.org/pub/gegl/0.4/gegl-0.4.0.tar.bz2
geglmm                      0.1.6                 20 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/geglmm/0.1/geglmm-0.1.6.tar.xz
geis                        2.2.16                01 Sep 2014   https://launchpad.net/geis/trunk/2.2.16/+download/geis-2.2.16.tar.xz
genius                      1.0.23                13 May 2017   http://ftp.gnome.org/pub/gnome/sources/genius/1.0/genius-1.0.23.tar.xz
genshi                      0.4.1                 Jun 2014      http://ftp.edgewall.com/pub/genshi/Genshi-0.4.1.tar.bz2
genx4r                      0.05                  Jun 2014      https://rubygems.org/downloads/genx4r-0.05.gem
geoclue                     2.4.8                 15 Apr 2018   https://www.freedesktop.org/software/geoclue/releases/2.4/geoclue-2.4.8.tar.xz
geocodeglib                 3.24.0                11 Sep 2017   http://ftp.gnome.org/pub/GNOME/sources/geocode-glib/3.24/geocode-glib-3.24.0.tar.xz
geos                        3.6.2                 20 Sep 2017   http://download.osgeo.org/geos/geos-3.6.2.tar.bz2
geshi                       1.0.9.0               20 Sep 2017   https://sourceforge.net/projects/geshi/files/geshi/GeSHi%201.0.9.0/GeSHi-1.0.9.0.tar.bz2
getmail                     5.4                   05 Dec 2017   http://pyropus.ca/software/getmail/old-versions/getmail-5.4.tar.gz
gettext                     0.19.8.1              11 Jun 2016   ftp://ftp.gnu.org/gnu/gettext/gettext-0.19.8.1.tar.gz
gexiv2                      0.10.8                08 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gexiv2/0.10/gexiv2-0.10.8.tar.xz
gfbgraph                    0.2.3                 15 Jul 2015   http://ftp.gnome.org/pub/GNOME/sources/gfbgraph/0.2/gfbgraph-0.2.3.tar.xz
gftp                        2.0.19                01 Jan 2013   http://gftp.seul.org/gftp-2.0.19.tar.bz2
ggv                         2.12.0                01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/ggv/2.12/ggv-2.12.0.tar.bz2
ghemical                    3.0.0                 Nov 2012      http://bioinformatics.org/ghemical/download/current/ghemical-3.0.0.tar.gz
ghex                        3.18.2                13 Jun 2016   http://ftp.gnome.org/pub/GNOME/sources/ghex/3.18/ghex-3.18.2.tar.xz
ghostscript                 9.23                  21 Mar 2018   https://github.com/ArtifexSoftware/ghostpdl-downloads/releases/download/gs923/ghostscript-9.23.tar.gz
giblib                      1.2.4                 01 Jun 2014   http://linuxbrit.co.uk/downloads/giblib-1.2.4.tar.gz
gif2apng                    1.6                   Jun 2014      http://sourceforge.net/projects/gif2apng/files/1.6/gif2apng-1.6
giflib                      5.1.4                 23 Jul 2017   http://downloads.sourceforge.net/giflib/giflib-5.1.4.tar.bz2
gifsicle                    1.88                  18 Mar 2017   http://www.lcdf.org/gifsicle/gifsicle-1.88.tar.gz
gift                        0.1.14                01 Jun 2014   ftp://ftp.gnu.org/gnu/gift/gift-0.1.14.tar.gz
gimp                        2.10.0                27 Apr 2018   https://download.gimp.org/pub/gimp/v2.10/gimp-2.10.0.tar.bz2
gimpsharp                   0.13                  01 Jun 2014   http://gimp-sharp.sourceforge.net/
giostandalone               0.1.2                 01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/gio-standalone/0.1/gio-standalone-0.1.2.tar.bz2
girara                      0.2.6                 18 Aug 2016   https://pwmt.org/projects/girara/download/girara-0.2.6.tar.gz
girl                        9.9.8                 27 Apr 2017   http://ftp.gnome.org/pub/gnome/sources/girl/9.9/girl-9.9.8.tar.xz
gist                        4.6.2                 09 Jan 2018   https://rubygems.org/downloads/gist-4.6.2.gem
git                         2.17.0                03 Apr 2018   https://www.kernel.org/pub/software/scm/git/git-2.17.0.tar.xz
gitcola                     2.10                  27 Jul 2017   https://github.com/git-cola/git-cola/archive/v2.10.tar.gz
gitdb                       0.6.4                 10 Aug 2017   https://pypi.python.org/packages/e3/95/7e5d7261feb46c0539ac5e451be340ddd64d78c5118f2d893b052c76fe8c/gitdb-0.6.4.tar.gz#md5=44e4366b8bdfd306b075c3a52c96ae1a
gitg                        3.26.0                09 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/gitg/3.26/gitg-3.26.0.tar.xz
giv                         0.9.15                Jun 2014      http://downloads.sourceforge.net/giv/giv-0.9.15.tar.gz
gjs                         1.52.2                18 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gjs/1.52/gjs-1.52.2.tar.xz
gkrellm                     2.3.10                20 Jul 2017   http://gkrellm.srcbox.net/releases/gkrellm-2.3.10.tar.bz2
glabels                     3.4.1                 29 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/glabels/3.4/glabels-3.4.1.tar.xz
glade                       3.22.1                03 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/glade/3.22/glade-3.22.1.tar.xz
glade3                      3.8.6                 08 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/glade3/3.8/glade3-3.8.6.tar.xz
glamoregl                   0.6.0                 Jan 2014      http://xorg.freedesktop.org/releases/individual/driver/glamor-egl-0.6.0.tar.bz2
glark                       1.7.10                28 Jul 2016   https://sourceforge.net/projects/glark/files/glark/1.7.10/glark-1.7.10.tar.gz
glib                        2.56.1                10 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/glib/2.56/glib-2.56.1.tar.xz
glibc                       2.27                  02 Feb 2018   http://ftp.gnu.org/gnu/glibc/glibc-2.27.tar.xz
glibclibidn                 2.10.1                Jun 2014      http://ftp.gnu.org/gnu/libc/glibc-libidn-2.10.1.tar.bz2
glibmm                      2.56.0                01 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/glibmm/2.56/glibmm-2.56.0.tar.xz
glibnetworking              2.55.90               19 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/glib-networking/2.55/glib-networking-2.55.90.tar.xz
glibopenssl                 2.50.7                27 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/glib-openssl/2.50/glib-openssl-2.50.7.tar.xz
glimmer                     3.02b                 24 Jun 2017   http://ccb.jhu.edu/software/glimmer/glimmer302b.tar.gz
glob2                       0.9.4.4               01 Jul 2013   http://dl.sv.nongnu.org/releases/glob2/0.9.4/glob2-0.9.4.4.tar.gz
globalid                    0.4.1                 05 Feb 2018   https://rubygems.org/downloads/globalid-0.4.1.gem
glom                        1.30.4                11 Jun 2016   http://ftp.gnome.org/pub/GNOME/sources/glom/1.30/glom-1.30.4.tar.xz
glpk                        4.63                  01 Aug 2017   http://ftp.gnu.org/pub/gnu/glpk/glpk-4.63.tar.gz
glproto                     1.4.17                Dec 2013      http://xorg.freedesktop.org/releases/individual/proto/glproto-1.4.17.tar.bz2
glu                         9.0.0                 01 Aug 2015   ftp://ftp.freedesktop.org/pub/mesa/glu/glu-9.0.0.tar.bz2
glue                        1.1.1                 01 Dec 2017   https://rubygems.org/downloads/glue-1.1.1.gem
glut                        3.7                   Dec 2012      http://www.opengl.org/resources/libraries/glut/glut-3.7.tar.gz
gmail                       0.6.0                 27 Dec 2017   https://rubygems.org/downloads/gmail-0.6.0.gem
gmailxoauth                 0.4.2                 27 Dec 2017   https://rubygems.org/downloads/gmail_xoauth-0.4.2.gem
gmerlin                     0.3.5                 Jun 2014      http://gmerlin.sourceforge.net/
gmic                        1.5.7.1               Oct 2013      http://downloads.sourceforge.net/project/gmic/gmic_1.5.7.1.tar.gz
gmime                       3.2.0                 21 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/gmime/3.2/gmime-3.2.0.tar.xz
gmp                         6.1.2                 17 Nov 2017   https://gmplib.org/download/gmp/gmp-6.1.2.tar.xz
gmsh                        1.65.0                Jun 2014      http://geuz.org/gmsh/src/gmsh-1.65.0-source.tgz
gmtk                        1.0.9a                Nov 2013      http://gmtk.googlecode.com/files/gmtk-1.0.9a.tar.gz
gmuehle                     0.2                   01 Jan 2013   http://stpohle.dyndns.org/index.php?page=progs#gmuehle
gnash                       0.8.10                03 Jun 2014   http://ftp.gnu.org/gnu/gnash/0.8.10/gnash-0.8.10.tar.bz2
gnet                        2.0.8                 Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/gnet/2.0/gnet-2.0.8.tar.bz2
gneutronica                 0.33                  Jun 2014      http://sourceforge.net/projects/gneutronica/files/gneutronica/gneutronica-0.33/gneutronica-0.33.tar.gz
gno3dtet                    1.96.1                28 Jul 2016   http://www.eseb.net/ftp/gno3dtet/gno3dtet-1.96.1.tgz
gnoise                      0.1.15                Jun 2014      http://peterhost.dl.sourceforge.net/sourceforge/gnoise/gnoise-0.1.15.tar.gz
gnomeapplets                3.26.0                03 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-applets/3.26/gnome-applets-3.26.0.tar.xz
gnomeappletsensors          1.7.12                01 Jun 2014   http://sensors-applet.sourceforge.net/
gnomeaudio                  2.22.2                01 Sep 2012   http://ftp.gnome.org/pub/GNOME/sources/gnome-audio/2.22/gnome-audio-2.22.2.tar.bz2
gnomeautoar                 0.2.2                 31 Jan 2018   https://ftp.gnome.org/pub/gnome/sources/gnome-autoar/0.2/gnome-autoar-0.2.2.tar.xz
gnomebackgrounds            3.27.90               08 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-backgrounds/3.27/gnome-backgrounds-3.27.90.tar.xz
gnomebaker                  0.6.2                 Jun 2014      http://sourceforge.net/projects/gnomebaker/
gnomebatterybench           3.15.4                07 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/gnome-battery-bench/3.15/gnome-battery-bench-3.15.4.tar.xz
gnomebluetooth              3.26.1                15 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-bluetooth/3.26/gnome-bluetooth-3.26.1.tar.xz
gnomeboxes                  3.28.2                10 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-boxes/3.28/gnome-boxes-3.28.2.tar.xz
gnomebtdownload             0.0.32                Jun 2014      http://sourceforge.net/projects/gnome-bt/files/gnome-bt/0.0.32/gnome-btdownload-0.0.32.tar.gz
gnomebuild                  0.2.4                 01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/gnome-build/0.2/gnome-build-0.2.4.tar.bz2
gnomebuilder                3.27.90               05 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-builder/3.27/gnome-builder-3.27.90.tar.xz
gnomecalculator             3.27.2                14 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-calculator/3.27/gnome-calculator-3.27.2.tar.xz
gnomecalendar               3.28.0                20 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-calendar/3.28/gnome-calendar-3.28.0.tar.xz
gnomecharacters             3.26.2                30 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-characters/3.26/gnome-characters-3.26.2.tar.xz
gnomechemistryutils         0.9.2                 Jun 2014      http://download.savannah.nongnu.org/releases/gchemutils/0.9/gnome-chemistry-utils-0.9.2.tar.bz2
gnomechess                  3.28.1                10 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-chess/3.28/gnome-chess-3.28.1.tar.xz
gnomeclocks                 3.27.1                25 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-clocks/3.27/gnome-clocks-3.27.1.tar.xz
gnomecodeassistance         3.16.0                30 Apr 2015   http://ftp.gnome.org/pub/GNOME/sources/gnome-code-assistance/3.16/gnome-code-assistance-3.16.0.tar.xz
gnomecolormanager           3.26.0                11 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-color-manager/3.26/gnome-color-manager-3.26.0.tar.xz
gnomecommander              1.8.0                 09 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-commander/1.8/gnome-commander-1.8.0.tar.xz
gnomecommon                 3.18.0                22 Sep 2015   http://ftp.gnome.org/pub/GNOME/sources/gnome-common/3.18/gnome-common-3.18.0.tar.xz
gnomecontacts               3.26                  24 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-contacts/3.26/gnome-contacts-3.26.tar.xz
gnomecontrolcenter          3.28.0                24 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-control-center/3.28/gnome-control-center-3.28.0.tar.xz
gnomecupsmanager            0.33                  Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/gnome-cups-manager/0.33/gnome-cups-manager-0.33.tar.bz2
gnomedesktop                3.27.2                14 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-desktop/3.27/gnome-desktop-3.27.2.tar.xz
gnomedictionary             3.26.1                02 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-dictionary/3.26/gnome-dictionary-3.26.1.tar.xz
gnomedirectorythumbnailer   0.1.10                26 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-directory-thumbnailer/0.1/gnome-directory-thumbnailer-0.1.10.tar.xz
gnomediskutility            3.27.4                09 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-disk-utility/3.27/gnome-disk-utility-3.27.4.tar.xz
gnomedocuments              3.26.1                03 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-documents/3.26/gnome-documents-3.26.1.tar.xz
gnomedocutils               0.20.10               20 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/gnome-doc-utils/0.20/gnome-doc-utils-0.20.10.tar.xz
gnomedvbdaemon              0.2.90                01 Aug 2014   http://ftp.gnome.org/pub/GNOME/sources/gnome-dvb-daemon/0.2/gnome-dvb-daemon-0.2.90.tar.xz
gnomeflashback              3.26.0                06 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-flashback/3.26/gnome-flashback-3.26.0.tar.xz
gnomefontviewer             3.27.0                16 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-font-viewer/3.27/gnome-font-viewer-3.27.0.tar.xz
gnomegames                  3.28.0                30 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-games/3.28/gnome-games-3.28.0.tar.xz
gnomehearts                 0.2                   Jun 2014      http://www.jejik.com/files/gnome-hearts/gnome-hearts-0.2.tar.gz
gnomeicontheme              3.12.0                01 Apr 2014   http://ftp.gnome.org/pub/gnome/sources/gnome-icon-theme/3.12/gnome-icon-theme-3.12.0.tar.xz
gnomeiconthemeextras        3.12.0                Apr 2014      http://ftp.gnome.org/pub/gnome/sources/gnome-icon-theme-extras/3.12/gnome-icon-theme-extras-3.12.0.tar.xz
gnomeiconthemesymbolic      3.12.0                Apr 2014      http://ftp.gnome.org/pub/gnome/sources/gnome-icon-theme-symbolic/3.12/gnome-icon-theme-symbolic-3.12.0.tar.xz
gnomeinitialsetup           3.25.92               08 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-initial-setup/3.25/gnome-initial-setup-3.25.92.tar.xz
gnomeinternetradiolocator   1.0.7                 27 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-internet-radio-locator/1.0/gnome-internet-radio-locator-1.0.7.tar.xz
gnomekeyring                3.27.4                09 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-keyring/3.27/gnome-keyring-3.27.4.tar.xz
gnomekeyringmanager         2.20.0                Jun 2014      ftp://ftp.gnome.org/pub/gnome/sources/gnome-keyring-manager/2.20/gnome-keyring-manager-2.20.0.tar.bz2
gnomeklotski                3.22.2                09 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-klotski/3.22/gnome-klotski-3.22.2.tar.xz
gnomekraorathumbnailer      1.3                   01 Dec 2013   http://ftp.gnome.org/pub/GNOME/sources/gnome-kra-ora-thumbnailer/1.3/gnome-kra-ora-thumbnailer-1.3.tar.xz
gnomelatex                  3.27.2                17 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-latex/3.27/gnome-latex-3.27.2.tar.xz
gnomelogs                   3.26.3                02 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-logs/3.26/gnome-logs-3.26.3.tar.xz
gnomemag                    0.15.1                01 Jun 2014   http://ftp.gnome.org/pub/gnome/sources/gnome-mag/0.15/gnome-mag-0.15.1.tar.bz2
gnomemahjongg               3.21.2                01 Jun 2016   http://ftp.gnome.org/pub/GNOME/sources/gnome-mahjongg/3.21/gnome-mahjongg-3.21.2.tar.xz
gnomemainmenu               1.8.0                 Jun 2014      http://pub.mate-desktop.org/releases/1.8/gnome-main-menu-1.8.0.tar.xz
gnomemaps                   3.28.1                18 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-maps/3.28/gnome-maps-3.28.1.tar.xz
gnomemedia                  3.4.0                 24 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/gnome-media/3.4/gnome-media-3.4.0.tar.xz
gnomemeeting                1.2.2                 Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/gnomemeeting
gnomemenus                  3.13.3                06 Aug 2014   http://ftp.gnome.org/pub/GNOME/sources/gnome-menus/3.13/gnome-menus-3.13.3.tar.xz
gnomemimedata               2.18.0                01 Jul 2012   http://ftp.gnome.org/pub/gnome/sources/gnome-mime-data/2.18/gnome-mime-data-2.18.0.tar.bz2
gnomemines                  3.27.90               05 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-mines/3.27/gnome-mines-3.27.90.tar.xz
gnomemount                  0.6                   01 Jun 2014   http://people.freedesktop.org/~david/dist/gnome-mount-0.6.tar.gz
gnomemplayer                1.0.9b                01 Nov 2013   https://storage.googleapis.com/google-code-archive-downloads/v2/code.google.com/gnome-mplayer/gnome-mplayer-1.0.9b.tar.gz
gnomemultiwriter            3.26.0                11 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-multi-writer/3.26/gnome-multi-writer-3.26.0.tar.xz
gnomemusic                  3.28.0                18 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-music/3.28/gnome-music-3.28.0.tar.xz
gnomenetstatus              2.28.2                02 Aug 2017   http://ftp.gnome.org/pub/GNOME/sources/gnome-netstatus/2.28/gnome-netstatus-2.28.2.tar.gz
gnomenettool                3.8.1                 Jun 2013      http://ftp.gnome.org/pub/GNOME/sources/gnome-nettool/3.8/gnome-nettool-3.8.1.tar.xz
gnomenetwork                1.99.5                01 Jun 2014   ftp://ftp.gnome.org/pub/GNOME/sources/gnome-network/1.99/gnome-network-1.99.5.tar.bz2
gnomenibbles                3.21.2                01 Jun 2016   http://ftp.gnome.org/pub/GNOME/sources/gnome-nibbles/3.21/gnome-nibbles-3.21.2.tar.xz
gnomeonlineaccounts         3.28.0                20 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-online-accounts/3.28/gnome-online-accounts-3.28.0.tar.xz
gnomeonlineminers           3.26.0                11 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-online-miners/3.26/gnome-online-miners-3.26.0.tar.xz
gnomepackagekit             3.26.0                11 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-packagekit/3.26/gnome-packagekit-3.26.0.tar.xz
gnomepanel                  3.26.0                09 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-panel/3.26/gnome-panel-3.26.0.tar.xz
gnomephonemanager           0.69                  24 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/gnome-phone-manager/0.69/gnome-phone-manager-0.69.tar.xz
gnomephotos                 3.28.0                20 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-photos/3.28/gnome-photos-3.28.0.tar.xz
gnomepkgtool                0.5.2                 Jun 2014      http://gnome-pkgtool.sourceforge.net/
gnomepowermanager           3.26.0                31 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-power-manager/3.26/gnome-power-manager-3.26.0.tar.xz
gnomepython                 2.28.1                01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/gnome-python/2.28/gnome-python-2.28.1.tar.gz
gnomepythondesktop          2.23.0                01 Jan 2013   http://ftp.gnome.org/pub/GNOME/sources/gnome-python-desktop/2.23/gnome-python-desktop-2.23.0.tar.bz2
gnomerecipes                1.2.0                 08 May 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-recipes/1.2/gnome-recipes-1.2.0.tar.xz
gnomerobots                 3.22.2                09 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-robots/3.22/gnome-robots-3.22.2.tar.xz
gnomescan                   0.5.94                01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/gnome-scan/0.5/gnome-scan-0.5.94.tar.bz2
gnomeschedule               2.2.2                 01 Jun 2014   http://sourceforge.net/projects/gnome-schedule/files/gnome-schedule-2/gnome-schedule-2-2-2/gnome-schedule-2.2.2.tar.gz
gnomescreensaver            3.6.1                 24 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/gnome-screensaver/3.6/gnome-screensaver-3.6.1.tar.xz
gnomescreenshot             3.26.0                30 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-screenshot/3.26/gnome-screenshot-3.26.0.tar.xz
gnomesession                3.27.3                15 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-session/3.27/gnome-session-3.27.3.tar.xz
gnomesettingsdaemon         3.28.0                24 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-settings-daemon/3.28/gnome-settings-daemon-3.28.0.tar.xz
gnomesharp                  2.24.0                01 Jun 2014   http://ftp.gnome.org/pub/gnome/sources/gnome-sharp/2.24/gnome-sharp-2.24.0.tar.bz2
gnomeshell                  3.28.1                26 Apr 2018   ftp://ftp.gnome.org/pub/gnome/sources/gnome-shell/3.28/gnome-shell-3.28.1.tar.xz
gnomeshellextensions        3.28.1                30 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-shell-extensions/3.28/gnome-shell-extensions-3.28.1.tar.xz
gnomesoftware               3.28.1                10 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-software/3.28/gnome-software-3.28.1.tar.xz
gnomesoundrecorder          3.19.91               29 Feb 2016   http://ftp.gnome.org/pub/GNOME/sources/gnome-sound-recorder/3.19/gnome-sound-recorder-3.19.91.tar.xz
gnomespeech                 0.4.16                01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/gnome-speech/
gnomesubtitles              1.1                   01 Jun 2014   http://downloads.sourceforge.net/gnome-subtitles/gnome-subtitles-1.1.tar.gz
gnomesudoku                 3.27.3                11 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-sudoku/3.27/gnome-sudoku-3.27.3.tar.xz
gnomesystemmonitor          3.27.2                14 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-system-monitor/3.27/gnome-system-monitor-3.27.2.tar.xz
gnomesystemtools            3.0.0                 20 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/gnome-system-tools/3.0/gnome-system-tools-3.0.0.tar.bz2
gnometaquin                 3.26.1                02 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-taquin/3.26/gnome-taquin-3.26.1.tar.xz
gnometerminal               3.27.4                09 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-terminal/3.27/gnome-terminal-3.27.4.tar.xz
gnometerminallauncher       0.8                   01 Sep 2013   http://gnome-tla.sourceforge.net/
gnometetravex               3.19.92               16 Mar 2016   http://ftp.gnome.org/pub/GNOME/sources/gnome-tetravex/3.19/gnome-tetravex-3.19.92.tar.xz
gnomethemes                 3.0.0                 Jun 2014      ftp://ftp.gnome.org/pub/GNOME/sources/gnome-themes/3.0/gnome-themes-3.0.0.tar.bz2
gnomethemesextra            3.28                  24 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-themes-extra/3.28/gnome-themes-extra-3.28.tar.xz
gnomethemesstandard         3.27.90               14 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-themes-standard/3.27/gnome-themes-standard-3.27.90.tar.xz
gnometodo                   3.27.2                16 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-todo/3.27/gnome-todo-3.27.2.tar.xz
gnometweaks                 3.27.4                27 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/gnome-tweaks/3.27/gnome-tweaks-3.27.4.tar.xz
gnometweaktool              3.26.4                30 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-tweak-tool/3.26/gnome-tweak-tool-3.26.4.tar.xz
gnomeusershare              3.18.0                21 Sep 2015   http://ftp.gnome.org/pub/GNOME/sources/gnome-user-share/3.18/gnome-user-share-3.18.0.tar.xz
gnomeutils                  3.2.1                 20 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/gnome-utils/3.2/gnome-utils-3.2.1.tar.xz
gnomevfs                    2.24.4                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/gnome-vfs/2.24/gnome-vfs-2.24.4.tar.bz2
gnomevfsmm                  2.26.0                Jun 2014      http://ftp.acc.umu.se/pub/GNOME/sources/gnome-vfsmm/2.26/gnome-vfsmm-2.26.0.tar.bz2
gnomevideoarcade            0.8.8                 31 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-video-arcade/0.8/gnome-video-arcade-0.8.8.tar.xz
gnomevideoeffects           0.4.1                 Mar 2014      http://ftp.gnome.org/pub/GNOME/sources/gnome-video-effects/0.4/gnome-video-effects-0.4.1.tar.xz
gnomevoicecontrol           0.4                   Jun 2014      http://prdownload.berlios.de/festlang/gnome-voice-control-0.4.tar.gz
gnomevolumemanager          2.17.0                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/gnome-volume-manager/
gnomeweather                3.26.0                11 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gnome-weather/3.26/gnome-weather-3.26.0.tar.xz
gnonlin                     1.2.0                 01 Apr 2014   http://gstreamer.freedesktop.org/src/gnonlin/gnonlin-1.2.0.tar.xz
gnopernicus                 1.1.2                 Jun 2014      http://ftp.gnome.org/pub/gnome/sources/gnopernicus/1.1/gnopernicus-1.1.2.tar.bz2
gnormalize                  0.63                  Jun 2014      http://prdownloads.sourceforge.net/gnormalize/gnormalize-0.63.tar.gz
gnote                       3.28.0                19 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gnote/3.28/gnote-3.28.0.tar.xz
gnuastro                    0.5                   26 Dec 2017   http://ftp.gnu.org/pub/gnu/gnuastro/gnuastro-0.5.tar.lz
gnucash                     3.1                   29 Apr 2018   http://downloads.sourceforge.net/gnucash/gnucash-3.1.tar.bz2
gnuchess                    6.2.5                 28 Jul 2017   http://ftp.gnu.org/gnu/chess/gnuchess-6.2.5.tar.gz
gnucobol                    2.2                   11 Sep 2017   https://sourceforge.net/projects/open-cobol/files/gnu-cobol/2.2/gnucobol-2.2.tar.xz
gnugo                       3.8                   Jan 2013      http://ftp.gnu.org/gnu/gnugo/gnugo-3.8.tar.gz
gnuhealth                   3.2.6                 04 Nov 2017   http://ftp.gnu.org/pub/gnu/health/gnuhealth-3.2.6.tar.gz
gnujump                     1.0.6                 Dec 2012      http://download.savannah.gnu.org/releases/gnujump/
gnumeric                    1.12.40               30 Apr 2018   ftp://ftp.gnome.org/pub/gnome/sources/gnumeric/1.12/gnumeric-1.12.40.tar.xz
gnump3d                     3.0                   01 Jun 2014   http://savannah.gnu.org/download/gnump3d/gnump3d-3.0.tar.bz2
gnunet                      0.8.0                 01 Jan 2013   http://gnunet.org/download/GNUnet-0.8.0.tar.bz2
gnunetgtk                   0.7.2b                Jun 2014      http://gnunet.org/download/gnunet-gtk-0.7.0e.tar.bz2
gnupdf                      16.10.2013            16 Oct 2013   https://www.gnu.org/software/pdf/
gnupg                       2.2.6                 10 Apr 2018   ftp://ftp.gnupg.org/gcrypt/gnupg/gnupg-2.2.6.tar.bz2
gnuplot                     5.2.2                 22 Nov 2017   https://sourceforge.net/projects/gnuplot/files/gnuplot/5.2.2/gnuplot-5.2.2.tar.gz
gnurl                       7.58.0                31 Jan 2018   https://ftp.gnu.org/pub/gnu/gnunet/gnurl-7.58.0.tar.bz2
gnustepbase                 1.24.0                Jun 2014      ftp://ftp.gnustep.org/pub/gnustep/core/gnustep-base-1.24.0.tar.gz
gnustepmake                 1.12.0                Jun 2014      ftp://ftp.gnustep.org/pub/gnustep/core/gnustep-make-1.12.0.tar.gz
gnutls                      3.6.2                 20 Feb 2018   ftp://ftp.gnupg.org/gcrypt/gnutls/v3.6/gnutls-3.6.2.tar.xz
go                          1.4.2                 19 May 2015   https://storage.googleapis.com/golang/go1.4.2.src.tar.gz
gob2                        2.0.20                01 Dec 2013   http://ftp.gnome.org/pub/GNOME/sources/gob2/2.0/gob2-2.0.20.tar.xz
gobby                       0.4.94                01 Jun 2014   http://releases.0x539.de/gobby/gobby-0.4.94.tar.gz
gobjectintrospection        1.56.0                26 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gobject-introspection/1.56/gobject-introspection-1.56.0.tar.xz
gocr                        0.47                  02 Aug 2017   https://sourceforge.net/projects/jocr/files/gocr/0.47/gocr-0.47.tar.gz
god                         0.7.3                 01 May 2013   http://godrb.com/
goffice                     0.10.40               30 Apr 2018   http://ftp.acc.umu.se/pub/GNOME/sources/goffice/0.10/goffice-0.10.40.tar.xz
gok                         2.30.1                20 Aug 2017   http://ftp.acc.umu.se/pub/GNOME/sources/gok/2.30/gok-2.30.1.tar.gz
golly                       3.0                   03 Sep 2017   https://sourceforge.net/projects/golly/files/golly/golly-3.0/golly-3.0-src.tar.gz
gom                         0.3.3                 28 Jun 2017   http://ftp.gnome.org/pub/gnome/sources/gom/0.3/gom-0.3.3.tar.xz
gonzui                      1.2                   01 Jun 2014   https://rubygems.org/downloads/gonzui-1.2.gem
goobox                      3.4.1                 23 Sep 2015   http://ftp.gnome.org/pub/GNOME/sources/goobox/3.4/goobox-3.4.1.tar.xz
goocanvas                   2.0.4                 10 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/goocanvas/2.0/goocanvas-2.0.4.tar.xz
gosu                        0.12.1                05 Aug 2017   https://github.com/gosu/gosu/archive/v0.12.1.tar.gz
gpac                        0.7.1                 27 Feb 2018   https://github.com/gpac/gpac/archive/v0.7.1.tar.gz
gpaint                      2.0.3.3               01 Jun 2014   ftp://alpha.gnu.org/gnu/gpaint/gpaint-2-0.3.3.tar.gz
gparted                     0.31.0                20 Mar 2018   http://downloads.sourceforge.net/gparted/gparted-0.31.0.tar.gz
gpass                       0.5.1                 Jun 2014      http://projects.netlab.jp/gpass/
gpdf                        2.10.0                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/gpdf/2.10/gpdf-2.10.0.tar.bz2
gperf                       3.1                   20 Jul 2017   ftp://ftp.gnu.org/gnu/gperf/gperf-3.1.tar.gz
gperiodic                   2.0.10                01 Jun 2014   http://www.frantz.fi/software/gperiodic-2.0.10.tar.gz
gpgme                       1.11.1                22 Apr 2018   https://www.gnupg.org/ftp/gcrypt/gpgme/gpgme-1.11.1.tar.bz2
gphoto2                     2.5.15                04 Oct 2017   https://sourceforge.net/projects/gphoto/files/gphoto/2.5.15/gphoto2-2.5.15.tar.bz2
gpm                         1.99.7                14 Apr 2015   http://www.nico.schottelius.org/software/gpm/archives/gpm-1.99.7.tar.gz
gpredict                    0.9.0                 Jun 2014      http://groundstation.sourceforge.net/gpredict/
gprolog                     1.4.2                 Dec 2012      http://www.gprolog.org/gprolog-1.4.2.tar.gz
gpsd                        2.36                  01 Jun 2014   http://download.berlios.de/gpsd/gpsd-2.36.tar.gz
gptfdisk                    1.0.3                 03 Aug 2017   https://sourceforge.net/projects/gptfdisk/files/gptfdisk/1.0.3/gptfdisk-1.0.3.tar.gz
gqview                      2.1.5                 02 Jan 2018   http://prdownloads.sourceforge.net/gqview/gqview-2.1.5.tar.gz
grabc                       1.1                   01 Jun 2014   http://freshmeat.net/projects/grabc
gramps                      4.2.6                 20 Sep 2017   https://sourceforge.net/projects/gramps/files/Stable/4.2.6/gramps-4.2.6.tar.gz
granatier                   4.14.3                12 Jun 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/granatier-4.14.3.tar.xz
grantlee                    0.5.1                 13 Apr 2015   http://downloads.grantlee.org/grantlee-0.5.1.tar.gz
grantleeeditor              18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/grantlee-editor-18.04.0.tar.xz
grantleetheme               18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/grantleetheme-18.04.0.tar.xz
graphene                    1.8.0                 27 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/graphene/1.8/graphene-1.8.0.tar.xz
graphicsmagick              1.3.27                16 Jan 2018   https://sourceforge.net/projects/graphicsmagick/files/graphicsmagick/1.3.27/GraphicsMagick-1.3.27.tar.xz
graphite2                   1.3.10                23 Jul 2017   https://github.com/silnrsi/graphite/releases/download/1.3.10/graphite2-1.3.10.tgz
graphviz                    2.40.1                29 Dec 2016   http://www.graphviz.org/pub/graphviz/ARCHIVE/graphviz-2.40.1.tar.gz
graphvizcairo               2.8                   Jun 2014      http://www.graphviz.org/pub/graphviz/ARCHIVE/graphviz-cairo-2.8.tar.gz
greenfish                   0.0.4                 15 Apr 2015   greenfish-0.0.4
grep                        3.1                   04 Jul 2017   http://ftp.gnu.org/gnu/grep/grep-3.1.tar.xz
grhino                      0.16.0                01 Jan 2013   http://rhino.sourceforge.net/
grilo                       0.3.4                 24 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/grilo/0.3/grilo-0.3.4.tar.xz
griloplugins                0.3.5                 25 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/grilo-plugins/0.3/grilo-plugins-0.3.5.tar.xz
grism                       0.9.0                 16 Feb 2017   http://www.grism.org/grism-0.9.0.tar.gz
groff                       1.22.3                04 Nov 2014   ftp://ftp.gnu.org/gnu/groff/groff-1.22.3.tar.gz
groonga                     5.1.0                 29 Nov 2015   http://packages.groonga.org/source/groonga/groonga-5.1.0.tar.gz
grub                        2.02                  26 Apr 2017   ftp://ftp.gnu.org/gnu/grub/grub-2.02.tar.xz
gruff                       0.7.0                 16 Oct 2017   https://rubygems.org/downloads/gruff-0.7.0.gem
gsambad                     0.1.9                 Jun 2014      http://directory.fsf.org/wiki/GSAMBAD
gscanbus                    0.8                   04 Nov 2017   https://sourceforge.net/projects/gscanbus.berlios/files/gscanbus-0.8.tar.gz
gsettingsdesktopschemas     3.27.90               08 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gsettings-desktop-schemas/3.27/gsettings-desktop-schemas-3.27.90.tar.xz
gsl                         2.4                   13 Aug 2017   ftp://ftp.gnu.org/gnu/gsl/gsl-2.4.tar.gz
gslapt                      0.5.4c                16 Oct 2017   http://software.jaos.org/source/gslapt/gslapt-0.5.4c.tar.gz
gsmartcontrol               0.8.7                 11 Apr 2015   http://sourceforge.net/projects/gsmartcontrol/files/0.8.7/gsmartcontrol-0.8.7.tar.bz2
gsound                      1.0.2                 01 Nov 2015   http://ftp.gnome.org/pub/GNOME/sources/gsound/1.0/gsound-1.0.2.tar.xz
gspell                      1.7.1                 09 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/gspell/1.7/gspell-1.7.1.tar.xz
gssdp                       1.0.2                 10 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/gssdp/1.0/gssdp-1.0.2.tar.xz
gstdebugger                 0.90.0                09 Oct 2015   http://ftp.gnome.org/pub/GNOME/sources/gst-debugger/0.90/gst-debugger-0.90.0.tar.xz
gstlibav                    1.6.1                 31 Oct 2015   http://gstreamer.freedesktop.org/src/gst-libav/gst-libav-1.6.1.tar.xz
gstm                        1.2                   Jun 2014      https://sourceforge.net/projects/gstm/files/gSTM/gSTM-1.2/gstm-1.2.tar.gz
gstplugins                  0.8.12                May 2013      http://gstreamer.freedesktop.org/src/gst-plugins/gst-plugins-0.8.12.tar.bz2
gstpluginsbad               1.12.2                17 Sep 2017   https://gstreamer.freedesktop.org/src/gst-plugins-bad/gst-plugins-bad-1.12.2.tar.xz
gstpluginsbase              1.14.0                20 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gst-plugins-base/1.14/gst-plugins-base-1.14.0.tar.xz
gstpluginsgood              1.14.0                20 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gst-plugins-good/1.14/gst-plugins-good-1.14.0.tar.xz
gstpluginsugly              1.12.2                17 Sep 2017   https://gstreamer.freedesktop.org/src/gst-plugins-ugly/gst-plugins-ugly-1.12.2.tar.xz
gstpython                   0.10.22               20 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/gst-python/0.10/gst-python-0.10.22.tar.xz
gstreamer                   1.14.0                20 Mar 2018   https://gstreamer.freedesktop.org/src/gstreamer/gstreamer-1.14.0.tar.xz
gstreamermm                 1.10.0                21 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/gstreamermm/1.10/gstreamermm-1.10.0.tar.xz
gstrtspserver               1.4.5                 02 Mar 2015   http://gstreamer.freedesktop.org/src/gst-rtsp/gst-rtsp-server-1.4.5.tar.xz
gsview                      4.9                   01 Jun 2014   http://mirror.cs.wisc.edu/pub/mirrors/ghost/ghostgum/gsview-4.9.tar.gz
gtef                        1.99.2                12 Mar 2017   http://ftp.gnome.org/pub/GNOME/sources/gtef/1.99/gtef-1.99.2.tar.xz
gthumb                      3.6.0                 20 Nov 2017   http://ftp.gnome.org/pub/GNOME/sources/gthumb/3.6/gthumb-3.6.0.tar.xz
gtk+                        3.22.30               17 Apr 2018   ftp://ftp.gnome.org/pub/GNOME/sources/gtk+/3.22/gtk+-3.22.30.tar.xz
gtkam                       0.2.0                 Apr 2014      http://sourceforge.net/projects/gphoto/files/gtkam/0.2.0/gtkam-0.2.0.tar.gz
gtkchtheme                  0.3.1                 Dec 2012      http://plasmasturm.org/code/gtk-chtheme/gtk-chtheme-0.3.1.tar.bz2
gtkclearlooks               0.5                   Dec 2012      http://ftp.gnome.org/pub/GNOME/teams/art.gnome.org/themes/gtk_engines/gtk-clearlooks-0.5.tar.bz2
gtkdatabox                  0.8.0.0               01 Dec 2012   http://www.eudoxos.net/gtk/gtkdatabox/download/gtkdatabox-0.8.0.0.tar.gz
gtkdoc                      1.27                  07 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/gtk-doc/1.27/gtk-doc-1.27.tar.xz
gtkengines                  2.91.1                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/gtk-engines/2.91/gtk-engines-2.91.1.tar.bz2
gtkglarea                   2.1.0                 Apr 2014      http://ftp.gnome.org/pub/gnome/sources/gtkglarea/2.1/gtkglarea-2.1.0.tar.xz
gtkglext                    1.2.0                 Nov 2012      http://downloads.sourceforge.net/gtkglext/gtkglext-1.2.0.tar.gz
gtkhtml                     4.10.0                21 Sep 2015   http://ftp.gnome.org/pub/GNOME/sources/gtkhtml/4.10/gtkhtml-4.10.0.tar.xz
gtkiptables                 0.5.0                 Jun 2014      http://gtk-iptables.sourceforge.net/
gtkmm                       3.91.2                25 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/gtkmm/3.91/gtkmm-3.91.2.tar.xz
gtkpacman                   1.2                   Dec 2012      https://gna.org/projects/gtkpacman/
gtkperl                     0.7010                21 Aug 2017   http://search.cpan.org/CPAN/authors/id/M/ML/MLEHMANN/Gtk-Perl-0.7010.tar.gz
gtkrecordmydesktop          0.2.1r2               Dec 2012      http://recordmydesktop.sourceforge.net/
gtksharp                    2.12.45               21 Aug 2017   https://download.mono-project.com/sources/gtk-sharp212/gtk-sharp-2.12.45.tar.gz
gtksourceview               4.0.0                 08 Apr 2018   http://ftp.acc.umu.se/pub/gnome/sources/gtksourceview/4.0/gtksourceview-4.0.0.tar.xz
gtksourceview2              3.2.4                 15 Apr 2018   https://rubygems.org/downloads/gtksourceview2-3.2.4.gem
gtksourceview3              3.2.4                 15 Apr 2018   https://rubygems.org/downloads/gtksourceview3-3.2.4.gem
gtkspell                    2.0.16                01 Dec 2012   http://gtkspell.sourceforge.net/download/gtkspell-2.0.16.tar.gz
gtkspell3                   3.0.4                 Dec 2013      http://gtkspell.sourceforge.net/download/gtkspell3-3.0.4.tar.gz
gtkvnc                      0.7.2                 24 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/gtk-vnc/0.7/gtk-vnc-0.7.2.tar.xz
gtkwave                     3.3.86                18 Nov 2017   http://gtkwave.sourceforge.net/gtkwave-3.3.86.tar.gz
gtkxfceengine               3.2.0                 30 Aug 2017   http://archive.xfce.org/src/xfce/gtk-xfce-engine/3.2/gtk-xfce-engine-3.2.0.tar.bz2
gtranslator                 2.91.7                16 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/gtranslator/2.91/gtranslator-2.91.7.tar.xz
gucharmap                   10.0.4                05 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gucharmap/10.0/gucharmap-10.0.4.tar.xz
guichan                     0.8.2                 Jun 2014      http://guichan.googlecode.com/files/guichan-0.8.2.tar.gz
guile                       2.2.3                 03 Dec 2017   http://ftp.gnu.org/pub/gnu/guile/guile-2.2.3.tar.xz
guilib                      1.2.1                 Jun 2014      http://www.libsdl.org/projects/GUIlib/src/GUIlib-1.2.1.tar.gz
guiloader                   2.99.0                Jun 2014      http://nothing-personal.googlecode.com/files/guiloader-2.99.0.tar.xz
gujin                       2.8.7                 08 Mar 2017   https://sourceforge.net/projects/gujin/files/gujin/2.8.7/gujin-2.8.7.tar.gz
gumboparser                 14.08.2013            Aug 2013      gumboparser-14.08.2013.tar.xz
gupnp                       1.0.2                 10 Aug 2017   http://ftp.gnome.org/pub/GNOME/sources/gupnp/1.0/gupnp-1.0.2.tar.xz
gupnpav                     0.12.10               10 Aug 2017   http://ftp.gnome.org/pub/GNOME/sources/gupnp-av/0.12/gupnp-av-0.12.10.tar.xz
gupnpdlna                   0.10.5                10 Aug 2017   http://ftp.acc.umu.se/pub/GNOME/sources/gupnp-dlna/0.10/gupnp-dlna-0.10.5.tar.xz
gupnpigd                    0.2.5                 21 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/gupnp-igd/0.2/gupnp-igd-0.2.5.tar.xz
gupnptools                  0.8.14                09 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/gupnp-tools/0.8/gupnp-tools-0.8.14.tar.xz
gutenprint                  5.2.14                24 Apr 2018   https://downloads.sourceforge.net/gimp-print/gutenprint-5.2.14.tar.bz2
guyum                       0.4.1                 01 Jun 2014   http://sourceforge.net/projects/guyum/files/guyum/guyum-0.4/guyum-0.4.1.tar.gz
gv                          3.5.8                 Jun 2014      ftp://ftpthep.physik.uni-mainz.de/pub/gv/unix/gv-3.5.8.tar.gz
gvfs                        1.36.1                18 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/gvfs/1.36/gvfs-1.36.1.tar.xz
gwenhywfar                  4.20.0                02 Apr 2018   https://github.com/cstim/gwenhywfar/archive/4.20.0.tar.gz
gwenview                    18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/gwenview-18.04.0.tar.xz
gwget                       1.0.4                 Jun 2014      http://ftp.gnome.org/pub/gnome/sources/gwget/1.0/gwget-1.0.4.tar.bz2
gxine                       0.5.910               13 Jan 2018   http://sourceforge.net/projects/xine/files/gxine/0.5.910/gxine-0.5.910.tar.xz
gxml                        0.16.2                08 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/gxml/0.16/gxml-0.16.2.tar.xz
gzip                        1.9                   08 Jan 2018   ftp://ftp.gnu.org/gnu/gzip/gzip-1.9.tar.gz
hal                         0.5.14                Jun 2014      http://hal.freedesktop.org/releases/hal-0.5.14.tar.bz2
haml                        5.0.4                 09 Jan 2018   https://rubygems.org/downloads/haml-5.0.4.gem
hanami                      1.2.0                 01 May 2018   https://rubygems.org/downloads/hanami-1.2.0.gem
harfbuzz                    1.7.6                 14 Mar 2018   https://www.freedesktop.org/software/harfbuzz/release/harfbuzz-1.7.6.tar.bz2
hashie                      3.5.7                 21 Dec 2017   https://rubygems.org/downloads/hashie-3.5.7.gem
haveged                     1.9.2                 18 Nov 2017   https://sourceforge.net/projects/haveged/files/haveged-1.9.2.tar.gz
hawknl                      1.70                  Jun 2014      http://hawksoft.com/download/files/HawkNL17b1src.zip
hd2u                        1.0.3                 Jan 2014      http://hany.sk/~hany/_data/hd2u/hd2u-1.0.3.tgz
hdf5                        1.6.5                 Jun 2014      ftp://hdf.ncsa.uiuc.edu/HDF5/current/src/hdf5-1.6.5.tar.gz
hdparm                      9.55                  26 Mar 2018   http://downloads.sourceforge.net/hdparm/hdparm-9.55.tar.gz
heckle                      1.4.3                 30 Nov 2017   https://rubygems.org/downloads/heckle-1.4.3.gem
heimdal                     1.6rc2                22 Sep 2015   http://www.h5l.org/dist/src/heimdal-1.6rc2.tar.gz
help2man                    1.47.5                25 Sep 2017   http://mirror2.klaus-uwe.me/gnu/help2man/help2man-1.47.5.tar.xz
herbstluftwm                0.7.0                 04 Nov 2017   https://www.herbstluftwm.org/tarballs/herbstluftwm-0.7.0.tar.gz
hexahop                     1.1.0                 26 Feb 2017   https://sourceforge.net/projects/hexahop/files/1.1.0/hex-a-hop-1.1.0.tar.gz
hexchat                     2.14.1                20 Mar 2018   https://dl.hexchat.net/hexchat/hexchat-2.14.1.tar.xz
hexedit                     0.9.7                 Jun 2014      http://www.rogoyski.com/adam/programs/hexedit/hexedit-0.9.7.tar.gz
hicoloricontheme            0.17                  15 Sep 2017   https://icon-theme.freedesktop.org/releases/hicolor-icon-theme-0.17.tar.xz
highlight                   3.42                  29 Jan 2018   http://www.andre-simon.de/zip/highlight-3.42.tar.bz2
highline                    1.7.10                18 Dec 2017   https://rubygems.org/downloads/highline-1.7.10.gem
highmoon                    1.2.4                 Jun 2014      http://highmoon.gerdsmeier.net/
hiki                        0.8.7                 Feb 2013      http://rubyforge.org/frs/?group_id=1444&release_id=4578
hitori                      3.22.4                02 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/hitori/3.22/hitori-3.22.4.tar.xz
hmount                      0.2.2                 Jan 2013      http://sourceforge.net/project/showfiles.php?group_id=186602&package_id=217560
hoe                         3.17.0                19 Mar 2018   https://rubygems.org/downloads/hoe-3.17.0.gem
hornetseyeffmpeg            1.2.5                 10 Oct 2017   https://rubygems.org/downloads/hornetseye-ffmpeg-1.2.5.gem
hotbabe                     0.2.2                 Jun 2014      http://dindinx.net/hotbabe/download.php
hplip                       3.18.3                13 Mar 2018   https://sourceforge.net/projects/hplip/files/hplip/3.18.3/hplip-3.18.3.tar.gz
hpricot                     0.8.4                 01 Jun 2014   https://github.com/hpricot/hpricot/hpricot-0.8.4.tgz
hsakmt                      1.0.0                 26 Oct 2015   http://xorg.freedesktop.org/releases/individual/lib/hsakmt-1.0.0.tar.bz2
hspell                      1.3                   13 Apr 2015   http://hspell.ivrix.org.il/hspell-1.3.tar.gz
htop                        2.0.2                 24 Jul 2016   http://hisham.hm/htop/releases/2.0.2/htop-2.0.2.tar.gz
httpcookie                  1.0.3                 29 Sep 2017   https://rubygems.org/downloads/http-cookie-1.0.3.gem
httpd                       2.4.33                24 Mar 2018   http://www.apache.org/dist/httpd/httpd-2.4.33.tar.gz
hugin                       2017.0.0              21 Aug 2017   https://sourceforge.net/projects/hugin/files/hugin/hugin-2017.0/hugin-2017.0.0.tar.bz2
humphrey                    24.06.2014            01 Jun 2014   http://retrospec.sgn.net/users/ignacio/downloads/humphrey-24.06.2014
hunspell                    1.6.2                 26 Sep 2017   https://github.com/hunspell/hunspell/archive/v1.6.2.tar.gz
hwd                         4.8.1                 Jun 2014      http://user-contributions.org/projects/hwd/src/hwd-4.8.1.tar.gz
hwloc                       1.11.6                25 Feb 2017   https://www.open-mpi.org/software/hwloc/v1.11/downloads/hwloc-1.11.6.tar.gz
hydrogen                    0.9.5.1               01 Nov 2015   http://sourceforge.net/projects/hydrogen/files/Hydrogen/0.9.5%20Sources/hydrogen-0.9.5.1.tar.gz
hyperbole                   7.0.2                 24 Nov 2017   http://ftp.gnu.org/pub/gnu/hyperbole/hyperbole-7.0.2.tar.gz
hypermammut                 0.0.1                 Jun 2014      http://switch.dl.sourceforge.net/sourceforge/hypermammut/hypermammut-0.0.1.tar.bz2
hyphen                      2.8.8                 11 Jun 2015   http://sourceforge.net/projects/hunspell/files/Hyphen/2.8/hyphen-2.8.8.tar.gz
i18n                        1.0.1                 01 May 2018   https://rubygems.org/downloads/i18n-1.0.1.gem
iagno                       3.28.0                18 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/iagno/3.28/iagno-3.28.0.tar.xz
ianaetc                     2.20                  Jun 2014      http://sethwklein.net/projects/iana-etc/
ibus                        1.5.18                02 Mar 2018   https://github.com/ibus/ibus/releases/download/1.5.18/ibus-1.5.18.tar.gz
ice                         3.4.2                 Jun 2014      http://www.zeroc.com/download/Ice/3.4/Ice-3.4.2.tar.gz
iceauth                     1.0.8                 08 Mar 2018   http://xorg.freedesktop.org/releases/individual/app/iceauth-1.0.8.tar.bz2
icebreaker                  1.9.8                 Jun 2014      http://mattdm.org/icebreaker/1.9.x/icebreaker-1.9.8.tgz
icecast                     2.4.2                 25 Aug 2015   http://downloads.xiph.org/releases/icecast/icecast-2.4.2.tar.gz
icedtea                     2.4.7                 May 2014      http://icedtea.classpath.org/download/source/icedtea-2.4.7.tar.xz
icewm                       1.4.3                 12 Aug 2017   https://github.com/bbidulock/icewm/archive/icewm-1.4.3.tar.gz
icinga                      1.3.1                 01 Jun 2014   https://www.icinga.org/
ico                         1.0.4                 01 Jan 2013   http://xorg.freedesktop.org/releases/individual/app/ico-1.0.4.tar.bz2
iconnamingutils             0.8.90                01 Jun 2014   http://tango.freedesktop.org/releases/icon-naming-utils-0.8.90.tar.bz2
icoutils                    0.31.2                08 Mar 2017   http://savannah.nongnu.org/download/icoutils/icoutils-0.31.2.tar.bz2
icu4c                       60.2                  05 Apr 2018   http://download.icu-project.org/files/icu4c/60.2/icu4c-61_1-src.tgz
id3ed                       1.10.4                Jun 2014      http://www.ibiblio.org/pub/Linux/apps/sound/editors/id3ed-1.10.4.tar.gz
id3lib                      3.8.3                 01 May 2014   https://sourceforge.net/projects/id3lib/files/id3lib/3.8.3/id3lib-3.8.3.tar.gz
idesk                       0.7.5                 04 Sep 2015   http://nchc.dl.sourceforge.net/sourceforge/idesk/idesk-0.7.5.tar.bz2
idjc                        0.7.2                 Jun 2014      http://worldforum.pardus-linux.nl/index.php?topic=1501.5;wap2
iftop                       0.17                  Jun 2014      http://www.ex-parrot.com/pdw/iftop/download/iftop-0.17.tar.gz
ijs                         0.35                  Jan 2013      http://www.openprinting.org/download/ijs/download/ijs-0.35.tar.bz2
ilmbase                     2.2.0                 09 Jul 2015   http://download.savannah.nongnu.org/releases/openexr/ilmbase-2.2.0.tar.gz
imageexiftool               10.67                 20 Nov 2017   http://owl.phy.queensu.ca/~phil/exiftool/Image-ExifTool-10.67.tar.gz
imagemagick                 7.0.7.29              30 Apr 2018   ftp://ftp.imagemagick.org/pub/ImageMagick/ImageMagick-7.0.7-29.tar.xz
imageworsener               1.3.0                 02 Dec 2015   http://entropymine.com/imageworsener/imageworsener-1.3.0.tar.gz
imaging                     1.1.6                 01 Jun 2014   http://effbot.org/downloads/Imaging-1.1.6.tar.gz
imake                       1.0.7                 01 May 2014   http://xorg.freedesktop.org/releases/individual/util/imake-1.0.7.tar.bz2
imlib                       1.9.15                Sep 2013      http://ftp.gnome.org/pub/GNOME/sources/imlib/1.9/imlib-1.9.15.tar.bz2
imlib2                      1.5.1                 26 Mar 2018   https://downloads.sourceforge.net/enlightenment/imlib2-1.5.1.tar.bz2
inch                        0.8.0                 01 May 2018   https://rubygems.org/downloads/inch-0.8.0.gem
incidenceeditor             18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/incidenceeditor-18.04.0.tar.xz
incron                      0.5.7                 01 May 2014   http://inotify.aiken.cz/download/incron/incron-0.5.7.tar.bz2
inetutils                   1.9.4                 18 Oct 2015   http://ftp.gnu.org/gnu/inetutils/inetutils-1.9.4.tar.xz
initdtools                  0.1.3                 24 Jul 2017   http://people.freedesktop.org/~dbn/initd-tools/releases/initd-tools-0.1.3.tar.gz
initng                      0.6.10.2              Jun 2014      http://download.initng.org/initng/v0.6/initng-0.6.10.2.tar.bz2
inkscape                    0.92.3                24 Mar 2018   https://inkscape.org/en/gallery/item/12187/inkscape-0.92.3.tar.bz2
inotifytools                3.14                  Jun 2014      http://github.com/downloads/rvoicilas/inotify-tools/inotify-tools-3.14.tar.gz
inputproto                  2.3.2                 31 Jul 2016   https://www.x.org/releases/individual/proto/inputproto-2.3.2.tar.bz2
instiki                     0.10.2                Jan 2013      https://rubygems.org/downloads/instiki-0.10.2.gem
intelgputools               1.21                  23 Jan 2018   https://www.x.org/releases/individual/app/intel-gpu-tools-1.21.tar.xz
intelvaapidriver            2.1.0                 20 Feb 2018   https://github.com/intel/intel-vaapi-driver/releases/download/2.1.0/intel-vaapi-driver-2.1.0.tar.bz2
intltool                    0.51.0                04 Apr 2015   https://launchpad.net/intltool/trunk/0.51.0/+download/intltool-0.51.0.tar.gz
iotop                       0.6                   01 Jun 2014   http://guichaz.free.fr/iotop/files/iotop-0.6.tar.gz
iowa                        0.99.2.14             01 Jul 2013   https://github.com/wyhaines/iowa
iproute2                    4.15.0                31 Jan 2018   https://www.kernel.org/pub/linux/utils/net/iproute2/iproute2-4.15.0.tar.xz
iptables                    1.6.2                 02 Feb 2018   http://ftp.netfilter.org/pub/iptables/iptables-1.6.2.tar.bz2
iptraf                      3.0.0                 01 Jul 2011   ftp://iptraf.seul.org/pub/iptraf/iptraf-3.0.0.tar.gz
ipython                     0.8.1                 Jun 2014      http://ipython.org/
ire                         0.93                  Jan 2013      http://ire.sourceforge.net/
irrlicht                    1.8.3                 18 Mar 2016   http://downloads.sourceforge.net/irrlicht/irrlicht-1.8.3.zip
irssi                       1.1.0                 18 Jan 2018   https://github.com/irssi-import/irssi/releases/download/1.1.0/irssi-1.1.0.tar.xz
isbf                        0.1                   01 May 2014   http://freshmeat.net/redir/isbf/66799/url_tgz/isbf-0.1.tar.gz
isl                         0.18                  21 Dec 2016   http://isl.gforge.inria.fr/isl-0.18.tar.xz
isocodes                    3.76                  26 Sep 2017   https://pkg-isocodes.alioth.debian.org/downloads/iso-codes-3.76.tar.xz
isomaster                   1.1                   Jun 2014      http://littlesvr.ca/isomaster/
ispell                      3.4.00                07 Feb 2016   http://www.cs.hmc.edu/~geoff/tars/ispell-3.4.00.tar.gz
itstool                     2.0.4                 19 Oct 2017   http://files.itstool.org/itstool/itstool-2.0.4.tar.bz2
ivtv                        1.0.2                 Jun 2014      http://dl.ivtvdriver.org/ivtv/archive/
jack                        1.9.10                04 Aug 2015   https://dl.dropboxusercontent.com/u/28869550/jack-1.9.10.tar.bz2
jackaudioconnectionkit      0.125.0               15 Nov 2017   http://jackaudio.org/downloads/jack-audio-connection-kit-0.125.0.tar.gz
jailkit                     2.17                  25 Apr 2015   http://olivier.sessink.nl/jailkit/jailkit-2.17.tar.bz2
jam                         1.05                  01 Jun 2014   http://www.disi.unige.it/person/LagorioG/jam/jam105.zip
jansson                     2.10                  30 Apr 2017   http://www.digip.org/jansson/releases/jansson-2.10.tar.gz
jasper                      2.0.14                18 Sep 2017   http://www.ece.uvic.ca/~frodo/jasper/software/jasper-2.0.14.tar.gz
jawavedit                   1.16beta              Jun 2014      http://www.bome.com/JaWavedit/JaWavedit.tar.gz
jed                         0.99-19               11 Mar 2017   http://www.jedsoft.org/releases/jed/jed-0.99-19.tar.bz2
jekyll                      3.8.1                 01 May 2018   https://rubygems.org/downloads/jekyll-3.8.1.gem
jemalloc                    5.0.1                 27 Nov 2017   https://github.com/jemalloc/jemalloc/releases/download/5.0.1/jemalloc-5.0.1.tar.bz2
jfsutils                    1.1.15                11 Jun 2015   http://jfs.sourceforge.net/project/pub/jfsutils-1.1.15.tar.gz
jhbuild                     3.15.92               19 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/jhbuild/3.15/jhbuild-3.15.92.tar.xz
jigdo                       0.7.3                 21 Aug 2017   http://atterer.org/sites/atterer/files/2009-08/jigdo/jigdo-0.7.3.tar.bz2
jikes                       1.22                  01 Jun 2014   https://ovh.dl.sourceforge.net/sourceforge/jikes/jikes-1.22.tar.bz2
joe                         4.6                   13 Jan 2018   https://downloads.sourceforge.net/joe-editor/joe-4.6.tar.gz
john                        1.8.0                 18 Mar 2017   http://www.openwall.com/john/j/john-1.8.0.tar.xz
jokosher                    0.10.1                01 Jun 2014   http://edge.launchpad.net/jokosher/0.10/0.10.1/+download/jokosher-0.10.1.tar.gz
jovie                       17.08.3               09 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/jovie-17.08.3.tar.xz
jp2a                        1.0.6                 01 Jun 2014   http://sourceforge.net/projects/jp2a/files/jp2a/1.0.6/jp2a-1.0.6.tar.bz2
jpeg                        9a                    18 Feb 2016   http://www.ijg.org/files/jpegsr9b.zip
jpegoptim                   1.4.3                 19 Jun 2015   http://www.kokkonen.net/tjko/src/jpegoptim-1.4.3.tar.gz
jquery                      3.2.1                 27 Mar 2017   http://code.jquery.com/jquery-3.2.1.js
jqueryui                    1.11.4                27 Oct 2015   http://code.jquery.com/jquery-ui-1.11.4.js
jre                         1.8.0                 May 2014      http://www.java.com/en/download/manual.jsp?locale=en
jruby                       1.6.5                 Jan 2013      http://jruby.org.s3.amazonaws.com/downloads/1.6.5/jruby-src-1.6.5.tar.gz
json                        2.1.0                 27 Nov 2017   https://rubygems.org/downloads/json-2.1.0.gem
jsonc                       0.13.1                16 Mar 2018   https://s3.amazonaws.com/json-c_releases/releases/json-c-0.13.1.tar.gz
jsoncpp                     19.09.2017            19 Sep 2017   https://github.com/open-source-parsers/jsoncpp/archive/master.zip
jsonglib                    1.4.2                 23 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/json-glib/1.4/json-glib-1.4.2.tar.xz
jsonpure                    2.1.0                 06 Jan 2018   https://rubygems.org/downloads/json_pure-2.1.0.gem
jsonrpcglib                 3.27.90               05 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/jsonrpc-glib/3.27/jsonrpc-glib-3.27.90.tar.xz
jthread                     1.3.1                 Jun 2014      http://research.edm.uhasselt.be/jori/jthread/jthread-1.3.1.tar.bz2
judy                        1.0.5                 01 Jun 2014   http://sourceforge.net/projects/judy/files/judy/Judy-1.0.5/Judy-1.0.5.tar.gz
juk                         18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/juk-18.04.0.tar.xz
julia                       0.6.0                 13 Oct 2017   https://github.com/JuliaLang/julia/releases/download/v0.6.0/julia-0.6.0.tar.gz
jumpstart                   0.3                   Jun 2014      http://bitwagon.com/jumpstart/jumpstart-0.3.tgz
jwm                         2.2.2                 24 May 2015   http://joewing.net/projects/jwm/releases/jwm-2.2.2.tar.xz
k3b                         18.04.0               19 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/k3b-18.04.0.tar.xz
kaccessible                 17.08.3               09 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/kaccessible-17.08.3.tar.xz
kaccountsintegration        18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kaccounts-integration-18.04.0.tar.xz
kaccountsproviders          18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kaccounts-providers-18.04.0.tar.xz
kactivities                 5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kactivities-5.45.0.tar.xz
kactivitiesstats            5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kactivities-stats-5.45.0.tar.xz
kactivitymanagerd           5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kactivitymanagerd-5.12.4.tar.xz
kaddressbook                18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kaddressbook-18.04.0.tar.xz
kaffeine                    1.2.2                 Jun 2014      http://downloads.sourceforge.net/kaffeine/kaffeine-1.2.2.tar.gz
kajaanikombat               0.7                   01 Jan 2013   http://kombat.kajaani.net/dl/kajaani-kombat-0.7.tar.gz
kajongg                     4.14.3                11 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kajongg-4.14.3.tar.xz
kalarm                      18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kalarm-18.04.0.tar.xz
kalarmcal                   18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kalarmcal-18.04.0.tar.xz
kalgebra                    4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kalgebra-4.14.3.tar.xz
kalzium                     4.13.3                Jul 2014      ftp://ftp.kde.org/pub/kde/stable/4.13.3/src/kalzium-4.13.3.tar.xz
kamera                      4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kamera-4.14.3.tar.xz
kamikaze                    0.2.2                 Jun 2014      http://kamikaze.coolprojects.org/download/kamikaze-0.2.2.tar.gz
kamoso                      18.04.0               24 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kamoso-18.04.0.tar.xz
kanagram                    4.14.3                31 May 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kanagram-4.14.3.tar.xz
kapidox                     5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kapidox-5.45.0.tar.xz
kapman                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kapman-18.04.0.tar.xz
kapptemplate                18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kapptemplate-18.04.0.tar.xz
karchive                    5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/karchive-5.45.0.tar.xz
karmen                      0.11                  Jun 2014      karmen.sourceforge.net
kasablanca                  0.4.0.2               Jan 2013      http://download.berlios.de/kasablanca/kasablanca-0.4.0.2.tar.gz
katchtv                     0.91                  Jun 2014      http://www.digitalunleashed.com/downloads/katchtv/katchtv_latest_release.tar.bz2
kate                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kate-18.04.0.tar.xz
katomic                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/katomic-18.04.0.tar.xz
kauth                       5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kauth-5.45.0.tar.xz
kbackup                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kbackup-18.04.0.tar.xz
kbd                         1.15.5                26 Jun 2016   ftp://ftp.altlinux.org/pub/people/legion/kbd/kbd-1.15.5.tar.gz
kbfx                        0.4.9.3.1             01 Jun 2014   https://www.linux-apps.com/p/1081006/
kblackbox                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kblackbox-18.04.0.tar.xz
kblocks                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kblocks-18.04.0.tar.xz
kblog                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kblog-18.04.0.tar.xz
kblogger                    1.0alpha2             Jun 2014      http://kblogger.pwsp.net/files/kblogger-1.0-alpha2.tar.bz2
kbookmarks                  5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kbookmarks-5.45.0.tar.xz
kbounce                     4.14.3                09 Jun 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kbounce-4.14.3.tar.xz
kbproto                     1.0.7                 04 May 2015   http://xorg.freedesktop.org/releases/individual/proto/kbproto-1.0.7.tar.bz2
kbreakout                   4.14.3                16 May 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kbreakout-4.14.3.tar.xz
kbruch                      4.14.3                11 Jun 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kbruch-4.14.3.tar.xz
kcachegrind                 4.14.3                14 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kcachegrind-4.14.3.tar.xz
kcalc                       4.14.3                14 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kcalc-4.14.3.tar.xz
kcalcore                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kcalcore-18.04.0.tar.xz
kcalutils                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kcalutils-18.04.0.tar.xz
kcharselect                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kcharselect-18.04.0.tar.xz
kchmviewer                  7.7                   16 Sep 2017   https://sourceforge.net/projects/kchmviewer/files/kchmviewer/7.7/kchmviewer-7.7.tar.gz
kcmutils                    5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kcmutils-5.45.0.tar.xz
kcodecs                     5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kcodecs-5.45.0.tar.xz
kcolorchooser               18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kcolorchooser-18.04.0.tar.xz
kcompletion                 5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kcompletion-5.45.0.tar.xz
kconfig                     5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kconfig-5.45.0.tar.xz
kconfigwidgets              5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kconfigwidgets-5.45.0.tar.xz
kcontacts                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kcontacts-18.04.0.tar.xz
kcoreaddons                 5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kcoreaddons-5.45.0.tar.xz
kcrash                      5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kcrash-5.45.0.tar.xz
kcron                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kcron-18.04.0.tar.xz
kdav                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdav-18.04.0.tar.xz
kdbedit                     0.5.4                 Jun 2014      kdbedit-0.5.4
kdbg                        2.1.0                 Jun 2014      http://prdownloads.sourceforge.net/kdbg/kdbg-2.1.0.tar.gz
kdbusaddons                 5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kdbusaddons-5.45.0.tar.xz
kdeadmin                    4.3.0                 Jun 2014      ftp://gd.tuwien.ac.at/kde/stable/4.3.0/src/kdeadmin-4.3.0.tar.bz2
kdeartwork                  4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kdeartwork-4.14.3.tar.xz
kdebaseapps                 16.03.80              27 Mar 2016   http://download.kde.org/unstable/applications/16.03.80/src/kde-baseapps-16.03.80.tar.xz
kdebaseartwork              15.08.3               08 Apr 2018   https://download.kde.org/Attic/applications/15.08.3/src/kde-base-artwork-15.08.3.tar.xz
kdebaseruntime              4.3.90                08 Mar 2015   http://ftp.gwdg.de/pub/x11/kde/stable/4.0.2/src/kdebase-runtime-4.3.90.tar.xz
kdebaseworkspace            4.3.0                 Jun 2014      ftp://gd.tuwien.ac.at/kde/stable/4.3.0/src/kdebase-workspace-4.3.0.tar.bz2
kdebindings                 4.3.0                 Nov 2013      ftp://gd.tuwien.ac.at/kde/stable/4.3.0/src/kdebindings-4.3.0.tar.bz2
kdebugsettings              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdebugsettings-18.04.0.tar.xz
kdeclarative                5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kdeclarative-5.45.0.tar.xz
kdeclitools                 5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kde-cli-tools-5.12.4.tar.xz
kdecoration                 5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kdecoration-5.12.4.tar.xz
kded                        5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kded-5.45.0.tar.xz
kdedevscripts               4.14.3                01 May 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kde-dev-scripts-4.14.3.tar.xz
kdedevutils                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kde-dev-utils-18.04.0.tar.xz
kdeedudata                  18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdeedu-data-18.04.0.tar.xz
kdegraphicsmobipocket       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdegraphics-mobipocket-18.04.0.tar.xz
kdegraphicsstrigianalyzer   4.12.97               Apr 2014      ftp://gd.tuwien.ac.at/kde/unstable/4.12.97/src/kdegraphics-strigi-analyzer-4.12.97.tar.xz
kdegraphicsthumbnailers     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdegraphics-thumbnailers-18.04.0.tar.xz
kdegtkconfig                5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kde-gtk-config-5.12.4.tar.xz
kdelibs                     4.14.38               09 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/kdelibs-4.14.38.tar.xz
kdelibs4support             5.40.0                01 Dec 2017   https://download.kde.org/stable/frameworks/5.40/portingAids/kdelibs4support-5.40.0.tar.xz
kdenetwork                  4.0.3                 Jun 2014      ftp://gd.tuwien.ac.at/kde/stable/4.0.3/src/kdenetwork-4.0.3.tar.bz2
kdenetworkfilesharing       4.13.3                Jul 2014      ftp://ftp.kde.org/pub/kde/stable/4.13.3/src/kdenetwork-filesharing-4.13.3.tar.xz
kdenetworkstrigianalyzers   4.14.3                12 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kdenetwork-strigi-analyzers-4.14.3.tar.xz
kdenlive                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdenlive-18.04.0.tar.xz
kdepim                      16.03.80              27 Mar 2016   http://download.kde.org/unstable/applications/16.03.80/src/kdepim-16.03.80.tar.xz
kdepimaddons                18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdepim-addons-18.04.0.tar.xz
kdepimappslibs              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdepim-apps-libs-18.04.0.tar.xz
kdepimlibs                  4.14.9                09 Jul 2015   http://download.kde.org/stable/applications/15.04.2/src/kdepimlibs-4.14.9.tar.xz
kdepimruntime               18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdepim-runtime-18.04.0.tar.xz
kdeplasmaaddons             5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kdeplasma-addons-5.12.4.tar.xz
kderuntime                  17.08.3               09 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/kde-runtime-17.08.3.tar.xz
kdesdkkioslaves             4.14.3                12 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kdesdk-kioslaves-4.14.3.tar.xz
kdesdkthumbnailers          18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdesdk-thumbnailers-18.04.0.tar.xz
kdesignerplugin             5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kdesignerplugin-5.45.0.tar.xz
kdesu                       5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kdesu-5.45.0.tar.xz
kdesvn                      0.14.6                Jun 2014      http://www.alwins-world.de/programs/download/kdesvn/0.14.x/kdesvn-0.14.6.tar.bz2
kdevelop                    5.2.1                 24 Nov 2017   http://download.kde.org/stable/kdevelop/5.2.1/src/kdevelop-5.2.1.tar.xz
kdewallpapers               4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kde-wallpapers-4.14.3.tar.xz
kdewebdev                   4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kdewebdev-4.14.3.tar.xz
kdewebkit                   5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kdewebkit-5.45.0.tar.xz
kdeworkspace                4.11.21               09 Jul 2015   http://download.kde.org/stable/applications/15.04.3/src/kde-workspace-4.11.21.tar.xz
kdf                         4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kdf-4.14.3.tar.xz
kdialog                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kdialog-18.04.0.tar.xz
kdiamond                    4.14.3                24 May 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kdiamond-4.14.3.tar.xz
kdnssd                      5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kdnssd-5.45.0.tar.xz
kdoctools                   5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kdoctools-5.45.0.tar.xz
keditbookmarks              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/keditbookmarks-18.04.0.tar.xz
kemoticons                  5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kemoticons-5.45.0.tar.xz
keytouch                    2.4.0beta             01 Jun 2014   http://keytouch.sourceforge.net/keytouch-2.4.0beta.tar.xz
keyutils                    1.5.9                 01 Jun 2014   http://people.redhat.com/~dhowells/keyutils/keyutils-1.5.9.tar.bz2
kfilemetadata               5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kfilemetadata-5.45.0.tar.xz
kfilereplace                17.08.3               09 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/kfilereplace-17.08.3.tar.xz
kfind                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kfind-18.04.0.tar.xz
kflickr                     20140907              24 Apr 2016   http://sourceforge.net/projects/kflickr/files/kflickr/20140907/kflickr-20140907.tar.bz2
kfloppy                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kfloppy-18.04.0.tar.xz
kfourinline                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kfourinline-18.04.0.tar.xz
kgamma                      4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kgamma-4.14.3.tar.xz
kgamma5                     5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kgamma5-5.12.4.tar.xz
kgeography                  4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kgeography-4.14.3.tar.xz
kget                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kget-18.04.0.tar.xz
kglobalaccel                5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kglobalaccel-5.45.0.tar.xz
kgoldrunner                 4.14.3                14 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kgoldrunner-4.14.3.tar.xz
kgpg                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kgpg-18.04.0.tar.xz
kgraphviewer                1.99.1                Jun 2014      http://download.gna.org/kgraphviewer/kgraphviewer-1.99.1.tar.bz2
kguiaddons                  5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kguiaddons-5.45.0.tar.xz
khangman                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/khangman-18.04.0.tar.xz
khelpcenter                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/khelpcenter-18.04.0.tar.xz
kholidays                   5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kholidays-5.45.0.tar.xz
khotkeys                    5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/khotkeys-5.12.4.tar.xz
khtml                       5.40.0                01 Dec 2017   https://download.kde.org/stable/frameworks/5.40/portingAids/khtml-5.40.0.tar.xz
ki18n                       5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/ki18n-5.45.0.tar.xz
kiconthemes                 5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kiconthemes-5.45.0.tar.xz
kid                         0.9.5                 01 Jun 2014   http://cheeseshop.python.org/pypi/kid/
kid3                        3.5.0                 16 Sep 2017   https://prdownloads.sourceforge.net/kid3/kid3-3.5.0.tar.gz
kidentitymanagement         18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kidentitymanagement-18.04.0.tar.xz
kidletime                   5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kidletime-5.45.0.tar.xz
kig                         18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kig-18.04.0.tar.xz
kigo                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kigo-18.04.0.tar.xz
kildclient                  2.7.0                 Jun 2014      http://heanet.dl.sourceforge.net/sourceforge/kildclient/kildclient-2.7.0.tar.gz
kile                        2.9.91                31 Oct 2017   https://kile.sourceforge.io/download.php?get=https://sourceforge.net/projects/kile/files/unstable/kile-3.0b1/kile-2.9.91.tar.bz2
killbots                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/killbots-18.04.0.tar.xz
kimageformats               5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kimageformats-5.45.0.tar.xz
kimagemapeditor             18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kimagemapeditor-18.04.0.tar.xz
kimap                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kimap-18.04.0.tar.xz
kimwitu++                   2.3.11                26 Sep 2017   https://www2.informatik.hu-berlin.de/sam/kimwitu++/kimwitu++-2.3.11.tar.gz
kinfocenter                 5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kinfocenter-5.12.4.tar.xz
kinit                       5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kinit-5.45.0.tar.xz
kino                        1.3.4                 01 Jun 2014   http://downloads.sourceforge.net/kino/kino-1.3.4.tar.gz
kio                         5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kio-5.45.0.tar.xz
kioextras                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kio-extras-18.04.0.tar.xz
kirigami2                   5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kirigami2-5.45.0.tar.xz
kiriki                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kiriki-18.04.0.tar.xz
kismet                      2016-07-R1            27 Jan 2018   https://www.kismetwireless.net/code/kismet-2016-07-R1.tar.xz
kite                        1.0.4                 Jun 2014      http://www.kite-language.org/files/kite-1.0.4.tar.gz
kitemmodels                 5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kitemmodels-5.45.0.tar.xz
kitemviews                  5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kitemviews-5.45.0.tar.xz
kiten                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kiten-18.04.0.tar.xz
kiwi                        1.9.29                20 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/kiwi/1.9/kiwi-1.9.29.tar.xz
kjobwidgets                 5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kjobwidgets-5.45.0.tar.xz
kjs                         5.40.0                01 Dec 2017   https://download.kde.org/stable/frameworks/5.40/portingAids/kjs-5.40.0.tar.xz
kjsembed                    5.40.0                01 Dec 2017   https://download.kde.org/stable/frameworks/5.40/portingAids/kjsembed-5.40.0.tar.xz
kjumpingcube                18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kjumpingcube-18.04.0.tar.xz
klavaro                     3.03                  01 Jun 2014   http://downloads.sourceforge.net/project/klavaro/klavaro-3.03.tar.bz2
kldap                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kldap-18.04.0.tar.xz
klear                       0.6.1                 01 Jun 2014   http://www.klear.org/sources/
kleopatra                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kleopatra-18.04.0.tar.xz
klettres                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/klettres-18.04.0.tar.xz
klickety                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/klickety-18.04.0.tar.xz
klineakconfig               0.8beta2              Jun 2014      http://nchc.dl.sourceforge.net/sourceforge/lineak/klineakconfig-0.8-beta2.tar.gz
klines                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/klines-18.04.0.tar.xz
klininfo                    0.2                   Jun 2014      http://freshmeat.net/projects/klininfo/?branch_id=65372&release_id=231523
klinkstatus                 17.08.3               09 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/klinkstatus-17.08.3.tar.xz
kmag                        4.14.3                14 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kmag-4.14.3.tar.xz
kmahjongg                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmahjongg-18.04.0.tar.xz
kmail                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmail-18.04.0.tar.xz
kmailaccountwizard          18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmail-account-wizard-18.04.0.tar.xz
kmailtransport              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmailtransport-18.04.0.tar.xz
kmarkdownwebview            0.3.0                 01 Nov 2017   https://download.kde.org/stable/kmarkdownwebview/0.3.0/src/kmarkdownwebview-0.3.0.tar.xz
kmbox                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmbox-18.04.0.tar.xz
kmediaplayer                5.40.0                01 Dec 2017   https://download.kde.org/stable/frameworks/5.40/portingAids/kmediaplayer-5.40.0.tar.xz
kmenuedit                   5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kmenuedit-5.12.4.tar.xz
kmime                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmime-18.04.0.tar.xz
kmines                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmines-18.04.0.tar.xz
kmix                        4.14.3                12 Apr 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kmix-4.14.3.tar.xz
kmod                        25                    09 Jan 2018   https://www.kernel.org/pub/linux/utils/kernel/kmod/kmod-25.tar.xz
kmousetool                  18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmousetool-18.04.0.tar.xz
kmouth                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmouth-18.04.0.tar.xz
kmp3burn                    0.3.2                 Jun 2014      http://www.martin-keil.de/
kmpg2                       1.95                  Jun 2014      http://nchc.dl.sourceforge.net/sourceforge/kmpg2/KmPg2-1.95.tar.bz2
kmplayer                    0.11.0rc3             Jun 2014      http://kmplayer.kde.org/download.php
kmplot                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kmplot-18.04.0.tar.xz
kmuddy                      22.03.2016            22 Mar 2016   http://www.kmuddy.com/releases/stable/kmuddy-1.0.1.tar.gz
kmymoney                    5.0.0                 07 Feb 2018   http://download.kde.org/stable/kmymoney/5.0.0/src/kmymoney-5.0.0.tar.xz
knavalbattle                18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/knavalbattle-18.04.0.tar.xz
knetdockapp                 0.8                   Jun 2014      http://www.kde-apps.org/content/show.php/KNetDockApp?content=29398
knetwalk                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/knetwalk-18.04.0.tar.xz
knewstuff                   5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/knewstuff-5.45.0.tar.xz
knotes                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/knotes-18.04.0.tar.xz
knotifications              5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/knotifications-5.45.0.tar.xz
knotifyconfig               5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/knotifyconfig-5.45.0.tar.xz
kobodeluxe                  0.5.1                 Aug 2013      http://www.olofson.net/kobodl/download/KoboDeluxe-0.5.1.tar.bz2
kolf                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kolf-18.04.0.tar.xz
kollision                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kollision-18.04.0.tar.xz
kolourpaint                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kolourpaint-18.04.0.tar.xz
kompare                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kompare-18.04.0.tar.xz
konforka                    0.0                   Jun 2014      http://kin.klever.net/dist/konforka-0.0.tar.bz2
konqueror                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/konqueror-18.04.0.tar.xz
konquest                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/konquest-18.04.0.tar.xz
konsole                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/konsole-18.04.0.tar.xz
kontact                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kontact-18.04.0.tar.xz
kontactinterface            18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kontactinterface-18.04.0.tar.xz
konversation                1.6                   09 Jul 2015   http://download.kde.org/download.php?url=stable/konversation/1.6/src/konversation-1.6.tar.xz
kopete                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kopete-18.04.0.tar.xz
korganizer                  18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/korganizer-18.04.0.tar.xz
korundum                    4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/korundum-4.14.3.tar.xz
kpackage                    5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kpackage-5.45.0.tar.xz
kparts                      5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kparts-5.45.0.tar.xz
kpat                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kpat-18.04.0.tar.xz
kpeople                     5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kpeople-5.45.0.tar.xz
kpimtextedit                18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kpimtextedit-18.04.0.tar.xz
kplayer                     0.6.3                 01 Jun 2014   http://heanet.dl.sourceforge.net/sourceforge/kplayer/kplayer-0.6.3.tar.bz2
kplotting                   5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kplotting-5.45.0.tar.xz
kppp                        17.08.3               11 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/kppp-17.08.3.tar.xz
kpty                        5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kpty-5.45.0.tar.xz
kqtquickcharts              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kqtquickcharts-18.04.0.tar.xz
kramdown                    1.16.2                09 Jan 2018   https://rubygems.org/downloads/kramdown-1.16.2.gem
kraptor                     03APR2004             Jun 2014      http://kraptor.sourceforge.net/
krb5                        1.15.2                06 Oct 2017   http://web.mit.edu/kerberos/dist/krb5/1.15/krb5-1.15.2.tar.gz
krb5authdialog              3.26.1                12 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/krb5-auth-dialog/3.26/krb5-auth-dialog-3.26.1.tar.xz
krdc                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/krdc-18.04.0.tar.xz
krecord                     1.16                  01 Jun 2014   http://dl.bytesex.org/releases/krecord/
kremotecontrol              4.14.3                09 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kremotecontrol-4.14.3.tar.xz
kreversi                    4.14.3                04 Jun 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kreversi-4.14.3.tar.xz
krfb                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/krfb-18.04.0.tar.xz
krita                       4.0.1                 10 Apr 2018   https://download.kde.org/stable/krita/4.0.1/krita-4.0.1.tar.gz
kross                       5.40.0                01 Dec 2017   https://download.kde.org/stable/frameworks/5.40/portingAids/kross-5.40.0.tar.xz
krossinterpreters           18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kross-interpreters-18.04.0.tar.xz
kruler                      4.14.3                29 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kruler-4.14.3.tar.xz
krunner                     5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/krunner-5.45.0.tar.xz
krusader                    2.6.0                 12 Apr 2017   http://download.kde.org/stable/krusader/2.6.0/krusader-2.6.0.tar.xz
ksaneplugin                 17.08.3               12 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/ksaneplugin-17.08.3.tar.xz
kscd                        17.08.3               12 Nov 2017   https://download.kde.org/stable/applications/17.08.3/src/kscd-17.08.3.tar.xz
kscreen                     5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kscreen-5.12.4.tar.xz
kscreenlocker               5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kscreenlocker-5.12.4.tar.xz
kservice                    5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kservice-5.45.0.tar.xz
kshisen                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kshisen-18.04.0.tar.xz
kshutdown                   1.0.2                 01 Jun 2014   http://superb-west.dl.sourceforge.net/sourceforge/kshutdown/kshutdown-1.0.2.tar.bz2
ksirk                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ksirk-18.04.0.tar.xz
ksmtp                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ksmtp-18.04.0.tar.xz
ksnakeduel                  18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ksnakeduel-18.04.0.tar.xz
ksnapshot                   4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/ksnapshot-4.14.3.tar.xz
ksniffer                    0.3.2                 01 Jun 2014   http://www.ksniffer.org/
kspaceduel                  18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kspaceduel-18.04.0.tar.xz
ksquares                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ksquares-18.04.0.tar.xz
ksquirrel                   0.8.0                 01 Jun 2014   http://downloads.sourceforge.net/ksquirrel/ksquirrel-0.8.0.tar.bz2
ksquirrellibs               0.7.1                 Jun 2014      http://ksquirrel.sourceforge.net/download.php
ksshaskpass                 5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/ksshaskpass-5.12.4.tar.xz
kstars                      2.8.8                 01 Dec 2017   http://mirror.easyname.at/kde/stable/kstars/kstars-2.8.8.tar.xz
ksubtile                    1.3                   01 Jun 2014   http://ksubtile.sourceforge.net/
ksudoku                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ksudoku-18.04.0.tar.xz
ksysguard                   5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/ksysguard-5.12.4.tar.xz
ksystemlog                  4.14.3                15 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/ksystemlog-4.14.3.tar.xz
kteatime                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kteatime-18.04.0.tar.xz
ktexteditor                 5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/ktexteditor-5.45.0.tar.xz
ktextwidgets                5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/ktextwidgets-5.45.0.tar.xz
ktimer                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktimer-18.04.0.tar.xz
ktnef                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktnef-18.04.0.tar.xz
ktorrent                    4.3.1                 01 Jan 2013   http://ktorrent.pwsp.net/downloads/4.3.1/ktorrent-4.3.1.tar.bz2
ktouch                      4.14.3                03 Jun 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/ktouch-4.14.3.tar.xz
ktpaccountskcm              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-accounts-kcm-18.04.0.tar.xz
ktpapprover                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-approver-18.04.0.tar.xz
ktpauthhandler              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-auth-handler-18.04.0.tar.xz
ktpcallui                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-call-ui-18.04.0.tar.xz
ktpcommoninternals          18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-common-internals-18.04.0.tar.xz
ktpcontactlist              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-contact-list-18.04.0.tar.xz
ktpcontactrunner            18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-contact-runner-18.04.0.tar.xz
ktpdesktopapplets           18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-desktop-applets-18.04.0.tar.xz
ktpfiletransferhandler      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-filetransfer-handler-18.04.0.tar.xz
ktpkdedmodule               18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-kded-module-18.04.0.tar.xz
ktpsendfile                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-send-file-18.04.0.tar.xz
ktptextui                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktp-text-ui-18.04.0.tar.xz
ktuberling                  18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/ktuberling-18.04.0.tar.xz
kturtle                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kturtle-18.04.0.tar.xz
kubrick                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kubrick-18.04.0.tar.xz
kuklomenos                  0.4.5                 10 Oct 2017   http://mbays.freeshell.org/kuklomenos/src/kuklomenos-0.4.5.tar.gz
kunitconversion             5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kunitconversion-5.45.0.tar.xz
kuser                       4.14.3                15 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/kuser-4.14.3.tar.xz
kvideoencoder               0.08                  01 Jun 2014   http://kde-apps.org/content/show.php?content=31385
kvkbd                       0.5                   01 Jun 2014   http://www.kde-apps.org/content/show.php/Kvkbd?content=56019
kwalify                     0.7.2                 01 Dec 2017   https://rubygems.org/downloads/kwalify-0.7.2.gem
kwallet                     5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kwallet-5.45.0.tar.xz
kwalletmanager              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kwalletmanager-18.04.0.tar.xz
kwalletpam                  5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kwallet-pam-5.12.4.tar.xz
kwave                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kwave-18.04.0.tar.xz
kwayland                    5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kwayland-5.45.0.tar.xz
kwaylandintegration         5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kwayland-integration-5.12.4.tar.xz
kwidgetsaddons              5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kwidgetsaddons-5.45.0.tar.xz
kwifiselector               0.8                   01 Jun 2014   http://sourceforge.net/projects/kwifiselector
kwin                        5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kwin-5.12.4.tar.xz
kwindowsystem               5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kwindowsystem-5.45.0.tar.xz
kwlan                       0.6.2                 01 Jun 2014   http://www.kde-apps.org/content/show.php?content=37041
kwordquiz                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/kwordquiz-18.04.0.tar.xz
kwrited                     5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/kwrited-5.12.4.tar.xz
kxgenerator                 0.3.7                 Jun 2014      http://kde-apps.org/content/show.php?content=39085
kxmlgui                     5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kxmlgui-5.45.0.tar.xz
kxmlrpcclient               5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/kxmlrpcclient-5.45.0.tar.xz
kye                         0.9.3                 Jun 2014      http://games.moria.org.uk/kye/pygtk
lablgtk                     2.10.0                Jun 2014      http://wwwfun.kurims.kyoto-u.ac.jp/soft/olabl/dist/lablgtk-2.10.0.tar.gz
ladspasdk                   1.13                  01 Nov 2012   http://www.ladspa.org/download/ladspa_sdk_1.13.tgz
lame                        3.100                 26 Oct 2017   https://sourceforge.net/projects/lame/files/lame/3.100/lame-3.100.tar.gz
lapack                      3.7.1                 09 Jul 2017   http://www.netlib.org/lapack/lapack-3.7.1.tgz
larswm                      7.5.3                 27 Jul 2017   http://porneia.free.fr/larswm/larswm-7.5.3.tar.gz
lasem                       0.4.3                 04 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/lasem/0.4/lasem-0.4.3.tar.xz
latexila                    3.27.1                09 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/latexila/3.27/latexila-3.27.1.tar.xz
lbreakout                   010315                Dec 2012      http://prdownloads.sourceforge.net/lgames/lbreakout-010315.tar.gz
lbreakout2                  2.6.4                 Dec 2012      http://sourceforge.net/projects/lgames/files/lbreakout2/2.6/lbreakout2-2.6.4.tar.gz
lbxproxy                    1.0.3                 Feb 2013      http://xorg.freedesktop.org/releases/individual/app/lbxproxy-1.0.3.tar.bz2
lcms                        1.19                  01 Jan 2013   http://sourceforge.net/projects/lcms/files/lcms/1.19/lcms-1.19.tar.gz
lcms2                       2.9                   11 Nov 2017   https://sourceforge.net/projects/lcms/files/lcms/2.9/lcms2-2.9.tar.gz
ldmud                       3.5.0                 22 Feb 2017   https://github.com/ldmud/ldmud/tarball/master/ldmud-3.5.0
leafpad                     0.8.17                24 Nov 2017   http://savannah.nongnu.org/download/leafpad/leafpad-0.8.17.tar.gz
leptonica                   1.72                  12 Dec 2015   http://www.leptonica.com/source/leptonica-1.72.tar.gz
less                        530                   17 Feb 2018   http://www.greenwoodsoftware.com/less/less-530.tar.gz
lesstif                     0.95.2                01 Jun 2014   http://sourceforge.net/projects/lesstif/files/lesstif/0.95.2/lesstif-0.95.2.tar.gz
lfhex                       0.4                   01 Jun 2014   http://stoopidsimple.com/files/lfhex-0.4.tar.gz
lftp                        4.8.3                 10 Oct 2017   http://lftp.yar.ru/ftp/lftp-4.8.3.tar.xz
lgeneral                    1.4.1                 23 Sep 2017   https://sourceforge.net/projects/lgeneral/files/lgeneral/lgeneral-1.4.1.tar.gz
libabigail                  1.0.rc5               01 Jul 2016   http://mirrors.kernel.org/sourceware/libabigail/libabigail-1.0.rc5.tar.gz
libao                       1.2.0                 14 Aug 2017   https://ftp.osuosl.org/pub/xiph/releases/ao/libao-1.2.0.tar.gz
libapplewm                  1.3.0                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/libAppleWM-1.3.0.tar.bz2
libapreq2                   2.08                  01 Jun 2014   http://apache.4any.org/httpd/libapreq/libapreq2-2.08.tar.gz
libarchive                  3.3.2                 06 Nov 2017   http://www.libarchive.org/downloads/libarchive-3.3.2.tar.gz
libartlgpl                  2.3.21                01 Jun 2014   ftp://ftp.gnome.org/pub/GNOME/sources/libart_lgpl/2.3/libart_lgpl-2.3.21.tar.bz2
libass                      0.14.0                11 Nov 2017   https://github.com/libass/libass/releases/download/0.14.0/libass-0.14.0.tar.xz
libassuan                   2.5.1                 09 Dec 2017   ftp://ftp.gnupg.org/gcrypt/libassuan/libassuan-2.5.1.tar.bz2
libast                      0.7                   09 Jul 2015   http://www.eterm.org/download/libast-0.7.tar.gz
libatasmart                 0.19                  01 Jun 2014   http://0pointer.de/public/libatasmart-0.19.tar.xz
libatomicops                7.6.4                 30 Mar 2018   https://github.com/ivmai/libatomic_ops/releases/download/v7.6.4/libatomic_ops-7.6.4.tar.gz
libav                       11.3                  22 May 2015   https://libav.org/releases/libav-11.3.tar.xz
libavc1394                  0.5.4                 Jun 2014      http://sourceforge.net/projects/libavc1394/files/libavc1394/libavc1394-0.5.4.tar.gz
libavg                      0.7.0                 Jun 2014      http://www.libavg.de/libavg-0.7.0.tar.gz
libbash                     0.9.10                Jun 2014      http://surfnet.dl.sourceforge.net/sourceforge/libbash/libbash-0.9.10.tar.bz2
libblockdev                 2.17                  29 Apr 2018   https://github.com/storaged-project/libblockdev/releases/download/2.17-1/libblockdev-2.17.tar.gz
libbluray                   0.9.2                 12 Dec 2015   ftp://ftp.videolan.org/pub/videolan/libbluray/0.9.2/libbluray-0.9.2.tar.bz2
libbonobo                   2.32.1                01 May 2012   http://ftp.gnome.org/pub/GNOME/sources/libbonobo/2.32/libbonobo-2.32.1.tar.bz2
libbonoboui                 2.24.5                01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/libbonoboui/2.24/libbonoboui-2.24.5.tar.bz2
libbpg                      0.9.7                 27 Aug 2016   http://bellard.org/bpg/libbpg-0.9.7.tar.gz
libbtctl                    0.11.1                Jun 2014      http://ftp.gnome.org/pub/gnome/sources/libbtctl/0.11/libbtctl-0.11.1.tar.bz2
libburn                     1.4.8                 20 Sep 2017   http://files.libburnia-project.org/releases/libburn-1.4.8.tar.gz
libbytesize                 1.3                   21 Apr 2018   https://github.com/storaged-project/libbytesize/releases/download/1.3/libbytesize-1.3.tar.gz
libcaca                     0.99.beta19           12 Mar 2015   http://caca.zoy.org/files/libcaca/libcaca-0.99.beta19.tar.gz
libcacard                   2.5.2                 17 Dec 2015   http://www.spice-space.org/download/libcacard/libcacard-2.5.2.tar.xz
libcanberra                 0.30                  01 Jan 2013   http://0pointer.de/lennart/projects/libcanberra/libcanberra-0.30.tar.xz
libcap                      2.24                  22 May 2015   https://www.kernel.org/pub/linux/libs/security/linux-privs/libcap2/libcap-2.24.tar.xz
libcap2                     2.24                  08 Mar 2015   ftp://ftp.de.debian.org/debian/pool/main/libc/libcap2/libcap2_2.24.orig.tar.xz
libcapng                    0.7.7                 21 May 2015   https://people.redhat.com/sgrubb/libcap-ng/libcap-ng-0.7.7.tar.gz
libcddb                     1.3.2                 01 Jun 2014   http://prdownloads.sourceforge.net/libcddb/libcddb-1.3.2.tar.bz2
libcdio                     2.0.0                 02 Jan 2018   https://ftp.gnu.org/gnu/libcdio/libcdio-2.0.0.tar.gz
libcerf                     1.3                   03 Jan 2016   https://sourceforge.net/projects/libcerf/files/libcerf-1.3.tgz
libchamplain                0.12.16               07 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/libchamplain/0.12/libchamplain-0.12.16.tar.xz
libcm                       0.1.1                 01 Jun 2014   http://ftp.acc.umu.se/pub/GNOME/sources/libcm/0.1/libcm-0.1.1.tar.bz2
libconfig                   1.7.2                 08 Apr 2018   https://github.com/hyperrealm/libconfig/archive/v1.7.2.tar.gz
libcroco                    0.6.12                06 Apr 2017   http://ftp.gnome.org/pub/gnome/sources/libcroco/0.6/libcroco-0.6.12.tar.xz
libcryptui                  3.12.2                01 May 2014   http://ftp.acc.umu.se/pub/GNOME/sources/libcryptui/3.12/libcryptui-3.12.2.tar.xz
libdaemon                   0.14                  01 Aug 2013   http://0pointer.de/lennart/projects/libdaemon/libdaemon-0.14.tar.gz
libdap                      3.19.1                21 Dec 2017   https://www.opendap.org/pub/source/libdap-3.19.1.tar.gz
libdazzle                   3.26.3                21 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/libdazzle/3.26/libdazzle-3.26.3.tar.xz
libdbi                      0.9.0                 04 Jul 2017   https://sourceforge.net/projects/libdbi/files/libdbi/libdbi-0.9.0/libdbi-0.9.0.tar.gz
libdbusmenuqt               0.9.2                 01 Nov 2012   https://launchpad.net/libdbusmenu-qt/trunk/0.9.2/+download/libdbusmenu-qt-0.9.2.tar.bz2
libdc1394                   2.1.4                 Jun 2014      http://sourceforge.net/projects/libdc1394/files/libdc1394-2/libdc1394-2.1.4.tar.gz
libdca                      0.0.5                 Jun 2014      http://download.videolan.org/pub/videolan/libdca/0.0.5/libdca-0.0.5.tar.bz2
libdisasm                   0.22                  Jun 2014      http://freshmeat.net/redir/libdisasm/72406/url_tgz/libdisasm-0.22.tar.gz
libdiscid                   0.6.1                 14 Apr 2015   http://ftp.musicbrainz.org/pub/musicbrainz/libdiscid/libdiscid-0.6.1.tar.gz
libdivecomputer             0.4.2                 02 Jun 2015   http://www.libdivecomputer.org/releases/libdivecomputer-0.4.2.tar.gz
libdmtx                     0.7.4                 19 Sep 2017   https://sourceforge.net/projects/libdmtx/files/libdmtx/0.7.4/libdmtx-0.7.4.tar.gz
libdmx                      1.1.2                 Dec 2012      http://xorg.freedesktop.org/releases/individual/lib/libdmx-1.1.2.tar.bz2
libdnet                     1.12                  Jun 2014      http://libdnet.googlecode.com/files/libdnet-1.12.tgz
libdrm                      2.4.91                08 Mar 2018   https://dri.freedesktop.org/libdrm/libdrm-2.4.91.tar.bz2
libdv                       1.0.0                 01 Jun 2014   http://sourceforge.net/projects/libdv/files/libdv/1.0.0/libdv-1.0.0.tar.gz
libdvbpsi                   0.2.0                 Jun 2014      http://download.videolan.org/pub/libdvbpsi/0.2.0/libdvbpsi-0.2.0.tar.bz2
libdvdcss                   1.4.1                 27 Mar 2018   https://get.videolan.org/libdvdcss/1.4.1/libdvdcss-1.4.1.tar.bz2
libdvdnav                   6.0.0                 20 Jan 2018   http://download.videolan.org/pub/videolan/libdvdnav/6.0.0/libdvdnav-6.0.0.tar.bz2
libdvdread                  6.0.0                 19 Jan 2018   http://download.videolan.org/videolan/libdvdread/6.0.0/libdvdread-6.0.0.tar.bz2
libebml                     1.3.4                 25 Jul 2017   https://dl.matroska.org/downloads/libebml/libebml-1.3.4.tar.bz2
libebt                      1.3.0                 01 Jun 2014   http://libebt.berlios.de/
libedit                     3.1                   11 Sep 2017   http://thrysoee.dk/editline/libedit-20170329-3.1.tar.gz
libelf                      0.8.13                01 Jun 2014   http://www.mr511.de/software/libelf-0.8.13.tar.gz
libepc                      0.4.4                 01 Sep 2013   http://ftp.gnome.org/pub/gnome/sources/libepc/0.4/libepc-0.4.4.tar.xz
libepoxy                    1.5.0                 01 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/libepoxy/1.5/libepoxy-1.5.0.tar.xz
liberror                    2.1.80011             01 Jun 2014   http://www.theiling.de/projects/liberror.html#download
libesmtp                    1.0.6                 01 Jun 2014   http://www.stafford.uklinux.net/libesmtp/libesmtp-1.0.6.tar.bz2
libetc                      0.4                   31 Oct 2017   http://ordiluc.net/fs/libetc/libetc-0.4.tar.gz
libetpan                    1.1                   25 Aug 2016   https://sourceforge.net/projects/libetpan/files/libetpan/1.1/libetpan-1.1.tar.gz
libevdev                    1.5.9                 14 Mar 2018   https://www.freedesktop.org/software/libevdev/libevdev-1.5.9.tar.xz
libevent                    2.1.8                 26 Jul 2017   https://github.com/libevent/libevent/releases/download/release-2.1.8-stable/libevent-2.1.8-stable.tar.gz
libexif                     0.6.21                01 Mar 2013   http://downloads.sourceforge.net/libexif/libexif-0.6.21.tar.bz2
libextractor                1.5                   12 Oct 2017   http://ftp.gnu.org/gnu/libextractor/libextractor-1.5.tar.gz
libfakekey                  0.1                   01 Sep 2014   http://downloads.yoctoproject.org/releases/matchbox/libfakekey/0.1/libfakekey-0.1.tar.bz2
libfame                     0.9.1                 Jun 2014      https://puzzle.dl.sourceforge.net/sourceforge/fame/libfame-0.9.1.tar.gz
libferris                   1.5.19                11 Nov 2017   https://sourceforge.net/projects/witme/files/libferris/1.5.19/libferris-1.5.19.tar.xz
libfetch                    2.33                  Jun 2014      ftp://ftp.archlinux.org/other/libfetch/libfetch-2.33.tar.gz
libffi                      3.2.1                 24 May 2015   ftp://sourceware.org/pub/libffi/libffi-3.2.1.tar.gz
libfirm                     1.22.0                04 Jan 2016   https://github.com/MatzeB/libfirm/archive/libfirm-1.22.0.tar.gz
libfixbuf                   1.5.0                 Jul 2014      http://tools.netsa.cert.org/releases/libfixbuf-1.5.0.tar.gz
libflowmanager              2.0.2                 01 Aug 2012   http://research.wand.net.nz/software/libflowmanager/libflowmanager-2.0.2.tar.gz
libfm                       1.2.5                 11 Nov 2017   https://downloads.sourceforge.net/pcmanfm/libfm-1.2.5.tar.xz
libfontenc                  1.1.3                 03 May 2015   http://xorg.freedesktop.org/releases/individual/lib/libfontenc-1.1.3.tar.gz
libfreebob                  1.0.11                Jun 2014      https://sourceforge.net/projects/freebob/files/libfreebob-1.x/libfreebob-1.0.11/libfreebob-1.0.11.tar.gz
libfs                       1.0.7                 03 May 2015   http://xorg.freedesktop.org/releases/individual/lib/libFS-1.0.7.tar.bz2
libft                       0.4                   Jun 2014      http://defiant.homedns.org/~erik/ft/libft/files/libft-0.4.tar.gz
libftdi                     0.13                  Jun 2014      http://www.intra2net.com/de/produkte/opensource/ftdi/TGZ/libftdi-0.13.tar.gz
libgadu                     1.12.2                19 Sep 2017   http://github.com/wojtekka/libgadu/releases/download/1.12.2/libgadu-1.12.2.tar.gz
libgailgnome                1.20.4                01 Nov 2012   http://ftp.gnome.org/pub/GNOME/sources/libgail-gnome/1.20/libgail-gnome-1.20.4.tar.bz2
libgamessupport             1.0.2                 07 May 2016   http://ftp.gnome.org/pub/GNOME/sources/libgames-support/1.0/libgames-support-1.0.2.tar.xz
libgcrypt                   1.8.2                 18 Dec 2017   ftp://ftp.gnupg.org/gcrypt/libgcrypt/libgcrypt-1.8.2.tar.gz
libgd                       2.2.5                 12 Jan 2018   https://github.com/libgd/libgd/releases/download/gd-2.2.5/libgd-2.2.5.tar.xz
libgda                      5.2.4                 13 Jun 2015   http://ftp.gnome.org/pub/GNOME/sources/libgda/5.2/libgda-5.2.4.tar.xz
libgdamm                    4.99.11               04 Nov 2015   http://ftp.gnome.org/pub/GNOME/sources/libgdamm/4.99/libgdamm-4.99.11.tar.xz
libgdata                    0.17.9                23 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/libgdata/0.17/libgdata-0.17.9.tar.xz
libgdiplus                  2.10.9                Jan 2013      http://download.mono-project.com/sources/libgdiplus/libgdiplus-2.10.9.tar.bz2
libgee                      0.20.1                12 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/libgee/0.20/libgee-0.20.1.tar.xz
libgepub                    0.5.3                 17 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/libgepub/0.5/libgepub-0.5.3.tar.xz
libggi                      2.2.2                 01 Jun 2014   http://prdownloads.sourceforge.net/ggi/libggi-2.2.2.src.tar.gz
libghemical                 3.0.0                 01 Jun 2014   http://bioinformatics.org/ghemical/download/current/libghemical-3.0.0.tar.gz
libgig                      3.3.0                 01 Jun 2014   http://download.linuxsampler.org/packages/libgig-3.3.0.tar.bz2
libgii                      1.0.2                 Jun 2014      http://www.ggi-project.org/packages/libgii-1.0.2.html
libgit2                     0.25.0                08 Aug 2017   https://github.com/libgit2/libgit2/archive/libgit2-0.25.0.tar.gz
libgit2glib                 0.26.2                30 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/libgit2-glib/0.26/libgit2-glib-0.26.2.tar.xz
libgksu                     2.0.12                27 Dec 2017   http://people.debian.org/~kov/gksu/libgksu-2.0.12.tar.gz
libglade                    2.6.4                 01 Jun 2014   http://ftp.acc.umu.se/pub/GNOME/sources/libglade/2.6/libglade-2.6.4.tar.bz2
libglademm                  2.6.6                 01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/libglademm/2.6/libglademm-2.6.6.tar.bz2
libgnome                    2.32.1                01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/libgnome/2.32/libgnome-2.32.1.tar.bz2
libgnomecanvas              2.30.3                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/libgnomecanvas/2.30/libgnomecanvas-2.30.3.tar.bz2
libgnomecanvasmm            2.20.0                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/libgnomecanvasmm/2.20/libgnomecanvasmm-2.20.0.tar.bz2
libgnomecups                0.2.3                 Jun 2014      http://ftp.acc.umu.se/pub/gnome/sources/libgnomecups/0.2/libgnomecups-0.2.3.tar.bz2
libgnomedb                  3.99.3                Jun 2014      http://www.gnome-db.org/
libgnomegamessupport        1.3.90                19 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/libgnome-games-support/1.3/libgnome-games-support-1.3.90.tar.xz
libgnomekbd                 3.26.0                12 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/libgnomekbd/3.26/libgnomekbd-3.26.0.tar.xz
libgnomekeyring             3.12.0                10 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/libgnome-keyring/3.12/libgnome-keyring-3.12.0.tar.xz
libgnomemm                  2.30.0                01 Jun 2014   http://ftp.gnome.org/pub/GNOME/sources/libgnomemm/2.30/libgnomemm-2.30.0.tar.bz2
libgnomeprintui             2.18.6                Jun 2014      http://ftp.acc.umu.se/pub/GNOME/sources/libgnomeprintui/2.18/libgnomeprintui-2.18.6.tar.bz2
libgnomeui                  2.24.5                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/libgnomeui/2.24/libgnomeui-2.24.5.tar.bz2
libgnomeuimm                2.28.0                01 Jun 2014   http://ftp.acc.umu.se/pub/GNOME/sources/libgnomeuimm/2.28/libgnomeuimm-2.28.0.tar.bz2
libgovirt                   0.3.3                 09 Apr 2015   http://ftp.gnome.org/pub/GNOME/sources/libgovirt/0.3/libgovirt-0.3.3.tar.xz
libgpgerror                 1.29                  13 Apr 2018   ftp://ftp.gnupg.org/gcrypt/libgpg-error/libgpg-error-1.29.tar.gz
libgphoto2                  2.5.16                26 Oct 2017   https://sourceforge.net/projects/gphoto/files/libgphoto/2.5.16/libgphoto2-2.5.16.tar.bz2
libgravatar                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libgravatar-18.04.0.tar.xz
libgrss                     0.7.0                 17 Jul 2015   http://ftp.gnome.org/pub/GNOME/sources/libgrss/0.7/libgrss-0.7.0.tar.xz
libgsasl                    1.7.6                 01 Aug 2013   ftp://alpha.gnu.org/pub/gnu/gsasl/libgsasl-1.7.6.tar.gz
libgsf                      1.14.43               21 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/libgsf/1.14/libgsf-1.14.43.tar.xz
libgtkhtml                  2.11.1                08 Apr 2009   http://ftp.gnome.org/pub/GNOME/sources/libgtkhtml/2.11/libgtkhtml-2.11.1.tar.bz2
libgtop                     2.38.0                12 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/libgtop/2.38/libgtop-2.38.0.tar.xz
libgudev                    232                   01 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/libgudev/232/libgudev-232.tar.xz
libgusb                     0.3.0                 20 Feb 2018   http://people.freedesktop.org/~hughsient/releases/libgusb-0.3.0.tar.xz
libgweather                 3.28.1                24 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/libgweather/3.28/libgweather-3.28.1.tar.xz
libgxps                     0.3.0                 09 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/libgxps/0.3/libgxps-0.3.0.tar.xz
libhttpseverywhere          0.8.2                 19 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/libhttpseverywhere/0.8/libhttpseverywhere-0.8.2.tar.xz
libical                     3.0.3                 08 Mar 2018   https://github.com/libical/libical/releases/download/v3.0.3/libical-3.0.3.tar.gz
libicalglib                 1.0.4                 23 Jan 2016   http://ftp.gnome.org/pub/GNOME/sources/libical-glib/1.0/libical-glib-1.0.4.tar.xz
libice                      1.0.9                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/libICE-1.0.9.tar.bz2
libiconv                    1.15                  18 Jul 2017   http://ftp.gnu.org/pub/gnu/libiconv/libiconv-1.15.tar.gz
libid3tag                   0.15.1b               01 Jun 2014   https://sourceforge.net/projects/mad/files/libid3tag/0.15.1b/libid3tag-0.15.1b.tar.gz
libidl                      0.8.14                01 Jan 2013   http://ftp.gnome.org/pub/gnome/sources/libIDL/0.8/libIDL-0.8.14.tar.bz2
libidn                      1.34                  08 Apr 2018   http://ftp.gnu.org/gnu/libidn/libidn-1.34.tar.gz
libidn2                     2.0.4                 11 Sep 2017   http://ftp.gnu.org/pub/gnu/libidn/libidn2-2.0.4.tar.gz
libinput                    1.10.4                21 Apr 2018   https://www.freedesktop.org/software/libinput/libinput-1.10.4.tar.xz
libiodbc                    3.52.10               15 Jun 2015   http://downloads.sourceforge.net/project/iodbc/iodbc/3.52.10/libiodbc-3.52.10.tar.gz
libisoburn                  1.4.8                 20 Sep 2017   http://files.libburnia-project.org/releases/libisoburn-1.4.8.tar.gz
libisofs                    1.4.8                 16 Sep 2017   http://files.libburnia-project.org/releases/libisofs-1.4.8.tar.gz
libjpeg                     8d                    07 Mar 2015   http://www.ijg.org/files/jpegsrc.v8d.tar.gz
libjpegturbo                1.5.3                 17 Dec 2017   http://downloads.sourceforge.net/libjpeg-turbo/libjpeg-turbo-1.5.3.tar.gz
libkcddb                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkcddb-18.04.0.tar.xz
libkcompactdisc             18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkcompactdisc-18.04.0.tar.xz
libkdcraw                   4.14.3                15 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/libkdcraw-4.14.3.tar.xz
libkdeedu                   4.14.3                16 May 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/libkdeedu-4.14.3.tar.xz
libkdegames                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkdegames-18.04.0.tar.xz
libkdepim                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkdepim-18.04.0.tar.xz
libkeduvocdocument          18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkeduvocdocument-18.04.0.tar.xz
libkexif                    0.2.5                 01 Jun 2014   http://prdownloads.sourceforge.net/kipi/libkexif-0.2.5.tar.bz2
libkexiv2                   4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/libkexiv2-4.14.3.tar.xz
libkface                    17.08.1               01 Jan 2018   https://download.kde.org/stable/applications/17.08.1/src/libkface-17.08.1.tar.xz
libkgapi                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkgapi-18.04.0.tar.xz
libkgeomap                  18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkgeomap-18.04.0.tar.xz
libkipi                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkipi-18.04.0.tar.xz
libkleo                     18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkleo-18.04.0.tar.xz
libkmahjongg                18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkmahjongg-18.04.0.tar.xz
libkomparediff2             18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libkomparediff2-18.04.0.tar.xz
libksane                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libksane-18.04.0.tar.xz
libksba                     1.3.4                 15 Jul 2016   ftp://ftp.gnupg.org/gcrypt/libksba/libksba-1.3.4.tar.bz2
libkscreen                  5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/libkscreen-5.12.4.tar.xz
libksieve                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/libksieve-18.04.0.tar.xz
libksysguard                5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/libksysguard-5.12.4.tar.xz
liblbxutil                  1.1.0                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/liblbxutil-1.1.0.tar.bz2
liblinear                   220                   09 Dec 2017   https://github.com/cjlin1/liblinear/archive/v220/liblinear-220.tar.gz
liblinebreak                2.1                   18 Jan 2018   https://sourceforge.net/projects/vimgadgets/files/liblinebreak/2.1/liblinebreak-2.1.tar.gz
liblo                       0.29                  26 Oct 2017   https://sourceforge.net/projects/liblo/files/liblo-0.29.tar.gz
liblrdf                     0.4.0                 01 Dec 2012   https://sourceforge.net/projects/lrdf/files/liblrdf/0.4.0/liblrdf-0.4.0.tar.gz
libmad                      0.15.1b               01 Sep 2013   ftp://ftp.mars.org/pub/mpeg/libmad-0.15.1b.tar.gz
libmanette                  0.2.0                 01 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/libmanette/0.2/libmanette-0.2.0.tar.xz
libmatekbd                  1.20.1                27 Mar 2018   http://pub.mate-desktop.org/releases/1.20/libmatekbd-1.20.1.tar.xz
libmatekeyring              1.6.0                 01 Aug 2013   http://pub.mate-desktop.org/releases/1.6/libmatekeyring-1.6.0.tar.xz
libmatemixer                1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/libmatemixer-1.20.0.tar.xz
libmateweather              1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/libmateweather-1.20.0.tar.xz
libmatheval                 1.1.8                 01 Jun 2012   http://ftp.gnu.org/gnu/libmatheval/libmatheval-1.1.8.tar.gz
libmatroska                 1.4.8                 30 Sep 2017   https://dl.matroska.org/downloads/libmatroska/libmatroska-1.4.8.tar.xz
libmbim                     1.16.0                24 Jan 2018   https://www.freedesktop.org/software/libmbim/libmbim-1.16.0.tar.xz
libmcs                      0.7.2                 12 Dec 2015   http://distfiles.atheme.org/libmcs-0.7.2.tgz
libmd                       0.3                   21 Jul 2016   ftp://ftp.penguin.cz/pub/users/mhi/libmd/libmd-0.3.tar.bz2
libmediaart                 1.9.4                 23 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/libmediaart/1.9/libmediaart-1.9.4.tar.xz
libmemcached                0.22                  01 Jun 2014   http://download.tangent.org/libmemcached-0.22.tar.gz
libmicrohttpd               0.9.56                25 Nov 2017   http://ftp.gnu.org/pub/gnu/libmicrohttpd/libmicrohttpd-0.9.56.tar.gz
libmikmod                   3.1.12                01 Jun 2014   http://sourceforge.net/projects/mikmod/files/libmikmod%20%28source%29/3.1.12/libmikmod-3.1.12.tar.gz
libmirage                   1.5.0                 Jun 2014      http://downloads.sourceforge.net/cdemu/libmirage-1.5.0.tar.bz2
libmng                      2.0.3                 22 Oct 2015   http://sourceforge.net/projects/libmng/files/libmng-devel/2.0.3/libmng-2.0.3.tar.xz
libmodplug                  0.8.8.5               26 Feb 2017   https://sourceforge.net/projects/modplug-xmms/files/libmodplug/0.8.8.5/libmodplug-0.8.8.5.tar.gz
libmowgli                   1.0.0                 09 Mar 2017   http://distfiles.atheme.org/libmowgli-0.9.50.tar.bz2
libmp3splt                  0.7.2                 Jun 2014      http://downloads.sourceforge.net/project/mp3splt/libmp3splt/0.7.2/libmp3splt-0.7.2.tar.gz
libmpcdec                   1.2.6                 Jun 2014      http://www.musepack.net/index.php?pg=src
libmpeg2                    0.5.1                 Feb 2013      http://libmpeg2.sourceforge.net/files/libmpeg2-0.5.1.tar.gz
libmpeg3                    1.8                   Feb 2013      http://downloads.sourceforge.net/heroines/libmpeg3-1.8-src.tar.bz2
libmspack                   0.0.20060920alpha     Jun 2014      http://www.kyz.uklinux.net/downloads/libmspack-0.0.20040308alpha.tar.gz
libmtp                      1.1.14                06 Oct 2017   https://sourceforge.net/projects/libmtp/files/libmtp/1.1.14/libmtp-1.1.14.tar.gz
libmusicbrainz              5.0.1                 Feb 2013      https://github.com/downloads/metabrainz/libmusicbrainz/libmusicbrainz-5.0.1.tar.gz
libmxp                      0.2.2                 Jun 2014      http://www.kmuddy.net/libmxp/files/libmxp-0.2.2.tar.gz
libmypaint                  1.3.0                 10 Sep 2017   https://github.com/mypaint/libmypaint/releases/download/v1.3.0/libmypaint-1.3.0.tar.xz
libndp                      1.4                   01 Oct 2014   http://libndp.org/files/libndp-1.4.tar.gz
libnet                      1.1.2.1               Jun 2014      http://www.packetfactory.net/libnet/dist/libnet.tar.gz
libnice                     0.1.13                16 Sep 2015   http://nice.freedesktop.org/releases/libnice-0.1.13.tar.gz
libnids                     1.24                  01 May 2013   https://sourceforge.net/projects/libnids/files/libnids/1.24/libnids-1.24.tar.gz
libnih                      1.0.3                 Jan 2013      https://launchpad.net/libnih/1.0/1.0.3/+download/libnih-1.0.3.tar.gz
libnl                       3.2.25                19 May 2015   http://www.infradead.org/~tgr/libnl/files/libnl-3.2.25.tar.gz
libnotify                   0.7.7                 30 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/libnotify/0.7/libnotify-0.7.7.tar.xz
libnsl                      1.2.0                 18 Nov 2017   https://github.com/thkukuk/libnsl/archive/v1.2.0/libnsl-1.2.0.tar.gz
libnxml                     0.18.3                31 Oct 2017   http://www.autistici.org/bakunin/libnxml/libnxml-0.18.3.tar.gz
liboauth                    1.0.3                 19 Apr 2015   http://sourceforge.net/projects/liboauth/files/liboauth-1.0.3.tar.gz
libogg                      1.3.3                 11 Nov 2017   http://downloads.xiph.org/releases/ogg/libogg-1.3.3.tar.xz
liboggz                     1.1.1                 Jun 2014      http://downloads.xiph.org/releases/liboggz/liboggz-1.1.1.tar.gz
liboil                      0.3.17                23 Aug 2017   https://liboil.freedesktop.org/download/liboil-0.3.17.tar.gz
liboobs                     3.0.0                 20 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/liboobs/3.0/liboobs-3.0.0.tar.bz2
libopenmodeller             0.4.2                 20 Sep 2017   http://sourceforge.net/projects/openmodeller/files/openModeller/1.5.0/libopenmodeller-src-1.5.0.zip
libopenraw                  0.0.8                 01 Jun 2014   http://libopenraw.freedesktop.org/download/libopenraw-0.0.8.tar.gz
libopensync                 0.36                  01 Jun 2014   http://www.opensync.org/download/releases/?C=M;O=D
libosinfo                   1.0.0                 08 Jan 2018   https://releases.pagure.org/libosinfo/libosinfo-1.0.0.tar.gz
libosmium                   2.13.0                16 Aug 2017   https://github.com/osmcode/libosmium/archive/v2.13.0.tar.gz
libpaper                    1.1.23                Jun 2014      http://packages.debian.org/unstable/source/libpaper
libpcap                     1.7.4                 11 Sep 2015   http://www.tcpdump.org/release/libpcap-1.7.4.tar.gz
libpciaccess                0.14                  24 Oct 2017   https://www.x.org/releases/individual/lib/libpciaccess-0.14.tar.gz
libpeas                     1.22.0                10 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/libpeas/1.22/libpeas-1.22.0.tar.xz
libpipeline                 1.2.3                 May 2013      http://download.savannah.gnu.org/releases/libpipeline/libpipeline-1.2.3.tar.gz
libpng                      1.6.34                30 Sep 2017   https://sourceforge.net/projects/libpng/files/libpng16/1.6.34/libpng-1.6.34.tar.xz
libproxy                    0.4.15                23 Sep 2017   https://github.com/libproxy/libproxy/releases/download/0.4.15/libproxy-0.4.15.tar.xz
libpthreadstubs             0.4                   18 Mar 2017   https://xorg.freedesktop.org/releases/individual/xcb/libpthread-stubs-0.4.tar.bz2
libptytty                   1.2                   Jun 2014      http://software.schmorp.de/pkg/libptytty
libpwquality                1.3.0                 19 Jan 2017   https://fedorahosted.org/releases/l/i/libpwquality/libpwquality-1.3.0.tar.bz2
libqglviewer                2.3.17                Jun 2014      http://www.libqglviewer.com/src/libQGLViewer-2.3.17.tar.gz
libqmi                      1.20.0                24 Jan 2018   https://www.freedesktop.org/software/libqmi/libqmi-1.20.0.tar.xz
libquicktime                1.2.4                 Jun 2014      https://sourceforge.net/projects/libquicktime/files/libquicktime/1.2.4/libquicktime-1.2.4.tar.gz
libquvi                     0.9.4                 09 Jun 2016   https://sourceforge.net/projects/quvi/files/0.9/libquvi/libquvi-0.9.4.tar.xz
libquviscripts              0.9.20131130          09 Jun 2016   https://sourceforge.net/projects/quvi/files/0.9/libquvi-scripts/libquvi-scripts-0.9.20131130.tar.xz
libraw                      0.18.9                29 Apr 2018   http://www.libraw.org/data/LibRaw-0.18.9.tar.gz
libraw1394                  2.0.5                 01 Jun 2014   http://www.linux1394.org/dl/libraw1394-2.0.5.tar.gz
libreoffice                 4.4.3.2               17 Jun 2015   http://download.documentfoundation.org/libreoffice/src/4.4.3/libreoffice-4.4.3.2.tar.xz
libreofficebinfilter        3.6.4.1               08 Mar 2015   http://download.documentfoundation.org/libreoffice/src/4.2.2/libreoffice-binfilter-3.6.4.1.tar.xz
libreofficecore             3.6.4.3               06 Mar 2014   http://download.documentfoundation.org/libreoffice/src/4.2.2/libreoffice-core-3.6.4.3.tar.xz
libreofficehelp             4.2.2.1               01 Mar 2014   http://download.documentfoundation.org/libreoffice/src/4.2.2/libreoffice-help-4.2.2.1.tar.xz
librep                      0.92.6                25 Jul 2017   http://download.tuxfamily.org/librep/librep_0.92.6.tar.xz
libressl                    2.7.0                 22 Mar 2018   http://ftp.openbsd.org/pub/OpenBSD/LibreSSL/libressl-2.7.0.tar.gz
librevenge                  0.0.4                 13 Mar 2016   https://sourceforge.net/projects/libwpd/files/librevenge/librevenge-0.0.4/librevenge-0.0.4.tar.xz
librsvg                     2.42.2                02 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/librsvg/2.42/librsvg-2.42.2.tar.xz
libsafe                     2.0-16                01 Jun 2014   http://pubs.research.avayalabs.com/src/libsafe-2.0-16.tgz
libsamplerate               0.1.8                 01 Jun 2014   http://www.mega-nerd.com/SRC/libsamplerate-0.1.8.tar.gz
libseccomp                  2.3.3                 14 Jan 2018   https://github.com/seccomp/libseccomp/releases/download/v2.3.3/libseccomp-2.3.3.tar.gz
libsecret                   0.18.6                29 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/libsecret/0.18/libsecret-0.18.6.tar.xz
libselinux                  2.7                   05 Aug 2017   https://github.com/SELinuxProject/selinux/archive/libselinux-2.7.tar.gz
libsexy                     0.1.11                01 Jun 2014   http://releases.chipx86.com/libsexy/libsexy/libsexy-0.1.11.tar.gz
libshout                    2.3.1                 Jun 2014      http://downloads.us.xiph.org/releases/libshout/libshout-2.3.1.tar.gz
libsigc++                   2.99.11               11 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/libsigc++/2.99/libsigc++-2.99.11.tar.xz
libsigsegv                  2.12                  18 Jan 2018   http://ftp.gnu.org/gnu/libsigsegv/libsigsegv-2.12.tar.gz
libslab                     2.30.0                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/libslab/2.30/libslab-2.30.0.tar.gz
libsm                       1.2.2                 01 Sep 2013   http://xorg.freedesktop.org/releases/individual/lib/libSM-1.2.2.tar.bz2
libsndfile                  1.0.28                28 Dec 2017   http://www.mega-nerd.com/libsndfile/files/libsndfile-1.0.28.tar.gz
libsodium                   1.0.16                15 Dec 2017   https://download.libsodium.org/libsodium/releases/libsodium-1.0.16.tar.gz
libsoup                     2.62.1                13 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/libsoup/2.62/libsoup-2.62.1.tar.xz
libspectre                  0.2.7                 Jun 2014      http://libspectre.freedesktop.org/releases/libspectre-0.2.7.tar.gz
libspnav                    0.2.3                 04 Jun 2016   https://sourceforge.net/projects/spacenav/files/spacenav%20library%20%28SDK%29/libspnav%200.2.3/libspnav-0.2.3.tar.gz
libstatgrab                 0.91                  09 Aug 2017   http://www.mirrorservice.org/sites/ftp.i-scream.org/pub/i-scream/libstatgrab/libstatgrab-0.91.tar.gz
libtar                      1.2.11                01 Jun 2014   ftp://ftp.feep.net/pub/software/libtar/libtar-1.2.11.tar.gz
libtasn1                    4.13                  18 Jan 2018   http://ftp.gnu.org/gnu/libtasn1/libtasn1-4.13.tar.gz
libtheora                   1.1.1                 12 Aug 2017   http://downloads.xiph.org/releases/theora/libtheora-1.1.1.tar.xz
libtirpc                    1.0.3                 26 Mar 2018   http://downloads.sourceforge.net/project/libtirpc/libtirpc/1.0.3/libtirpc-1.0.3.tar.bz2
libtool                     2.4.6                 18 Feb 2015   ftp://ftp.gnu.org/gnu/libtool/libtool-2.4.6.tar.gz
libtorrent                  0.13.3                Jun 2014      http://libtorrent.rakshasa.no/downloads/libtorrent-0.13.3.tar.gz
libtrace                    3.0.14                Jun 2014      http://research.wand.net.nz/software/libtrace/libtrace-3.0.14.tar.bz2
libtranslate                0.99                  Jun 2014      http://savannah.nongnu.org/download/libtranslate/libtranslate-0.99.tar.gz
libungif                    4.1.4                 Jun 2014      http://sourceforge.net/projects/libungif
libunibreak                 3.0                   30 Aug 2016   https://github.com/adah1972/libunibreak/releases/download/libunibreak_3_0/libunibreak-3.0.tar.gz
libunicap                   0.9.12                30 Dec 2015   http://unicap-imaging.org/downloads/libunicap-0.9.12.tar.gz
libuninum                   2.6                   01 Jun 2014   http://billposer.org/Software/libuninum.html#downloads
libunique                   3.0.2                 01 Aug 2013   http://ftp.acc.umu.se/pub/GNOME/sources/libunique/3.0/libunique-3.0.2.tar.xz
libunistring                0.9.9                 10 Mar 2018   http://ftp.gnu.org/gnu/libunistring/libunistring-0.9.9.tar.xz
libunwind                   1.2.1                 30 Jul 2017   https://download.savannah.gnu.org/releases/libunwind/libunwind-1.2.1.tar.gz
libupnp                     1.6.21                17 Apr 2017   https://sourceforge.net/projects/pupnp/files/pupnp/libUPnP%201.6.21/libupnp-1.6.21.tar.bz2
libusb                      1.0.22                08 Apr 2018   https://github.com//libusb/libusb/releases/download/v1.0.22/libusb-1.0.22.tar.bz2
libusbcompat                0.1.4                 01 Jan 2013   http://downloads.sourceforge.net/libusb/libusb-compat-0.1.4.tar.bz2
libutempter                 1.1.5                 31 Oct 2015   http://freecode.com/projects/libutempter/libutempter-1.1.5.tar.xz
libuv                       1.20.2                24 Apr 2018   https://github.com/libuv/libuv/archive/v1.20.2/libuv-1.20.2.tar.gz
libva                       2.1.0                 20 Feb 2018   https://github.com/intel/libva/releases/download/2.1.0/libva-2.1.0.tar.bz2
libvautils                  1.8.2                 21 Sep 2017   https://www.freedesktop.org/software/vaapi/releases/libva/libva-utils-1.8.2.tar.bz2
libvdpau                    1.1.1                 11 Oct 2015   http://people.freedesktop.org/~aplattner/vdpau/libvdpau-1.1.1.tar.bz2
libvdpauvagl                0.3.4                 11 Apr 2015   https://github.com/i-rinat/libvdpau-va-gl/releases/download/v0.3.4/libvdpau-va-gl-0.3.4.tar.gz
libviper                    1.4.6                 01 Jun 2014   http://sourceforge.net/projects/libviper/files/libviper-1.4.6.tar.gz
libvirt                     4.2.0                 01 Apr 2018   ftp://libvirt.org/libvirt/libvirt-4.2.0.tar.xz
libvisual                   0.4.0                 01 Jan 2013   http://sourceforge.net/projects/libvisual/files/libvisual/libvisual-0.4.0/libvisual-0.4.0.tar.bz2
libvolumeid                 0.81.0                01 Jun 2014   http://www.marcuscom.com/downloads/libvolume_id-0.81.0.tar.bz2
libvorbis                   1.3.6                 17 Mar 2018   http://downloads.xiph.org/releases/vorbis/libvorbis-1.3.6.tar.gz
libvpx                      v1.7.0                29 Jan 2018   https://github.com/webmproject/libvpx/archive/v1.7.0/libvpx-v1.7.0.tar.gz
libwacom                    0.29                  05 Apr 2018   https://sourceforge.net/projects/linuxwacom/files/libwacom/libwacom-0.29.tar.bz2
libwebp                     1.0.0                 22 Apr 2018   http://downloads.webmproject.org/releases/webp/libwebp-1.0.0.tar.gz
libwindowswm                1.0.0                 01 Jun 2014   http://ftp.cica.es/pub/X/pub/X11R7.3/src/lib/libWindowsWM-1.0.0.tar.bz2
libwmf                      0.2.8.4               01 Jun 2014   https://sourceforge.net/projects/wvware/files/libwmf/0.2.8.4/libwmf-0.2.8.4.tar.gz
libwnck                     3.24.1                27 Jul 2017   http://ftp.gnome.org/pub/gnome/sources/libwnck/3.24/libwnck-3.24.1.tar.xz
libwps                      0.4.3                 09 Mar 2016   https://sourceforge.net/projects/libwps/files/libwps/libwps-0.4.3/libwps-0.4.3.tar.xz
libwrapiter                 1.2.0                 01 Jun 2014   http://libwrapiter.berlios.de/
libwwwperl                  6.30                  09 Dec 2017   http://search.cpan.org/CPAN/authors/id/O/OA/OALDERS/libwww-perl-6.30.tar.gz
libx11                      1.6.5                 10 Mar 2017   https://www.x.org/releases/individual/lib/libX11-1.6.5.tar.gz
libxau                      1.0.8                 01 May 2014   http://xorg.freedesktop.org/releases/individual/lib/libXau-1.0.8.tar.gz
libxaw                      1.0.13                03 May 2015   http://xorg.freedesktop.org/releases/individual/lib/libXaw-1.0.13.tar.bz2
libxaw3d                    1.6                   01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/libXaw3d-1.6.tar.bz2
libxaw3dxft                 1.6.2d                15 Nov 2015   http://sourceforge.net/projects/sf-xpaint/files/libxaw3dxft/libXaw3dXft-1.6.2d.tar.bz2
libxcb                      1.13                  08 Mar 2018   https://www.x.org/releases/individual/xcb/libxcb-1.13.tar.bz2
libxcm                      0.5.3                 10 Oct 2015   http://sourceforge.net/projects/oyranos/files/libXcm/libXcm-0.5/libXcm-0.5.3.tar.gz
libxcomposite               0.4.4                 01 May 2013   https://www.x.org/releases/individual/lib/libXcomposite-0.4.4.tar.bz2
libxcursor                  1.1.15                30 Nov 2017   http://xorg.freedesktop.org/releases/individual/lib/libXcursor-1.1.15.tar.bz2
libxdamage                  1.1.3                 01 May 2014   http://xorg.freedesktop.org/releases/individual/lib/libXdamage-1.1.3.tar.bz2
libxdmcp                    1.1.2                 23 Mar 2015   http://xorg.freedesktop.org/releases/individual/lib/libXdmcp-1.1.2.tar.bz2
libxevie                    1.0.3                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/libXevie-1.0.3.tar.bz2
libxext                     1.3.3                 10 Oct 2015   http://xorg.freedesktop.org/releases/individual/lib/libXext-1.3.3.tar.gz
libxfce4ui                  4.13.3                30 Aug 2017   http://archive.xfce.org/src/xfce/libxfce4ui/4.13/libxfce4ui-4.13.3.tar.bz2
libxfce4util                4.13.1                30 Aug 2017   http://archive.xfce.org/src/xfce/libxfce4util/4.13/libxfce4util-4.13.1.tar.bz2
libxfixes                   5.0.3                 08 Oct 2016   https://www.x.org/releases/individual/lib/libXfixes-5.0.3.tar.gz
libxfont                    1.5.3                 22 Oct 2017   https://www.x.org/releases/individual/lib/libXfont-1.5.3.tar.gz
libxfont2                   2.0.3                 30 Nov 2017   https://www.x.org/releases/individual/lib/libXfont2-2.0.3.tar.gz
libxfontcache               1.0.4                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/libXfontcache-1.0.4.tar.bz2
libxft                      2.3.2                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/libXft-2.3.2.tar.bz2
libxi                       1.7.9                 02 Feb 2017   https://www.x.org/releases/individual/lib/libXi-1.7.9.tar.gz
libxinerama                 1.1.2                 01 Jun 2014   https://www.x.org/releases/individual/lib/libXinerama-1.1.2.tar.bz2
libxkbcommon                0.7.2                 07 Aug 2017   https://xkbcommon.org/download/libxkbcommon-0.7.2.tar.xz
libxkbfile                  1.0.9                 03 May 2015   http://xorg.freedesktop.org/releases/individual/lib/libxkbfile-1.0.9.tar.bz2
libxkbui                    1.0.2                 01 Jun 2014   https://www.x.org/releases/individual/lib/libxkbui-1.0.2.tar.bz2
libxklavier                 5.3                   01 Sep 2013   http://ftp.gnome.org/pub/GNOME/sources/libxklavier/5.3/libxklavier-5.3.tar.xz
libxml++                    3.0.0                 03 Feb 2016   http://ftp.gnome.org/pub/GNOME/sources/libxml++/3.0/libxml++-3.0.0.tar.xz
libxml2                     2.9.8                 16 Mar 2018   http://xmlsoft.org/sources/libxml2-2.9.8.tar.gz
libxml2python               2.6.15                01 Jan 2013   ftp://xmlsoft.org/libxml2/python/libxml2-python-2.6.15.tar.gz
libxmp                      4.3.9                 31 Jul 2015   http://sourceforge.net/projects/xmp/files/libxmp/4.3.9/libxmp-4.3.9.tar.gz
libxmu                      1.1.2                 01 Sep 2013   http://xorg.freedesktop.org/releases/individual/lib/libXmu-1.1.2.tar.bz2
libxp                       1.0.3                 26 Feb 2015   http://xorg.freedesktop.org/releases/individual/lib/libXp-1.0.3.tar.gz
libxpm                      3.5.12                16 Dec 2016   https://www.x.org/releases/individual/lib/libXpm-3.5.12.tar.bz2
libxpresent                 1.0.0                 14 Apr 2015   http://xorg.freedesktop.org/releases/individual/lib/libXpresent-1.0.0.tar.gz
libxprintutil               1.0.1                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/libXprintUtil-1.0.1.tar.bz2
libxrandr                   1.5.1                 08 Oct 2016   https://www.x.org/releases/individual/lib/libXrandr-1.5.1.tar.gz
libxrender                  0.9.10                08 Oct 2016   https://www.x.org/releases/individual/lib/libXrender-0.9.10.tar.gz
libxres                     1.2.0                 14 Oct 2017   https://www.x.org/releases/individual/lib/libXres-1.2.0.tar.gz
libxscrnsaver               1.2.2                 01 Nov 2012   http://xorg.freedesktop.org/releases/individual/lib/libXScrnSaver-1.2.2.tar.bz2
libxshmfence                1.2                   31 Jan 2015   http://xorg.freedesktop.org/releases/individual/lib/libxshmfence-1.2.tar.bz2
libxslt                     1.1.32                11 Nov 2017   http://xmlsoft.org/sources/libxslt-1.1.32.tar.gz
libxspf                     1.2.0                 16 Feb 2017   http://downloads.xiph.org/releases/xspf/libxspf-1.2.0.tar.bz2
libxt                       1.1.5                 03 May 2015   http://xorg.freedesktop.org/releases/individual/lib/libXt-1.1.5.tar.gz
libxtrap                    1.0.1                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/libXTrap-1.0.1.tar.bz2
libxtst                     1.2.3                 08 Oct 2016   https://www.x.org/releases/individual/lib/libXtst-1.2.3.tar.gz
libxv                       1.0.11                08 Oct 2016   https://www.x.org/releases/individual/lib/libXv-1.0.11.tar.gz
libxvmc                     1.0.10                08 Oct 2016   https://www.x.org/releases/individual/lib/libXvMC-1.0.10.tar.gz
libxxf86dga                 1.0.99.2              01 Jun 2014   http://xorg.freedesktop.org/releases/individual/lib/libXxf86dga-1.0.99.2.tar.bz2
libxxf86misc                1.0.3                 04 Jan 2018   https://www.x.org/releases/individual/lib/libXxf86misc-1.0.3.tar.gz
libxxf86vm                  1.1.4                 26 Feb 2015   http://xorg.freedesktop.org/releases/individual/lib/libXxf86vm-1.1.4.tar.gz
libzapojit                  0.0.3                 17 Apr 2015   http://ftp.gnome.org/pub/GNOME/sources/libzapojit/0.0/libzapojit-0.0.3.tar.xz
libzeitgeist                0.3.18                Jan 2014      https://launchpad.net/libzeitgeist/0.3/0.3.18/+download/libzeitgeist-0.3.18.tar.gz
libzip                      1.3.2                 21 Nov 2017   https://nih.at/libzip/libzip-1.3.2.tar.xz
libzrtpcpp                  2.0.0                 01 Jun 2014   http://ftp.gnu.org/gnu/ccrtp/libzrtpcpp-2.0.0.tar.gz
licq                        1.8.2                 09 Jul 2015   http://downloads.sourceforge.net/licq/licq-1.8.2.tar.bz2
liferea                     1.10.16               30 Aug 2015   https://github.com/lwindolf/liferea/releases/download/v1.10.16/liferea-1.10.16.tar.bz2
lightdm                     1.24.0                06 Jan 2018   https://launchpad.net/lightdm/1.24/1.24.0/+download/lightdm-1.24.0.tar.xz
lightfeather                0.5.5                 Jun 2014      http://lightfeather.de/news.php
lightsoff                   3.27.90               05 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/lightsoff/3.27/lightsoff-3.27.90.tar.xz
lighttpd                    1.4.49                12 Mar 2018   http://download.lighttpd.net/lighttpd/releases-1.4.x/lighttpd-1.4.49.tar.xz
lilo                        24.2                  23 Nov 2015   http://lilo.alioth.debian.org/ftp/sources/lilo-24.2.tar.gz
lilykde                     0.6.1                 Jun 2014      http://lilykde.googlecode.com/files/lilykde-0.6.1.tar.gz
lilypond                    2.18.2                16 Jul 2017   http://download.linuxaudio.org/lilypond/sources/v2.18/lilypond-2.18.2.tar.gz
lilyterm                    0.9.9.4               Jul 2013      http://lilyterm.luna.com.tw/file/lilyterm-0.9.9.4.tar.gz
linc                        1.0.3                 03 Mar 2015   http://hisham.hm/htop/releases/1.0.3/linc-1.0.3.tar.gz
lincityng                   2.0                   01 Jan 2013   http://download.berlios.de/lincity-ng/lincity-ng-2.0.tar.bz2
lineakconfig                0.3.2                 01 Jun 2014   http://prdownloads.sourceforge.net/lineak/lineakconfig-0.3.2.tar.gz
lineakd                     0.9                   May 2014      http://prdownloads.sourceforge.net/lineak/lineakd-0.9.tar.gz
linkgrammar                 5.2.5                 28 Sep 2015   http://www.abiword.org/downloads/link-grammar/5.2.5/link-grammar-5.2.5.tar.gz
links                       2.15                  24 Mar 2018   http://links.twibright.com/download/links-2.15.tar.bz2
linlibertine                2.0.9                 Jun 2014      http://sourceforge.net/projects/linuxlibertine
linux                       4.16.6                30 Apr 2018   https://www.kernel.org/pub/linux/kernel/v4.x/linux-4.16.6.tar.xz
linuxlive                   6.2.4                 Jun 2014      ftp://ftp.slax.org/Linux-Live/linux-live-6.2.4.tar.gz
linuxpam                    1.3.0                 18 Jul 2017   http://linux-pam.org/library/Linux-PAM-1.3.0.tar.bz2
liquidwar                   5.6.4                 Jun 2014      http://www.gnu.org/software/liquidwar6/#downloading
listmoreutils               0.428                 17 Dec 2017   https://www.cpan.org/authors/id/R/RE/REHSACK/List-MoreUtils-0.428.tar.gz
listres                     1.0.1                 Jun 2014      http://xorg.freedesktop.org/releases/individual/app/listres-1.0.1.tar.bz2
littleutils                 1.0.37                18 Jul 2017   https://sourceforge.net/projects/littleutils/files/littleutils-source/1.0.37/littleutils-1.0.37.tar.xz
lives                       0.9.8.12              01 Jun 2014   http://www.xs4all.nl/%7Esalsaman/lives/current/LiVES-0.9.8.12.tar.bz2
liveslak                    1.1.9.1               01 Oct 2017   http://bear.alienbase.nl/cgit/liveslak/snapshot/liveslak-1.1.9.1.tar.xz
llvm                        6.0.0                 08 Mar 2018   http://releases.llvm.org/6.0.0/llvm-6.0.0.src.tar.xz
lmarbles                    1.0.8                 26 Mar 2016   https://sourceforge.net/projects/lgames/files/lmarbles/lmarbles-1.0.8.tar.gz
lmsensors                   3.4.0                 26 Jul 2017   http://pkgs.fedoraproject.org/repo/pkgs/lm_sensors/lm_sensors-3.4.0.tar.bz2/c03675ae9d43d60322110c679416901a/lm_sensors-3.4.0.tar.bz2
lndir                       1.0.3                 13 Mar 2016   http://xorg.freedesktop.org/releases/individual/util/lndir-1.0.3.tar.gz
log4cpp                     1.1.2rc1              08 Dec 2015   http://sourceforge.net/projects/log4cpp/files/log4cpp-1.1.x%20%28new%29/log4cpp-1.1/log4cpp-1.1.2rc1.tar.gz
log4r                       1.0.5                 Mar 2013      http://log4r.sourceforge.net/
logrotate                   3.13.0                05 Dec 2017   https://github.com/logrotate/logrotate/releases/download/3.13.0/logrotate-3.13.0.tar.xz
lokalize                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/lokalize-18.04.0.tar.xz
longomatch                  1.0.2                 28 Feb 2015   http://ftp.gnome.org/pub/GNOME/sources/longomatch/1.0/longomatch-1.0.2.tar.xz
loopaes                     v3.7d                 25 Jul 2015   http://sourceforge.net/projects/loop-aes/files/loop-aes/v3.7d/loop-AES-v3.7d.tar.bz2
lordsawar                   0.2.0                 Jun 2014      http://download.savannah.gnu.org/releases-noredirect/lordsawar/lordsawar-0.2.0.tar.gz
loudmouth                   1.5.3                 05 Mar 2016   https://github.com/mcabber/loudmouth/archive/1.5.3.tar.gz
lpairs                      1.0.3                 Jun 2014      http://downloads.sourceforge.net/lgames/lpairs-1.0.3.tar.gz
lrzsz                       0.12.20               13 Jul 2017   https://ohse.de/uwe/releases/lrzsz-0.12.20.tar.gz
lsdvd                       0.17                  15 Nov 2015   http://sourceforge.net/projects/lsdvd/files/lsdvd/lsdvd-0.17.tar.gz
lshw                        B.02.17               Mar 2014      http://ezix.org/software/files/lshw-B.02.17.tar.gz
lshwd                       1.1.3.1               Jun 2014      http://user-contributions.org/projects/lshwd/
lskat                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/lskat-18.04.0.tar.xz
lsof                        4.89                  31 Oct 2015   ftp://sunsite.ualberta.ca/pub/Mirror/lsof/lsof_4.89.tar.bz2
ltris                       1.0.19                02 Jul 2016   http://prdownloads.sourceforge.net/lgames/ltris-1.0.19.tar.gz
lua                         5.3.4                 12 Mar 2017   http://www.lua.org/ftp/lua-5.3.4.tar.gz
luajit                      2.0.5                 09 Oct 2017   http://luajit.org/download/LuaJIT-2.0.5.tar.gz
luarocks                    2.4.1                 20 Oct 2016   http://www.luarocks.org/releases/luarocks-2.4.1.tar.gz
luit                        1.1.1                 01 Nov 2012   http://xorg.freedesktop.org/releases/individual/app/luit-1.1.1.tar.bz2
lxappearance                0.6.3                 06 Oct 2017   https://sourceforge.net/projects/lxde/files/LXAppearance/lxappearance-0.6.3.tar.xz
lxc                         2.1.1                 28 Dec 2017   https://linuxcontainers.org/downloads/lxc/lxc-2.1.1.tar.gz
lxdecommon                  0.99.2                24 Feb 2017   https://sourceforge.net/projects/lxde/files/lxde-common%20%28default%20config%29/lxde-common%200.99/lxde-common-0.99.2.tar.xz
lxdm                        0.5.3                 24 Feb 2017   https://sourceforge.net/projects/lxde/files/lxdm/lxdm%200.5.3/lxdm-0.5.3.tar.xz
lxdvdrip                    1.60                  Jun 2014      http://lxdvdrip.berlios.de/
lxml                        4.2.1                 26 Mar 2018   https://pypi.python.org/packages/e8/5d/98f56e274bdf17f2e0d9016d1788ca80d26d8987dcd5e1d9416d86ee0625/lxml-4.2.1.tar.gz
lxpanel                     0.2.9.0               25 May 2015   http://sourceforge.net/projects/lxde/files/LXPanel%20%28desktop%20panel%29/LXPanel%200.8.x/lxpanel-0.8.1.tar.xz
lxsession                   0.5.3                 31 Oct 2017   https://downloads.sourceforge.net/lxde/lxsession-0.5.3.tar.xz
lxterminal                  0.3.1                 11 Nov 2017   https://downloads.sourceforge.net/lxde/lxterminal-0.3.1.tar.xz
lyntin                      4.2                   Jun 2014      http://sourceforge.net/projects/lyntin/files/lyntin/4.2/lyntin-4.2.tar.gz
lynx                        2.8.8-rel2            01 Aug 2014   http://lynx.isc.org/current/lynx2.8.8rel.2.tar.bz2
lyx                         2.3.0                 27 Feb 2018   ftp://ftp.lyx.org/pub/lyx/stable/2.3.x/lyx-2.3.0.tar.xz
lzip                        1.18                  27 Sep 2016   http://download.savannah.gnu.org/releases/lzip/lzip-1.18.tar.gz
lzma                        4.32.7                Dec 2012      http://tukaani.org/lzma/lzma-4.32.7.tar.bz2
lzo                         2.10                  07 Jan 2018   http://www.oberhumer.com/opensource/lzo/download/lzo-2.10.tar.gz
m17nlib                     1.7.0                 03 Jan 2018   http://download.savannah.gnu.org/releases/m17n/m17n-lib-1.7.0.tar.gz
m2crypto                    0.27.0                05 Dec 2017   https://pypi.python.org/packages/01/bd/a41491718f9e2bebab015c42b5be7071c6695acfa301e3fc0480bfd6a15b/M2Crypto-0.27.0.tar.gz
m4                          1.4.18                01 Jan 2017   ftp://ftp.gnu.org/gnu/m4/m4-1.4.18.tar.xz
madwifi                     0.9.4                 Jun 2014      http://downloads.sourceforge.net/madwifi/madwifi-0.9.4.tar.bz2
mafft                       7.310                 20 Sep 2017   http://mafft.cbrc.jp/alignment/software/mafft-7.310-with-extensions-src.tgz
mail                        2.7.0                 30 Nov 2017   https://rubygems.org/downloads/mail-2.7.0.gem
mailcommon                  18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/mailcommon-18.04.0.tar.xz
mailimporter                18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/mailimporter-18.04.0.tar.xz
mailman                     2.1.26                06 Feb 2018   https://ftp.gnu.org/pub/gnu/mailman/mailman-2.1.26.tgz
mailutils                   3.4                   04 Nov 2017   http://ftp.gnu.org/pub/gnu/mailutils/mailutils-3.4.tar.xz
make                        4.2.1                 11 Jun 2016   ftp://ftp.gnu.org/gnu/make/make-4.2.1.tar.bz2
makedepend                  1.0.5                 Jun 2014      http://xorg.freedesktop.org/releases/individual/util/makedepend-1.0.5.tar.bz2
mako                        1.0.7                 25 Jul 2017   https://pypi.python.org/packages/eb/f3/67579bb486517c0d49547f9697e36582cd19dafb5df9e687ed8e22de57fa/Mako-1.0.7.tar.gz
mandb                       2.8.2                 05 Apr 2018   http://mirror.easyname.at/nongnu/man-db/man-db-2.8.2.tar.xz
mandvd                      2.4                   Jun 2014      http://csgib36.ifrance.com/FTP/mandvd-2.4.tar.gz
manpages                    4.16                  30 Apr 2018   https://www.kernel.org/pub/linux/docs/man-pages/man-pages-4.16.tar.xz
mantisbt                    1.2.5                 08 Mar 2015   http://sourceforge.net/projects/mantisbt/files/mantis-stable/1.2.5/mantisbt-1.2.5.tar.gz
mapacman                    1.00                  Jan 2013      http://prdownloads.sourceforge.net/arianne/mapacman-1.00.tar.gz
mapmvideo                   5.32                  01 May 2012   http://sourceforge.net/project/showfiles.php?group_id=215566
marble                      4.14.3                24 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/marble-4.14.3.tar.xz
marco                       1.20.1                27 Mar 2018   http://pub.mate-desktop.org/releases/1.20/marco-1.20.1.tar.xz
mariadb                     10.2.14               28 Mar 2018   ftp://ftp.osuosl.org/pub/mariadb/mariadb-10.2.14/source/mariadb-10.2.14.tar.gz
markdown                    1.0.1                 01 Jul 2011   http://daringfireball.net/projects/downloads/markdown-1.0.1.tar.bz2
mars                        0.2.1                 01 Dec 2012   http://www.marsnomercy.org/cms2/
massxpert                   3.6.0                 12 Dec 2015   http://download.tuxfamily.org/massxpert/source/massxpert_3.6.0.tar.gz
mateapplets                 1.20.1                27 Mar 2018   http://pub.mate-desktop.org/releases/1.20/mate-applets-1.20.1.tar.xz
matebackgrounds             1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-backgrounds-1.20.0.tar.xz
matecalc                    1.20.1                27 Mar 2018   http://pub.mate-desktop.org/releases/1.20/mate-calc-1.20.1.tar.xz
matecommon                  1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-common-1.20.0.tar.xz
mateconf                    1.4.0                 Aug 2013      http://pub.mate-desktop.org/releases/1.4/mate-conf-1.4.0.tar.xz
matecontrolcenter           1.20.2                27 Mar 2018   http://pub.mate-desktop.org/releases/1.20/mate-control-center-1.20.2.tar.xz
matecorba                   1.4.0                 Aug 2013      http://pub.mate-desktop.org/releases/1.4/mate-corba-1.4.0.tar.xz
matedesktop                 1.20.1                27 Mar 2018   http://pub.mate-desktop.org/releases/1.20/mate-desktop-1.20.1.tar.xz
matedialogs                 1.8.0                 Jun 2014      http://pub.mate-desktop.org/releases/1.8/mate-dialogs-1.8.0.tar.xz
matedocutils                1.6.1                 Aug 2013      http://pub.mate-desktop.org/releases/1.6/mate-doc-utils-1.6.1.tar.xz
matefilemanager             1.6.2                 Aug 2013      http://pub.mate-desktop.org/releases/1.6/mate-file-manager-1.6.2.tar.xz
mateicontheme               1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-icon-theme-1.20.0.tar.xz
mateiconthemefaenza         1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-icon-theme-faenza-1.20.0.tar.xz
mateindicatorapplet         1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-indicator-applet-1.20.0.tar.xz
matekeyring                 1.6.0                 01 Aug 2013   http://pub.mate-desktop.org/releases/1.6/mate-keyring-1.6.0.tar.xz
matemedia                   1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-media-1.20.0.tar.xz
matemenus                   1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-menus-1.20.0.tar.xz
matenetbook                 1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-netbook-1.20.0.tar.xz
matenetspeed                1.10.2                23 Jul 2015   http://pub.mate-desktop.org/releases/1.10/mate-netspeed-1.10.2.tar.xz
matenotificationdaemon      1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-notification-daemon-1.20.0.tar.xz
matepanel                   1.21.0                30 Apr 2018   http://pub.mate-desktop.org/releases/1.21/mate-panel-1.21.0.tar.xz
matepolkit                  1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-polkit-1.20.0.tar.xz
matepowermanager            1.20.1                27 Mar 2018   http://pub.mate-desktop.org/releases/1.20/mate-power-manager-1.20.1.tar.xz
matescreensaver             1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-screensaver-1.20.0.tar.xz
matesensorsapplet           1.20.1                27 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-sensors-applet-1.20.1.tar.xz
matesessionmanager          1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-session-manager-1.20.0.tar.xz
matesettingsdaemon          1.20.1                27 Mar 2018   http://pub.mate-desktop.org/releases/1.20/mate-settings-daemon-1.20.1.tar.xz
matesystemmonitor           1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-system-monitor-1.20.0.tar.xz
matesystemtools             1.8.0                 01 Mar 2014   http://pub.mate-desktop.org/releases/1.8/mate-system-tools-1.8.0.tar.xz
mateterminal                1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-terminal-1.20.0.tar.xz
matethemes                  1.8.1                 Jun 2014      http://pub.mate-desktop.org/releases/1.8/mate-themes-1.8.1.tar.xz
mateuserguide               1.20.0                09 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-user-guide-1.20.0.tar.xz
mateusershare               1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-user-share-1.20.0.tar.xz
mateutils                   1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mate-utils-1.20.0.tar.xz
mathomatic                  15.8.4                01 Jun 2014   http://mathomatic.org/mathomatic-15.8.4.tar.bz2
maxemumtvguide              7.3.2                 01 Jun 2014   http://sourceforge.net/projects/mtvg/files/mtvg/7.3.2/maxemumtvguide-7.3.2.tar.gz
maxima                      5.40.0                20 Sep 2017   https://sourceforge.net/projects/maxima/files/Maxima-source/5.40.0-source/maxima-5.40.0.tar.gz
mboximporter                18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/mbox-importer-18.04.0.tar.xz
mc                          4.8.20                26 Nov 2017   http://ftp.midnight-commander.org/mc-4.8.20.tar.xz
mcs                         0.4.1                 Jun 2014      mcs-0.4.1
mcsim                       5.6.5                 27 Feb 2016   http://ftp.gnu.org/pub/gnu/mcsim/mcsim-5.6.5.tar.gz
mdadm                       3.3.2                 12 Jun 2015   http://www.kernel.org/pub/linux/utils/raid/mdadm/mdadm-3.3.2.tar.xz
meanwhile                   1.0.2                 Jun 2014      http://meanwhile.sourceforge.net/
mechanize                   2.7.5                 21 Sep 2017   https://rubygems.org/downloads/mechanize-2.7.5.gem
mediatomb                   0.12.1                01 Jun 2014   https://sourceforge.net/projects/mediatomb/files/MediaTomb/0.12.1/mediatomb-0.12.1.tar.gz
mediawiki                   1.25.1                28 May 2015   http://releases.wikimedia.org/mediawiki/1.25/mediawiki-1.25.1.tar.gz
medit                       1.2.0                 09 May 2017   https://sourceforge.net/projects/mooedit/files/medit/1.2.0/medit-1.2.0.tar.bz2
megapov                     1.2.1                 01 Jan 2013   http://megapov.inetart.net/packages/unix/megapov-1.2.1.tar.bz2
megatools                   1.9.97                05 Apr 2016   https://megatools.megous.com/builds/megatools-1.9.97.tar.gz
meld                        3.18.1                29 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/meld/3.18/meld-3.18.1.tar.xz
melons                      1.1.1                 Jun 2014      http://www.imitationpickles.org/melons/melons.tgz
memtester                   4.3.0                 Jun 2014      http://pyropus.ca/software/memtester/old-versions/memtester-4.3.0.tar.gz
menucache                   1.1.0                 11 Nov 2017   https://downloads.sourceforge.net/lxde/menu-cache-1.1.0.tar.xz
merb                        0.9.4                 Jun 2014      https://github.com/merb/merb
mercurial                   4.5.2                 08 Mar 2018   https://www.mercurial-scm.org/release/mercurial-4.5.2.tar.gz
mercurycompiler             0.13.1                Jun 2014      http://www.mercury.csse.unimelb.edu.au/download.html
mesa                        18.0.2                28 Apr 2018   https://mesa.freedesktop.org/archive/mesa-18.0.2.tar.xz
mesademos                   6.5                   Jun 2014      http://mesh.dl.sourceforge.net/sourceforge/mesa3d/MesaDemos-6.5.tar.bz2
mesaglut                    7.10                  Jun 2014      ftp://ftp.freedesktop.org/pub/mesa/7.10/MesaGLUT-7.10.tar.bz2
mesk                        0.1.0                 Jun 2014      http://mesk.nicfit.net/releases/mesk-0.1.0.tgz
meson                       0.45.1                10 Apr 2018   https://pypi.python.org/packages/e7/09/2a2d6f99f6ff4ad990743444a12b097a619779ad13d7b124d7e54f0c3682/meson-0.45.1.tar.gz
messagelib                  18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/messagelib-18.04.0.tar.xz
metacity                    3.26.0                03 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/metacity/3.26/metacity-3.26.0.tar.xz
metv                        0.8.12                Jun 2014      http://launchpad.net/me-tv/stable/0.8/+download/me-tv-0.8.12.tar.gz
mftrace                     1.2.14                Jun 2013      http://www.xs4all.nl/~hanwen/mftrace/mftrace-1.2.14.tar.gz
mgaview                     0.0.30                01 Jun 2014   http://sourceforge.net/projects/mgaview/mgaview-0.0.30
midillo                     0.0                   Jun 2014      http://kin.klever.net/konforka/
midori                      0.5.1                 01 Feb 2012   http://archive.xfce.org/src/apps/midori/0.5/midori-0.5.1.tar.bz2
milkytracker                0.90.85               Jun 2014      http://milkytracker.org/files/milkytracker-0.90.85.tar.bz2
milou                       5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/milou-5.12.4.tar.xz
mimetypes                   3.1                   29 Sep 2017   https://rubygems.org/downloads/mime-types-3.1.gem
mimetypesdata               3.2016.0521           29 Sep 2017   https://rubygems.org/downloads/mime-types-data-3.2016.0521.gem
ming                        0.4.0rc1              01 Jun 2014   http://sourceforge.net/project/showfiles.php?group_id=18365&package_id=187304&release_id=611489
mingetty                    1.07                  01 Jun 2014   http://ftp.de.debian.org/debian/pool/main/m/mingetty/mingetty-1.07.orig.tar.gz
minimime                    1.0.0                 30 Nov 2017   https://rubygems.org/downloads/mini_mime-1.0.0.gem
miniportile2                2.3.0                 03 Dec 2017   https://rubygems.org/downloads/mini_portile2-2.3.0.gem
minit                       0.10                  03 Mar 2015   http://hisham.hm/htop/releases/1.0.3/minit-0.10.tar.xz
minitest                    5.11.3                27 Jan 2018   https://rubygems.org/downloads/minitest-5.11.3.gem
minuet                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/minuet-18.04.0.tar.xz
mirage                      0.8                   Jun 2014      http://raschix.de/article/mirage-image-viewer
missile                     1.0.1                 01 Jun 2014   http://missile.sourceforge.net/dl/missile-1.0.1.tar.gz
mjpegtools                  1.8.0                 01 Jun 2014   http://citkit.dl.sourceforge.net/sourceforge/mjpeg/mjpegtools-1.8.0.tar.gz
mkcfm                       1.0.1                 Jun 2014      http://xorg.freedesktop.org/releases/individual/app/mkcfm-1.0.1.tar.bz2
mkcomposecache              1.2.1                 Jun 2014      http://xorg.freedesktop.org/releases/individual/app/mkcomposecache-1.2.1.tar.bz2
mkfontdir                   1.0.7                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/app/mkfontdir-1.0.7.tar.bz2
mkfontscale                 1.1.3                 15 Mar 2018   http://xorg.freedesktop.org/archive/individual/app/mkfontscale-1.1.3.tar.bz2
mkrf                        0.2.3                 29 Nov 2017   https://rubygems.org/downloads/mkrf-0.2.3.gem
mktemp                      1.7                   01 Dec 2012   ftp://ftp.mktemp.org/pub/mktemp/mktemp-1.7.tar.gz
mkvtoolnix                  11.0.0                05 May 2017   https://mkvtoolnix.download/sources/mkvtoolnix-11.0.0.tar.xz
mlr                         4.4.0                 14 Aug 2016   https://github.com/johnkerl/miller/releases/download/v4.4.0/mlr-4.4.0.tar.gz
mlt                         0.7.4                 01 Jun 2014   http://downloads.sourceforge.net/project/mlt/mlt/mlt-0.7.4.tar.gz
mmcommon                    0.9.12                08 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/mm-common/0.9/mm-common-0.9.12.tar.xz
mobs                        2.3.2                 01 Jun 2014   http://www.dervishd.net/Projects/mobs-2.3.2.tar.gz
moc                         2.5.2                 09 Jun 2017   http://ftp.daper.net/pub/soft/moc/stable/moc-2.5.2.tar.bz2
mochikit                    1.3.1                 01 Jun 2014   http://mochikit.com/
modemmanager                1.6.12                29 Dec 2017   https://www.freedesktop.org/software/ModemManager/ModemManager-1.6.12.tar.xz
modemmanagerqt              5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/modemmanager-qt-5.45.0.tar.xz
modfastcgi                  2.4.2                 01 Jun 2014   http://freshmeat.net/redir/mod_fastcgi/6562/url_tgz/mod_fastcgi-2.4.2.tar.gz
modmono                     1.2.5                 Jun 2014      http://go-mono.com/sources/mod_mono/mod_mono-1.2.5.tar.bz2
modperl                     2.0.10                28 Oct 2016   http://www-eu.apache.org/dist/perl/mod_perl-2.0.10.tar.gz
modpython                   3.5.0                 31 Oct 2017   http://dist.modpython.org/dist/mod_python-3.5.0.tgz
modspin                     1.1.6                 01 Jun 2014   http://freecode.com/projects/mod_spin/releases
moduleinittools             3.16                  Jun 2014      ftp://ftp.kernel.org/pub/linux/utils/kernel/module-init-tools/module-init-tools-3.16.tar.bz2
modules                     3.2.10                27 Aug 2015   http://sourceforge.net/projects/modules/files/Modules/modules-3.2.10/modules-3.2.10.tar.bz2
moe                         1.8                   17 Feb 2016   http://ftp.gnu.org/pub/gnu/moe/moe-1.8.tar.lz
mojolicious                 2.0                   Jan 2013      http://cpan.metacpan.org/authors/id/S/SR/SRI/Mojolicious-2.0.tar.gz
momomoto                    0.2.1                 01 Dec 2017   https://rubygems.org/downloads/momomoto-0.2.1.gem
money                       6.11.1                01 May 2018   https://rubygems.org/downloads/money-6.11.1.gem
mongodb                     r3.4.6                20 Apr 2015   https://fastdl.mongodb.org/src/mongodb-src-r3.4.6.tar.gz
mongrel                     1.1.5                 01 Aug 2017   https://rubygems.org/downloads/mongrel-1.1.5.gem
mongrel2                    v1.10.0               22 Dec 2015   https://github.com/mongrel2/mongrel2/releases/download/v1.10.0/mongrel2-v1.10.0.tar.bz2
monit                       4.10                  01 Jun 2014   http://www.tildeslash.com/monit/dist/monit-4.10.tar.gz
mono                        5.15.0.301            29 Apr 2018   http://download.mono-project.com/sources/mono/nightly/mono-5.15.0.301.tar.bz2
monoaddins                  0.4                   01 Jun 2014   http://ftp.novell.com/pub/mono/sources/mono-addins/mono-addins-0.4.tar.bz2
monodevelop                 6.0.0.4761            28 Mar 2016   http://download.mono-project.com/sources/monodevelop/monodevelop-6.0.0.4761.tar.bz2
monsterz                    0.7.1                 10 Oct 2017   http://sam.zoy.org/monsterz/monsterz-0.7.1.tar.gz
moodle                      3.4                   08 Dec 2017   https://sourceforge.net/projects/moodle/files/Moodle/stable34/moodle-3.4.tgz
moonbuggy                   1.0.51                24 Mar 2016   http://m.seehuhn.de/programs/moon-buggy-1.0.51.tar.gz
moserial                    3.0.12                08 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/moserial/3.0/moserial-3.0.12.tar.xz
mosh                        1.3.0                 27 Mar 2017   https://mosh.org/mosh-1.3.0.tar.gz
most                        5.0.0                 01 Jun 2014   ftp://space.mit.edu/pub/davis/most/most-5.0.0a.tar.bz2
motif                       2.3.8                 09 Dec 2017   https://sourceforge.net/projects/motif/files/Motif%202.3.8%20Source%20Code/motif-2.3.8.tar.gz
mousepad                    0.4.0                 26 Jul 2017   http://archive.xfce.org/src/apps/mousepad/0.4/mousepad-0.4.0.tar.bz2
mousetrap                   3.17.3                23 Jun 2015   http://ftp.gnome.org/pub/GNOME/sources/mousetrap/3.17/mousetrap-3.17.3.tar.xz
mozart2                     13.12.2015            13 Dec 2015   http://www.mozart-oz.org/download/mozart-ftp/store/1.3.1-2004-06-16/mozart2-13.12.2015.tar.xz
mozjs                       38.2.1.rc0            22 Aug 2017   https://ftp.osuosl.org/pub/blfs/conglomeration/mozjs/mozjs-38.2.1.rc0.tar.bz2
mozo                        1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/mozo-1.20.0.tar.xz
mp                          5.2.2                 01 Jun 2014   http://triptico.com/download/mp-5.2.2.tar.gz
mp3blaster                  3.2.6                 17 Nov 2017   https://sourceforge.net/projects/mp3blaster/files/mp3blaster/mp3blaster-3.2.6/mp3blaster-3.2.6.tar.gz
mp3cat                      0.4                   Jun 2014      http://tomclegg.net/software/mp3cat-0.4.tar.gz
mp3daemon                   0.63                  May 2014      http://search.cpan.org/CPAN/authors/id/B/BE/BEPPU/MP3-Daemon-0.63.tar.gz
mp3diags                    1.0.12.079            Jan 2013      http://sourceforge.net/projects/mp3diags/files/mp3diags-src/MP3Diags-1.0.12.079.tar.gz
mp3gain                     1.4.6                 Jun 2014      http://mp3gain.sourceforge.net/download.php
mp3info                     0.8.5                 Jun 2014      ftp://ftp.ibiblio.org/pub/linux/apps/sound/mp3-utils/mp3info/mp3info-0.8.5.tgz
mp3splt                     2.4.2                 Jun 2014      http://downloads.sourceforge.net/project/mp3splt/mp3splt/2.4.2/mp3splt-2.4.2.tar.gz
mp3val                      0.1.8                 Jan 2013      http://downloads.sourceforge.net/mp3val/mp3val-0.1.8-src.tar.gz
mp3wrap                     0.5                   Jun 2014      http://prdownloads.sourceforge.net/mp3wrap/mp3wrap-0.5-src.tar.gz
mpage                       2.5.6                 07 Feb 2016   http://www.mesa.nl/pub/mpage/mpage-2.5.6.tgz
mpc                         1.1.0                 19 Jan 2018   https://ftp.gnu.org/gnu/mpc/mpc-1.1.0.tar.gz
mpd                         0.20.15               20 Jan 2018   http://www.musicpd.org/download/mpd/0.20/mpd-0.20.15.tar.xz
mpeg2dec                    0.4.1                 01 Jun 2014   http://libmpeg2.sourceforge.net/files/mpeg2dec-0.4.1.tar.gz
mpeg4ip                     1.5.0.1               01 Jun 2014   http://wiki.ubuntuusers.de/Archiv/mpeg4ip
mpfr                        4.0.1                 10 Feb 2018   https://ftp.gnu.org/pub/gnu/mpfr/mpfr-4.0.1.tar.xz
mpg123                      1.25.10               16 Mar 2018   http://www.mpg123.de/download/mpg123-1.25.10.tar.bz2
mpg321                      0.2.13.3              Jun 2014      http://sourceforge.net/projects/mpg321/files/mpg321/0.2.13/mpg321-0.2.13.3.tar.gz
mpgedit                     0.75dev2              Jun 2014      http://mpgedit.org/mpgedit/download/0_75/mpgedit_0-75dev2_src.tgz
mpgtx                       1.3.1                 Jun 2014      http://ovh.dl.sourceforge.net/sourceforge/mpgtx/mpgtx-1.3.1.tgz
mplayer                     1.3.0                 17 Feb 2016   ftp://ftp1.mplayerhq.hu/MPlayer/releases/MPlayer-1.3.0.tar.xz
mpop                        1.2.5                 24 Jun 2016   https://sourceforge.net/projects/mpop/files/mpop/1.2.5/mpop-1.2.5.tar.xz
mppenc                      1.16                  01 Jun 2014   http://files.musepack.net/source/mppenc-1.16.tar.bz2
mpv                         17.04.2018            17 Apr 2018   mpv-17.04.2018
mrepo                       0.8.4                 Jun 2014      http://dag.wieers.com/home-made/mrepo/
mrxvt                       0.5.4                 Jun 2014      http://prdownloads.sourceforge.net/materm/mrxvt-0.5.4.tar.gz
msgpack                     2.1.5                 01 Jan 2018   https://github.com/msgpack/msgpack-c/releases/download/cpp-2.1.5/msgpack-2.1.5.tar.gz
msitools                    0.97                  01 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/msitools/0.97/msitools-0.97.tar.xz
msleep                      0.1.0                 23 Mar 2017   https://rubygems.org/downloads/msleep-0.1.0.gem
mssys                       2.1.2                 Jun 2014      http://ms-sys.sourceforge.net/
mtail                       1.1.1                 Jan 2013      http://matt.immute.net/src/mtail/mtail-1.1.1.tgz
mtdev                       1.1.5                 28 May 2015   http://bitmath.org/code/mtdev/mtdev-1.1.5.tar.bz2
mtools                      4.0.17                Nov 2012      ftp://ftp.gnu.org/gnu/mtools/mtools-4.0.17.tar.bz2
mtpaint                     3.31                  Jun 2014      http://sourceforge.net/projects/mtpaint/files/mtpaint/3.31/mtpaint-3.31.tar.bz2
mtr                         0.87                  19 Oct 2016   ftp://ftp.bitwizard.nl/mtr/mtr-0.87.tar.gz
mudlet                      1.0.5                 01 Jun 2014   mudlet-1.0.5.tar.gz
mudmagic                    1.9                   01 Jun 2014   https://sourceforge.net/projects/kyndig/files/Mud%20Magic%20Source/1.9/mudmagic-1.9.tar.gz
multiaterm                  0.2.1                 01 Jun 2014   http://www.nongnu.org/materm/multi-aterm-0.2.1.tar.gz
multijson                   1.13.1                16 Jan 2018   https://rubygems.org/downloads/multi_json-1.13.1.gem
multipartpost               2.0.0                 03 Dec 2017   https://rubygems.org/downloads/multipart-post-2.0.0.gem
mummer                      3.23                  01 Nov 2013   https://sourceforge.net/projects/mummer/files/mummer/3.23/MUMmer3.23.tar.gz
mupdf                       1.13.0                22 Apr 2018   http://www.mupdf.com/downloads/archive/mupdf-1.13.0-source.tar.gz
muse                        2.2.1                 25 Sep 2015   http://sourceforge.net/projects/lmuse/files/muse-2.2/muse-2.2.1.tar.gz
musepack                    r475                  Nov 2012      http://files.musepack.net/source/musepack_src_r475.tar.gz
musl                        1.1.18                29 Dec 2017   http://www.musl-libc.org/releases/musl-1.1.18.tar.gz
mustermann                  1.0.2                 26 Feb 2018   https://rubygems.org/downloads/mustermann-1.0.2.gem
mutagen                     1.31                  05 Mar 2016   https://pypi.python.org/packages/source/m/mutagen/mutagen-1.31.tar.gz
mutt                        1.9.5                 15 Apr 2018   ftp://ftp.mutt.org/pub/mutt/mutt-1.9.5.tar.gz
mutter                      3.28.1                29 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/mutter/3.28/mutter-3.28.1.tar.xz
mutterwayland               3.12.1                01 Apr 2014   http://ftp.gnome.org/pub/gnome/sources/mutter-wayland/3.12/mutter-wayland-3.12.1.tar.xz
mxk                         1.10                  01 Jun 2014   http://welz.org.za/projects/mxk/mxk-1.10.tar.gz
mxml                        2.7                   Jun 2014      http://ftp.easysw.com/pub/mxml/2.7/mxml-2.7.tar.gz
myghty                      1.0                   Jun 2014      http://easynews.dl.sourceforge.net/sourceforge/myghty/Myghty-1.0.tar.gz
myman                       0.7.0                 10 Oct 2017   https://sourceforge.net/projects/myman/files/myman/myman-0.7.0/myman-0.7.0.tar.gz
mypaint                     1.2.1                 10 Sep 2017   https://github.com/mypaint/mypaint/releases/download/v1.2.1/mypaint-1.2.1.tar.xz
mysql                       5.7.22                19 Apr 2018   https://cdn.mysql.com/Downloads/MySQL-5.7/mysql-5.7.22.tar.gz
mythplugins                 0.20a                 Jun 2014      http://www.mythtv.org/modules.php?name=Downloads&d_op=getit&lid=124/mythplugins-0.20a
nagios                      4.3.1                 Jun 2014      https://assets.nagios.com/downloads/nagioscore/releases/nagios-4.3.1.tar.gz#_ga=1.110313093.1455961778.1489835372
naim                        0.11.8.3.1            Jun 2014      http://naim.googlecode.com/files/naim-0.11.8.3.1.tar.bz2
najitool                    0.8.4                 07 Oct 2017   https://sourceforge.net/projects/najitool/files/najitool/0.8.4/najitool-0.8.4.src.tar.bz2
nana                        201.5.4               08 Aug 2017   https://sourceforge.net/projects/nanapro/files/Nana/Nana%201.x/nana%201.5.4.zip
nano                        2.9.6                 27 Apr 2018   https://www.nano-editor.org/dist/latest/nano-2.9.6.tar.gz
nap                         1.5.4                 Jun 2014      http://nap.sourceforge.net/dist/nap-1.5.4.tar.gz
nas                         1.9.3                 01 Aug 2013   http://sourceforge.net/projects/nas/files/nas/nas.1.9.3%20%28stable%29/nas-1.9.3.src.tar.gz
nasm                        2.13.02               02 Dec 2017   http://www.nasm.us/pub/nasm/releasebuilds/2.13.02/nasm-2.13.02.tar.xz
nast                        0.2.0                 05 Jun 2014   http://download.berlios.de/nast/nast-0.2.0.tar.gz
nativepackageinstaller      1.0.6                 17 Dec 2017   https://rubygems.org/downloads/native-package-installer-1.0.6.gem
nautilus                    3.28.1                10 Apr 2018   ftp://ftp.gnome.org/pub/gnome/sources/nautilus/3.28/nautilus-3.28.1.tar.xz
nautilusactions             3.2.4                 01 Aug 2014   http://ftp.gnome.org/pub/GNOME/sources/nautilus-actions/3.2/nautilus-actions-3.2.4.tar.xz
nautiluscdburner            2.22.1                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/nautilus-cd-burner/2.22/nautilus-cd-burner-2.22.1.tar.bz2
nautilusmedia               0.8.1                 Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/nautilus-media/0.8/nautilus-media-0.8.1.tar.bz2
nautiluspython              1.2.2                 15 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/nautilus-python/1.2/nautilus-python-1.2.2.tar.xz
nautilussendto              3.8.6                 09 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/nautilus-sendto/3.8/nautilus-sendto-3.8.6.tar.xz
nazghul                     0.7.1                 31 Mar 2015   https://downloads.sourceforge.net/project/nazghul/nazghul/nazghul-0.7.1/nazghul-0.7.1.tar.gz
ncbiblast                   2.7.0+                14 Oct 2017   ftp://ftp.ncbi.nlm.nih.gov/blast/executables/blast+/LATEST/ncbi-blast-2.7.0+-src.tar.gz
ncbicxx                     18.0.0                20 Sep 2017   ftp://ftp.ncbi.nlm.nih.gov/toolbox/ncbi_tools++/ARCHIVE/2017/Jan_10_2017/ncbi_cxx--18_0_0.tar.gz
ncc                         2.8                   Jun 2014      http://students.ceid.upatras.gr/~sxanth/ncc/ncc-2.8.tar.gz
ncdu                        1.4                   Jun 2014      http://dev.yorhel.nl/ncdu/
ncftp                       3.2.6                 28 Nov 2016   ftp://ftp.ncftp.com/ncftp/ncftp-3.2.6-src.tar.xz
ncmpcpp                     0.5.10                01 Jun 2014   http://unkart.ovh.org/ncmpcpp/ncmpcpp-0.5.10.tar.bz2
ncurses                     6.1                   30 Jan 2018   ftp://ftp.gnu.org/gnu/ncurses/ncurses-6.1.tar.gz
ndeskdbus                   0.6.0                 01 Jun 2014   http://www.ndesk.org/DBusSharp
ndeskdbusglib               0.4.1                 Feb 2013      http://www.ndesk.org/archive/dbus-sharp/ndesk-dbus-glib-0.4.1.tar.gz
ndiswrapper                 1.61                  26 Jul 2017   https://sourceforge.net/projects/ndiswrapper/files/stable/ndiswrapper-1.61.tar.gz
nemiver                     0.9.6                 24 Sep 2015   http://ftp.gnome.org/pub/GNOME/sources/nemiver/0.9/nemiver-0.9.6.tar.xz
neon                        0.30.2                22 Nov 2016   https://fossies.org/linux/www/neon-0.30.2.tar.gz
nepomukcore                 4.14.3                09 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/nepomuk-core-4.14.3.tar.xz
net6                        1.3.5                 01 Jun 2014   http://releases.0x539.de/net6/
netatalk                    2.1.1                 Jun 2014      http://downloads.sourceforge.net/netatalk/netatalk-2.1.1.tar.bz2
netcat                      0.7.1                 Jun 2014      http://netcat.sourceforge.net/
nethack                     3.6.0                 Jun 2014      https://sourceforge.net/projects/nethack/files/nethack/3.6.0/nethack-360-src.tgz
nethttp                     6.17                  27 Sep 2017   http://search.cpan.org/CPAN/authors/id/O/OA/OALDERS/Net-HTTP-6.17.tar.gz
netkitbase                  0.17                  Jun 2014      ftp://ftp.uk.linux.org/pub/linux/Networking/netkit/netkit-base-0.17.tar.gz
netkitrsh                   0.17                  Jun 2014      ftp://ftp.uk.linux.org/pub/linux/Networking/netkit/netkit-rsh-0.17.tar.gz
netpbm                      10.47.66              28 Dec 2017   https://sourceforge.net/projects/netpbm/files/super_stable/10.47.66/netpbm-10.47.66.tgz
netrc                       0.11.0                29 Sep 2017   https://rubygems.org/downloads/netrc-0.11.0.gem
netscp                      1.2.1                 08 Jan 2018   https://rubygems.org/downloads/net-scp-1.2.1.gem
nettle                      3.4                   28 Nov 2017   https://ftp.gnu.org/gnu/nettle/nettle-3.4.tar.gz
networkmanager              1.10.6                12 Mar 2018   http://ftp.gnome.org/pub/GNOME/sources/NetworkManager/1.10/NetworkManager-1.10.6.tar.xz
networkmanagerapplet        1.8.10                29 Dec 2017   http://ftp.gnome.org/pub/gnome/sources/network-manager-applet/1.8/network-manager-applet-1.8.10.tar.xz
networkmanagerfortisslvpn   1.2.8                 17 Jan 2018   http://ftp.gnome.org/pub/gnome/sources/NetworkManager-fortisslvpn/1.2/NetworkManager-fortisslvpn-1.2.8.tar.xz
networkmanagerlibreswan     1.2.2                 14 May 2016   http://ftp.gnome.org/pub/GNOME/sources/NetworkManager-libreswan/1.2/NetworkManager-libreswan-1.2.2.tar.xz
networkmanageropenconnect   1.2.2                 14 May 2016   http://ftp.gnome.org/pub/GNOME/sources/NetworkManager-openconnect/1.2/NetworkManager-openconnect-1.2.2.tar.xz
networkmanageropenvpn       1.8.0                 21 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/NetworkManager-openvpn/1.8/NetworkManager-openvpn-1.8.0.tar.xz
networkmanagerpptp          1.2.6                 01 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/NetworkManager-pptp/1.2/NetworkManager-pptp-1.2.6.tar.xz
networkmanagerqt            5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/networkmanager-qt-5.45.0.tar.xz
networkmanagervpnc          1.2.2                 12 May 2016   http://ftp.gnome.org/pub/GNOME/sources/NetworkManager-vpnc/1.2/NetworkManager-vpnc-1.2.2.tar.xz
neverball                   1.6.0                 27 Mar 2016   http://neverball.org/neverball-1.6.0.tar.gz
newlib                      2.0.0                 Jun 2014      ftp://sourceware.org/pub/newlib/newlib-2.0.0.tar.gz
newrelicrpm                 5.1.0                 01 May 2018   https://rubygems.org/downloads/newrelic_rpm-5.1.0.344.gem
newsbeuter                  2.9                   03 Oct 2017   http://www.newsbeuter.org/downloads/newsbeuter-2.9.tar.gz
newt                        0.52.20               24 Jul 2017   https://releases.pagure.org/newt/newt-0.52.20.tar.gz
nfsutils                    2.2.1                 04 Nov 2017   http://downloads.sourceforge.net/nfs/nfs-utils-2.2.1.tar.bz2
nghttp2                     1.31.1                15 Apr 2018   https://github.com/nghttp2/nghttp2/releases/download/v1.31.1/nghttp2-1.31.1.tar.xz
nginx                       1.14.0                17 Apr 2018   http://nginx.org/download/nginx-1.14.0.tar.gz
ngstar                      1.3.3                 01 Jun 2014   http://cycojesus.free.fr/faire/coder/jouer/ng-star/files/
nim                         0.16.0                21 Feb 2017   https://nim-lang.org/download/nim-0.16.0.tar.xz
ninja                       1.8.2                 26 Sep 2017   https://github.com/ninja-build/ninja/archive/v1.8.2.tar.gz
nmap                        7.70                  21 Mar 2018   http://download.insecure.org/nmap/dist/nmap-7.70.tgz
node                        v9.11.1               25 Apr 2018   https://nodejs.org/dist/v9.11.1/node-v9.11.1.tar.xz
nokogiri                    1.8.2                 30 Jan 2018   https://rubygems.org/downloads/nokogiri-1.8.2.gem
normalize                   0.7.7                 Jun 2014      http://savannah.nongnu.org/download/normalize/normalize-0.7.7.tar.bz2
notificationdaemon          3.18.2                16 Feb 2016   http://ftp.gnome.org/pub/GNOME/sources/notification-daemon/3.18/notification-daemon-3.18.2.tar.xz
notify2                     0.3.1                 04 Sep 2017   https://pypi.python.org/packages/aa/e8/d4b335aa739dc299a77766ecc5f1972d1de1993524aa94acef3219bba315/notify2-0.3.1.tar.gz
notifypython                0.1.1                 25 Apr 2015   http://www.galago-project.org/files/releases/source/notify-python/notify-python-0.1.1.tar.bz2
npth                        1.5                   09 Jun 2017   ftp://ftp.gnupg.org/gcrypt/npth/npth-1.5.tar.bz2
nsd                         4.1.17                25 Jul 2017   https://www.nlnetlabs.nl/downloads/nsd/nsd-4.1.17.tar.gz
nspluginwrapper             1.2.2                 Jun 2014      http://gwenole.beauchesne.info/projects/nspluginwrapper/files/nspluginwrapper-1.2.2.tar.bz2
nspr                        4.17                  24 Sep 2017   https://archive.mozilla.org/pub/nspr/releases/v4.17/src/nspr-4.17.tar.gz
nss                         3.34.1                11 Jan 2018   https://archive.mozilla.org/pub/security/nss/releases/NSS_3_34_1_RTM/src/nss-3.34.1.tar.gz
ntfs3gntfsprogs             2017.3.23             12 Sep 2017   https://tuxera.com/opensource/ntfs-3g_ntfsprogs-2017.3.23.tgz
ntp                         4.2.8p8               17 Jul 2016   https://www.eecis.udel.edu/~ntp/ntp_spool/ntp4/ntp-4.2/ntp-4.2.8p8.tar.gz
ntrack                      017                   09 Jul 2015   https://launchpad.net/ntrack/main/017/+download/ntrack-017.tar.gz
numactl                     2.0.11                02 Sep 2017   https://github.com/numactl/numactl/archive/numactl-2.0.11.tar.gz
numeric                     24.2                  01 Jun 2014   Numeric-24.2
numpy                       1.14.2                04 Apr 2018   https://github.com/numpy/numpy/releases/download/v1.14.2/numpy-1.14.2.tar.gz
nuvie                       0.5                   19 Oct 2014   http://sourceforge.net/projects/nuvie/files/Nuvie/0.5/nuvie-0.5.tgz
nvclock                     0.8                   01 Jun 2014   http://www.linuxhardware.org/nvclock/nvclock0.8b4.tar.gz
nvidia                      352.63.               14 Dec 2015   http://us.download.nvidia.com/XFree86/Linux-x86/352.63/NVIDIA-Linux-x86-352.63.run
nwcc                        0.8.2                 01 Jun 2014   http://sourceforge.net/projects/nwcc/files/nwcc/nwcc%200.8.2/nwcc_0.8.2.tar.gz
nzbget                      17.1                  06 Sep 2016   https://github.com/nzbget/nzbget/releases/download/v17.1/nzbget-17.1-src.tar.gz
obby                        0.4.6                 Jun 2014      http://releases.0x539.de/obby/obby-0.4.6.tar.gz
obconf                      2.0.4                 23 Aug 2017   http://openbox.org/dist/obconf/obconf-2.0.4.tar.gz
obexdataserver              0.4.6                 Dec 2012      http://tadas.dailyda.com/software/obex-data-server-0.4.6.tar.gz
ocaml                       4.04.0                25 Feb 2017   http://caml.inria.fr/pub/distrib/ocaml-4.04/ocaml-4.04.0.tar.gz
oclock                      1.0.1                 Jun 2014      http://xorg.freedesktop.org/releases/individual/app/oclock-1.0.1.tar.bz2
ocra                        1.3.10                01 Dec 2017   https://rubygems.org/downloads/ocra-1.3.10.gem
ocrad                       0.26                  01 Dec 2017   http://ftp.gnu.org/gnu/ocrad/ocrad-0.26.tar.lz
ocrfeeder                   0.8.1                 12 Mar 2015   http://ftp.gnome.org/pub/GNOME/sources/ocrfeeder/0.8/ocrfeeder-0.8.1.tar.xz
octave                      4.4.0                 02 May 2018   http://ftp.gnu.org/gnu/octave/octave-4.4.0.tar.xz
ogmrip                      1.0.1                 30 Aug 2015   http://sourceforge.net/projects/ogmrip/files/ogmrip/1.0/1.0.1/ogmrip-1.0.1.tar.gz
ogmtools                    1.5                   Jun 2014      http://www.bunkus.org/videotools/ogmtools/ogmtools-1.5.tar.bz2
ogre                        1.8.1                 20 May 2015   http://sourceforge.net/projects/ogre/files/ogre/1.8/1.8.1/ogre_src_v1-8-1.tar.bz2
oki                         0.1.6                 Jun 2014      http://free.of.pl/s/szatkus/soft/gry/oki-0.1.6.tar.gz
okteta                      4.14.3                09 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/okteta-4.14.3.tar.xz
okular                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/okular-18.04.0.tar.xz
omake                       0.9.8.5.3             Jun 2014      http://omake.metaprl.org/download.html
opal                        3.10.10               24 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/opal/3.10/opal-3.10.10.tar.xz
openal                      0.0.8                 01 Jun 2014   http://www.openal.org/openal_webstf/downloads/openal-0.0.8.tar.gz
openalsoft                  1.15.1                01 Nov 2013   http://www.openal-soft.org/openal-releases/openal-soft-1.15.1.tar.bz2
openbabel                   2.4.1                 20 Sep 2017   https://sourceforge.net/projects/openbabel/files/openbabel/2.4.1/openbabel-2.4.1.tar.gz
openbox                     3.6.1                 01 Jul 2015   http://openbox.org/dist/openbox/openbox-3.6.1.tar.gz
opencobol                   1.1                   01 Dec 2013   https://downloads.sourceforge.net/project/open-cobol/open-cobol/1.1/open-cobol-1.1.tar.gz
openconnect                 6.00                  Jul 2014      ftp://ftp.infradead.org/pub/openconnect/openconnect-6.00.tar.gz
opencv                      3.4.0                 27 Dec 2017   http://sourceforge.net/projects/opencvlibrary/files/opencv-unix/3.4.0/opencv-3.4.0.zip
openexr                     2.2.0                 09 Jul 2015   http://download.savannah.nongnu.org/releases/openexr/openexr-2.2.0.tar.gz
openinvaders                0.3                   Dec 2012      http://www.jamyskis.net/invaders.php
openjade                    1.3.2                 Jun 2014      http://prdownloads.sourceforge.net/openjade/openjade-1.3.2.tar.gz
openjpeg                    2.3.0                 12 Oct 2017   https://github.com/uclouvain/openjpeg/archive/v2.3.0.tar.gz
openldap                    2.4.46                23 Mar 2018   ftp://ftp.openldap.org/pub/OpenLDAP/openldap-release/openldap-2.4.46.tgz
openldev                    1.0                   21 Aug 2017   https://sourceforge.net/projects/openldev/files/openldev/1.0/openldev-1.0.tar.gz
openmovieeditor             0.0.20090105          Jun 2014      http://openmovieeditor.sourceforge.net/HomePage
openmpi                     3.0.0                 27 Sep 2017   https://www.open-mpi.org/software/ompi/v3.0/downloads/openmpi-3.0.0.tar.gz
openobex                    1.7.1                 01 Jan 2014   https://downloads.sourceforge.net/project/openobex/openobex/1.7.1/openobex-1.7.1-Source.tar.gz
openscenegraph              2.4.0                 Jun 2014      OpenSceneGraph-2.4.0
openshot                    1.4.3                 Jun 2014      http://launchpad.net/openshot/1.4/1.4.3/+download/openshot-1.4.3.tar.gz
openshotqt                  2.4.1                 12 Nov 2017   http://launchpad.net/openshot/2.4/2.4.1/+download/openshot-qt-2.4.1.tar.gz
opensp                      1.5.2                 Jun 2014      http://ovh.dl.sourceforge.net/sourceforge/openjade/OpenSP-1.5.2.tar.gz
openssh                     7.7p1                 03 Apr 2018   https://ftp3.usa.openbsd.org/pub/OpenBSD/OpenSSH/portable/openssh-7.7p1.tar.gz
openssl                     1.1.0h                27 Mar 2018   ftp://ftp.openssl.org/source/openssl-1.1.0h.tar.gz
openssn                     1.3                   Dec 2012      http://sourceforge.net/projects/openssn/files/openssn-1.3/openssn-1.3.tar.gz
openttd                     1.2.3                 08 Aug 2015   https://binaries.openttd.org/releases/1.5.1/openttd-1.5.1-source.tar.gz
openvrml                    0.18.9                01 Jun 2014   http://sourceforge.net/projects/openvrml/files/openvrml/0.18.9/openvrml-0.18.9.tar.gz
opera                       12.00                 Jun 2014      http://snapshot.opera.com/unix/bonkers_12.00-1440/opera-next-12.00-1440.x86_64.linux.tar.xz
ophcrack                    3.6.0                 Jul 2013      http://downloads.sourceforge.net/project/ophcrack/ophcrack/3.6.0/ophcrack-3.6.0.tar.bz2
optipng                     0.7.6                 29 Sep 2016   https://sourceforge.net/projects/optipng/files/OptiPNG/optipng-0.7.6/optipng-0.7.6.tar.gz
opus                        1.1.4                 13 Aug 2017   https://ftp.osuosl.org/pub/xiph/releases/opus/opus-1.1.4.tar.gz
opusfile                    0.9                   25 Dec 2017   https://archive.mozilla.org/pub/opus/opusfile-0.9.tar.gz
opustools                   0.1.10                25 Dec 2017   https://archive.mozilla.org/pub/opus/opus-tools-0.1.10.tar.gz
orbit2                      2.14.19               Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/ORBit2/2.14/ORBit2-2.14.19.tar.bz2
orca                        3.28.1                29 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/orca/3.28/orca-3.28.1.tar.xz
ostree                      2014.4                Apr 2014      http://ftp.gnome.org/pub/gnome/sources/ostree/2014.4/ostree-2014.4.tar.xz
oxygen                      5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/oxygen-5.12.4.tar.xz
oxygengtk                   1.1.6                 Aug 2013      http://download.kde.org/stable/oxygen-gtk/1.1.6/src/oxygen-gtk-1.1.6.tar.bz2
oxygenicons5                5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/oxygen-icons5-5.45.0.tar.xz
p11kit                      0.23.10               16 Mar 2018   https://github.com/p11-glue/p11-kit/releases/download/0.23.10/p11-kit-0.23.10.tar.gz
p7zip                       9.20.1                28 Sep 2017   https://sourceforge.net/projects/p7zip/files/p7zip/16.02/p7zip_16.02_src_all.tar.bz2
packagekit                  1.0.10                16 Oct 2015   http://www.freedesktop.org/software/PackageKit/releases/PackageKit-1.0.10.tar.xz
pacman                      21.09.2017            21 Sep 2017   ftp://ftp.archlinux.org/other/pacman/pacman-21.09.2017.tar.xz
padrino                     0.14.3                02 Mar 2018   https://rubygems.org/downloads/padrino-0.14.3.gem
paint                       2.0.1                 09 Jan 2018   https://rubygems.org/downloads/paint-2.0.1.gem
paintown                    3.6.0                 01 May 2013   http://sourceforge.net/projects/paintown/files/paintown/3.6.0/paintown-3.6.0.tar.bz2
palapeli                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/palapeli-18.04.0.tar.xz
paludis                     2.6.0                 18 Jul 2017   http://paludis.exherbo.org/download/paludis-2.6.0.tar.bz2
panda3d                     1.8.0                 01 Dec 2012   http://www.panda3d.org/download/panda3d-1.8.0/panda3d-1.8.0.tar.gz
pandas                      0.20.3                09 Jul 2017   https://pypi.python.org/packages/ee/aa/90c06f249cf4408fa75135ad0df7d64c09cf74c9870733862491ed5f3a50/pandas-0.20.3.tar.gz
pandora                     0.1.2                 01 Jun 2014   https://rubygems.org/downloads/pandora-0.1.2.gem
pango                       1.42.1                10 Apr 2018   http://ftp.gnome.org/pub/GNOME/sources/pango/1.42/pango-1.42.1.tar.xz
pangomm                     2.41.4                25 Aug 2017   http://ftp.gnome.org/pub/gnome/sources/pangomm/2.41/pangomm-2.41.4.tar.xz
pangzero                    1.3                   01 Dec 2012   http://sourceforge.net/projects/pangzero/files/pangzero/1.3/pangzero-1.3.tar.gz
papyrus                     0.13.3                28 Mar 2016   https://sourceforge.net/projects/libpapyrus/files/papyrus/0.13.3/papyrus-0.13.3.tar.gz
paragui                     1.1.8                 01 Jun 2014   https://github.com/pipelka/paragui
parallel                    20140222              01 Feb 2014   http://ftp.gnu.org/gnu/parallel/parallel-20140222.tar.bz2
paratim                     0.2.0                 01 Dec 2012   http://paratim.sourceforge.net/
parley                      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/parley-18.04.0.tar.xz
parole                      1.0.1                 13 Apr 2018   http://archive.xfce.org/src/apps/parole/1.0/parole-1.0.1.tar.bz2
parsetree                   3.0.9                 01 Aug 2017   https://rubygems.org/downloads/ParseTree-3.0.9.gem
parseyapp                   1.21                  07 Aug 2017   https://cpan.metacpan.org/authors/id/W/WB/WBRASWELL/Parse-Yapp-1.21.tar.gz
parted                      3.2                   01 Jul 2014   ftp://ftp.gnu.org/gnu/parted/parted-3.2.tar.xz
partimage                   0.6.9                 28 Mar 2016   https://sourceforge.net/projects/partimage/files/stable/0.6.9/partimage-0.6.9.tar.bz2
passenger                   5.2.3                 01 May 2018   https://rubygems.org/downloads/passenger-5.2.3.gem
patch                       2.7.6                 06 Feb 2018   https://ftp.gnu.org/pub/gnu/patch/patch-2.7.6.tar.xz
patchelf                    0.9                   19 Oct 2017   https://nixos.org/releases/patchelf/patchelf-0.9/patchelf-0.9.tar.gz
pathlib                     1.0.1                 27 Dec 2017   https://pypi.python.org/packages/ac/aa/9b065a76b9af472437a0059f77e8f962fe350438b927cb80184c32f075eb/pathlib-1.0.1.tar.gz
pavucontrol                 3.0                   18 Jul 2017   http://freedesktop.org/software/pulseaudio/pavucontrol/pavucontrol-3.0.tar.xz
pawm                        2.3.0                 Jun 2014      http://www.pleyades.net/david/projects/pawm/pawm-2.3.0.tar.bz2
paxutils                    1.1.6                 05 Mar 2016   http://distfiles.gentoo.org/distfiles/pax-utils-1.1.6.tar.xz
pbzip2                      1.1.13                21 Sep 2017   https://launchpad.net/pbzip2/1.1/1.1.13/+download/pbzip2-1.1.13.tar.gz
pcc                         02.10.2007            Jun 2014      ftp://226.net120.skekraft.net/pcc/
pciutils                    3.5.6                 05 Dec 2017   https://www.kernel.org/pub/software/utils/pciutils/pciutils-3.5.6.tar.xz
pcmciautils                 014                   01 May 2012   http://kernel.org/pub/linux/utils/kernel/pcmcia/pcmciautils-014.tar.bz2
pcre                        8.42                  27 Mar 2018   ftp://ftp.csx.cam.ac.uk/pub/software/programming/pcre/pcre-8.42.tar.gz
pcre2                       10.30                 21 Sep 2017   ftp://ftp.csx.cam.ac.uk/pub/software/programming/pcre/pcre2-10.30.tar.gz
pcsclite                    1.8.18                11 Aug 2016   https://alioth.debian.org/frs/download.php/file/4173/pcsc-lite-1.8.18.tar.bz2
pdal                        1.5.0                 21 Sep 2017   http://download.osgeo.org/pdal/PDAL-1.5.0-src.tar.gz
pdfcore                     0.8.1                 01 May 2018   https://rubygems.org/downloads/pdf-core-0.8.1.gem
pdfcrack                    0.14                  12 Sep 2014   http://sourceforge.net/projects/pdfcrack/files/pdfcrack/pdfcrack-0.14/pdfcrack-0.14.tar.gz
pdfedit                     0.4.5                 01 Jun 2014   http://sourceforge.net/projects/pdfedit/files/pdfedit/0.4.5/pdfedit-0.4.5.tar.bz2
pdfgrep                     2.0.1                 25 Mar 2017   https://pdfgrep.org/download/pdfgrep-2.0.1.tar.gz
pdfreader                   2.1.0                 02 Mar 2018   https://rubygems.org/downloads/pdf-reader-2.1.0.gem
pdftk                       2.02                  10 May 2015   https://www.pdflabs.com/tools/pdftk-the-pdf-toolkit/pdftk-2.02-src.zip
pdl                         2.016                 29 Jun 2016   https://sourceforge.net/projects/pdl/files/PDL-2.016/PDL-2.016.tar.gz/
ped                         0.1.6                 01 Jun 2014   http://schwarz-mode.de/files/ped/
pekwm                       0.1.17                01 Jan 2014   https://www.pekwm.org/projects/pekwm/files/pekwm-0.1.17.tar.bz2
penguincommand              1.6.11                01 Jan 2013   http://user.cs.tu-berlin.de/~karlb/penguin-command/
pengupop                    2.2.4                 Jun 2014      http://www.junoplay.com/pengupop
pentagram                   16.02.2008            01 Dec 2012   http://pentagram.sourceforge.net/download.php
perl                        5.26.1                23 Sep 2017   http://www.cpan.org/src/5.0/perl-5.26.1.tar.gz
perlgettext                 1.05                  Jun 2014      http://search.cpan.org/dist/gettext/
perlglib                    1.222                 Jun 2014      http://search.cpan.org/CPAN/authors/id/T/TS/TSCH/Glib-1.222.tar.gz
pg                          1.0.0                 16 Jan 2018   https://rubygems.org/downloads/pg-1.0.0.gem
phodav                      2.2                   20 Sep 2017   http://ftp.gnome.org/pub/GNOME/sources/phodav/2.2/phodav-2.2.tar.xz
phonon                      4.10.0                25 Feb 2018   http://download.kde.org/stable/phonon/4.10.0/phonon-4.10.0.tar.xz
phononbackendgstreamer      4.9.0                 13 Oct 2017   http://download.kde.org/stable/phonon/phonon-backend-gstreamer/4.9.0/phonon-backend-gstreamer-4.9.0.tar.xz
phononbackendvlc            0.10.0                25 Feb 2018   http://download.kde.org/stable/phonon/phonon-backend-vlc/0.10.0/phonon-backend-vlc-0.10.0.tar.xz
php                         7.2.5                 24 Apr 2018   http://us3.php.net/distributions/php-7.2.5.tar.xz
phpbb                       3.1.3                 26 Feb 2014   https://www.phpbb.com/files/release/phpBB-3.1.3.zip
phpunit                     6.3                   24 Sep 2017   https://phar.phpunit.de/phpunit-6.3.phar
phpwiki                     1.5.5                 02 Aug 2017   https://sourceforge.net/projects/phpwiki/files/PhpWiki%201.5%20%28current%29/phpwiki-1.5.5.zip
phylip                      3.68                  Jun 2014      http://evolution.gs.washington.edu/phylip/download/phylip-3.68.tar.gz
physfs                      3.0.1                 13 Nov 2017   https://icculus.org/physfs/downloads/physfs-3.0.1.tar.bz2
picmi                       4.14.3                09 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/picmi-4.14.3.tar.xz
pidgin                      2.13.0                09 Mar 2018   http://downloads.sourceforge.net/pidgin/pidgin-2.13.0.tar.bz2
pidify                      0.2-                  01 Dec 2017   https://rubygems.org/downloads/pidify-0.2-i686-linux.gem
pimcommon                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/pimcommon-18.04.0.tar.xz
pimdataexporter             18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/pim-data-exporter-18.04.0.tar.xz
pimsieveeditor              18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/pim-sieve-editor-18.04.0.tar.xz
pine                        4.64                  Jun 2014      ftp://ftp.cac.washington.edu/pine/pine.tar.bz2
pinentry                    1.1.0                 07 Dec 2017   https://www.gnupg.org/ftp/gcrypt/pinentry/pinentry-1.1.0.tar.bz2
pinfo                       0.6.8                 01 Jun 2014   http://freshmeat.net/redir/pinfo/8107/url_tgz/pinfo-0.6.8.tar.gz
pingus                      0.7.6                 Jul 2013      http://pingus.googlecode.com/files/pingus-0.7.6.tar.bz2
pinpoint                    0.1.8                 23 Sep 2015   http://ftp.gnome.org/pub/GNOME/sources/pinpoint/0.1/pinpoint-0.1.8.tar.xz
pinta                       1.4                   30 Nov 2014   https://github.com/downloads/PintaProject/Pinta/pinta-1.4.tar.gz
pioneers                    15.4                  01 Nov 2017   https://sourceforge.net/projects/pio/files/Source/pioneers-15.4.tar.gz
pip                         8.1.2                 02 Aug 2016   https://pypi.python.org/packages/e7/a8/7556133689add8d1a54c0b14aeff0acb03c64707ce100ecd53934da1aa13/pip-8.1.2.tar.gz#md5=87083c0b9867963b29f7aba3613e8f4a
pipemeter                   1.1.2.1               Jun 2014      http://spamaps.org/files/pipemeter/pipemeter-1.1.2-1.tar.gz
pipepanic                   0.1.3                 Dec 2012      http://www.users.waitrose.com/~thunor/pipepanic/#downloads
pipewalker                  0.4.3                 01 Dec 2012   http://sourceforge.net/project/showfiles.php?group_id=198283
pitivi                      0.99                  21 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/pitivi/0.99/pitivi-0.99.tar.xz
pixman                      0.34.0                03 Feb 2016   http://xorg.freedesktop.org/releases/individual/lib/pixman-0.34.0.tar.gz
pjproject                   1.14.2                Jun 2014      http://www.pjsip.org/release/1.14.2/pjproject-1.14.2.tar.bz2
pkgconfig                   0.29.2                26 Mar 2017   https://pkgconfig.freedesktop.org/releases/pkg-config-0.29.2.tar.gz
pl                          6.2.2                 Jun 2014      http://www.swi-prolog.org/download/stable/src/pl-6.2.2.tar.gz
plasmadesktop               5.12.5                01 May 2018   http://download.kde.org/stable/plasma/5.12.5/plasma-desktop-5.12.5.tar.xz
plasmaframework             5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/plasma-framework-5.45.0.tar.xz
plasmaintegration           5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/plasma-integration-5.12.4.tar.xz
plasmanm                    5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/plasma-nm-5.12.4.tar.xz
plasmapa                    5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/plasma-pa-5.12.4.tar.xz
plasmasdk                   5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/plasma-sdk-5.12.4.tar.xz
plasmatests                 5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/plasma-tests-5.12.4.tar.xz
plasmavault                 5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/plasma-vault-5.12.4.tar.xz
plasmaworkspace             5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/plasma-workspace-5.12.4.tar.xz
plasmaworkspacewallpapers   5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/plasma-workspace-wallpapers-5.12.4.tar.xz
plib                        1.8.4                 Jun 2014      http://plib.sourceforge.net/download.html
ploticus                    2.3.2                 Jun 2014      http://ploticus.sourceforge.net/download/pl232src.tar.gz
pluma                       1.20.1                27 Mar 2018   http://pub.mate-desktop.org/releases/1.20/pluma-1.20.1.tar.xz
ply                         2.3                   Jun 2014      http://www.dabeaz.com/ply/
plymouth                    0.9.3                 11 Oct 2017   https://www.freedesktop.org/software/plymouth/releases/plymouth-0.9.3.tar.xz
plymouthkcm                 5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/plymouth-kcm-5.12.4.tar.xz
plzip                       1.6                   30 Nov 2017   http://download.savannah.gnu.org/releases/lzip/plzip/plzip-1.6.tar.gz
pmacct                      0.14.1                01 Jun 2014   http://www.pmacct.net/pmacct-0.14.1.tar.gz
pmk                         0.10.4                Jun 2014      http://prdownloads.sourceforge.net/pmk/pmk-0.10.4.tar.gz
png++                       0.2.9                 30 Jul 2016   http://download.savannah.gnu.org/releases/pngpp/png++-0.2.9.tar.gz
pngcrush                    1.7.41                01 Dec 2012   http://sourceforge.net/projects/pmt/files/pngcrush/1.7.41/pngcrush-1.7.41.tar.xz
pngquant                    2.9.1                 06 Apr 2017   http://pngquant.org/pngquant-2.9.1-src.tar.gz
poco                        1.1.2                 01 Jun 2014   http://www.basha.org/poco.shtml
podofo                      0.9.5                 31 Oct 2017   http://sourceforge.net/projects/podofo/files/podofo/0.9.5/podofo-0.9.5.tar.gz
polari                      3.26.1                04 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/polari/3.26/polari-3.26.1.tar.xz
policykit                   0.9                   01 Jun 2014   PolicyKit-0.9
polkit                      0.114                 20 Apr 2018   https://www.freedesktop.org/software/polkit/releases/polkit-0.114.tar.gz
polkitgnome                 0.105                 Jun 2014      ftp://ftp.gnome.org/pub/gnome/sources/polkit-gnome/0.105/polkit-gnome-0.105.tar.xz
polkitkdeagent              1-5.12.4              29 Mar 2018   https://download.kde.org/stable/plasma//1-5.12.4/polkit-kde-agent-1-5.12.4.tar.xz
polkitqt                    1-0.112.0             03 Mar 2015   http://download.kde.org/stable/apps/KDE4.x/admin/polkit-qt-1-0.112.0.tar.bz2
polylib                     5.22.5                Nov 2012      http://icps.u-strasbg.fr/polylib/polylib_src/polylib-5.22.5.tar.gz
poppler                     0.64.0                18 Apr 2018   https://poppler.freedesktop.org/poppler-0.64.0.tar.xz
popplerdata                 0.4.9                 29 Apr 2018   http://poppler.freedesktop.org/poppler-data-0.4.9.tar.gz
popt                        1.16                  Jun 2014      http://rpm5.org/files/popt/popt-1.16.tar.gz
porcupine                   0.0.7                 Jun 2014      http://www.innoscript.org/component/option,com_remository/Itemid,33/
porg                        0.10                  01 Sep 2016   https://sourceforge.net/projects/porg/files/porg-0.10.tar.gz
portaudio                   0.19                  Jun 2014      http://www.portaudio.com/download.html
postfix                     3.3.0                 22 Feb 2018   ftp://ftp.porcupine.org/mirrors/postfix-release/official/postfix-3.3.0.tar.gz
postgis                     2.3.1                 18 Mar 2017   http://download.osgeo.org/postgis/source/postgis-2.3.1.tar.gz
postgresql                  10.3                  01 Mar 2018   http://ftp.postgresql.org/pub/source/v10.3/postgresql-10.3.tar.bz2
postr                       0.13.1                05 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/postr/0.13/postr-0.13.1.tar.xz
potrace                     1.15                  20 Aug 2017   https://downloads.sourceforge.net/potrace/potrace-1.15.tar.gz
povray                      3.7.0beta25b          May 2013      http://www.povray.org/redirect/www.povray.org/ftp/pub/povray/Official/Linux/povlinux-3.6.tgz
powerdevil                  5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/powerdevil-5.12.4.tar.xz
powermanga                  0.93                  10 Oct 2017   http://linux.tlk.fr/games/Powermanga/download/powermanga-0.93.tgz
powertop                    2.0                   Jun 2014      https://01.org/powertop/sites/default/files/downloads/powertop-2.0.tar.bz2
poxml                       18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/poxml-18.04.0.tar.xz
ppl                         1.2                   18 Feb 2016   ftp://ftp.cs.unipr.it/pub/ppl/releases/1.2/ppl-1.2.tar.gz
ppp                         2.4.5                 28 Aug 2015   http://samba.org/ftp/ppp/ppp-2.4.5.tar.gz
prawn                       2.2.2                 06 Jul 2017   https://rubygems.org/downloads/prawn-2.2.2.gem
prefixsuffix                0.6.9                 08 Dec 2015   http://ftp.gnome.org/pub/GNOME/sources/prefixsuffix/0.6/prefixsuffix-0.6.9.tar.xz
presentproto                1.1                   18 Mar 2017   https://www.x.org/releases/individual/proto/presentproto-1.1.tar.bz2
primer3                     2.3.7                 12 Apr 2016   https://sourceforge.net/projects/primer3/files/primer3/2.3.7/primer3-2.3.7.tar.gz
printmanager                4.14.3                14 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/print-manager-4.14.3.tar.xz
printproto                  1.0.5                 Jun 2014      http://xorg.freedesktop.org/releases/individual/proto/printproto-1.0.5.tar.bz2
prison                      5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/prison-5.45.0.tar.xz
processing                  0111                  Jun 2014      http://processing.org/download/processing-0111.tgz
procps                      3.2.8                 13 Dec 2015   http://procps.sourceforge.net/procps-3.2.8.tar.gz
procpsng                    3.3.12                01 Sep 2014   http://sourceforge.net/projects/procps-ng/files/Production/procps-ng-3.3.12.tar.xz
proftpd                     1.3.6                 10 Apr 2017   ftp://ftp.proftpd.org/distrib/source/proftpd-1.3.6.tar.gz
progsreiserfs               0.3.0.4               01 Jun 2014   http://reiserfs.osdn.org.ua/progsreiserfs-0.3.0.4.tar.gz
projectx                    0.90.3.01             Jun 2014      http://peterhost.dl.sourceforge.net/sourceforge/project-x/ProjectX_Source_0.82.1.00.zip
protobufcpp                 3.4.1                 30 Sep 2017   https://github.com/google/protobuf/releases/download/v3.4.1/protobuf-cpp-3.4.1.tar.gz
protocol                    1.0.1                 01 Dec 2017   https://rubygems.org/downloads/protocol-1.0.1.gem
protoeditor                 1.0                   09 Feb 2018   https://sourceforge.net/projects/protoeditor/files/protoeditor/1.0/protoeditor-1.0.tar.gz
proxymngr                   1.0.4                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/proxymngr-1.0.4.tar.gz
pry                         0.11.3                11 Dec 2017   https://rubygems.org/downloads/pry-0.11.3.gem
pscpug                      0.3.2                 Jun 2014      http://www.diablonet.net/~mercadal/projects/pscpug/pscpug030.tgz
psmisc                      22.17                 Jun 2014      http://sourceforge.net/projects/psmisc/files/psmisc/psmisc-22.17.tar.gz
pspp                        0.11.0                13 Aug 2017   http://ftp.gnu.org/pub/gnu/pspp/pspp-0.11.0.tar.gz
pth                         2.0.7                 Jun 2014      ftp://ftp.gnu.org/gnu/pth/pth-2.0.7.tar.gz
ptlib                       2.10.11               07 Nov 2015   http://ftp.gnome.org/pub/GNOME/sources/ptlib/2.10/ptlib-2.10.11.tar.xz
pulseaudio                  11.1                  18 Sep 2017   http://freedesktop.org/software/pulseaudio/releases/pulseaudio-11.1.tar.xz
puma                        3.11.4                01 May 2018   https://rubygems.org/downloads/puma-3.11.4.gem
puppet                      5.5.1                 01 May 2018   https://rubygems.org/downloads/puppet-5.5.1.gem
purpose                     5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/purpose-5.45.0.tar.xz
pwdutils                    3.0                   01 Jun 2014   http://www.thkukuk.de/pam/pwdutils/
pwlib                       1.10.0                01 Jun 2014   http://www.voxgratia.org/modules/news/
py2cairo                    1.10.0                25 Apr 2015   http://cairographics.org/releases/py2cairo-1.10.0.tar.bz2
pyatspi                     2.26.0                12 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/pyatspi/2.26/pyatspi-2.26.0.tar.xz
pybliographer               1.4.0                 05 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/pybliographer/1.4/pybliographer-1.4.0.tar.xz
pycairo                     1.17.0                17 Apr 2018   https://github.com/pygobject/pycairo/releases/download/v1.17.0/pycairo-1.17.0.tar.gz
pycdio                      2.0.0                 06 Feb 2018   https://ftp.gnu.org/pub/gnu/libcdio/pycdio-2.0.0.tar.gz
pycha                       0.7.0                 Jun 2014      https://pypi.python.org/packages/source/p/pycha/pycha-0.7.0.tar.gz
pycups                      1.9.30                Jun 2014      http://freshmeat.net/redir/pycups/63335/url_bz2/pycups-1.9.30.tar.bz2
pydisplay                   0.2.0                 Jun 2014      http://downloads.sourceforge.net/pydisplay/pydisplay-0.2.0.tar.gz
pygame                      1.9.3                 10 May 2017   https://pypi.python.org/packages/61/06/3c25051549c252cc6fde01c8aeae90b96831370884504fe428a623316def/pygame-1.9.3.tar.gz
pyglet                      1.0                   Nov 2012      http://pyglet.googlecode.com/files/pyglet-1.0.tar.gz
pygobject                   3.28.2                30 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/pygobject/3.28/pygobject-3.28.2.tar.xz
pygraphviz                  0.22                  Jun 2014      http://surfnet.dl.sourceforge.net/sourceforge/networkx/pygraphviz-0.22.tar.gz
pygtk                       2.24.0                01 Aug 2012   http://ftp.gnome.org/pub/GNOME/sources/pygtk/2.24/pygtk-2.24.0.tar.bz2
pygtksourceview             2.3.0                 Jan 2013      http://ftp.gnome.org/pub/gnome/sources/pygtksourceview/2.3/pygtksourceview-2.3.0.tar.bz2
pygui                       2.2                   Jun 2014      http://www.cosc.canterbury.ac.nz/greg.ewing/python_gui/PyGUI-2.2.tar.gz
pymol                       v1.8.6.0              01 Jan 2018   https://sourceforge.net/projects/pymol/files/pymol/1.8/pymol-v1.8.6.0.tar.bz2
pyorbit                     2.24.0                Jun 2014      http://ftp.gnome.org/pub/GNOME/sources/pyorbit/2.24/pyorbit-2.24.0.tar.bz2
pype                        2.9.4                 Jan 2013      http://sourceforge.net/projects/pype/files/pype/PyPE%202.9.4/PyPE-2.9.4-src.zip
pypy                        NAME                  01 Apri 2018  https://bitbucket.org/pypy/pypy/downloads/pypy3-v5.10.1-src.tar.bz2
pyqt                        4.12.1                03 Sep 2017   http://sourceforge.net/projects/pyqt/files/PyQt4/PyQt-4.12.1/PyQt4_gpl_x11-4.12.1.tar.gz
pyrex                       0.9.9                 06 Oct 2017   http://www.cosc.canterbury.ac.nz/greg.ewing/python/Pyrex/Pyrex-0.9.9.tar.gz
pyserial                    2.2                   Jan 2013      http://sourceforge.net/project/showfiles.php?group_id=46487&package_id=39324&release_id=346093
pysqlite                    2.6.3                 Jun 2014      http://pysqlite.googlecode.com/files/pysqlite-2.6.3.tar.gz
python                      3.6.5                 01 Apr 2018   https://www.python.org/ftp/python/3.6.5/Python-3.6.5.tar.xz
pythoncaja                  1.20.0                07 Feb 2018   http://pub.mate-desktop.org/releases/1.20/python-caja-1.20.0.tar.xz
pythondbusmock              0.16.9                24 Jul 2016   https://pypi.python.org/packages/dd/c6/3d1979a07190ec9242966112ce134d3c32cf081f90a4f67bc9385d08ba77/python-dbusmock-0.16.9.tar.gz
pytone                      3.0.3                 Jun 2014      http://www.luga.de/pytone/download/PyTone-3.0.3.tar.gz
pyvorbis                    1.4                   01 Aug 2013   http://ekyo.nerim.net/software/pyogg/index.html
pyxdg                       0.15                  Nov 2012      http://www.freedesktop.org/~lanius/pyxdg-0.15.tar.gz
pyxfce                      4.3.0                 Jun 2014      http://pyxfce.xfce.org/pyxfce-4.3.0.tar.gz
pyxml                       0.8.4                 Jun 2014      http://mesh.dl.sourceforge.net/sourceforge/pyxml/PyXML-0.8.4.tar.gz
pyyaml                      3.12                  11 Oct 2017   https://pypi.python.org/packages/4a/85/db5a2df477072b2902b0eb892feb37d88ac635d36245a72a6a69b23b383a/PyYAML-3.12.tar.gz
qca                         2.1.3                 27 Feb 2017   http://download.kde.org/stable/qca/2.1.3/src/qca-2.1.3.tar.xz
qcaqt5                      2.1.0.3               22 Sep 2017   https://download.kde.org/stable/qca-qt5/2.1.0.3/src/qca-qt5-2.1.0.3.tar.xz
qdbm                        1.8.77                12 Sep 2015   http://sourceforge.net/projects/qdbm/files/qdbm/1.8.77/qdbm-1.8.77.tar.gz
qdvdauthor                  2.3.1                 01 Sep 2014   http://sourceforge.net/projects/qdvdauthor/files/qdvdauthor/2.3.1/qdvdauthor-2.3.1.tar.gz
qemu                        2.12.0                24 Apr 2018   http://wiki.qemu.org/download/qemu-2.12.0.tar.bz2
qgis                        2.18.13               20 Sep 2017   http://qgis.org/downloads/qgis-2.18.13.tar.bz2
qimageblitz                 0.0.6                 01 Jan 2014   http://download.kde.org/stable/qimageblitz/qimageblitz-0.0.6.tar.bz2
qingy                       1.0.0                 Jun 2014      http://sourceforge.net/projects/qingy/files/qingy/qingy%201.0.0/
qiv                         2.1pre12              Jun 2014      http://www.klografx.net/qiv/download/
qjackctl                    0.3.11                Apr 2014      http://downloads.sourceforge.net/qjackctl/qjackctl-0.3.11.tar.gz
qjson                       24.05.2015            24 May 2015   http://downloads.sourceforge.net/qjson/qjson-0.8.1.tar.bz2
qpdf                        8.0.2                 10 Mar 2018   https://github.com/qpdf/qpdf/releases/download/release-qpdf-8.0.2/qpdf-8.0.2.tar.gz
qqc2desktopstyle            5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/qqc2-desktop-style-5.45.0.tar.xz
qqwing                      1.3.4                 09 Aug 2015   https://github.com/stephenostermiller/qqwing/archive/v1.3.4.zip
qrencode                    4.0.0                 31 Jan 2018   https://fukuchi.org/works/qrencode/qrencode-4.0.0.tar.bz2
qt                          5.10.1                12 Feb 2018   http://download.qt-project.org/official_releases/qt/5.10/5.10.1/single/qt-everywhere-src-5.10.1.tar.xz
qt4qtruby                   2.2.0                 Dec 2012      http://rubyforge.org/frs/download.php/71843/qt4-qtruby-2.2.0.tar.gz
qtgstreamer                 1.2.0                 10 Jul 2015   http://gstreamer.freedesktop.org/src/qt-gstreamer/qt-gstreamer-1.2.0.tar.xz
qtruby                      4.14.3                15 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/qtruby-4.14.3.tar.xz
qtwebengineopensourcesrc    5.9.3                 01 Dec 2017   https://download.qt.io/archive/qt/5.9/5.9.3/submodules/qtwebengine-opensource-src-5.9.3.tar.xz
quadkonsole                 2.0.3                 01 Jun 2014   http://nomis80.org/quadkonsole/quadkonsole-2.0.3.tar.bz2
quadrapassel                3.21.2                01 Jun 2016   http://ftp.gnome.org/pub/GNOME/sources/quadrapassel/3.21/quadrapassel-3.21.2.tar.xz
quagga                      1.2.2                 02 Jan 2018   http://download.savannah.gnu.org/releases/quagga/quagga-1.2.2.tar.gz
quelcom                     0.4.0                 Nov 2012      http://www.etse.urv.es/~dmanye/quelcom/src/quelcom-0.4.0.tar.gz
quodlibet                   3.9.1                 28 Jul 2017   https://github.com/quodlibet/quodlibet/releases/download/release-3.9.1/quodlibet-3.9.1.tar.gz
quvi                        0.9.5                 09 Jun 2016   https://sourceforge.net/projects/quvi/files/0.9/quvi/quvi-0.9.5.tar.xz
qwt                         6.0.2                 Dec 2012      http://sourceforge.net/projects/qwt/files/qwt/6.0.2/qwt-6.0.2.tar.bz2
r                           3.4.3                 03 Jan 2018   https://cran.r-project.org/src/base/R-3/R-3.4.3.tar.gz
rabbit                      2.2.1                 31 Oct 2017   https://rubygems.org/downloads/rabbit-2.2.1.gem
racc                        1.4.14                07 Dec 2017   https://rubygems.org/downloads/racc-1.4.14.gem
rack                        2.0.5                 01 May 2018   https://rubygems.org/downloads/rack-2.0.5.gem
rackprotection              2.0.1                 26 Feb 2018   https://rubygems.org/downloads/rack-protection-2.0.1.gem
rage                        0.1.4                 21 May 2015   http://download.enlightenment.org/rel/apps/rage/rage-0.1.4.tar.gz
ragel                       6.10                  27 Mar 2017   http://www.colm.net/files/ragel/ragel-6.10.tar.gz
rails                       5.2.0                 01 May 2018   https://rubygems.org/downloads/rails-5.2.0.gem
railties                    5.2.0                 01 May 2018   https://rubygems.org/downloads/railties-5.2.0.gem
rainbow                     3.0.0                 09 Jan 2018   https://rubygems.org/downloads/rainbow-3.0.0.gem
rak                         1.0.21                Jun 2014      rak-1.0.21.tar.xz
rake                        12.3.1                01 May 2018   https://rubygems.org/downloads/rake-12.3.1.gem
randrproto                  1.5.0                 17 May 2015   http://xorg.freedesktop.org/releases/individual/proto/randrproto-1.5.0.tar.gz
rant                        0.5.7                 01 Dec 2017   https://rubygems.org/downloads/rant-0.5.7.gem
raptor2                     2.0.15                22 May 2015   http://download.librdf.org/source/raptor2-2.0.15.tar.gz
rarian                      0.8.1                 Jan 2013      http://ftp.gnome.org/pub/gnome/sources/rarian/0.8/rarian-0.8.1.tar.bz2
rasmol                      2.7.5.2               Jun 2014      http://www.rasmol.org/software/RasMol_2.7.5.2.tar.gz
rasqal                      0.9.30                Jan 2014      http://download.librdf.org/source/rasqal-0.9.30.tar.gz
ratpoison                   1.4.5                 Jun 2014      http://download.savannah.nongnu.org/releases/ratpoison/ratpoison-1.4.5.tar.gz
rawrec                      0.9.991               01 Jun 2014   https://sourceforge.net/projects/rawrec/files/rawrec/rawrec-0.9.991/rawrec-0.9.991.tar.gz
rcairo                      1.15.12               18 Mar 2018   https://www.cairographics.org/releases/rcairo-1.15.12.tar.gz
rcov                        1.0.0                 31 Oct 2017   https://rubygems.org/downloads/rcov-1.0.0.gem
re2c                        1.0.3                 17 Nov 2017   https://github.com/skvadrik/re2c/releases/download/1.0.3/re2c-1.0.3.tar.gz
readedid                    2.0.0                 Jun 2014      http://polypux.org/projects/read-edid/read-edid-2.0.0.tar.gz
readline                    7.0                   21 Apr 2017   http://ftp.gnu.org/gnu/readline/readline-7.0.tar.gz
recode                      3.7                   Jun 2014      http://recode.progiciels-bpi.ca/recode-3.7.tar.bz2
recordmydesktop             0.3.8.1               Jun 2014      http://sourceforge.net/projects/recordmydesktop/files/recordmydesktop/0.3.8.1/recordmydesktop-0.3.8.1.tar.gz
recordproto                 1.14.2                Jun 2014      http://xorg.freedesktop.org/releases/individual/proto/recordproto-1.14.2.tar.bz2
recutils                    1.7                   03 Sep 2014   http://ftp.gnu.org/gnu/recutils/recutils-1.7.tar.gz
redcloth                    4.3.2                 21 Sep 2017   https://rubygems.org/downloads/RedCloth-4.3.2.gem
redis                       4.0.2                 21 Sep 2017   http://download.redis.io/releases/redis-4.0.2.tar.gz
redland                     1.0.17                01 Aug 2015   http://download.librdf.org/source/redland-1.0.17.tar.gz
redmine                     3.2.0                 31 Dec 2015   http://www.redmine.org/releases/redmine-3.2.0.tar.gz
reft                        0.11                  01 Jun 2014   http://www.rafkind.com/jon/tar/reft-0.11.tar.gz
reiserfsprogs               3.6.27                03 Aug 2017   https://www.kernel.org/pub/linux/kernel/people/jeffm/reiserfsprogs/v3.6.27/reiserfsprogs-3.6.27.tar.xz
relion                      08.01.2018            08 Jan 2018   http://www2.mrc-lmb.cam.ac.uk/groups/scheres/1sep15/relion-08.01.2018.tar.xz
rendercheck                 1.5                   12 Jun 2015   http://xorg.freedesktop.org/releases/individual/app/rendercheck-1.5.tar.bz2
renderproto                 0.11                  01 Jun 2014   http://xorg.freedesktop.org/releases/individual/proto/renderproto-0.11.tar.bz2
reportlab                   1.20                  01 Jun 2014   http://www.reportlab.org/ftp/ReportLab_1_20.tgz
resmgr                      1.0                   01 Jun 2014   ftp://ftp.lst.de/pub/people/okir/resmgr/resmgr-1.0.tar.bz2
resourceproto               1.2.0                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/proto/resourceproto-1.2.0.tar.bz2
rest                        0.8.1                 17 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/rest/0.8/rest-0.8.1.tar.xz
restclient                  2.0.2                 21 Sep 2017   https://rubygems.org/downloads/rest-client-2.0.2.gem
retrogtk                    0.13.2                12 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/retro-gtk/0.13/retro-gtk-0.13.2.tar.xz
rex                         1.4.0                 09 Mar 2016   http://www.cpan.org/authors/id/F/FE/FERKI/Rex-1.4.0.tar.gz
rezound                     0.13.1beta            31 Oct 2017   https://sourceforge.net/projects/rezound/files/ReZound/0.13.1beta/rezound-0.13.1beta.tar.gz
rfpdf                       1.5.3f                01 Jun 2014   http://zeropluszero.com/software/fpdf/rfpdf153g.tar.gz
rgb                         1.0.6                 31 Jul 2016   http://xorg.freedesktop.org/archive/individual/app/rgb-1.0.6.tar.bz2
rhythmbox                   3.4                   08 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/rhythmbox/3.4/rhythmbox-3.4.tar.xz
rili                        2.0.1                 28 May 2015   https://sourceforge.net/projects/ri-li/files/Ri-li%20Linux_Unix/Ri-li%20V2.0.1/Ri-li-2.0.1.tar.bz2
ripoff                      0.8.3                 Jan 2013      http://sourceforge.net/projects/ripoffc/files/RipOff/0.8.3/ripoff-0.8.3.tar.gz
ripperx                     2.7.2                 Jun 2014      http://sourceforge.net/projects/ripperx/
rison                       2.1.0                 01 Dec 2017   https://rubygems.org/downloads/rison-2.1.0.gem
rkward                      0.6.5                 16 Sep 2017   http://download.kde.org/stable/rkward/0.6.5/src/rkward-0.6.5.tar.gz
rlog                        1.3.7                 Jun 2014      http://www.arg0.net/rlog
rlwrap                      0.37                  Jun 2014      http://utopia.knoware.nl/~hlub/uck/rlwrap/rlwrap-0.37.tar.gz
rmagick                     2.16.0                22 Aug 2017   https://rubygems.org/downloads/rmagick-2.16.0.gem
rman                        3.2                   01 Jun 2014   http://switch.dl.sourceforge.net/sourceforge/polyglotman/rman-3.2.tar.gz
rmovie                      0.5.1                 01 Dec 2017   https://rubygems.org/downloads/rmovie-0.5.1.gem
rnalila                     0.2                   26 Jan 2018   https://github.com/mtw/RNAlila/releases/RNAlila-0.2.tar.xz
rnaz                        2.1                   29 Jun 2017   https://www.tbi.univie.ac.at/software/RNAz/RNAz-2.1.tar.gz
robodoc                     4.99.34               01 May 2014   http://sourceforge.net/projects/robodoc/
rocksndiamonds              3.2.4                 Nov 2012      http://www.artsoft.org/rocksndiamonds/download.html
rocs                        18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/rocs-18.04.0.tar.xz
roo                         2.7.1                 01 Dec 2017   https://rubygems.org/downloads/roo-2.7.1.gem
rope                        0.9.3                 May 2014      http://nchc.dl.sourceforge.net/sourceforge/rope/rope-0.9.3.tar.gz
rosegarden                  17.04                 08 Oct 2017   http://sourceforge.net/projects/rosegarden/files/rosegarden/17.04/rosegarden-17.04.tar.bz2
roxclib                     2.1.10                21 Feb 2016   http://www.kerofin.demon.co.uk/rox/ROX-CLib-2.1.10.tar.gz
roxsession                  0.1.25                Jun 2014      http://sourceforge.net/project/showfiles.php?group_id=7023
roxterm                     2.9.7                 09 Jul 2015   http://sourceforge.net/projects/roxterm/files/roxterm/2.9.7/roxterm-2.9.7.tar.bz2
rpcbind                     0.2.4                 25 Jul 2017   http://downloads.sourceforge.net/rpcbind/rpcbind-0.2.4.tar.bz2
rpcsvcproto                 1.3.1                 14 Jan 2018   https://github.com/thkukuk/rpcsvc-proto/archive/v1.3.1/rpcsvc-proto-1.3.1.tar.gz
rpm                         4.14.1                16 Jan 2018   http://ftp.rpm.org/releases/rpm-4.14.x/rpm-4.14.1.tar.bz2
rrdtool                     1.2.11                Jun 2014      http://people.ee.ethz.ch/~oetiker/webtools/rrdtool/pub/rrdtool-1.2.11.tar.gz
rspec                       3.7.0                 03 Dec 2017   https://rubygems.org/downloads/rspec-3.7.0.gem
rspeccore                   3.7.1                 18 Jan 2018   https://rubygems.org/downloads/rspec-core-3.7.1.gem
rspecexpectations           3.7.0                 26 Jan 2018   https://rubygems.org/downloads/rspec-expectations-3.7.0.gem
rstart                      1.0.5                 01 Feb 2013   http://xorg.freedesktop.org/releases/individual/app/rstart-1.0.5.tar.bz2
rsync                       3.1.3                 29 Jan 2018   http://rsync.samba.org/ftp/rsync/rsync-3.1.3.tar.gz
rtorrent                    01.10.2017            30 Sep 2017   https://github.com/rakshasa/rtorrent-01.10.2017
rtranscoder                 0.1.3                 01 Dec 2017   https://rubygems.org/downloads/rtranscoder-0.1.3.gem
rubberband                  1.8.1                 17 Apr 2018   https://github.com/falkTX/rubberband/archive/v1.8.1.tar.gz
rubinius                    2.7                   22 Dec 2015   https://rubinius-releases-rubinius-com.s3.amazonaws.com/rubinius-2.7.tar.bz2
rubocop                     0.55.0                01 May 2018   https://rubygems.org/downloads/rubocop-0.55.0.gem
ruby                        2.5.1                 29 Mar 2018   ftp://ftp.ruby-lang.org/pub/ruby/2.5/ruby-2.5.1.tar.xz
rubygame                    2.6.4                 01 Dec 2017   https://rubygems.org/downloads/rubygame-2.6.4.gem
rubygems                    2.7.6                 17 Feb 2018   https://rubygems.org/rubygems/rubygems-2.7.6.tgz
rubygnome2                  3.2.1                 15 Dec 2017   https://sourceforge.net/projects/ruby-gnome2/files/ruby-gnome2/ruby-gnome2-3.2.1/ruby-gnome2-all-3.2.1.tar.gz
rubygraphviz                1.2.3                 21 Sep 2017   https://rubygems.org/downloads/ruby-graphviz-1.2.3.gem
rubyinline                  3.12.4                02 Apr 2018   https://rubygems.org/downloads/RubyInline-3.12.4.gem
rubyjs                      0.8.0                 01 Dec 2017   https://rubygems.org/downloads/rubyjs-0.8.0.gem
rubyprogressbar             1.9.0                 25 Dec 2017   https://rubygems.org/downloads/ruby-progressbar-1.9.0.gem
rubystats                   0.2.3                 01 May 2014   http://rubyforge.org/frs/download.php/39488/rubystats-0.2.3.tgz
rubytorrent                 0.3                   02 Dec 2017   https://rubygems.org/downloads/rubytorrent-0.3.gem
rubyxosd                    1.1.0                 01 May 2014   https://rubyforge.org/projects/ruby-xosd/
rubyzip                     1.2.1                 02 Aug 2017   https://rubygems.org/downloads/rubyzip-1.2.1.gem
rungetty                    1.2                   01 Jun 2014   http://packages.debian.org/testing/admin/rungetty.html
runit                       1.8.0                 May 2014      http://smarden.sunsite.dk/runit/runit-1.8.0.tar.gz
ruport                      1.7.1                 01 Dec 2017   https://rubygems.org/downloads/ruport-1.7.1.gem
ruvi                        0.4.12                01 Jun 2014   https://rubygems.org/downloads/ruvi-0.4.12.gem
rxvt                        2.7.10                01 May 2014   https://sourceforge.net/projects/rxvt/files/rxvt-dev/2.7.10/rxvt-2.7.10.tar.gz
rxvtunicode                 9.21                  23 Jun 2015   http://dist.schmorp.de/rxvt-unicode/Attic/rxvt-unicode-9.21.tar.bz2
rygel                       0.36.0                12 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/rygel/0.36/rygel-0.36.0.tar.xz
sakura                      3.3.3                 16 Jan 2016   https://launchpad.net/sakura/trunk/3.3.3/+download/sakura-3.3.3.tar.bz2
samba                       4.8.1                 26 Apr 2018   http://us1.samba.org/samba/ftp/stable/samba-4.8.1.tar.gz
samtools                    1.6                   26 Oct 2017   https://sourceforge.net/projects/samtools/files/samtools/1.6/samtools-1.6.tar.bz2
sanebackends                1.0.27                23 May 2017   https://alioth.debian.org/frs/download.php/file/4224/sane-backends-1.0.27.tar.gz
sanefrontends               1.0.14                01 Jun 2014   http://www.sane-project.org/snapshots/sane-frontends-2008-07-29.tar.gz
sash                        3.7                   May 2014      http://members.tip.net.au/~dbell/programs/sash-3.7.tar.gz
sass                        3.5.6                 01 May 2018   https://rubygems.org/downloads/sass-3.5.6.gem
sassrails                   5.0.7                 09 Jan 2018   https://rubygems.org/downloads/sass-rails-5.0.7.gem
sawfish                     1.3.3                 Jan 2014      http://download.tuxfamily.org/sawfish/sawfish-1.9.1.tar.xz
schroedinger                1.0.11                19 Jan 2016   https://launchpad.net/schroedinger/trunk/1.0.11/+download/schroedinger-1.0.11.tar.gz
scim                        1.4.17                14 Aug 2017   https://sourceforge.net/projects/scim/files/scim/1.4.17/scim-1.4.17.tar.gz
scintilla                   4.0.0                 23 Sep 2017   http://www.scintilla.org/scintilla400.tgz
scipy                       1.0.0                 26 Oct 2017   https://github.com/scipy/scipy/releases/download/v1.0.0/scipy-1.0.0.tar.xz
scite                       4.0.2                 11 Feb 2018   http://www.scintilla.org/scite402.tgz
scons                       3.0.1                 18 Nov 2017   http://prdownloads.sourceforge.net/scons/scons-3.0.1.tar.gz
scourge                     0.15                  Dec 2012      http://scourge.svn.sourceforge.net/viewvc/scourge/scourge2.tar.gz
screen                      4.6.2                 23 Oct 2017   http://ftp.gnu.org/gnu/screen/screen-4.6.2.tar.gz
scribus                     1.4.7                 28 Apr 2018   https://downloads.sourceforge.net/scribus/scribus-1.4.7.tar.xz
scripts                     1.0.1                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/scripts-1.0.1.tar.bz2
scrnsaverproto              1.2.2                 01 May 2014   http://xorg.freedesktop.org/releases/individual/proto/scrnsaverproto-1.2.2.tar.bz2
scrollkeeper                0.3.14                Mar 2014      ftp://ftp.gnome.org/pub/GNOME/sources/scrollkeeper/0.3/scrollkeeper-0.3.14.tar.bz2
scrot                       0.8                   May 2014      http://linuxbrit.co.uk/downloads/scrot-0.8.tar.gz
scruffy                     0.2.6                 02 Dec 2017   https://rubygems.org/downloads/scruffy-0.2.6.gem
scummvm                     2.0.0                 15 Jan 2018   http://www.scummvm.org/frs/scummvm/2.0.0/scummvm-2.0.0.tar.xz
sddm                        0.16.0                10 Oct 2017   https://github.com/sddm/sddm/releases/download/v0.16.0/sddm-0.16.0.tar.xz
sddmkcm                     5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/sddm-kcm-5.12.4.tar.xz
sdl                         1.2.15                01 Jun 2013   http://www.libsdl.org/release/SDL-1.2.15.tar.gz
sdl2                        2.0.8                 08 Mar 2018   http://www.libsdl.org/release/SDL2-2.0.8.tar.gz
sdl2gfx                     1.0.1                 31 Jan 2016   http://sourceforge.net/projects/sdl2gfx/files/SDL2_gfx-1.0.1.tar.gz
sdl2image                   2.0.2                 18 Nov 2017   http://www.libsdl.org/projects/SDL_image/release/SDL2_image-2.0.2.tar.gz
sdl2mixer                   2.0.2                 28 Oct 2017   http://www.libsdl.org/projects/SDL_mixer/release/SDL2_mixer-2.0.2.tar.gz
sdl2net                     2.0.0                 01 Jul 2014   http://www.libsdl.org/projects/SDL_net/release/SDL2_net-2.0.0.tar.gz
sdl2ttf                     2.0.12                24 Jun 2015   http://www.libsdl.org/projects/SDL_ttf/release/SDL2_ttf-2.0.12.tar.gz
sdlgfx                      2.0.22                May 2014      http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.22.tar.gz
sdlimage                    1.2.12                May 2014      http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.12.tar.gz
sdlmixer                    1.2.12                Dec 2012      http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.12.tar.gz
sdlmm                       0.1.8                 May 2014      http://sdlmm.sourceforge.net/
sdlnet                      1.2.8                 Nov 2012      http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.8.tar.gz
sdlpango                    0.1.2                 Nov 2012      http://sourceforge.net/projects/sdlpango/
sdlperl                     1.20.3                16 Jul 2016   http://backpan.perl.org/authors/id/D/DG/DGOEHRIG/SDL_Perl-2.2.0.tar.gz
sdltty                      0.0.1                 01 May 2014   http://www.libsdl.org/projects/
sdoc                        1.0.0                 13 Feb 2018   https://rubygems.org/downloads/sdoc-1.0.0.gem
sdparm                      1.02                  May 2014      http://sg.torque.net/sg/sdparm.html#mozTocId166213
seahorse                    3.20.0                25 Mar 2016   http://ftp.gnome.org/pub/GNOME/sources/seahorse/3.20/seahorse-3.20.0.tar.xz
seahorsenautilus            3.11.92               Mar 2014      http://ftp.gnome.org/pub/GNOME/sources/seahorse-nautilus/3.11/seahorse-nautilus-3.11.92.tar.xz
seamonkey                   2.49.2                08 Feb 2018   https://ftp.mozilla.org/pub/seamonkey/releases/2.49.2/source/seamonkey-2.49.2.source.tar.xz
seatris                     0.0.14                May 2014      http://www.earth.li/projectpurple/files/seatris-0.0.14.tar.gz
sed                         4.5                   01 Apr 2018   ftp://ftp.gnu.org/gnu/sed/sed-4.5.tar.xz
seed                        3.8.1                 Dec 2013      http://ftp.gnome.org/pub/gnome/sources/seed/3.8/seed-3.8.1.tar.xz
segatex                     5.70                  May 2014      https://sourceforge.net/projects/segatex/files/?source=navbar
semantik                    0.6.0                 13 Apr 2015   http://ftp.waf.io/pub/release/semantik-0.9.3.tar.bz2
sendmail                    8.15.2                17 Jul 2015   ftp://ftp.sendmail.org/pub/sendmail/sendmail.8.15.2.tar.gz
sequel                      5.8.0                 01 May 2018   https://rubygems.org/downloads/sequel-5.8.0.gem
serf                        1.3.9                 03 Jan 2018   https://archive.apache.org/dist/serf/serf-1.3.9.tar.bz2
sessreg                     1.1.1                 11 Mar 2017   https://www.x.org/releases/individual/app/sessreg-1.1.1.tar.gz
setuptools                  38.2.4                06 Dec 2017   https://pypi.python.org/packages/69/56/f0f52281b5175e3d9ca8623dadbc3b684e66350ea9e0006736194b265e99/setuptools-38.2.4.zip
setxkbmap                   1.3.1                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/setxkbmap-1.3.1.tar.gz
sg3utils                    1.36                  Jan 2014      http://sg.danny.cz/sg/p/sg3_utils-1.36.tar.xz
sgmlcommon                  0.6.3                 10 Jul 2015   ftp://sources.redhat.com/pub/docbook-tools/new-trials/SOURCES/sgml-common-0.6.3.tgz
shadow                      4.5                   18 Jul 2017   https://github.com/shadow-maint/shadow/releases/download/4.5/shadow-4.5.tar.xz
shapelib                    1.3.0                 Nov 2013      http://download.osgeo.org/shapelib/shapelib-1.3.0.tar.gz
shareddesktopontologies     0.11.0                Oct 2013      http://sourceforge.net/projects/oscaf/files/shared-desktop-ontologies/0.11.0/shared-desktop-ontologies-0.11.0.tar.bz2
sharedmimeinfo              1.9                   26 Sep 2017   https://people.freedesktop.org/~hadess/shared-mime-info-1.9.tar.xz
sharutils                   4.14                  Jul 2014      http://ftp.gnu.org/gnu/sharutils/sharutils-4.14.tar.xz
shed                        1.15                  May 2014      http://sourceforge.net/projects/shed/files/shed/shed%201.15/shed-1.15.tar.gz
shindo                      0.3.8                 25 Dec 2017   https://rubygems.org/downloads/shindo-0.3.8.gem
shine                       21.05.2015            20 May 2015   shine-21.05.2015
shipping                    1.6.0                 01 Dec 2017   https://rubygems.org/downloads/shipping-1.6.0.gem
shmux                       1.0.2                 Nov 2012      http://web.taranis.org/shmux/dist/shmux-1.0.2.tgz
shntool                     3.0.7                 May 2014      http://www.etree.org/shnutils/shntool/dist/src/shntool-3.0.7.tar.gz
shoes                       1.0.0                 May 2014      https://github.com/shoes/shoes
shorturl                    1.0.0                 May 2014      https://rubygems.org/downloads/shorturl-1.0.0.gem
shotgun                     0.9.2                 02 Aug 2017   https://rubygems.org/downloads/shotgun-0.9.2.gem
shotwell                    0.29.1                24 Apr 2018   https://download.gnome.org/sources/shotwell/0.29/shotwell-0.29.1.tar.xz
showfont                    1.0.5                 31 Jul 2016   http://xorg.freedesktop.org/archive/individual/app/showfont-1.0.5.tar.bz2
signonkwalletextension      18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/signon-kwallet-extension-18.04.0.tar.xz
sigopt                      1.3.0                 04 Apr 2016   https://pypi.python.org/packages/source/s/sigopt/sigopt-1.3.0.tar.gz#md5=ccd67d5c514c1a20659f6217686f0782
silk                        3.10.1                08 Mar 2015   https://tools.netsa.cert.org/releases/silk-3.10.1.tar.gz
simplescan                  3.27.90               02 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/simple-scan/3.27/simple-scan-3.27.90.tar.xz
simsoup                     0.3                   May 2014      http://www.simsoup.info/SimSoup-0.3-src.tar.gz
sinatra                     2.0.1                 26 Feb 2018   https://rubygems.org/downloads/sinatra-2.0.1.gem
sip                         4.19.7                03 Feb 2018   https://sourceforge.net/projects/pyqt/files/sip/sip-4.19.7/sip-4.19.7.tar.gz
sipwitch                    1.9.1                 May 2014      http://ftp.gnu.org/gnu/sipwitch/sipwitch-1.9.1.tar.gz
sisiya                      0.4-21                May 2014      http://ovh.dl.sourceforge.net/sourceforge/sisiya/sisiya-0.4-21.tar.gz
sitemapgenerator            6.0.1                 13 Jan 2018   https://rubygems.org/downloads/sitemap_generator-6.0.1.gem
sithwm                      1.2.3                 May 2014      http://sithwm.darkside.no/sn/sithwm-1.2.3.tgz
six                         1.11.0                26 Sep 2017   https://pypi.python.org/packages/16/d8/bc6316cf98419719bd59c91742194c111b6f2e85abac88e496adefaf7afe/six-1.11.0.tar.gz
skencil                     0.6.16                May 2014      http://www.skencil.org/
skijump                     0.2.0                 May 2014      http://prdownloads.sourceforge.net/skijump/skijump-0.2.0.tar.gz
slag                        0.1                   May 2014      http://download.savannah.gnu.org/releases/slag/slag-0.1.tar.bz2
slang                       2.3.1a                25 Jul 2017   http://www.jedsoft.org/releases/slang/slang-2.3.1a.tar.bz2
slaptget                    0.10.2f               May 2014      http://software.jaos.org/source/slapt-get/slapt-get-0.10.2f.tar.gz
slave                       0.2.0                 May 2014      http://www.codeforpeople.com/lib/ruby/slave/slave-0.2.0.tgz
sleepypenguin               3.1.0                 Nov 2012      http://bogomips.org/sleepy_penguin.git/snapshot/sleepy_penguin-3.1.0.tar.gz
slib                        3a5                   Jan 2014      http://groups.csail.mit.edu/mac/ftpdir/scm/slib-3b4.tar.gz
slideshow                   0.1.0                 May 2014      http://sidvind.com:8000/slideshow
slim                        3.0.9                 09 Jan 2018   https://rubygems.org/downloads/slim-3.0.9.gem
slocate                     3.1                   01 Jan 2014   http://slocate.trakker.ca/files/slocate-3.1.tar.gz
sloccount                   2.26                  May 2014      http://sourceforge.net/projects/sloccount/files/sloccount-2.26.tar.gz
slop                        4.6.2                 19 Mar 2018   https://rubygems.org/downloads/slop-4.6.2.gem
smake                       1.2.5                 07 Feb 2016   http://sourceforge.net/projects/s-make/files/smake-1.2.5.tar.gz
smalltalk                   3.2.5                 Nov 2013      ftp://ftp.gnu.org/gnu/smalltalk/smalltalk-3.2.5.tar.xz
smartmontools               6.6                   12 Nov 2017   https://sourceforge.net/projects/smartmontools/files/smartmontools/6.6/smartmontools-6.6.tar.gz
smb4k                       0.9.6                 May 2014      http://prdownload.berlios.de/smb4k/smb4k-0.9.6.tar.bz2
smc                         1.9                   Dec 2012      http://downloads.sourceforge.net/smclone/smc-1.9.tar.bz2
smf                         0.15.12               Jan 2013      http://www.funaba.org/archive/smf-0.15.12.tar.gz
smokeqt                     4.14.3                15 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/smokeqt-4.14.3.tar.xz
smpeg                       18.11.2011            Mar 2013      http://www.3ddownloads.com/linuxgames/loki/open-source/smpeg/smpeg-0.4.3.tar.gz;jsessionid=5423E28B7AB7B5592BC27E91975EC441#
smplayer                    17.10.0               13 Oct 2017   http://downloads.sourceforge.net/smplayer/smplayer-17.10.0.tar.bz2
smproxy                     1.0.6                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/smproxy-1.0.6.tar.gz
smuxi                       0.8.11                May 2014      https://www.smuxi.org/jaws/data/files/smuxi-0.8.11.tar.gz
snack                       2.2.10                Sep 2013      http://www.speech.kth.se/snack/dist/snack2.2.10.tar.gz
snake3d                     0.7                   May 2014      http://surfnet.dl.sourceforge.net/sourceforge/worms3d/snake3d-0.7.tgz
snappy                      1.0                   Apr 2014      http://ftp.gnome.org/pub/gnome/sources/snappy/1.0/snappy-1.0.tar.xz
snapscreenshot              1.0.14.3              Mar 2014      http://bisqwit.iki.fi/src/arch/snapscreenshot-1.0.14.3.tar.bz2
snd                         13.0                  May 2014      ftp://ccrma-ftp.stanford.edu/pub/Lisp/snd-13.0.tar.gz
sndlib                      1.0.1                 Nov 2012      ftp://ccrma-ftp.stanford.edu/pub/Lisp/sndlib.tar.gz
snes9x                      1.53                  08 Sep 2017   http://files.ipherswipsite.com/snes9x/snes9x-1.53-src.tar.bz2
snogray                     20.04.2008            01 May 2014   http://download.savannah.gnu.org/releases/snogray/snogray-20080420-0.tar.gz
snort                       2.9.11.1              04 Jan 2018   https://www.snort.org/downloads/snort/snort-2.9.11.1.tar.gz
soappy                      0.12.22               02 Aug 2017   https://pypi.python.org/packages/78/1b/29cbe26b2b98804d65e934925ced9810883bdda9eacba3f993ad60bfe271/SOAPpy-0.12.22.zip
solfege                     3.8.3                 May 2014      http://www.solfege.org/Solfege/Download
solid                       5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/solid-5.45.0.tar.xz
solseek                     0.9                   May 2014      https://www.gnome-look.org/p/1127043/
sonik                       1.0.0                 01 May 2014   http://prdownloads.sourceforge.net/sonik/sonik-1.0.0.tar.gz
sonnet                      5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/sonnet-5.45.0.tar.xz
soprano                     2.9.4                 Dec 2013      http://sourceforge.net/projects/soprano/files/Soprano/2.9.4/soprano-2.9.4.tar.bz2
sortversions                1.5                   26 Aug 2017   http://search.cpan.org/CPAN/authors/id/E/ED/EDAVIS/Sort-Versions-1.5.tar.gz
soundconverter              2.1.4                 20 Dec 2014   https://launchpad.net/soundconverter/trunk/2.1.4/+download/soundconverter-2.1.4.tar.xz
soundjuicer                 3.24.0                24 Mar 2017   http://ftp.gnome.org/pub/GNOME/sources/sound-juicer/3.24/sound-juicer-3.24.0.tar.xz
soundkonverter              2.1.2                 22 May 2015   http://kde-apps.org/content/show.php/soundKonverter?content=29024
soundtouch                  2.0.0                 08 Aug 2017   http://www.surina.net/soundtouch/soundtouch-2.0.0.tar.gz
sourceinstall               2.5rc2                May 2014      ftp://ftp.gnu.org/gnu/sourceinstall/sourceinstall-2.5rc2.tar.gz
sox                         14.4.2                12 Apr 2015   http://sourceforge.net/projects/sox/files/sox/14.4.2/sox-14.4.2.tar.gz
spdf                        0.2                   01 May 2014   http://users.tkk.fi/~jitulkki/spdf/spdf-0.2.tar.gz
spectacle                   18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/spectacle-18.04.0.tar.xz
speechd                     26.11.2013            Nov 2013      http://git.freebsoft.org/?p=speechd.git
speedcrunch                 0.10.1                May 2014      http://www.kde-apps.org/content/show.php/SpeedCrunch?content=16696
speex                       1.2.0                 16 Feb 2017   http://downloads.xiph.org/releases/speex/speex-1.2.0.tar.gz
speexdsp                    1.2rc3                27 Dec 2015   http://downloads.xiph.org/releases/speex/speexdsp-1.2rc3.tar.gz
sphinx                      2.2.11                15 Aug 2017   http://sphinxsearch.com/files/sphinx-2.2.11-release.tar.gz
spice                       0.12.8                08 Aug 2016   http://www.spice-space.org/download/releases/spice-0.12.8.tar.bz2
spiceprotocol               0.12.12               08 Aug 2016   http://spice-space.org/download/releases/spice-protocol-0.12.12.tar.bz2
spidermonkey                08.01.2007            Jun 2013      spidermonkey-08.01.2007
spkg                        1.0rc9                May 2014      http://spkg.megous.com/dl/releases/?C=M;O=D
splashy                     0.3.5                 May 2014      http://alioth.debian.org/frs/?group_id=30657
splint                      3.1.1                 May 2014      http://www.splint.org/downloads/splint-3.1.1.src.tgz
splitvt                     1.6.5                 May 2014      http://www.devolution.com/~slouken/projects/splitvt/splitvt-1.6.5.tar.gz
spreadsheet                 1.1.7                 19 Mar 2018   https://rubygems.org/downloads/spreadsheet-1.1.7.gem
sprockets                   3.7.1                 02 Aug 2017   https://rubygems.org/downloads/sprockets-3.7.1.gem
sprocketsrails              3.2.1                 21 Sep 2017   https://rubygems.org/downloads/sprockets-rails-3.2.1.gem
spyc                        0.3beta               May 2014      http://spyc.sourceforge.net/
sqliteautoconf              3230100               11 Apr 2018   http://www.sqlite.org/2018/sqlite-autoconf-3230100.tar.gz
sqlitebrowser               1.3                   May 2014      http://sourceforge.net/projects/sqlitebrowser/
sqliteman                   1.0.1                 May 2014      http://sqliteman.com/
sqliteruby                  2.2.3                 28 Nov 2017   https://rubygems.org/downloads/sqlite-ruby-2.2.3.gem
squashfs                    4.2                   May 2014      http://sourceforge.net/projects/squashfs/files/squashfs/squashfs4.2/squashfs-4.2.tar.gz
squid                       3.5.27                21 Aug 2017   http://www.squid-cache.org/Versions/v3/3.5/squid-3.5.27.tar.gz
sshfs                       3.2.0                 10 Aug 2017   https://github.com/libfuse/sshfs/releases/download/sshfs-3.2.0/sshfs-3.2.0.tar.gz
sslscan                     1.8.2                 Jan 2014      http://downloads.sourceforge.net/project/sslscan/sslscan/sslscan-1.8.2.tgz
ssysm                       0.2.4.3               May 2014      http://freshmeat.net/redir/ssysm/65338/url_tgz/ssysm-0.2.4.3.tar.gz
stager                      2.0.1                 01 May 2014   http://software.uninett.no/stager/download/Stager_2.0.1.tar.gz
startupnotification         0.12                  Jun 2013      http://www.freedesktop.org/software/startup-notification/releases/startup-notification-0.12.tar.gz
statifier                   1.7.1                 May 2014      http://sourceforge.net/projects/statifier/files/statifier/1.7.1/statifier-1.7.1.tar.gz
stax                        1.37                  Nov 2012      http://www.gamblin.ca/staxpc/
stella                      3.7.2                 May 2014      http://sourceforge.net/projects/stella/files/stella/3.7.2/stella-3.7.2-src.tar.gz
step                        4.14.3                15 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/step-4.14.3.tar.xz
stfl                        0.23                  03 Oct 2017   http://www.clifford.at/stfl/stfl-0.23.tar.gz
stlport                     5.1.3                 01 May 2014   http://sourceforge.net/projects/stlport
stow                        2.2.2                 29 Nov 2015   http://ftp.gnu.org/pub/gnu/stow/stow-2.2.2.tar.bz2
strace                      4.20                  18 Nov 2017   https://sourceforge.net/projects/strace/files/strace/4.20/strace-4.20.tar.xz
strasheela                  0.8                   01 Mar 2013   http://heanet.dl.sourceforge.net/sourceforge/strasheela/strasheela-0.8.tar.gz
stratagus                   2.2.5.5               01 Nov 2012   http://launchpad.net/stratagus/trunk/2.2.5.5/+download/stratagus_2.2.5.5.orig.tar.gz
streamripper                1.64.6                May 2014      http://sourceforge.net/projects/streamripper/files/streamripper%20%28current%29/1.64.6/streamripper-1.64.6.tar.gz
streamtuner                 0.99.99               01 Apr 2014   http://savannah.nongnu.org/download/streamtuner/streamtuner-0.99.99.tar.gz
strigi                      0.7.8                 Jan 2014      http://www.vandenoever.info/software/strigi/strigi-0.7.8.tar.bz2
strongswan                  4.6.4                 01 Jun 2012   http://download.strongswan.org/strongswan-4.6.4.tar.bz2
stunnel                     5.44                  02 Dec 2017   ftp://ftp.stunnel.org/stunnel/stunnel-5.44.tar.gz
sublib                      0.9                   May 2014      http://sourceforge.net/projects/sublib/files/sublib/0.9/
subtitlecomposer            11.10.2017            10 Oct 2017   https://github.com/maxrd2/subtitlecomposer
subtitleeditor              0.40.0                May 2014      http://download.gna.org/subtitleeditor/0.40/subtitleeditor-0.40.0.tar.gz
subtle                      xi.tbz2               Nov 2012      http://subforge.org/attachments/download/81/subtle-0.11.3224-xi.tbz2
subversion                  1.10.0                14 Apr 2018   http://www.apache.org/dist/subversion/subversion-1.10.0.tar.bz2
sudo                        1.8.22                17 Jan 2018   ftp://ftp.sudo.ws/pub/sudo/sudo-1.8.22.tar.gz
superkaramba                4.14.3                15 Jul 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/superkaramba-4.14.3.tar.xz
supertux                    0.5.1                 17 Nov 2016   https://github.com/SuperTux/supertux/releases/download/v0.5.1/SuperTux-v0.5.1-Source.tar.gz
supybot                     0.83.1                01 May 2014   https://surfnet.dl.sourceforge.net/sourceforge/supybot/Supybot-0.83.1.tar.bz2
sushi                       3.28.3                29 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/sushi/3.28/sushi-3.28.3.tar.xz
suspendutils                1.0                   Sep 2013      http://sourceforge.net/projects/suspend/files/suspend/suspend-1.0/suspend-utils-1.0.tar.bz2
sussen                      0.90                  01 May 2014   http://dev.mmgsecurity.com/projects/sussen/
svgalib                     1.9.25                Aug 2013      http://www.svgalib.org/svgalib-1.9.25.tar.gz
svgpart                     4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/svgpart-4.14.3.tar.xz
sweep                       0.9.1                 May 2014      http://www.metadecks.org/software/sweep/download/sweep-0.9.1.tar.bz2
sweeper                     4.14.3                16 Mar 2015   ftp://gd.tuwien.ac.at/kde/stable/4.14.3/src/sweeper-4.14.3.tar.xz
swellfoop                   3.27.90               05 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/swell-foop/3.27/swell-foop-3.27.90.tar.xz
swig                        3.0.12                10 Dec 2017   http://prdownloads.sourceforge.net/swig/swig-3.0.12.tar.gz
swinput                     0.6                   May 2014      http://download.savannah.nongnu.org/releases/swinput/swinput-0.6.tar.gz
swipl                       7.6.0-rc2             30 Sep 2017   http://www.swi-prolog.org/download/stable/src/swipl-7.6.0-rc2.tar.gz
swpkg                       0.51                  May 2014      http://web.taranis.org/swpkg/dist/swpkg-0.51.tgz
syck                        1.3.0                 14 May 2017   https://rubygems.org/downloads/syck-1.3.0.gem
sylpheed                    3.7.0                 01 Feb 2018   http://sylpheed.sraoss.jp/sylpheed/v3.7/sylpheed-3.7.0.tar.xz
sympa                       6.1.25                26 Nov 2017   http://www.sympa.org/distribution/sympa-6.1.25.tar.gz
sympy                       1.1.1                 27 Jul 2017   https://github.com/sympy/sympy/releases/download/sympy-1.1.1/sympy-1.1.1.tar.gz
synaptic                    0.84.2                10 Mar 2017   http://ftp.debian.org/debian/pool/main/s/synaptic/synaptic_0.84.2.tar.xz
syndication                 18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/syndication-18.04.0.tar.xz
synfig                      1.2.1                 08 Oct 2017   https://sourceforge.net/projects/synfig/files/releases/1.2.1/source/synfig-1.2.1.tar.gz
syntax                      1.2.2                 01 Dec 2017   https://rubygems.org/downloads/syntax-1.2.2.gem
syntaxhighlighting          5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/syntax-highlighting-5.45.0.tar.xz
sysdig                      0.18.0                25 Sep 2017   https://github.com/draios/sysdig/archive/0.18.0.tar.gz
sysklogd                    1.5                   May 2014      http://www.infodrom.org/projects/sysklogd/download/sysklogd-1.5.tar.gz
syslinux                    6.02                  08 Aug 2016   https://www.kernel.org/pub/linux/utils/boot/syslinux/syslinux-6.02.tar.xz
sysprof                     3.26.1                04 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/sysprof/3.26/sysprof-3.26.1.tar.xz
sysstat                     11.6.2                14 Jan 2018   http://perso.wanadoo.fr/sebastien.godard/sysstat-11.6.2.tar.xz
systemd                     228                   18 Nov 2015   https://www.freedesktop.org/software/systemd/systemd-228.tar.xz
systemsettings              5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/systemsettings-5.12.4.tar.xz
systemtap                   3.2                   01 Nov 2017   https://sourceware.org/systemtap/ftp/releases/systemtap-3.2.tar.gz
systemtoolsbackends         2.10.2                Feb 2014      http://ftp.gnome.org/pub/GNOME/sources/system-tools-backends/2.10/system-tools-backends-2.10.2.tar.gz
systemu                     2.2.0                 Nov 2012      http://codeforpeople.com/lib/ruby/systemu/systemu-2.2.0.tgz
sysuname                    1.0.3                 02 Dec 2017   https://rubygems.org/downloads/sys-uname-1.0.3.gem
sysvinit                    2.89                  28 Mar 2018   http://download.savannah.gnu.org/releases/sysvinit/sysvinit-2.89.tar.bz2
tabbed                      0.6                   30 Jun 2015   http://dl.suckless.org/tools/tabbed-0.6.tar.gz
tabble                      0.43                  Sep 2013      http://www.rillion.net/tabble/tabble-0.43.tar.gz
taglib                      1.11.1                08 Jan 2018   http://taglib.org/releases/taglib-1.11.1.tar.gz
tali                        3.19.92               16 Mar 2016   http://ftp.gnome.org/pub/GNOME/sources/tali/3.19/tali-3.19.92.tar.xz
talib                       0.4.10                30 Jul 2017   https://pypi.python.org/packages/c0/13/3d92ed6c09ed585ed58aeab5da6361ff2aeff7757d8224089bd574945716/TA-Lib-0.4.10.tar.gz
talloc                      2.1.13                08 Apr 2018   https://www.samba.org/ftp/talloc/talloc-2.1.13.tar.gz
tangoicontheme              0.7.2                 May 2014      http://tango-project.org/releases/tango-icon-theme-0.7.2.tar.gz
tar                         1.30                  17 Dec 2017   ftp://ftp.gnu.org/gnu/tar/tar-1.30.tar.xz
tartan                      0.2.1                 01 Nov 2012   https://rubygems.org/downloads/tartan-0.2.1.gem
tasks                       3.3.90                Nov 2013      http://ftp.gnome.org/pub/GNOME/sources/tasks/3.3/tasks-3.3.90.tar.xz
tasque                      0.1.12                24 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/tasque/0.1/tasque-0.1.12.tar.xz
tcc                         0.9.26                Aug 2013      http://download.savannah.gnu.org/releases/tinycc/tcc-0.9.26.tar.bz2
tcl                         8.6.8                 20 Dec 2017   http://downloads.sourceforge.net/tcl/tcl8.6.8-src.tar.gz
tcpdump                     4.9.2                 05 Sep 2017   http://www.tcpdump.org/release/tcpdump-4.9.2.tar.gz
tcsh                        6.20.00               21 Aug 2017   https://fossies.org/linux/misc/tcsh-6.20.00.tar.gz/
tdb                         1.3.15                28 Nov 2017   https://www.samba.org/ftp/tdb/tdb-1.3.15.tar.gz
tea                         44.1.0                18 Jul 2017   http://semiletov.org/tea/dloads/tea-44.1.0.tar.bz2
ted                         2.21                  01 May 2014   ftp://ftp.nluug.nl/pub/editors/ted/ted-2.21.src.tar.gz
telegnome                   0.3.2                 18 Jun 2017   http://ftp.gnome.org/pub/GNOME/sources/telegnome/0.3/telegnome-0.3.2.tar.xz
telepathyglib               0.24.1                16 Sep 2014   http://telepathy.freedesktop.org/releases/telepathy-glib/telepathy-glib-0.24.1.tar.gz
telepathylogger             0.8.0                 Oct 2013      http://telepathy.freedesktop.org/releases/telepathy-logger/telepathy-logger-0.8.0.tar.bz2
tellico                     2.3.10                24 May 2015   http://tellico-project.org/files/tellico-2.3.10.tar.bz2
templateglib                3.27.90               05 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/template-glib/3.27/template-glib-3.27.90.tar.xz
tepl                        4.0.0                 08 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/tepl/4.0/tepl-4.0.0.tar.xz
termanimation               2.4                   01 Jan 2013   http://search.cpan.org/CPAN/authors/id/K/KB/KBAUCOM/Term-Animation-2.4.tar.gz
termansicolor               1.6.0                 31 Jul 2017   https://rubygems.org/downloads/term-ansicolor-1.6.0.gem
termcap                     1.3.1                 May 2014      ftp://ftp.gnu.org/gnu/termcap/termcap-1.3.1.tar.gz
terminator                  0.97                  30 Jun 2015   http://launchpad.net/terminator/trunk/0.97/+download/terminator-0.97.tar.gz
terminology                 1.1.1                 09 Oct 2017   https://download.enlightenment.org/rel/apps/terminology/terminology-1.1.1.tar.gz
termit                      3.9.0                 11 Sep 2017   https://rubygems.org/downloads/termit-3.9.0.gem
testdisk                    6.11.3                01 May 2014   http://www.cgsecurity.org/testdisk-6.11.3.tar.bz2
tetex                       3.0                   01 May 2014   ftp://tug.ctan.org/tex-archive/systems/unix/teTeX/3.0/distrib/tetex-src-3.0.tar.gz
texi2html                   1.82                  01 Jan 2013   http://savannah.inetbridge.net/texi2html/texi2html-1.82.tar.bz2
texinfo                     6.5                   13 Sep 2017   ftp://ftp.gnu.org/gnu/texinfo/texinfo-6.5.tar.xz
texmaker                    3.3.4                 May 2014      http://www.xm1math.net/texmaker/texmaker-3.3.4.tar.bz2
textbibtex                  0.81                  03 Aug 2017   http://search.cpan.org/CPAN/authors/id/A/AM/AMBS/Text-BibTeX-0.81.tar.gz
thin                        1.7.2                 31 Jul 2017   https://rubygems.org/downloads/thin-1.7.2.gem
thoggen                     0.7.1                 Apr 2014      http://prdownloads.sourceforge.net/thoggen/thoggen-0.7.1.tar.gz
thor                        0.20.0                13 Nov 2017   https://rubygems.org/downloads/thor-0.20.0.gem
threadsafe                  0.3.6                 07 Dec 2017   https://rubygems.org/downloads/thread_safe-0.3.6.gem
threadweaver                5.45.0                17 Apr 2018   https://download.kde.org/stable/frameworks/5.45/threadweaver-5.45.0.tar.xz
thunar                      1.7.0                 02 Dec 2017   http://archive.xfce.org/src/xfce/thunar/1.7/Thunar-1.7.0.tar.bz2
thunarvolman                0.9.0                 26 Dec 2017   http://archive.xfce.org/src/xfce/thunar-volman/0.9/thunar-volman-0.9.0.tar.bz2
tidy                        1.1.2                 05 Mar 2017   https://rubygems.org/downloads/tidy-1.1.2.gem
tiff                        4.0.9                 20 Nov 2017   http://download.osgeo.org/libtiff/tiff-4.0.9.tar.gz
tightvnc                    1.3.10                01 May 2014   https://sourceforge.net/projects/vnc-tight/files/TightVNC-unix/1.3.10/tightvnc-1.3.10_unixsrc.tar.bz2
tilda                       14.01.2018            14 Jan 2018   https://github.com/lanoxx/tilda/tilda-14.01.2018
tilt                        2.0.8                 01 Aug 2017   https://rubygems.org/downloads/tilt-2.0.8.gem
timidity++                  2.14.0                01 May 2014   https://sourceforge.net/projects/timidity/files/TiMidity%2B%2B/TiMidity%2B%2B-2.14.0/TiMidity%2B%2B-2.14.0.tar.xz
tintin                      2.01.1                06 Sep 2015   http://sourceforge.net/projects/tintin/files/TinTin%2B%2B%20Source%20Code/2.01.1/tintin-2.01.1.tar.gz
tinyfugue                   5.07                  01 Feb 2013   https://tinyfugue.sourceforge.net/
tinyvm                      03.07.2011            May 2014      https://github.com/GenTiradentes/tinyvm/tinyvm-03.07.2011
tinyxml                     2.6.2                 May 2014      http://sourceforge.net/projects/tinyxml/files/tinyxml/2.6.2/tinyxml_2_6_2.tar.gz
tioga                       1.19.1                10 Feb 2016   https://rubygems.org/downloads/tioga-1.19.1.gem
tk                          8.6.7                 12 Aug 2017   http://downloads.sourceforge.net/tcl/tk8.6.7-src.tar.gz
tmux                        2.3                   30 Sep 2016   https://github.com/tmux/tmux/releases/download/2.3/tmux-2.3.tar.gz
tomboy                      1.15.9                16 Jul 2017   http://ftp.gnome.org/pub/gnome/sources/tomboy/1.15/tomboy-1.15.9.tar.xz
toppler                     1.1.6                 12 Dec 2015   http://sourceforge.net/projects/toppler/files/toppler/1.1.6/toppler-1.1.6.tar.gz
tork                        0.27                  May 2014      http://www.anonymityanywhere.com/tork/
torsmo                      0.18                  May 2014      https://sourceforge.net/projects/torsmo/files/torsmo/torsmo%200.18/torsmo-0.18.tar.gz
totem                       3.26.0                11 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/totem/3.26/totem-3.26.0.tar.xz
totemplparser               3.26.0                14 Sep 2017   http://ftp.gnome.org/pub/gnome/sources/totem-pl-parser/3.26/totem-pl-parser-3.26.0.tar.xz
toybox                      0.7.3                 03 Mar 2017   http://www.landley.net/toybox/downloads/toybox-0.7.3.tar.gz
toycars                     0.3.10                01 Dec 2012   http://sourceforge.net/projects/toycars/files/toycars/0.3.10/toycars-0.3.10.tar.gz
trac                        1.0.8                 30 Aug 2015   http://ftp.edgewall.com/pub/trac/Trac-1.0.8.tar.gz
traceroute                  2.1.0                 05 Dec 2017   https://sourceforge.net/projects/traceroute/files/traceroute/traceroute-2.1.0/traceroute-2.1.0.tar.gz
trackballs                  1.1.4                 03 Apr 2016   https://sourceforge.net/projects/trackballs/files/trackballs/1.1.4/trackballs-1.1.4.tar.gz
tracker                     2.0.3                 08 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/tracker/2.0/tracker-2.0.3.tar.xz
trackerminers               2.0.3                 15 Nov 2017   http://ftp.gnome.org/pub/gnome/sources/tracker-miners/2.0/tracker-miners-2.0.3.tar.xz
trackfs                     0.0.7                 May 2014      http://www.mr511.de/software/trackfs-0.0.7.tar.gz
tramp                       2.3.0                 24 Jul 2016   http://ftp.gnu.org/gnu/tramp/tramp-2.3.0.tar.gz
transcode                   1.1.7                 01 Jan 2014   https://bitbucket.org/france/transcode-tcforge/downloads/transcode-1.1.7.tar.bz2
transmission                2.94                  02 May 2018   https://github.com/transmission/transmission-releases/raw/master/transmission-2.94.tar.xz
transset                    1.0.1                 May 2014      http://xorg.freedesktop.org/releases/individual/app/transset-1.0.1.tar.bz2
trapproto                   3.4.3                 May 2014      http://xorg.freedesktop.org/releases/individual/proto/trapproto-3.4.3.tar.bz2
treetop                     1.6.10                01 May 2018   https://rubygems.org/downloads/treetop-1.6.10.gem
trimines                    1.3.0                 01 May 2014   http://www.freewebs.com/trimines/trimines-1.3.0.tar.gz
tripwire                    2.4.3.7               07 Oct 2017   https://github.com/Tripwire/tripwire-open-source/archive/2.4.3.7.tar.gz
trix                        0.93                  May 2014      http://www.kde-apps.org/content/show.php/trix?content=49417
trollop                     2.1.2                 06 Jul 2017   https://rubygems.org/downloads/trollop-2.1.2.gem
trtl                        0.0.2                 07 Oct 2017   https://rubygems.org/downloads/trtl-0.0.2.gem
tsombie                     1.1.2                 01 Dec 2012   http://mathias-kettner.com/download/tsombie-1.1.2.tar.gz
ttfunk                      1.5.1                 31 Jul 2017   https://rubygems.org/downloads/ttfunk-1.5.1.gem
ttycursor                   0.5.0                 17 Jan 2018   https://rubygems.org/downloads/tty-cursor-0.5.0.gem
ttyprogressbar              0.14.0                17 Jan 2018   https://rubygems.org/downloads/tty-progressbar-0.14.0.gem
ttyscreen                   0.6.4                 17 Jan 2018   https://rubygems.org/downloads/tty-screen-0.6.4.gem
tulip                       3.0.0B6               May 2014      http://downloads.sourceforge.net/auber/tulip-3.0.0B6.tar.bz2?modtime=1184356395&big_mirror=0
tumbler                     0.2.1                 02 Apr 2018   http://archive.xfce.org/src/xfce/tumbler/0.2/tumbler-0.2.1.tar.bz2
tunapie                     0.9.5.1               May 2014      http://downloads.sourceforge.net/project/tunapie/tunapie/2.1/tunapie-2.1.17.tar.gz?use_mirror=kent
tunnel                      1.2.1                 May 2014      http://tspiteri.org/tunnel/download/
turbovnc                    1.2.1                 Jul 2014      http://sourceforge.net/projects/turbovnc/files/1.2.1/turbovnc-1.2.1.tar.gz
tuxrip                      0.99beta6             01 May 2014   http://tuxrip.free.fr/tuxrip/tuxrip099beta6.tar.bz2
tv                          0.5.1                 24 Nov 2017   http://darwin.zoology.gla.ac.uk/~rpage/treeviewx/download/0.5/tv-0.5.1.tar.gz
tvtime                      1.0.1                 May 2014      http://prdownloads.sourceforge.net/tvtime/tvtime-1.0.1.tar.gz
twind                       1.1.0                 May 2014      http://puzzle.dl.sourceforge.net/sourceforge/twind/twind-1.1.0.tar.gz
twisted                     17.9.0                21 Dec 2017   https://github.com/twisted/twisted/archive/twisted-17.9.0.tar.gz
twitux                      0.69                  29 Jul 2016   https://sourceforge.net/projects/twitux/files/twitux/0.69/twitux-0.69.tar.bz2
twm                         1.0.10                14 Mar 2018   http://xorg.freedesktop.org/releases/individual/app/twm-1.0.10.tar.bz2
twolame                     0.3.13                Nov 2013      http://downloads.sourceforge.net/twolame/twolame-0.3.13.tar.gz
typespeed                   0.6.5                 27 Mar 2017   http://typespeed.sourceforge.net/typespeed-0.6.5.tar.gz
tzinfo                      1.2.5                 13 Feb 2018   https://rubygems.org/downloads/tzinfo-1.2.5.gem
uchardet                    0.0.6                 12 Mar 2017   https://www.freedesktop.org/software/uchardet/releases/uchardet-0.0.6.tar.xz
uclibc                      0.9.32                May 2014      http://www.uclibc.org/downloads/uClibc-0.9.32.tar.bz2
ucview                      0.16                  May 2014      http://www.unicap-imaging.org/downloads/ucview-0.16.tar.gz
udev                        182                   Aug 2013      http://www.kernel.org/pub/linux/utils/kernel/hotplug/udev-182.tar.xz
udftools                    1.0.0b3               May 2014      http://downloads.sourceforge.net/linux-udf/udftools-1.0.0b3.tar.gz
udisks                      2.7.5                 07 Dec 2017   https://github.com/storaged-project/udisks/archive/udisks-2.7.5.tar.gz
ufoai                       2.5                   09 Aug 2015   http://sourceforge.net/projects/ufoai/files/UFO_AI%202.x/2.5/ufoai-2.5-source.tar.bz2
uglifier                    4.1.10                01 May 2018   https://rubygems.org/downloads/uglifier-4.1.10.gem
uhttpmock                   0.5.1                 24 Oct 2017   http://tecnocode.co.uk/downloads/uhttpmock/uhttpmock-0.5.1.tar.xz
uim                         1.5.4                 May 2014      http://uim.googlecode.com/files/uim-1.5.4.tar.bz2
umbrello                    18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/umbrello-18.04.0.tar.xz
umockdev                    0.9.2                 01 Jul 2017   https://launchpad.net/umockdev/trunk/0.9.2/+download/umockdev-0.9.2.tar.xz
unbound                     1.7.0                 22 Mar 2018   https://unbound.net/downloads/unbound-1.7.0.tar.gz
unchartedruby               1.3.0                 May 2014      http://raa.ruby-lang.org/project/uncharted/
uncrustify                  0.65                  02 Aug 2017   https://sourceforge.net/projects/uncrustify/files/uncrustify/uncrustify-0.65/uncrustify-0.65.tar.gz
unf                         0.1.4                 21 Sep 2017   https://rubygems.org/downloads/unf-0.1.4.gem
unfext                      0.0.7                 29 Sep 2017   https://rubygems.org/downloads/unf_ext-0.0.7.4.gem
unhash                      0.7                   May 2014      http://www.geocities.com/dxp2532/
unicodecollate              1.25                  26 Nov 2017   http://search.cpan.org/CPAN/authors/id/S/SA/SADAHIRO/Unicode-Collate-1.25.tar.gz
unicorn                     5.4.0                 09 Jan 2018   https://rubygems.org/downloads/unicorn-5.4.0.gem
unieject                    6                     01 May 2014   http://prdownloads.sourceforge.net/unieject/unieject-6.tar.bz2
union                       1.0.5                 01 Dec 2017   https://rubygems.org/downloads/union-1.0.5.gem
unionfsfuse                 0.25                  May 2014      http://podgorny.cz/unionfs-fuse/releases/unionfs-fuse-0.25.tar.bz2
unity                       7.3.0                 17 Sep 2014   https://launchpad.net/unity/7.3/7.3.0/+download/unity-7.3.0.tar.bz2
unixodbc                    2.3.5                 04 Jan 2018   ftp://ftp.unixodbc.org/pub/unixODBC/unixODBC-2.3.5.tar.gz
unoconv                     26.11.2013            Nov 2013      http://dag.wieers.com/home-made/unoconv/unoconv-26.11.2013.tar.xz
unzip                       6.0                   17 Dec 2015   http://downloads.sourceforge.net/infozip/unzip60.tar.gz
upower                      0.99.7                02 Dec 2017   https://upower.freedesktop.org/releases/upower-0.99.7.tar.xz
upstart                     1.6.1                 Jan 2013      http://upstart.ubuntu.com/download/1.6.1/upstart-1.6.1.tar.gz
uri                         1.73                  13 Jan 2018   http://search.cpan.org/CPAN/authors/id/E/ET/ETHER/URI-1.73.tar.gz
uriparser                   0.8.4                 May 2014      https://sourceforge.net/projects/uriparser/files/Sources/0.8.4/uriparser-0.8.4.tar.bz2
urlgrabber                  3.1.0                 May 2014      http://linux.duke.edu/projects/urlgrabber/download/urlgrabber-3.1.0.tar.gz
urpkg                       1.4                   May 2014      http://www.svasey.org/urpkg/urpkg-1.4.tar.bz2
usbutils                    009                   28 Nov 2017   https://www.kernel.org/pub/linux/utils/usb/usbutils/usbutils-009.tar.xz
usermanager                 5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/user-manager-5.12.4.tar.xz
utillinux                   2.32                  21 Mar 2018   http://www.kernel.org/pub/linux/utils/util-linux/v2.32/util-linux-2.32.tar.xz
utillinuxng                 2.18                  May 2014      ftp://ftp.kernel.org/pub/linux/utils/util-linux-ng/v2.20/util-linux-ng-2.18.tar.bz2
utilmacros                  1.19.2                08 Mar 2018   http://xorg.freedesktop.org/releases/individual/util/util-macros-1.19.2.tar.bz2
uuid                        1.6.2                 01 Jul 2013   ftp://ftp.ossp.org/pkg/lib/uuid/uuid-1.6.2.tar.gz
v4lutils                    1.14.1                30 Dec 2017   https://www.linuxtv.org/downloads/v4l-utils/v4l-utils-1.14.1.tar.bz2
vala                        0.40.3                10 Apr 2018   http://ftp.gnome.org/pub/gnome/sources/vala/0.40/vala-0.40.3.tar.xz
valadoc                     0.36.1                09 Oct 2017   http://ftp.gnome.org/pub/gnome/sources/valadoc/0.36/valadoc-0.36.1.tar.xz
valencia                    0.8.0                 Aug 2014      http://ftp.gnome.org/pub/GNOME/sources/valencia/0.8/valencia-0.8.0.tar.xz
valgrind                    3.13.0                25 Jul 2017   ftp://sourceware.org/pub/valgrind/valgrind-3.13.0.tar.bz2
valknut                     0.3.23                01 Nov 2017   https://sourceforge.net/projects/wxdcgui/files/valknut/0.3.23/valknut-0.3.23.tar.bz2
valkyrie                    2.0.0                 17 Dec 2017   http://valgrind.org/downloads/valkyrie-2.0.0.tar.bz2
vapoursynth                 30.09.2015            30 Sep 2015   vapoursynth-30.09.2015.tar.xz
vc                          0.7.3                 09 Aug 2015   http://code.compeng.uni-frankfurt.de/attachments/download/174/Vc-0.7.3.tar.gz
vcinit                      1.2                   May 2014      http://www.dervishd.net/Projects/VCinit-1.2.tar.gz
vdr                         1.6.0                 May 2014      http://www.cadsoft.de/vdr/download.htm
veejay                      1.4                   22 Dec 2015   http://sourceforge.net/projects/veejay/files/OldFiles/veejay-1.4.tar.bz2
vera                        1.23                  10 Feb 2016   http://ftp.gnu.org/pub/gnu/vera/vera-1.23.tar.gz
vertris                     0.3.2                 May 2014      http://vertris.googlepages.com/
vice                        1.19                  May 2014      http://www.zimmers.net/anonftp/pub/cbm/crossplatform/emulators/VICE/vice-1.19.tar.gz
videocut                    0.2.0                 May 2014      http://www.kde-apps.org/content/show.php/VideoCut?content=60826
videoproto                  2.3.3                 12 Mar 2016   http://xorg.freedesktop.org/releases/individual/proto/videoproto-2.3.3.tar.gz
videotrans                  1.6.1                 May 2014      http://sourceforge.net/projects/videotrans/files/videotrans/1.6.1/videotrans-1.6.1.tar.bz2
viennarna                   2.4.4                 17 Apr 2018   https://www.tbi.univie.ac.at/RNA/download/sourcecode/2_4_x/ViennaRNA-2.4.4.tar.gz
viewres                     1.0.4                 08 Aug 2015   http://xorg.freedesktop.org/releases/individual/app/viewres-1.0.4.tar.gz
viewvc                      1.1.15                May 2014      http://viewvc.tigris.org/files/documents/3330/49223/viewvc-1.1.15.tar.gz
vim                         8.0.586               26 Jul 2017   http://ftp.vim.org/vim/unix/vim-8.0.586.tar.bz2
vinagre                     3.20.0                22 Mar 2016   http://ftp.gnome.org/pub/GNOME/sources/vinagre/3.20/vinagre-3.20.0.tar.xz
vino                        3.18.1                12 Nov 2015   http://ftp.gnome.org/pub/GNOME/sources/vino/3.18/vino-3.18.1.tar.xz
virtualenv                  15.1.0                03 Sep 2017   https://pypi.python.org/packages/d4/0c/9840c08189e030873387a73b90ada981885010dd9aea134d6de30cd24cb8/virtualenv-15.1.0.tar.gz
vitetris                    0.57                  Nov 2012      http://www.victornils.net/tetris/vitetris-0.57.tar.gz
vlc                         3.0.2                 23 Apr 2018   http://download.videolan.org/pub/videolan/vlc/3.0.2/vlc-3.0.2.tar.xz
vlock                       2.1                   May 2014      http://cthulhu.c3d2.de/~toidinamai/vlock/vlock.html
vmd                         1.9.3                 16 Jun 2017   http://www.ks.uiuc.edu/Research/vmd/vmd-1.9.3/files/final/vmd-1.9.3.src.tar.gz
vobcopy                     1.1.0                 May 2014      http://vobcopy.org/download/vobcopy-1.1.0.tar.bz2
volleyball                  0.82                  May 2014      http://www.losersjuegos.com.ar/juegos/volleyball/descargas/volleyball-0.82.tar.gz
vor                         0.5.5                 May 2014      http://qualdan.com/vor/vor-0.5.5.tar.bz2
vorbistools                 1.4.0                 08 Sep 2015   http://downloads.xiph.org/releases/vorbis/vorbis-tools-1.4.0.tar.gz
vpnc                        0.5.3                 May 2013      http://www.unix-ag.uni-kl.de/~massar/vpnc/vpnc-0.5.3.tar.gz
vrpe                        0.31                  May 2014      http://vrpe.sytes.net/VRPE/VRPE-0.31.tar.bz2
vsftpd                      3.0.3                 25 Jul 2015   https://security.appspot.com/downloads/vsftpd-3.0.3.tar.gz
vte                         0.52.1                14 Apr 2018   http://ftp.gnome.org/pub/GNOME/sources/vte/0.52/vte-0.52.1.tar.xz
w3m                         0.5.2                 29 Jul 2016   https://sourceforge.net/projects/w3m/files/w3m/w3m-0.5.2/w3m-0.5.2.tar.gz
waf                         2.0.7                 17 Apr 2018   https://github.com/waf-project/waf/archive/waf-2.0.7.tar.gz
waon                        0.10                  Mar 2014      http://sourceforge.net/projects/waon/files/waon/0.10/waon-0.10.tar.gz
warmux                      11.04.1               Jul 2014      http://sourceforge.net/projects/warmux/files/warmux-11.04.1.tar.bz2
warzone2100                 3.1.2                 26 Jul 2015   http://sourceforge.net/projects/warzone2100/files/releases/3.1.2/warzone2100-3.1.2.tar.xz
wavbreaker                  0.8                   May 2014      http://huli.org/wavbreaker/download.html
wavpack                     5.1.0                 16 Oct 2017s  https://github.com/dbry/WavPack/archive/5.1.0.tar.gz
wayland                     1.15.0                10 Apr 2018   https://wayland.freedesktop.org/releases/wayland-1.15.0.tar.xz
waylandprotocols            1.13                  20 Feb 2018   https://wayland.freedesktop.org/releases/wayland-protocols-1.13.tar.xz
wcd                         6.0.1-beta3           08 Aug 2017   https://waterlan.home.xs4all.nl/wcd/wcd-6.0.1-beta3.tar.gz
wdiff                       1.1.2                 May 2014      http://tweedo.com/mirror/gnu/wdiff/wdiff-1.1.2.tar.gz
webkit                      r189384               22 Dec 2015   http://builds.nightly.webkit.org/files/trunk/src/WebKit-r189384.tar.bz2
webkitgtk                   2.20.1                13 Apr 2018   https://webkitgtk.org/releases/webkitgtk-2.20.1.tar.xz
webmin                      1.881                 18 Mar 2018   http://downloads.sourceforge.net/webadmin/webmin-1.881.tar.gz
weechat                     1.9                   04 Aug 2017   https://weechat.org/files/src/weechat-1.9.tar.xz
wesnoth                     1.11.6                Sep 2013      http://sourceforge.net/projects/wesnoth/files/wesnoth/wesnoth-1.11.6/wesnoth-1.11.6.tar.bz2
weston                      2.99.91               18 Jul 2017   https://wayland.freedesktop.org/releases/weston-2.99.91.tar.xz
wget                        1.19.4                24 Jan 2018   ftp://ftp.gnu.org/gnu/wget/wget-1.19.4.tar.gz
which                       2.21                  17 Jun 2015   http://ftp.gnu.org/gnu/which/which-2.21.tar.gz
whitedune                   0.29beta670           May 2014      http://vrml.cip.ica.uni-stuttgart.de/dune/down.html
whois                       5.2.20                30 Dec 2017   http://ftp.debian.org/debian/pool/main/w/whois/whois_5.2.20.tar.xz
wicd                        1.7.4                 25 Jan 2016   https://launchpad.net/wicd/1.7/1.7.4/+download/wicd-1.7.4.tar.gz
windowmaker                 0.95.8                11 Mar 2017   http://windowmaker.org/pub/source/release/WindowMaker-0.95.8.tar.gz
windowswmproto              1.0.3                 May 2014      http://xorg.freedesktop.org/releases/individual/proto/windowswmproto-1.0.3.tar.bz2
wine                        3.2                   17 Feb 2018   http://dl.winehq.org/wine/source/3.x/wine-3.2.tar.xz
wings                       2.1.5                 28 Jul 2017   https://sourceforge.net/projects/wings/files/wings/2.1.5/wings-2.1.5.tar.bz2
winzig                      1.73                  May 2014      http://freshmeat.net/redir/winzig/20777/url_tgz/winzig.1.73.tar.gz
wirble                      0.1.3                 23 Mar 2017   https://rubygems.org/downloads/wirble-0.1.3.gem
wireguard                   0.0.20170918          19 Sep 2017   https://git.zx2c4.com/WireGuard/snapshot/WireGuard-0.0.20170918.tar.xz
wirelesstools               tools.29              01 May 2014   http://www.hpl.hp.com/personal/Jean_Tourrilhes/Linux/wireless_tools.29.tar.gz
wireshark                   2.6.0                 25 Apr 2018   https://www.wireshark.org/download/src/wireshark-2.6.0.tar.xz
wkhtmltox                   0.12.2.1              04 Jan 2016   http://download.gna.org/wkhtmltopdf/0.12/0.12.2.1/wkhtmltox-0.12.2.1.tar.bz2
wlassistant                 0.5.7                 May 2014      http://wlassistant.sourceforge.net/
wmctrl                      1.07                  May 2014      http://www.sweb.cz/tripie/utils/wmctrl/dist/wmctrl-1.07.tar.gz
wmii                        3                     May 2014      http://www.suckless.org/snaps/wmii-20071003.tgz
wordpress                   4.9.5                 04 Apr 2018   https://wordpress.org/wordpress-4.9.5.tar.gz
worker                      2.19.3                May 2014      http://www.boomerangsworld.de/cms/worker/downloads/worker-2.19.3.tar.bz2
wpasupplicant               2.6                   26 Jul 2017   http://hostap.epitest.fi/releases/wpa_supplicant-2.6.tar.gz
wput                        0.6.1                 May 2014      http://prdownloads.sourceforge.net/wput/wput-0.6.1.tgz
writeexcel                  1.0.5                 12 Aug 2017   https://rubygems.org/downloads/writeexcel-1.0.5.gem
wv                          1.2.9                 Aug 2013      http://www.abisource.com/downloads/wv/1.2.9/wv-1.2.9.tar.gz
wv2                         0.4.2                 May 2014      https://sourceforge.net/projects/wvware/files/wv2-0.4.2.tar.bz2
wxgtk                       2.6.3                 01 May 2014   http://mesh.dl.sourceforge.net/sourceforge/wxwindows/wxGTK-2.6.3.tar.bz2
wxpython                    4.0.0                 01 Feb 2018   https://github.com/wxWidgets/Phoenix/archive/wxPython-4.0.0.tar.gz
wxsvg                       1.1.2                 01 May 2014   http://sourceforge.net/projects/wxsvg/files/wxsvg/1.1.2/wxsvg-1.1.2.tar.bz2
wxwidgets                   3.0.3.1               28 Jul 2017   https://github.com/wxWidgets/wxWidgets/releases/download/v3.0.3.1/wxWidgets-3.0.3.1.tar.bz2
x11perf                     1.6.0                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/x11perf-1.6.0.tar.gz
x264                        15.12.2015            15 Dec 2015   ftp://ftp.videolan.org/pub/videolan/x264/snapshots/x264-snapshot-20151214-2245.tar.bz2
x86info                     1.30                  May 2014      http://codemonkey.org.uk/projects/x86info/x86info-1.30.tgz
xapianbindings              1.4.5                 28 Dec 2017   https://oligarchy.co.uk/xapian/1.4.5/xapian-bindings-1.4.5.tar.xz
xapiancore                  1.4.5                 28 Dec 2017   https://oligarchy.co.uk/xapian/1.4.5/xapian-core-1.4.5.tar.xz
xaric                       0.13.7                06 Dec 2015   http://xaric.org/software/xaric/releases/xaric-0.13.7.tar.gz
xaudio                      0.6.1                 01 Apr 2014   http://www.chaoticmind.net/~hcb/murx/xaudio/xaudio-0.6.1.tar.gz
xauth                       1.0.10                16 Feb 2017   https://www.x.org/releases/individual/app/xauth-1.0.10.tar.gz
xautomation                 1.02                  May 2014      http://hoopajoo.net/static/projects/xautomation-1.02.tar.gz
xawtv                       3.95                  May 2014      http://dl.bytesex.org/releases/xawtv/xawtv-3.95.tar.gz
xbacklight                  1.2.1                 Oct 2013      http://xorg.freedesktop.org/releases/individual/app/xbacklight-1.2.1.tar.bz2
xbak                        0.1.5                 May 2014      http://sourceforge.net/projects/xbak/files/xbak/xbak-0.1.5/xbak-0.1.5.tar.bz2
xbiff                       1.0.3                 01 May 2014   https://www.x.org/releases/individual/app/xbiff-1.0.3.tar.bz2
xbindkeys                   1.8.5                 May 2014      http://www.nongnu.org/xbindkeys/xbindkeys-1.8.5.tar.gz
xbitmaps                    1.1.2                 13 Mar 2018   https://www.x.org/releases/individual/data/xbitmaps-1.1.2.tar.bz2
xboard                      4.9.1                 08 Aug 2016   http://ftp.gnu.org/gnu/xboard/xboard-4.9.1.tar.gz
xcalc                       1.0.5                 01 Jan 2013   http://xorg.freedesktop.org/releases/individual/app/xcalc-1.0.5.tar.bz2
xcbproto                    1.13                  08 Mar 2018   https://www.x.org/releases/individual/xcb/xcb-proto-1.13.tar.bz2
xcbutil                     0.4.0                 13 Apr 2015   http://xcb.freedesktop.org/dist/xcb-util-0.4.0.tar.gz
xcbutilcursor               0.1.3                 16 May 2016   https://www.x.org/releases/individual/xcb/xcb-util-cursor-0.1.3.tar.bz2
xcbutilerrors               1.0                   01 Dec 2017   https://www.x.org/releases/individual/xcb/xcb-util-errors-1.0.tar.gz
xcbutilimage                0.4.0                 01 Jun 2014   https://www.x.org/releases/individual/xcb/xcb-util-image-0.4.0.tar.gz
xcbutilkeysyms              0.4.0                 12 Dec 2015   http://xorg.freedesktop.org/releases/individual/xcb/xcb-util-keysyms-0.4.0.tar.bz2
xcbutilrenderutil           0.3.9                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/xcb/xcb-util-renderutil-0.3.9.tar.bz2
xcbutilwm                   0.4.1                 09 Aug 2016   http://xcb.freedesktop.org/dist/xcb-util-wm-0.4.1.tar.bz2
xcbutilxrm                  1.0                   22 Nov 2016   https://github.com/Airblader/xcb-util-xrm/releases/download/v1.0/xcb-util-xrm-1.0.tar.bz2
xchat                       2.8.8                 01 Apr 2014   http://xchat.org/files/source/2.8/xchat-2.8.8.tar.bz2
xchm                        1.23                  05 Oct 2016   https://sourceforge.net/projects/xchm/files/xCHM/xchm-1.23/xchm-1.23.tar.gz
xclip                       0.12                  May 2014      http://downloads.sourceforge.net/project/xclip/xclip/0.12/xclip-0.12.tar.gz
xclipboard                  1.1.3                 Sep 2013      http://xorg.freedesktop.org/releases/individual/app/xclipboard-1.1.3.tar.bz2
xclock                      1.0.7                 Sep 2013      http://xorg.freedesktop.org/releases/individual/app/xclock-1.0.7.tar.bz2
xcm                         0.5.3                 01 May 2014   https://sourceforge.net/projects/oyranos/files/Xcm/xcm-0.5.3.tar.bz2
xcmiscproto                 1.2.2                 01 May 2014   http://xorg.freedesktop.org/releases/individual/proto/xcmiscproto-1.2.2.tar.bz2
xcmsdb                      1.0.5                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xcmsdb-1.0.5.tar.gz
xcompmgr                    1.1.7                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xcompmgr-1.1.7.tar.gz
xconsole                    1.0.6                 May 2014      http://xorg.freedesktop.org/releases/individual/app/xconsole-1.0.6.tar.bz2
xcursorgen                  1.0.6                 Jun 2014      http://xorg.freedesktop.org/releases/individual/app/xcursorgen-1.0.6.tar.gz
xcursorthemes               1.0.5                 13 Mar 2018   https://www.x.org/releases/individual/data/xcursor-themes-1.0.5.tar.bz2
xdbedizzy                   1.0.2                 May 2014      http://xorg.freedesktop.org/releases/individual/app/xdbedizzy-1.0.2.tar.bz2
xdgdesktopportalkde         5.12.4                29 Mar 2018   https://download.kde.org/stable/plasma//5.12.4/xdg-desktop-portal-kde-5.12.4.tar.xz
xdguserdirs                 0.17                  20 Mar 2018   https://user-dirs.freedesktop.org/releases/xdg-user-dirs-0.17.tar.gz
xdguserdirsgtk              0.10                  24 Sep 2014   http://ftp.gnome.org/pub/GNOME/sources/xdg-user-dirs-gtk/0.10/xdg-user-dirs-gtk-0.10.tar.xz
xdgutils                    1.1.1                 22 Nov 2015   http://portland.freedesktop.org/download/xdg-utils-1.1.1.tar.gz
xdialog                     2.3.1                 May 2014      http://xdialog.free.fr/Xdialog-2.3.1.tar.bz2
xditview                    1.0.4                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xditview-1.0.4.tar.gz
xdm                         1.1.11                May 2014      https://www.x.org/releases/individual/app/xdm-1.1.11.tar.bz2
xdotool                     2.20110530.1          01 Feb 2014   http://semicomplete.googlecode.com/files/xdotool-2.20110530.1.tar.gz
xdpyinfo                    1.3.2                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xdpyinfo-1.3.2.tar.gz
xdriinfo                    1.0.5                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xdriinfo-1.0.5.tar.gz
xdtv                        2.4.0                 31 Aug 2017   https://sourceforge.net/projects/xawdecode/files/01%20-%20XdTV/2.4.0/xdtv-2.4.0.tar.gz
xedit                       1.2.2                 26 Feb 2015   http://xorg.freedesktop.org/releases/individual/app/xedit-1.2.2.tar.bz2
xemacs                      21.5.33               Feb 2013      http://ftp.xemacs.org/xemacs/beta/xemacs-21.5.33.tar.gz
xen                         4.0.1                 May 2014      http://bits.xensource.com/oss-xen/release/4.0.1/xen-4.0.1.tar.gz
xercesc                     3.1.4                 18 Mar 2017   http://www-eu.apache.org/dist//xerces/c/3/sources/xerces-c-3.1.4.tar.xz
xev                         1.2.2                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xev-1.2.2.tar.gz
xextproto                   7.2.99.901            Nov 2013      http://xorg.freedesktop.org/releases/individual/proto/xextproto-7.2.99.901.tar.bz2
xf86bigfontproto            1.2.0                 May 2014      http://xorg.freedesktop.org/releases/individual/proto/xf86bigfontproto-1.2.0.tar.bz2
xf86dga                     1.0.2                 May 2014      http://xorg.freedesktop.org/releases/individual/app/xf86dga-1.0.2.tar.bz2
xf86dgaproto                2.1                   Jan 2013      http://xorg.freedesktop.org/releases/individual/proto/xf86dgaproto-2.1.tar.bz2
xf86driproto                2.1.1                 May 2014      http://xorg.freedesktop.org/releases/individual/proto/xf86driproto-2.1.1.tar.bz2
xf86inputelographics        1.4.1                 Feb 2013      http://xorg.freedesktop.org/releases/individual/driver/xf86-input-elographics-1.4.1.tar.bz2
xf86inputevdev              2.10.5                23 Jan 2017   https://www.x.org/releases/individual/driver/xf86-input-evdev-2.10.5.tar.gz
xf86inputevtouch            0.8.8                 01 May 2012   http://www.conan.de/touchscreen/xf86-input-evtouch-0.8.8.tar.bz2
xf86inputfpit               1.4.0                 22 Dec 2015   http://www.x.org/releases/individual/driver/xf86-input-fpit-1.4.0.tar.gz
xf86inputhyperpen           1.4.1                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-input-hyperpen-1.4.1.tar.bz2
xf86inputjoystick           1.6.3                 24 Nov 2016   https://www.x.org/releases/individual/driver/xf86-input-joystick-1.6.3.tar.bz2
xf86inputkeyboard           1.9.0                 03 Oct 2017   https://www.x.org/releases/individual/driver/xf86-input-keyboard-1.9.0.tar.gz
xf86inputlibinput           0.27.1                18 Apr 2018   https://www.x.org/releases/individual/driver/xf86-input-libinput-0.27.1.tar.bz2
xf86inputmouse              1.9.2                 03 Oct 2017   http://xorg.freedesktop.org/releases/individual/driver/xf86-input-mouse-1.9.2.tar.bz2
xf86inputmutouch            1.2.1                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-input-mutouch-1.2.1.tar.bz2
xf86inputpenmount           1.4.0                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-input-penmount-1.4.0.tar.bz2
xf86inputsynaptics          1.9.0                 24 Nov 2016   https://www.x.org/releases/individual/driver/xf86-input-synaptics-1.9.0.tar.bz2
xf86inputvmmouse            13.1.0                25 Jun 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-input-vmmouse-13.1.0.tar.gz
xf86inputvoid               1.1.1                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-input-void-1.1.1.tar.bz2
xf86miscproto               0.9.3                 01 May 2014   http://xorg.freedesktop.org/releases/individual/proto/xf86miscproto-0.9.3.tar.bz2
xf86rushproto               1.1.2                 May 2014      https://www.x.org/releases/individual/proto/xf86rushproto-1.1.2.tar.bz2
xf86videoamd                2.7.7.7               May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-amd-2.7.7.7.tar.bz2
xf86videoamdgpu             1.4.0                 10 Sep 2017   https://www.x.org/releases/individual/driver/xf86-video-amdgpu-1.4.0.tar.bz2
xf86videoark                0.7.4                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-ark-0.7.4.tar.bz2
xf86videoast                1.1.5                 22 Aug 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-ast-1.1.5.tar.bz2
xf86videoati                18.0.1                04 Apr 2018   https://www.x.org/releases/individual/driver/xf86-video-ati-18.0.1.tar.bz2
xf86videochips              1.2.6                 27 Sep 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-chips-1.2.6.tar.gz
xf86videocirrus             1.5.2                 01 May 2014   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-cirrus-1.5.2.tar.gz
xf86videodummy              0.3.8                 16 Dec 2016   https://www.x.org/releases/individual/driver/xf86-video-dummy-0.3.8.tar.gz
xf86videofbdev              0.4.4                 20 Apr 2015   ftp://ftp.x.org/pub/individual/driver/xf86-video-fbdev-0.4.4.tar.bz2
xf86videofreedreno          1.4.0                 12 Oct 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-freedreno-1.4.0.tar.bz2
xf86videogeode              2.11.18               05 Feb 2016   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-geode-2.11.18.tar.bz2
xf86videoglide              1.0.3                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-glide-1.0.3.tar.bz2
xf86videoi810               1.7.4                 01 May 2014   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-i810-1.7.4.tar.bz2
xf86videointel              2.99.917              11 Apr 2015   ftp://ftp.x.org/pub/individual/driver/xf86-video-intel-2.99.917.tar.bz2
xf86videomga                1.6.3                 Dec 2013      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-mga-1.6.3.tar.bz2
xf86videomodesetting        0.9.0                 Jun 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-modesetting-0.9.0.tar.gz
xf86videonewport            0.2.2                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-newport-0.2.2.tar.bz2
xf86videonouveau            1.0.14                18 Mar 2017   https://xorg.freedesktop.org/releases/individual/driver/xf86-video-nouveau-1.0.14.tar.gz
xf86videonv                 2.1.15                May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-nv-2.1.15.tar.bz2
xf86videoomap               0.4.4                 10 Oct 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-omap-0.4.4.tar.gz
xf86videoopenchrome         0.6.0                 08 Mar 2017   https://www.x.org/releases/individual/driver/xf86-video-openchrome-0.6.0.tar.bz2
xf86videoopentegra          0.7.0                 Jul 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-opentegra-0.7.0.tar.xz
xf86videoqxl                0.1.5                 31 Dec 2016   https://www.x.org/releases/individual/driver/xf86-video-qxl-0.1.5.tar.bz2
xf86videoradeonhd           1.3.0                 01 Nov 2017   https://www.x.org/releases/individual/driver/xf86-video-radeonhd-1.3.0.tar.bz2
xf86videorendition          4.2.6                 14 Nov 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-rendition-4.2.6.tar.gz
xf86videos3                 0.6.1                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-s3-0.6.1.tar.bz2
xf86videos3virge            1.10.7                28 Sep 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-s3virge-1.10.7.tar.bz2
xf86videosavage             2.3.8                 10 May 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-savage-2.3.8.tar.bz2
xf86videosiliconmotion      1.7.0                 01 May 2014   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-siliconmotion-1.7.0.tar.bz2
xf86videosis                0.10.8                31 Aug 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-sis-0.10.8.tar.bz2
xf86videosisusb             0.9.2                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-sisusb-0.9.2.tar.bz2
xf86videotga                1.2.1                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-tga-1.2.1.tar.bz2
xf86videotrident            1.3.7                 27 Oct 2016   http://xorg.freedesktop.org/archive/individual/driver/xf86-video-trident-1.3.7.tar.bz2
xf86videotseng              1.2.1                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-tseng-1.2.1.tar.bz2
xf86videov4l                0.2.0                 01 May 2014   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-v4l-0.2.0.tar.bz2
xf86videovboxvideo          1.0.0                 22 Dec 2017   https://www.x.org/releases/individual/driver/xf86-video-vboxvideo-1.0.0.tar.bz2
xf86videovesa               2.4.0                 24 Feb 2018   https://www.x.org/releases/individual/driver/xf86-video-vesa-2.4.0.tar.gz
xf86videovia                0.2.2                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-via-0.2.2.tar.bz2
xf86videovmware             13.2.1                24 Nov 2016   https://www.x.org/releases/individual/driver/xf86-video-vmware-13.2.1.tar.bz2
xf86videovoodoo             1.2.2                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-voodoo-1.2.2.tar.bz2
xf86videowsfb               0.4.0                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-wsfb-0.4.0.tar.bz2
xf86videoxgi                1.6.1                 22 Aug 2015   http://xorg.freedesktop.org/releases/individual/driver/xf86-video-xgi-1.6.1.tar.bz2
xf86videoxgixp              1.8.0                 May 2014      http://xorg.freedesktop.org/releases/individual/driver/xf86-video-xgixp-1.8.0.tar.bz2
xf86vidmodeproto            2.3.1                 01 May 2014   http://xorg.freedesktop.org/releases/individual/proto/xf86vidmodeproto-2.3.1.tar.bz2
xfburn                      0.5.5                 18 Dec 2017   http://archive.xfce.org/src/apps/xfburn/0.5/xfburn-0.5.5.tar.bz2
xfce4appfinder              4.13.0                30 Aug 2017   http://archive.xfce.org/src/xfce/xfce4-appfinder/4.13/xfce4-appfinder-4.13.0.tar.bz2
xfce4devtools               4.12.0                30 Aug 2017   http://archive.xfce.org/src/xfce/xfce4-dev-tools/4.12/xfce4-dev-tools-4.12.0.tar.bz2
xfce4eyesplugin             4.5.0                 25 Sep 2017   http://archive.xfce.org/src/panel-plugins/xfce4-eyes-plugin/4.5/xfce4-eyes-plugin-4.5.0.tar.bz2
xfce4genmonplugin           4.0.0                 26 Sep 2017   http://archive.xfce.org/src/panel-plugins/xfce4-genmon-plugin/4.0/xfce4-genmon-plugin-4.0.0.tar.bz2
xfce4mpcplugin              0.5.0                 30 Aug 2017   http://archive.xfce.org/src/panel-plugins/xfce4-mpc-plugin/0.5/xfce4-mpc-plugin-0.5.0.tar.bz2
xfce4notifyd                0.4.0                 26 Oct 2017   https://git.xfce.org/apps/xfce4-notifyd/snapshot/xfce4-notifyd-0.4.0.tar.bz2
xfce4panel                  4.13.1                30 Aug 2017   http://archive.xfce.org/src/xfce/xfce4-panel/4.13/xfce4-panel-4.13.1.tar.bz2
xfce4powermanager           1.6.0                 30 Aug 2017   http://archive.xfce.org/src/xfce/xfce4-power-manager/1.6/xfce4-power-manager-1.6.0.tar.bz2
xfce4pulseaudioplugin       0.3.0                 25 Sep 2017   http://archive.xfce.org/src/panel-plugins/xfce4-pulseaudio-plugin/0.3/xfce4-pulseaudio-plugin-0.3.0.tar.bz2
xfce4sampleplugin           0.1.2                 25 Sep 2017   http://archive.xfce.org/src/panel-plugins/xfce4-sample-plugin/0.1/xfce4-sample-plugin-0.1.2.tar.gz
xfce4session                4.13.0                30 Aug 2017   http://archive.xfce.org/src/xfce/xfce4-session/4.13/xfce4-session-4.13.0.tar.bz2
xfce4settings               4.12.3                20 Mar 2018   http://archive.xfce.org/src/xfce/xfce4-settings/4.12/xfce4-settings-4.12.3.tar.bz2
xfce4statusnotifierplugin   0.2.0                 26 Sep 2017   http://archive.xfce.org/src/panel-plugins/xfce4-statusnotifier-plugin/0.2/xfce4-statusnotifier-plugin-0.2.0.tar.bz2
xfce4terminal               0.8.7                 31 Mar 2018   https://git.xfce.org/apps/xfce4-terminal/snapshot/xfce4-terminal-0.8.7.tar.bz2
xfce4toys                   4.4.3                 May 2014      http://heanet.dl.sourceforge.net/sourceforge/xfce/xfce-4.2.3.2-src.tar.bz2
xfce4xkbplugin              0.8.1                 26 Sep 2017   http://archive.xfce.org/src/panel-plugins/xfce4-xkb-plugin/0.8/xfce4-xkb-plugin-0.8.1.tar.bz2
xfconf                      4.13.4                09 Sep 2017   http://archive.xfce.org/src/xfce/xfconf/4.13/xfconf-4.13.4.tar.bz2
xfd                         1.1.2                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xfd-1.1.2.tar.bz2
xfdesktop                   4.13.1                30 Aug 2017   http://archive.xfce.org/src/xfce/xfdesktop/4.13/xfdesktop-4.13.1.tar.bz2
xfe                         1.33                  May 2014      http://sourceforge.net/projects/xfe/files/xfe/1.33/xfe-1.33.tar.gz
xfig                        3.2.5                 01 May 2014   ftp://epb.lbl.gov/xfig/xfig.3.2.5.tar.bz2
xfindproxy                  1.0.4                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xfindproxy-1.0.4.tar.gz
xfmedia                     0.9.2                 May 2014      http://spuriousinterrupt.org/projects/xfmedia/files/xfmedia-0.9.2.tar.bz2
xfontsel                    1.0.5                 May 2014      http://xorg.freedesktop.org/releases/individual/app/xfontsel-1.0.5.tar.bz2
xforge                      0.2.2                 May 2014      http://users.tkk.fi/~phonkane/xforge/xforge-0.2.2.tar.gz
xfs                         1.2.0                 30 Nov 2017   http://xorg.freedesktop.org/releases/individual/app/xfs-1.2.0.tar.bz2
xfsdump                     2.2.33                May 2014      http://oss.sgi.com/projects/xfs/
xfsinfo                     1.0.1                 May 2014      http://xorg.freedesktop.org/releases/individual/app/xfsinfo-1.0.1.tar.bz2
xfsprogs                    4.16.1                01 May 2018   https://www.kernel.org/pub/linux/utils/fs/xfs/xfsprogs/xfsprogs-4.16.1.tar.xz
xft                         2.1.2                 Dec 2012      http://xlibs.freedesktop.org/release/xft-2.1.2.tar.gz
xfwm4                       4.13.0                30 Aug 2017   http://archive.xfce.org/src/xfce/xfwm4/4.13/xfwm4-4.13.0.tar.bz2
xfwp                        1.0.3                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xfwp-1.0.3.tar.bz2
xgamma                      1.0.6                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xgamma-1.0.6.tar.bz2
xgc                         1.0.5                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xgc-1.0.5.tar.bz2
xhost                       1.0.7                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xhost-1.0.7.tar.bz2
xinelib                     1.2.9                 12 Jan 2018   http://downloads.sourceforge.net/xine/xine-lib-1.2.9.tar.xz
xineramaproto               1.2.1                 01 May 2014   http://xorg.freedesktop.org/releases/individual/proto/xineramaproto-1.2.1.tar.bz2
xinetd                      2.3.15                01 May 2014   http://www.xinetd.org/xinetd-2.3.15.tar.gz
xineui                      0.99.10               30 Dec 2017   https://sourceforge.net/projects/xine/files/xine-ui/0.99.10/xine-ui-0.99.10.tar.xz
xinit                       1.4.0                 14 Mar 2018   http://xorg.freedesktop.org/releases/individual/app/xinit-1.4.0.tar.bz2
xinput                      1.6.2                 20 Oct 2015   http://xorg.freedesktop.org/releases/individual/app/xinput-1.6.2.tar.bz2
xkbcomp                     1.4.0                 05 May 2017   https://www.x.org/releases/individual/app/xkbcomp-1.4.0.tar.gz
xkbdata                     1.0.1                 01 May 2014   http://xorg.freedesktop.org/releases/individual/data/xkbdata-1.0.1.tar.bz2
xkbevd                      1.1.4                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xkbevd-1.1.4.tar.bz2
xkbprint                    1.0.4                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xkbprint-1.0.4.tar.bz2
xkbutils                    1.0.4                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xkbutils-1.0.4.tar.bz2
xkeyboardconfig             2.23.1                05 Feb 2018   http://xorg.freedesktop.org/archive/individual/data/xkeyboard-config/xkeyboard-config-2.23.1.tar.bz2
xkill                       1.0.4                 01 Sep 2013   http://xorg.freedesktop.org/releases/individual/app/xkill-1.0.4.tar.bz2
xload                       1.1.2                 Mar 2014      http://xorg.freedesktop.org/releases/individual/app/xload-1.1.2.tar.bz2
xlogo                       1.0.1                 May 2014      http://xorg.freedesktop.org/releases/individual/app/xlogo-1.0.1.tar.bz2
xlsatoms                    1.1.2                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xlsatoms-1.1.2.tar.gz
xlsclients                  1.1.3                 Sep 2013      http://xorg.freedesktop.org/releases/individual/app/xlsclients-1.1.3.tar.bz2
xlsfonts                    1.0.5                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xlsfonts-1.0.5.tar.bz2
xmag                        1.0.6                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xmag-1.0.6.tar.bz2
xmahjongg                   3.7                   May 2014      http://www.lcdf.org/xmahjongg/xmahjongg-3.7.tar.gz
xman                        1.1.4                 08 Mar 2015   http://xorg.freedesktop.org/releases/individual/app/xman-1.1.4.tar.bz2
xmedcon                     0.14.1                28 Jan 2016   http://sourceforge.net/projects/xmedcon/files/XMedCon-Source/0.14.1/xmedcon-0.14.1.tar.bz2
xmessage                    1.0.4                 Jan 2013      http://xorg.freedesktop.org/releases/individual/app/xmessage-1.0.4.tar.bz2
xmh                         1.0.3                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xmh-1.0.3.tar.bz2
xmlcopyeditor               1.0.7.7               May 2014      http://puzzle.dl.sourceforge.net/sourceforge/xml-copy-editor/xmlcopyeditor-1.0.7.7.tar.gz
xmldom                      1.44                  May 2014      http://search.cpan.org/CPAN/authors/id/T/TJ/TJMATHER/XML-DOM-1.44.tar.gz
xmllibxmlsimple             0.98                  11 Nov 2017   http://search.cpan.org/CPAN/authors/id/M/MA/MARKOV/XML-LibXML-Simple-0.98.tar.gz
xmlnamespacesupport         1.09                  28 Dec 2017   http://search.cpan.org/CPAN/authors/id/R/RB/RBERJON/XML-NamespaceSupport-1.09.tar.gz
xmlparser                   2.36                  01 May 2014   http://search.cpan.org/CPAN/authors/id/M/MS/MSERGEANT/XML-Parser-2.36.tar.gz
xmlsax                      1.00                  06 Apr 2018   http://search.cpan.org/CPAN/authors/id/G/GR/GRANTM/XML-SAX-1.00.tar.gz
xmlsaxbase                  1.09                  28 Dec 2017   http://search.cpan.org/CPAN/authors/id/G/GR/GRANTM/XML-SAX-Base-1.09.tar.gz
xmlsec1                     1.2.23                17 Apr 2017   https://www.aleksey.com/xmlsec/download/xmlsec1-1.2.23.tar.gz
xmlsimple                   2.25                  26 Mar 2018   http://www.cpan.org/authors/id/G/GR/GRANTM/XML-Simple-2.25.tar.gz
xmlto                       0.0.28                11 Aug 2016   https://releases.pagure.org/xmlto/xmlto-0.0.28.tar.bz2
xmltv                       0.5.63                01 Jul 2013   http://sourceforge.net/projects/xmltv/files/xmltv/0.5.63/xmltv-0.5.63.tar.bz2
xmms                        1.2.11                May 2014      http://xmms.org/files/1.2.x/xmms-1.2.11.tar.gz
xmodmap                     1.0.9                 18 Apr 2015   http://xorg.freedesktop.org/releases/individual/app/xmodmap-1.0.9.tar.bz2
xmore                       1.0.2                 01 Feb 2014   http://xorg.freedesktop.org/releases/individual/app/xmore-1.0.2.tar.bz2
xmp                         3.4.1                 01 May 2014   http://downloads.sourceforge.net/project/xmp/xmp/3.4.1/xmp-3.4.1.tar.gz
xorgcffiles                 1.0.6                 25 Dec 2015   http://xorg.freedesktop.org/releases/individual/util/xorg-cf-files-1.0.6.tar.gz
xorgproto                   2018.2                14 Feb 2018   https://www.x.org/releases/individual/proto/xorgproto-2018.2.tar.gz
xorgserver                  1.19.99.904           18 Apr 2018   https://www.x.org/releases/individual/xserver/xorg-server-1.19.99.904.tar.bz2
xorgsetup                   0.9.7                 22 Dec 2015   ftp://ftp.slackware.org.uk/slacky/slackware-12.1/hardware/x.org-setup/0.9.7/src/xorgsetup-0.9.7.tar.bz2
xorgsgmldoctools            1.11                  01 Oct 2013   http://ftp.x.org/pub/individual/doc/xorg-sgml-doctools-1.11.tar.bz2
xorriso                     1.4.8                 16 Sep 2017   http://ftp.gnu.org/pub/gnu/xorriso/xorriso-1.4.8.tar.gz
xosd                        2.2.14                01 Dec 2013   https://sourceforge.net/projects/libxosd/files/libxosd/xosd-2.2.14/xosd-2.2.14.tar.gz
xournal                     0.4.8                 08 Mar 2017   http://downloads.sourceforge.net/xournal/xournal-0.4.8.tar.gz
xpad                        4.5.0                 22 Apr 2015   https://launchpad.net/xpad/trunk/4.5/+download/xpad-4.5.0.tar.bz2
xpaint                      2.10.2                18 Nov 2017   https://sourceforge.net/projects/sf-xpaint/files/sf-xpaint/xpaint-2.10.2/xpaint-2.10.2.tar.bz2
xpdf                        4.00                  28 Sep 2017   http://www.xpdfreader.com/dl/xpdf-4.00.tar.gz
xphelloworld                1.0.1                 May 2014      http://xorg.freedesktop.org/releases/individual/app/xphelloworld-1.0.1.tar.bz2
xplsprinters                1.0.1                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xplsprinters-1.0.1.tar.bz2
xpr                         1.0.4                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xpr-1.0.4.tar.bz2
xpra                        0.17.5                26 Aug 2016   https://www.xpra.org/src/xpra-0.17.5.tar.xz
xprehashprinterlist         1.0.1                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xprehashprinterlist-1.0.1.tar.bz2
xprop                       1.2.3                 10 Mar 2018   https://www.x.org/releases/individual/app/xprop-1.2.3.tar.bz2
xproto                      7.0.31                08 Oct 2016   https://www.x.org/releases/individual/proto/xproto-7.0.31.tar.gz
xproxymanagementprotocol    1.0.3                 01 May 2014   https://www.x.org/archive/individual/proto/xproxymanagementprotocol-1.0.3.tar.bz2
xpyb                        1.3.1                 09 Jan 2018   https://xcb.freedesktop.org/dist/xpyb-1.3.1.tar.gz
xrandr                      1.4.3                 01 Aug 2014   http://xorg.freedesktop.org/releases/individual/app/xrandr-1.4.3.tar.bz2
xrdb                        1.1.1                 10 Mar 2018   https://www.x.org/releases/individual/app/xrdb-1.1.1.tar.bz2
xrefresh                    1.0.5                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xrefresh-1.0.5.tar.bz2
xrender                     0.8.3                 01 Nov 2012   http://freeware.sgi.com/source/xrender/xrender-0.8.3.tar.bz2
xrick                       021212                01 May 2014   http://www.bigorno.net/xrick/xrick-021212.tgz
xrx                         1.0.3                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xrx-1.0.3.tar.bz2
xsane                       0.999                 28 Dec 2017   http://www.xsane.org/download/xsane-0.999.tar.gz
xscope                      1.4.1                 01 Jun 2014   http://xorg.freedesktop.org/releases/individual/app/xscope-1.4.1.tar.gz
xscreensaver                5.38                  04 Jan 2018   http://www.jwz.org/xscreensaver/xscreensaver-5.38.tar.gz
xsel                        1.2.0                 01 May 2014   http://www.vergenet.net/~conrad/software/xsel/download/xsel-1.2.0.tar.gz
xset                        1.2.3                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xset-1.2.3.tar.bz2
xsetmode                    1.0.0                 01 Jan 2014   http://xorg.freedesktop.org/releases/individual/app/xsetmode-1.0.0.tar.bz2
xsetpointer                 1.0.0                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xsetpointer-1.0.0.tar.bz2
xsetroot                    1.1.1                 01 Jan 2013   http://xorg.freedesktop.org/releases/individual/app/xsetroot-1.1.1.tar.bz2
xsm                         1.0.3                 01 Feb 2013   http://xorg.freedesktop.org/releases/individual/app/xsm-1.0.3.tar.bz2
xstdcmap                    1.0.3                 01 May 2014   http://xorg.freedesktop.org/releases/individual/app/xstdcmap-1.0.3.tar.bz2
xterm                       332                   17 Apr 2018   http://invisible-mirror.net/archives/xterm/xterm-332.tgz
xtrace                      0.0.5                 01 May 2014   https://alioth.debian.org/frs/download.php/file/3733/xtrace_1.3.1.orig.tar.gz
xtrans                      1.3.5                 24 Sep 2014   http://xorg.freedesktop.org/releases/individual/lib/xtrans-1.3.5.tar.gz
xtrap                       1.0.3                 18 Apr 2018   https://www.x.org/releases/individual/app/xtrap-1.0.3.tar.bz2
xu4                         1.0beta3              01 Oct 2013   http://xu4.sourceforge.net/xu4-1.0beta3.tar.bz2
xulrunner                   41.0b9                05 Jan 2016   http://ftp.mozilla.org/pub/xulrunner/releases/41.0b9/source/xulrunner-41.0b9.source.tar.xz
xvidcap                     1.1.7                 01 Oct 2013   https://sourceforge.net/projects/xvidcap/files/xvidcap/1.1.7/xvidcap-1.1.7.tar.gz
xvidcore                    1.3.5                 18 Dec 2017   http://downloads.xvid.org/downloads/xvidcore-1.3.5.tar.gz
xvidtune                    1.0.3                 01 Jan 2013   http://xorg.freedesktop.org/releases/individual/app/xvidtune-1.0.3.tar.bz2
xvinfo                      1.1.2                 01 Feb 2013   http://xorg.freedesktop.org/releases/individual/app/xvinfo-1.1.2.tar.bz2
xvoice                      0.9.6                 01 Apr 2014   http://prdownloads.sourceforge.net/xvoice/xvoice-0.9.6.tar.gz
xwd                         1.0.6                 01 Feb 2014   http://xorg.freedesktop.org/releases/individual/app/xwd-1.0.6.tar.bz2
xwininfo                    1.1.3                 01 Feb 2014   http://xorg.freedesktop.org/releases/individual/app/xwininfo-1.1.3.tar.bz2
xwud                        1.0.4                 01 Nov 2012   http://xorg.freedesktop.org/releases/individual/app/xwud-1.0.4.tar.bz2
xz                          5.2.4                 29 Apr 2018   https://tukaani.org/xz/xz-5.2.4.tar.xz
yabause                     0.9.14                17 Feb 2017   https://sourceforge.net/projects/yabause/files/yabause/0.9.14/yabause-0.9.14.tar.gz
yaf                         0.8.1                 01 May 2014   http://tools.netsa.cert.org/yaf/download.html
yafc                        1.3.7                 14 Sep 2017   http://www.yafc-ftp.com/downloads/yafc-1.3.7.tar.xz
yakuake                     3.0.4                 27 Aug 2017   https://download.kde.org/stable/yakuake/3.0.4/src/yakuake-3.0.4.tar.xz
yaml                        0.1.7                 08 Oct 2016   http://pyyaml.org/download/libyaml/yaml-0.1.7.tar.gz
yamlnetparser               07.02.2008            01 Feb 2013   http://sourceforge.net/projects/yaml-net-parser/files/yaml-net-parser/
yard                        0.9.12                09 Jan 2018   https://rubygems.org/downloads/yard-0.9.12.gem
yasm                        1.3.0                 06 Sep 2014   http://www.tortall.net/projects/yasm/releases/yasm-1.3.0.tar.gz
yaz                         4.2.35                01 May 2014   http://ftp.indexdata.dk/pub/yaz/yaz-4.2.35.tar.gz
yelp                        3.28.0                19 Mar 2018   http://ftp.gnome.org/pub/gnome/sources/yelp/3.28/yelp-3.28.0.tar.xz
yelptools                   3.27.90               08 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/yelp-tools/3.27/yelp-tools-3.27.90.tar.xz
yelpxsl                     3.27.90               08 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/yelp-xsl/3.27/yelp-xsl-3.27.90.tar.xz
youtubedl                   dl                    07 Apr 2018   https://github.com/rg3/youtube-dl/archive/2018.04.03.tar.gz
ypserv                      2.19                  01 May 2014   ftp://ftp.kernel.org/pub/linux/utils/net/NIS/ypserv-2.19.tar.bz2
yptools                     4.2.2                 06 Dec 2017   http://www.linux-nis.org/download/yp-tools/yp-tools-4.2.2.tar.bz2
zabbix                      2.0.0                 01 May 2014   http://sourceforge.net/projects/zabbix/files/ZABBIX%20Latest%20Stable/2.0.0/zabbix-2.0.0.tar.gz
zatacka                     0.1.8                 01 May 2014   http://prdownloads.sourceforge.net/zatacka/zatacka-0.1.8_src.tar.gz
zathura                     0.3.6                 18 Aug 2016   https://pwmt.org/projects/zathura/download/zathura-0.3.6.tar.gz
zee                         0.6                   01 May 2014   https://sourceforge.net/projects/zee/files/zee/0.6/zee-0.6.tar.gz
zenity                      3.27.90               04 Feb 2018   http://ftp.gnome.org/pub/gnome/sources/zenity/3.27/zenity-3.27.90.tar.xz
zeroconfioslave             18.04.0               26 Apr 2018   https://download.kde.org/stable/applications/18.04.0/src/zeroconf-ioslave-18.04.0.tar.xz
zeromq                      4.1.3                 23 Nov 2015   http://download.zeromq.org/zeromq-4.1.3.tar.gz
zfs                         0.7.3                 17 Oct 2017   https://github.com/zfsonlinux/zfs/releases/download/zfs-0.7.3/zfs-0.7.3.tar.gz
zile                        2.4.8                 01 May 2014   http://ftp.gnu.org/gnu/zile/zile-2.4.8.tar.gz
zip                         3.0e                  01 May 2014   http://mesh.dl.sourceforge.net/sourceforge/infozip/zip231.zip
zipruby                     0.3.6                 03 Dec 2017   https://rubygems.org/downloads/zipruby-0.3.6.gem
zlib                        1.2.11                16 Jan 2017   http://www.zlib.net/zlib-1.2.11.tar.xz
zope                        2.10.2                01 May 2014   http://www.zope.org/Products/Zope/2.9.1/Zope-2.10.2.tar.gz
zopeinterface               4.4.2                 16 Sep 2017   https://pypi.python.org/packages/c5/88/93373971f893714f0dc15e09696ec4886ee8b4e561ce5ae45612c2c516c4/zope.interface-4.4.2.tar.gz
zsh                         5.5.1                 20 Apr 2018   http://www.zsh.org/pub/zsh-5.5.1.tar.gz
zutils                      1.6                   04 Aug 2017   http://download.savannah.gnu.org/releases/zutils/zutils-1.6.tar.lz
zvbi                        0.2.35                28 Sep 2015   https://sourceforge.net/projects/zapping/files/zvbi/0.2.35/zvbi-0.2.35.tar.bz2
zziplib                     0.13.66               11 Jun 2017   https://sourceforge.net/projects/zziplib/files/zziplib13/0.13.66/zziplib-0.13.66.tar.gz

</pre>


## Some options for the individual cookbook files explained

This section will explain some entries in a .yml file.

**skip_configure**:

If the option skip_configure is set to true, then RBT will not
attempt to invoke GNU ./configure.

This may be useful for programs that you are certain to not
have any configure script. The man-pages archive is one such
an example.

## Commandline ways to manipulate the dataset

There are some classes that can be used to manipulate the dataset
stored in the individual cookbooks files. This is presently quite
limited.

The only commandline-manipulation that is presently done, is 
done by **class ToggleKeepExtractedValue**.

This acts as a toggle-switch. If you invoke the class, and pass
the name of the program at hand, then the keep_extracted: value
will be toggled, from false to true and from true to false.

## Show everything about a given program (show all)

There is a class called ShowAllAbout, which will simply show
the whole .yml entry of a given program.

I aliased this on my system to "show_all", so then I can type:

    show_all htop

And the content of the .yml file is shown. This is convenient
because you can quickly view the content of the yaml file
at hand.

Note that there exists another way as well, via scookie, but
scookie does not necessarily show all information, whereas
class ShowAllAbout will do so.

A commandline variant also exists via **cookbooks** itself:

    cookbooks --show-all-about=htop
    cookbooks --show-all=htop
    cookbooks --show-file=htop

## Additional information

Consider having a look at the **doc/ subdirectory** of this project's
gem, for some more information. Another useful subdirectory may
be the **lib/yaml/** subdirectory, which also constains some
specifications such as **specification_of_registered_cookbook_entries.yml**.

## Statistics for this project


<pre>
# =========================================================================== #
# This file here (COOKBOOK_STATISTICS.md) was probably started during
# September 2005. It was later renamed from source_files.yml to 
# cookbook.yml (on the 04.05.2006), before it was then eventually renamed
# to COOKBOOK_STATISTICS.md years lateron.
# =========================================================================== #
# - How many programs do we have registered in the Cookbooks project?
#
#   ->  274 programs registered as of 25.10.2005
#   ->  340 programs registered as of 31.12.2005
#
#   ->  851 programs registered as of 28.04.2006
#   -> 1114 programs registered as of 11.07.2006
#   -> 1168 programs registered as of 01.08.2006
#   -> 1195 programs registered as of 07.08.2006
#   -> 1230 programs registered as of 24.08.2006
#   -> 1245 programs registered as of 31.08.2006
#   -> 1270 programs registered as of 16.09.2006
#   -> 1315 programs registered as of 15.10.2006
#   -> 1352 programs registered as of 13.11.2006
#   -> 1402 programs registered as of 27.12.2006
#
#   -> 1432 programs registered as of 28.01.2007
#   -> 1452 programs registered as of 07.02.2007
#   -> 1506 programs registered as of 17.03.2007
#   -> 1547 programs registered as of 19.04.2007
#   -> 1567 programs registered as of 08.05.2007
#   -> 1584 programs registered as of 24.05.2007
#   -> 1598 programs registered as of 04.06.2007
#   -> 1649 programs registered as of 01.07.2007
#   -> 1704 programs registered as of 05.08.2007
#   -> 1736 programs registered as of 01.09.2007
#   -> 1801 programs registered as of 18.09.2007
#   -> 1822 programs registered as of 27.09.2007
#   -> 1835 programs registered as of 03.10.2007
#   -> 1887 programs registered as of 27.10.2007
#   -> 1931 programs registered as of 30.11.2007
#   -> 1994 programs registered as of 30.01.2007
#
#   -> 2107 programs registered as of 05.04.2008
#   -> 2172 programs registered as of 02.06.2008
#   -> 2202 programs registered as of 29.07.2008
#   -> 2256 programs registered as of 12.12.2008
#
#   -> 2269 programs registered as of 31.01.2009
#   -> 2288 programs registered as of 03.05.2009
#   -> 2318 programs registered as of 01.09.2009
#   -> 2325 programs registered as of 24.11.2009
#   -> 2328 programs registered as of 08.12.2009
#
#   -> 2347 programs registered as of 31.03.2010
#
#   -> 2373 programs registered as of 28.02.2011
#   -> 2380 programs registered as of 19.03.2011
#   -> 2393 programs registered as of 25.04.2011
#   -> 2482 programs registered as of 29.08.2011
#   -> 2491 programs registered as of 13.10.2011
#
#   -> 2516 programs registered as of 04.01.2012
#   -> 2270 programs registered as of 28.07.2012
#
#   -> 2518 programs registered as of 25.09.2013
#   -> 2524 programs registered as of 25.10.2013
#   -> 2540 programs registered as of 20.11.2013
#
#   -> 2600 programs registered as of 26.01.2014
#   -> 2609 programs registered as of 26.02.2014
#   -> 2628 programs registered as of 22.06.2014
#   -> 2642 programs registered as of 12.07.2014
#   -> 2644 programs registered as of 14.09.2014
#
#   -> 2652 programs registered as of 10.01.2015
#   -> 2742 programs registered as of 04.06.2015
#   -> 2780 programs registered as of 26.07.2015
#   -> 2781 programs registered as of 02.08.2015.
#   -> 2795 programs registered as of 06.09.2015. 
#   -> 2800 programs registered as of 24.09.2015.
#   -> 2803 programs registered as of 28.09.2015. 
#   -> 2817 programs registered as of 26.11.2015.
#
#   -> 2903 programs registered as of 01.04.2017.
#   -> 2976 programs registered as of 09.08.2017.
#   -> 3231 programs registered as of 23.10.2017.
#   -> 3264 programs registered as of 01.12.2017.
#
#   -> 3314 programs registered as of 04.01.2018.
# =========================================================================== #

</pre>


## Contact information

For any specific suggestions or questions, please do feel free to
drop me an email at:

   shevegen@gmail.com

You can include specific suggestions what to change and improve. I'll
integrate them into the todo-list if they are within the scope of
the project, docu-related improvements or otherwise may make life
easier working with this project.
